/*/////////////////////////////////////////////////////////////////////////////
//
//     spiral_rfft_double.c
//
//     This library was generated by Spiral 6.0, developed at Carnegie Mellon
//     University, http://www.spiral.net. This code is distributed under the
//     GNU general purpose software license version 2.0.
//
//     Commercial licenses and support are available through SpiralGen, Inc.
//     fft@spiralgen.com
//
*/

#include "spiral_fft.h"
#include "spiral_private.h"

/*************************************************
 * Main dispatch  
 *************************************************/

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double)(int n, const double *pSrc, double *pDst ) {
    switch(n) {
        case 2: return spiral_rfftfwd_double_2(pSrc, pDst );
        case 4: return spiral_rfftfwd_double_4(pSrc, pDst );
        case 8: return spiral_rfftfwd_double_8(pSrc, pDst );
        case 16: return spiral_rfftfwd_double_16(pSrc, pDst );
        case 32: return spiral_rfftfwd_double_32(pSrc, pDst );
        case 64: return spiral_rfftfwd_double_64(pSrc, pDst );
        case 128: return spiral_rfftfwd_double_128(pSrc, pDst );
        case 256: return spiral_rfftfwd_double_256(pSrc, pDst );
        case 512: return spiral_rfftfwd_double_512(pSrc, pDst );
        case 1024: return spiral_rfftfwd_double_1024(pSrc, pDst );
        case 2048: return spiral_rfftfwd_double_2048(pSrc, pDst );
        case 4096: return spiral_rfftfwd_double_4096(pSrc, pDst );
        case 8192: return spiral_rfftfwd_double_8192(pSrc, pDst );
        default: return SPIRAL_SIZE_NOT_SUPPORTED;
    }
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double)(int n, const double *pSrc, double *pDst ) {
    switch(n) {
        case 2: return spiral_rfftinv_double_2(pSrc, pDst );
        case 4: return spiral_rfftinv_double_4(pSrc, pDst );
        case 8: return spiral_rfftinv_double_8(pSrc, pDst );
        case 16: return spiral_rfftinv_double_16(pSrc, pDst );
        case 32: return spiral_rfftinv_double_32(pSrc, pDst );
        case 64: return spiral_rfftinv_double_64(pSrc, pDst );
        case 128: return spiral_rfftinv_double_128(pSrc, pDst );
        case 256: return spiral_rfftinv_double_256(pSrc, pDst );
        case 512: return spiral_rfftinv_double_512(pSrc, pDst );
        case 1024: return spiral_rfftinv_double_1024(pSrc, pDst );
        case 2048: return spiral_rfftinv_double_2048(pSrc, pDst );
        case 4096: return spiral_rfftinv_double_4096(pSrc, pDst );
        case 8192: return spiral_rfftinv_double_8192(pSrc, pDst );
        default: return SPIRAL_SIZE_NOT_SUPPORTED;
    }
}


/*************************************************
 * Individual transform sizes  
 *************************************************/

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_2)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {double s, s2, s3, s4;
    s = *(src);
    s2 = *((src + 1));
    s3 = (s + s2);
    *(dst) = s3;
    s4 = (s - s2);
    *((dst + 1)) = s4;
    }
    
    return SPIRAL_OK;
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_4_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d s, s2, s3, s4, t;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_loadu_pd(((const double  *) (src + 2)));
    t = _mm_add_pd(s, s2);
    s3 = _mm_add_pd(v_neg03(v_hi2(t, t)), v_lo2(t, t));
    _mm_storeu_pd(((double  *) dst), s3);
    s4 = v_neg23(_mm_sub_pd(s, s2));
    _mm_storeu_pd(((double  *) (dst + 2)), s4);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_4)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_4_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d s, s2, s3, s4, t;
    __m128d  *a, *a2;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = *((a + 1));
    t = _mm_add_pd(s, s2);
    a2 = ((__m128d  *) dst);
    s3 = _mm_add_pd(v_neg03(v_hi2(t, t)), v_lo2(t, t));
    *(a2) = s3;
    s4 = v_neg23(_mm_sub_pd(s, s2));
    *((a2 + 1)) = s4;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_8)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {double a, a2, s, s01, s11, s2, s21, s3, s31, s4, s41, s5, s51, s6, s61, s7, s71, s8, s81, s9, t, t2
            , t3, t4, t5, t6, t7, t8;
    s = *(src);
    s2 = *((src + 4));
    t = (s + s2);
    t2 = (s - s2);
    s3 = *((src + 2));
    s4 = *((src + 6));
    t3 = (s3 + s4);
    t4 = (s3 - s4);
    s5 = *((src + 1));
    s6 = *((src + 5));
    t5 = (s5 + s6);
    s7 = *((src + 3));
    s8 = *((src + 7));
    t6 = (s7 + s8);
    t7 = (t + t3);
    t8 = (t5 + t6);
    s9 = (t7 + t8);
    *(dst) = s9;
    s01 = (t7 - t8);
    *((dst + 1)) = s01;
    s11 = (t - t3);
    *((dst + 4)) = s11;
    s21 = (t6 - t5);
    *((dst + 5)) = s21;
    a = (0.70710678118654757*(s5 - s6));
    a2 = (0.70710678118654757*(s7 - s8));
    s31 = (a - a2);
    s41 = (a + a2);
    s51 = (t2 + s31);
    *((dst + 2)) = s51;
    s61 = -((t4 + s41));
    *((dst + 3)) = s61;
    s71 = (t2 - s31);
    *((dst + 6)) = s71;
    s81 = (t4 - s41);
    *((dst + 7)) = s81;
    }
    
    return SPIRAL_OK;
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_16_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a2, s, s01, s02, s03, s11, s12, s2, s21, s22, s3, s31, s32, s4, s41, s42, s5, s51, s52, s6, s61
            , s62, s7, s71, s72, s8, s81, s82, s9, s91, s92, t, t01, t11, t2, t21, t3, t31, t4, t41, t5, t51, t6
            , t7, t8, t9;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_loadu_pd(((const double  *) (src + 8)));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = _mm_loadu_pd(((const double  *) (src + 4)));
    s4 = _mm_loadu_pd(((const double  *) (src + 12)));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = _mm_loadu_pd(((const double  *) (src + 2)));
    s6 = _mm_loadu_pd(((const double  *) (src + 10)));
    t5 = _mm_add_pd(s5, s6);
    s7 = _mm_loadu_pd(((const double  *) (src + 6)));
    s8 = _mm_loadu_pd(((const double  *) (src + 14)));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    t11 = _mm_add_pd(t7, t9);
    s9 = _mm_add_pd(v_neg03(v_hi2(t11, t11)), v_lo2(t11, t11));
    _mm_storeu_pd(((double  *) dst), s9);
    s01 = v_neg23(_mm_sub_pd(t7, t9));
    _mm_storeu_pd(((double  *) (dst + 8)), s01);
    s11 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t01));
    s21 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t01));
    s31 = v_lo2(s11, s21);
    s41 = v_hi2(s11, s21);
    s51 = _mm_add_pd(s31, s41);
    _mm_storeu_pd(((double  *) (dst + 4)), s51);
    s61 = v_neg23(_mm_sub_pd(s31, s41));
    _mm_storeu_pd(((double  *) (dst + 12)), s61);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a2 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s71 = _mm_add_pd(a, a2);
    s81 = _mm_sub_pd(a2, a);
    t21 = _mm_add_pd(t2, s71);
    t31 = _mm_sub_pd(s81, t4);
    t41 = _mm_sub_pd(t2, s71);
    t51 = _mm_add_pd(t4, s81);
    s91 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t21), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t31));
    s02 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t21), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t31));
    s12 = v_lo2(s91, s02);
    s22 = v_hi2(s91, s02);
    s32 = _mm_add_pd(s12, s22);
    _mm_storeu_pd(((double  *) (dst + 2)), s32);
    s42 = v_neg23(_mm_sub_pd(s12, s22));
    _mm_storeu_pd(((double  *) (dst + 14)), s42);
    s52 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t41), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t51));
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t41), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t51));
    s72 = v_lo2(s52, s62);
    s82 = v_hi2(s52, s62);
    s92 = _mm_add_pd(s72, s82);
    _mm_storeu_pd(((double  *) (dst + 10)), s92);
    s03 = v_neg23(_mm_sub_pd(s72, s82));
    _mm_storeu_pd(((double  *) (dst + 6)), s03);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_16)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_16_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a3, a4, s, s01, s02, s03, s11, s12, s2, s21, s22, s3, s31, s32, s4, s41, s42, s5, s51, s52, s6, s61
            , s62, s7, s71, s72, s8, s81, s82, s9, s91, s92, t, t01, t11, t2, t21, t3, t31, t4, t41, t5, t51, t6
            , t7, t8, t9;
    __m128d  *a, *a2;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = *((a + 4));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = *((a + 2));
    s4 = *((a + 6));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = *((a + 1));
    s6 = *((a + 5));
    t5 = _mm_add_pd(s5, s6);
    s7 = *((a + 3));
    s8 = *((a + 7));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    t11 = _mm_add_pd(t7, t9);
    a2 = ((__m128d  *) dst);
    s9 = _mm_add_pd(v_neg03(v_hi2(t11, t11)), v_lo2(t11, t11));
    *(a2) = s9;
    s01 = v_neg23(_mm_sub_pd(t7, t9));
    *((a2 + 4)) = s01;
    s11 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t01));
    s21 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t01));
    s31 = v_lo2(s11, s21);
    s41 = v_hi2(s11, s21);
    s51 = _mm_add_pd(s31, s41);
    *((a2 + 2)) = s51;
    s61 = v_neg23(_mm_sub_pd(s31, s41));
    *((a2 + 6)) = s61;
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s71 = _mm_add_pd(a3, a4);
    s81 = _mm_sub_pd(a4, a3);
    t21 = _mm_add_pd(t2, s71);
    t31 = _mm_sub_pd(s81, t4);
    t41 = _mm_sub_pd(t2, s71);
    t51 = _mm_add_pd(t4, s81);
    s91 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t21), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t31));
    s02 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t21), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t31));
    s12 = v_lo2(s91, s02);
    s22 = v_hi2(s91, s02);
    s32 = _mm_add_pd(s12, s22);
    *((a2 + 1)) = s32;
    s42 = v_neg23(_mm_sub_pd(s12, s22));
    *((a2 + 7)) = s42;
    s52 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t41), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t51));
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t41), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t51));
    s72 = v_lo2(s52, s62);
    s82 = v_hi2(s52, s62);
    s92 = _mm_add_pd(s72, s82);
    *((a2 + 5)) = s92;
    s03 = v_neg23(_mm_sub_pd(s72, s82));
    *((a2 + 3)) = s03;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_32_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a2, a3, a4, a5, a6, s, s01, s02, s03, s04, s05, s06, s07, s11, s12, s13, s14, s15, s16, s2, s21
            , s22, s23, s24, s25, s26, s3, s31, s32, s33, s34, s35, s36, s4, s41, s42, s43, s44, s45, s46, s5, s51, s52
            , s53, s54, s55, s56, s6, s61, s62, s63, s64, s65, s66, s7, s71, s72, s73, s74, s75, s76, s8, s81, s82, s83
            , s84, s85, s86, s9, s91, s92, s93, s94, s95, s96, t, t01, t02, t03, t04, t11, t12, t13, t14, t2, t21, t22
            , t23, t24, t3, t31, t32, t33, t34, t4, t41, t42, t43, t5, t51, t52, t53, t6, t61, t62, t63, t7, t71, t72
            , t73, t8, t81, t82, t83, t9, t91, t92, t93;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_loadu_pd(((const double  *) (src + 16)));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = _mm_loadu_pd(((const double  *) (src + 8)));
    s4 = _mm_loadu_pd(((const double  *) (src + 24)));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = _mm_loadu_pd(((const double  *) (src + 4)));
    s6 = _mm_loadu_pd(((const double  *) (src + 20)));
    t5 = _mm_add_pd(s5, s6);
    s7 = _mm_loadu_pd(((const double  *) (src + 12)));
    s8 = _mm_loadu_pd(((const double  *) (src + 28)));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a2 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s9 = _mm_add_pd(a, a2);
    s01 = _mm_sub_pd(a2, a);
    t11 = _mm_add_pd(t2, s9);
    t21 = _mm_sub_pd(s01, t4);
    t31 = _mm_sub_pd(t2, s9);
    t41 = _mm_add_pd(t4, s01);
    s11 = _mm_loadu_pd(((const double  *) (src + 2)));
    s21 = _mm_loadu_pd(((const double  *) (src + 18)));
    t51 = _mm_add_pd(s11, s21);
    t61 = _mm_sub_pd(s11, s21);
    s31 = _mm_loadu_pd(((const double  *) (src + 10)));
    s41 = _mm_loadu_pd(((const double  *) (src + 26)));
    t71 = _mm_add_pd(s31, s41);
    t81 = _mm_sub_pd(s31, s41);
    s51 = _mm_loadu_pd(((const double  *) (src + 6)));
    s61 = _mm_loadu_pd(((const double  *) (src + 22)));
    t91 = _mm_add_pd(s51, s61);
    s71 = _mm_loadu_pd(((const double  *) (src + 14)));
    s81 = _mm_loadu_pd(((const double  *) (src + 30)));
    t02 = _mm_add_pd(s71, s81);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_add_pd(t91, t02);
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
    a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
    s91 = _mm_add_pd(a3, a4);
    s02 = _mm_sub_pd(a4, a3);
    t32 = _mm_add_pd(t61, s91);
    t42 = _mm_sub_pd(s02, t81);
    t52 = _mm_sub_pd(t61, s91);
    t62 = _mm_add_pd(t81, s02);
    t72 = _mm_add_pd(t7, t9);
    t82 = _mm_sub_pd(t7, t9);
    t92 = _mm_add_pd(t12, t22);
    t03 = _mm_sub_pd(t12, t22);
    t13 = _mm_add_pd(t72, t92);
    s12 = _mm_add_pd(v_neg03(v_hi2(t13, t13)), v_lo2(t13, t13));
    _mm_storeu_pd(((double  *) dst), s12);
    s22 = v_neg23(_mm_sub_pd(t72, t92));
    _mm_storeu_pd(((double  *) (dst + 16)), s22);
    s32 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t82), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t03));
    s42 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t82), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t03));
    s52 = v_lo2(s32, s42);
    s62 = v_hi2(s32, s42);
    s72 = _mm_add_pd(s52, s62);
    _mm_storeu_pd(((double  *) (dst + 8)), s72);
    s82 = v_neg23(_mm_sub_pd(s52, s62));
    _mm_storeu_pd(((double  *) (dst + 24)), s82);
    s92 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t32), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
    s03 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t32), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
    t23 = _mm_add_pd(t11, s92);
    t33 = _mm_add_pd(t21, s03);
    t43 = _mm_sub_pd(t11, s92);
    t53 = _mm_sub_pd(t21, s03);
    s13 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t23), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t33));
    s23 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t23), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t33));
    s33 = v_lo2(s13, s23);
    s43 = v_hi2(s13, s23);
    s53 = _mm_add_pd(s33, s43);
    _mm_storeu_pd(((double  *) (dst + 2)), s53);
    s63 = v_neg23(_mm_sub_pd(s33, s43));
    _mm_storeu_pd(((double  *) (dst + 30)), s63);
    s73 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t43), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t53));
    s83 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t43), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t53));
    s93 = v_lo2(s73, s83);
    s04 = v_hi2(s73, s83);
    s14 = _mm_add_pd(s93, s04);
    _mm_storeu_pd(((double  *) (dst + 18)), s14);
    s24 = v_neg23(_mm_sub_pd(s93, s04));
    _mm_storeu_pd(((double  *) (dst + 14)), s24);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t51, t71));
    a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t91, t02));
    s34 = _mm_add_pd(a5, a6);
    s44 = _mm_sub_pd(a6, a5);
    t63 = _mm_add_pd(t8, s34);
    t73 = _mm_sub_pd(s44, t01);
    t83 = _mm_sub_pd(t8, s34);
    t93 = _mm_add_pd(t01, s44);
    s54 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t63), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t73));
    s64 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t63), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t73));
    s74 = v_lo2(s54, s64);
    s84 = v_hi2(s54, s64);
    s94 = _mm_add_pd(s74, s84);
    _mm_storeu_pd(((double  *) (dst + 4)), s94);
    s05 = v_neg23(_mm_sub_pd(s74, s84));
    _mm_storeu_pd(((double  *) (dst + 28)), s05);
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t83), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t93));
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t83), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t93));
    s35 = v_lo2(s15, s25);
    s45 = v_hi2(s15, s25);
    s55 = _mm_add_pd(s35, s45);
    _mm_storeu_pd(((double  *) (dst + 20)), s55);
    s65 = v_neg23(_mm_sub_pd(s35, s45));
    _mm_storeu_pd(((double  *) (dst + 12)), s65);
    s75 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t52), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t62));
    s85 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t52), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t62));
    t04 = _mm_add_pd(t31, s75);
    t14 = _mm_add_pd(t41, s85);
    t24 = _mm_sub_pd(t31, s75);
    t34 = _mm_sub_pd(t41, s85);
    s95 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t04), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t14));
    s06 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t04), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t14));
    s16 = v_lo2(s95, s06);
    s26 = v_hi2(s95, s06);
    s36 = _mm_add_pd(s16, s26);
    _mm_storeu_pd(((double  *) (dst + 6)), s36);
    s46 = v_neg23(_mm_sub_pd(s16, s26));
    _mm_storeu_pd(((double  *) (dst + 26)), s46);
    s56 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t24), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t34));
    s66 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t24), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t34));
    s76 = v_lo2(s56, s66);
    s86 = v_hi2(s56, s66);
    s96 = _mm_add_pd(s76, s86);
    _mm_storeu_pd(((double  *) (dst + 22)), s96);
    s07 = v_neg23(_mm_sub_pd(s76, s86));
    _mm_storeu_pd(((double  *) (dst + 10)), s07);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_32)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_32_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a2, a3, a4, a5, a7, a8, s, s01, s02, s03, s04, s05, s06, s07, s11, s12, s13, s14, s15, s16, s2, s21
            , s22, s23, s24, s25, s26, s3, s31, s32, s33, s34, s35, s36, s4, s41, s42, s43, s44, s45, s46, s5, s51, s52
            , s53, s54, s55, s56, s6, s61, s62, s63, s64, s65, s66, s7, s71, s72, s73, s74, s75, s76, s8, s81, s82, s83
            , s84, s85, s86, s9, s91, s92, s93, s94, s95, s96, t, t01, t02, t03, t04, t11, t12, t13, t14, t2, t21, t22
            , t23, t24, t3, t31, t32, t33, t34, t4, t41, t42, t43, t5, t51, t52, t53, t6, t61, t62, t63, t7, t71, t72
            , t73, t8, t81, t82, t83, t9, t91, t92, t93;
    __m128d  *a, *a6;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = *((a + 8));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = *((a + 4));
    s4 = *((a + 12));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = *((a + 2));
    s6 = *((a + 10));
    t5 = _mm_add_pd(s5, s6);
    s7 = *((a + 6));
    s8 = *((a + 14));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s9 = _mm_add_pd(a2, a3);
    s01 = _mm_sub_pd(a3, a2);
    t11 = _mm_add_pd(t2, s9);
    t21 = _mm_sub_pd(s01, t4);
    t31 = _mm_sub_pd(t2, s9);
    t41 = _mm_add_pd(t4, s01);
    s11 = *((a + 1));
    s21 = *((a + 9));
    t51 = _mm_add_pd(s11, s21);
    t61 = _mm_sub_pd(s11, s21);
    s31 = *((a + 5));
    s41 = *((a + 13));
    t71 = _mm_add_pd(s31, s41);
    t81 = _mm_sub_pd(s31, s41);
    s51 = *((a + 3));
    s61 = *((a + 11));
    t91 = _mm_add_pd(s51, s61);
    s71 = *((a + 7));
    s81 = *((a + 15));
    t02 = _mm_add_pd(s71, s81);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_add_pd(t91, t02);
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
    a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
    s91 = _mm_add_pd(a4, a5);
    s02 = _mm_sub_pd(a5, a4);
    t32 = _mm_add_pd(t61, s91);
    t42 = _mm_sub_pd(s02, t81);
    t52 = _mm_sub_pd(t61, s91);
    t62 = _mm_add_pd(t81, s02);
    t72 = _mm_add_pd(t7, t9);
    t82 = _mm_sub_pd(t7, t9);
    t92 = _mm_add_pd(t12, t22);
    t03 = _mm_sub_pd(t12, t22);
    t13 = _mm_add_pd(t72, t92);
    a6 = ((__m128d  *) dst);
    s12 = _mm_add_pd(v_neg03(v_hi2(t13, t13)), v_lo2(t13, t13));
    *(a6) = s12;
    s22 = v_neg23(_mm_sub_pd(t72, t92));
    *((a6 + 8)) = s22;
    s32 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t82), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t03));
    s42 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t82), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t03));
    s52 = v_lo2(s32, s42);
    s62 = v_hi2(s32, s42);
    s72 = _mm_add_pd(s52, s62);
    *((a6 + 4)) = s72;
    s82 = v_neg23(_mm_sub_pd(s52, s62));
    *((a6 + 12)) = s82;
    s92 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t32), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
    s03 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t32), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
    t23 = _mm_add_pd(t11, s92);
    t33 = _mm_add_pd(t21, s03);
    t43 = _mm_sub_pd(t11, s92);
    t53 = _mm_sub_pd(t21, s03);
    s13 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t23), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t33));
    s23 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t23), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t33));
    s33 = v_lo2(s13, s23);
    s43 = v_hi2(s13, s23);
    s53 = _mm_add_pd(s33, s43);
    *((a6 + 1)) = s53;
    s63 = v_neg23(_mm_sub_pd(s33, s43));
    *((a6 + 15)) = s63;
    s73 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t43), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t53));
    s83 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t43), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t53));
    s93 = v_lo2(s73, s83);
    s04 = v_hi2(s73, s83);
    s14 = _mm_add_pd(s93, s04);
    *((a6 + 9)) = s14;
    s24 = v_neg23(_mm_sub_pd(s93, s04));
    *((a6 + 7)) = s24;
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t51, t71));
    a8 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t91, t02));
    s34 = _mm_add_pd(a7, a8);
    s44 = _mm_sub_pd(a8, a7);
    t63 = _mm_add_pd(t8, s34);
    t73 = _mm_sub_pd(s44, t01);
    t83 = _mm_sub_pd(t8, s34);
    t93 = _mm_add_pd(t01, s44);
    s54 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t63), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t73));
    s64 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t63), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t73));
    s74 = v_lo2(s54, s64);
    s84 = v_hi2(s54, s64);
    s94 = _mm_add_pd(s74, s84);
    *((a6 + 2)) = s94;
    s05 = v_neg23(_mm_sub_pd(s74, s84));
    *((a6 + 14)) = s05;
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t83), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t93));
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t83), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t93));
    s35 = v_lo2(s15, s25);
    s45 = v_hi2(s15, s25);
    s55 = _mm_add_pd(s35, s45);
    *((a6 + 10)) = s55;
    s65 = v_neg23(_mm_sub_pd(s35, s45));
    *((a6 + 6)) = s65;
    s75 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t52), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t62));
    s85 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t52), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t62));
    t04 = _mm_add_pd(t31, s75);
    t14 = _mm_add_pd(t41, s85);
    t24 = _mm_sub_pd(t31, s75);
    t34 = _mm_sub_pd(t41, s85);
    s95 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t04), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t14));
    s06 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t04), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t14));
    s16 = v_lo2(s95, s06);
    s26 = v_hi2(s95, s06);
    s36 = _mm_add_pd(s16, s26);
    *((a6 + 3)) = s36;
    s46 = v_neg23(_mm_sub_pd(s16, s26));
    *((a6 + 13)) = s46;
    s56 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t24), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t34));
    s66 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t24), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t34));
    s76 = v_lo2(s56, s66);
    s86 = v_hi2(s56, s66);
    s96 = _mm_add_pd(s76, s86);
    *((a6 + 11)) = s96;
    s07 = v_neg23(_mm_sub_pd(s76, s86));
    *((a6 + 5)) = s07;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_64_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a01, a11, a2, a21, a3, a4, a5, a6, a7, a8, a9, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s2
            , s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s3, s31, s32, s33, s34, s35, s36
            , s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d
            , s4e, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s6, s61, s62, s63, s64, s65
            , s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c
            , s7d, s7e, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s9, s91, s92, s93, s94
            , s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b
            , t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a
            , t2b, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t4, t41, t42, t43, t44, t45, t46, t47, t48
            , t49, t4a, t4b, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t6, t61, t62, t63, t64, t65, t66
            , t67, t68, t69, t6a, t6b, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_loadu_pd(((const double  *) (src + 32)));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = _mm_loadu_pd(((const double  *) (src + 16)));
    s4 = _mm_loadu_pd(((const double  *) (src + 48)));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = _mm_loadu_pd(((const double  *) (src + 8)));
    s6 = _mm_loadu_pd(((const double  *) (src + 40)));
    t5 = _mm_add_pd(s5, s6);
    s7 = _mm_loadu_pd(((const double  *) (src + 24)));
    s8 = _mm_loadu_pd(((const double  *) (src + 56)));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a2 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s9 = _mm_add_pd(a, a2);
    s01 = _mm_sub_pd(a2, a);
    t11 = _mm_add_pd(t2, s9);
    t21 = _mm_sub_pd(s01, t4);
    t31 = _mm_sub_pd(t2, s9);
    t41 = _mm_add_pd(t4, s01);
    s11 = _mm_loadu_pd(((const double  *) (src + 2)));
    s21 = _mm_loadu_pd(((const double  *) (src + 34)));
    t51 = _mm_add_pd(s11, s21);
    t61 = _mm_sub_pd(s11, s21);
    s31 = _mm_loadu_pd(((const double  *) (src + 18)));
    s41 = _mm_loadu_pd(((const double  *) (src + 50)));
    t71 = _mm_add_pd(s31, s41);
    t81 = _mm_sub_pd(s31, s41);
    s51 = _mm_loadu_pd(((const double  *) (src + 10)));
    s61 = _mm_loadu_pd(((const double  *) (src + 42)));
    t91 = _mm_add_pd(s51, s61);
    s71 = _mm_loadu_pd(((const double  *) (src + 26)));
    s81 = _mm_loadu_pd(((const double  *) (src + 58)));
    t02 = _mm_add_pd(s71, s81);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_sub_pd(t51, t71);
    t32 = _mm_add_pd(t91, t02);
    t42 = _mm_sub_pd(t91, t02);
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
    a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
    s91 = _mm_add_pd(a3, a4);
    s02 = _mm_sub_pd(a4, a3);
    t52 = _mm_add_pd(t61, s91);
    t62 = _mm_sub_pd(s02, t81);
    t72 = _mm_sub_pd(t61, s91);
    t82 = _mm_add_pd(t81, s02);
    s12 = _mm_loadu_pd(((const double  *) (src + 4)));
    s22 = _mm_loadu_pd(((const double  *) (src + 36)));
    t92 = _mm_add_pd(s12, s22);
    t03 = _mm_sub_pd(s12, s22);
    s32 = _mm_loadu_pd(((const double  *) (src + 20)));
    s42 = _mm_loadu_pd(((const double  *) (src + 52)));
    t13 = _mm_add_pd(s32, s42);
    t23 = _mm_sub_pd(s32, s42);
    s52 = _mm_loadu_pd(((const double  *) (src + 12)));
    s62 = _mm_loadu_pd(((const double  *) (src + 44)));
    t33 = _mm_add_pd(s52, s62);
    s72 = _mm_loadu_pd(((const double  *) (src + 28)));
    s82 = _mm_loadu_pd(((const double  *) (src + 60)));
    t43 = _mm_add_pd(s72, s82);
    t53 = _mm_add_pd(t92, t13);
    t63 = _mm_add_pd(t33, t43);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
    a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
    s92 = _mm_add_pd(a5, a6);
    s03 = _mm_sub_pd(a6, a5);
    t73 = _mm_add_pd(t03, s92);
    t83 = _mm_sub_pd(s03, t23);
    t93 = _mm_sub_pd(t03, s92);
    t04 = _mm_add_pd(t23, s03);
    s13 = _mm_loadu_pd(((const double  *) (src + 6)));
    s23 = _mm_loadu_pd(((const double  *) (src + 38)));
    t14 = _mm_add_pd(s13, s23);
    t24 = _mm_sub_pd(s13, s23);
    s33 = _mm_loadu_pd(((const double  *) (src + 22)));
    s43 = _mm_loadu_pd(((const double  *) (src + 54)));
    t34 = _mm_add_pd(s33, s43);
    t44 = _mm_sub_pd(s33, s43);
    s53 = _mm_loadu_pd(((const double  *) (src + 14)));
    s63 = _mm_loadu_pd(((const double  *) (src + 46)));
    t54 = _mm_add_pd(s53, s63);
    s73 = _mm_loadu_pd(((const double  *) (src + 30)));
    s83 = _mm_loadu_pd(((const double  *) (src + 62)));
    t64 = _mm_add_pd(s73, s83);
    t74 = _mm_add_pd(t14, t34);
    t84 = _mm_sub_pd(t14, t34);
    t94 = _mm_add_pd(t54, t64);
    t05 = _mm_sub_pd(t54, t64);
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
    a8 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
    s93 = _mm_add_pd(a7, a8);
    s04 = _mm_sub_pd(a8, a7);
    t15 = _mm_add_pd(t24, s93);
    t25 = _mm_sub_pd(s04, t44);
    t35 = _mm_sub_pd(t24, s93);
    t45 = _mm_add_pd(t44, s04);
    t55 = _mm_add_pd(t7, t9);
    t65 = _mm_sub_pd(t7, t9);
    t75 = _mm_add_pd(t53, t63);
    t85 = _mm_sub_pd(t53, t63);
    t95 = _mm_add_pd(t12, t32);
    t06 = _mm_add_pd(t74, t94);
    t16 = _mm_add_pd(t55, t75);
    t26 = _mm_sub_pd(t55, t75);
    t36 = _mm_add_pd(t95, t06);
    t46 = _mm_sub_pd(t95, t06);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
    a01 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
    s14 = _mm_add_pd(a9, a01);
    s24 = _mm_sub_pd(a01, a9);
    t56 = _mm_add_pd(t65, s14);
    t66 = _mm_sub_pd(s24, t85);
    t76 = _mm_sub_pd(t65, s14);
    t86 = _mm_add_pd(t85, s24);
    s34 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
    s44 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
    s54 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
    s64 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
    s74 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
    s84 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
    t96 = _mm_add_pd(t11, s54);
    t07 = _mm_add_pd(t21, s64);
    t17 = _mm_sub_pd(t11, s54);
    t27 = _mm_sub_pd(t21, s64);
    t37 = _mm_add_pd(s34, s74);
    t47 = _mm_add_pd(s44, s84);
    t57 = _mm_sub_pd(s34, s74);
    t67 = _mm_sub_pd(s44, s84);
    t77 = _mm_add_pd(t96, t37);
    t87 = _mm_add_pd(t07, t47);
    t97 = _mm_sub_pd(t96, t37);
    t08 = _mm_sub_pd(t07, t47);
    t18 = _mm_add_pd(t17, t67);
    t28 = _mm_sub_pd(t27, t57);
    t38 = _mm_sub_pd(t17, t67);
    t48 = _mm_add_pd(t27, t57);
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
    a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
    s15 = _mm_add_pd(a11, a21);
    s25 = _mm_sub_pd(a21, a11);
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
    s45 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
    t58 = _mm_add_pd(t8, s15);
    t68 = _mm_sub_pd(s25, t01);
    t78 = _mm_sub_pd(t8, s15);
    t88 = _mm_add_pd(t01, s25);
    t98 = _mm_add_pd(s94, s35);
    t09 = _mm_add_pd(s05, s45);
    t19 = _mm_sub_pd(s94, s35);
    t29 = _mm_sub_pd(s05, s45);
    t39 = _mm_add_pd(t58, t98);
    t49 = _mm_add_pd(t68, t09);
    t59 = _mm_sub_pd(t58, t98);
    t69 = _mm_sub_pd(t68, t09);
    t79 = _mm_add_pd(t78, t29);
    t89 = _mm_add_pd(t88, t19);
    t99 = _mm_sub_pd(t78, t29);
    t0a = _mm_sub_pd(t19, t88);
    s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
    s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
    s75 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
    s85 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
    s95 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
    s06 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
    t1a = _mm_add_pd(t31, s75);
    t2a = _mm_add_pd(t41, s85);
    t3a = _mm_sub_pd(t31, s75);
    t4a = _mm_sub_pd(t41, s85);
    t5a = _mm_add_pd(s55, s95);
    t6a = _mm_add_pd(s65, s06);
    t7a = _mm_sub_pd(s55, s95);
    t8a = _mm_sub_pd(s65, s06);
    t9a = _mm_add_pd(t1a, t5a);
    t0b = _mm_add_pd(t2a, t6a);
    t1b = _mm_sub_pd(t1a, t5a);
    t2b = _mm_sub_pd(t2a, t6a);
    t3b = _mm_add_pd(t3a, t8a);
    t4b = _mm_sub_pd(t4a, t7a);
    t5b = _mm_sub_pd(t3a, t8a);
    t6b = _mm_add_pd(t4a, t7a);
    t7b = _mm_add_pd(t16, t36);
    s16 = _mm_add_pd(v_neg03(v_hi2(t7b, t7b)), v_lo2(t7b, t7b));
    _mm_storeu_pd(((double  *) dst), s16);
    s26 = v_neg23(_mm_sub_pd(t16, t36));
    _mm_storeu_pd(((double  *) (dst + 32)), s26);
    s36 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t77), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t87));
    s46 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t77), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t87));
    s56 = v_lo2(s36, s46);
    s66 = v_hi2(s36, s46);
    s76 = _mm_add_pd(s56, s66);
    _mm_storeu_pd(((double  *) (dst + 2)), s76);
    s86 = v_neg23(_mm_sub_pd(s56, s66));
    _mm_storeu_pd(((double  *) (dst + 62)), s86);
    s96 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t39), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t49));
    s07 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t39), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t49));
    s17 = v_lo2(s96, s07);
    s27 = v_hi2(s96, s07);
    s37 = _mm_add_pd(s17, s27);
    _mm_storeu_pd(((double  *) (dst + 4)), s37);
    s47 = v_neg23(_mm_sub_pd(s17, s27));
    _mm_storeu_pd(((double  *) (dst + 60)), s47);
    s57 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t9a), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t0b));
    s67 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t9a), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t0b));
    s77 = v_lo2(s57, s67);
    s87 = v_hi2(s57, s67);
    s97 = _mm_add_pd(s77, s87);
    _mm_storeu_pd(((double  *) (dst + 6)), s97);
    s08 = v_neg23(_mm_sub_pd(s77, s87));
    _mm_storeu_pd(((double  *) (dst + 58)), s08);
    s18 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t56), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t66));
    s28 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t56), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t66));
    s38 = v_lo2(s18, s28);
    s48 = v_hi2(s18, s28);
    s58 = _mm_add_pd(s38, s48);
    _mm_storeu_pd(((double  *) (dst + 8)), s58);
    s68 = v_neg23(_mm_sub_pd(s38, s48));
    _mm_storeu_pd(((double  *) (dst + 56)), s68);
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t5b), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t6b));
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t5b), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t6b));
    s98 = v_lo2(s78, s88);
    s09 = v_hi2(s78, s88);
    s19 = _mm_add_pd(s98, s09);
    _mm_storeu_pd(((double  *) (dst + 10)), s19);
    s29 = v_neg23(_mm_sub_pd(s98, s09));
    _mm_storeu_pd(((double  *) (dst + 54)), s29);
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t99), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t0a));
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t99), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t0a));
    s59 = v_lo2(s39, s49);
    s69 = v_hi2(s39, s49);
    s79 = _mm_add_pd(s59, s69);
    _mm_storeu_pd(((double  *) (dst + 12)), s79);
    s89 = v_neg23(_mm_sub_pd(s59, s69));
    _mm_storeu_pd(((double  *) (dst + 52)), s89);
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t38), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t48));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t38), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t48));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    _mm_storeu_pd(((double  *) (dst + 14)), s3a);
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    _mm_storeu_pd(((double  *) (dst + 50)), s4a);
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t26), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t46));
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t26), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t46));
    s7a = v_lo2(s5a, s6a);
    s8a = v_hi2(s5a, s6a);
    s9a = _mm_add_pd(s7a, s8a);
    _mm_storeu_pd(((double  *) (dst + 16)), s9a);
    s0b = v_neg23(_mm_sub_pd(s7a, s8a));
    _mm_storeu_pd(((double  *) (dst + 48)), s0b);
    s1b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t18), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t28));
    s2b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t18), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t28));
    s3b = v_lo2(s1b, s2b);
    s4b = v_hi2(s1b, s2b);
    s5b = _mm_add_pd(s3b, s4b);
    _mm_storeu_pd(((double  *) (dst + 18)), s5b);
    s6b = v_neg23(_mm_sub_pd(s3b, s4b));
    _mm_storeu_pd(((double  *) (dst + 46)), s6b);
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t79), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t89));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t79), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t89));
    s9b = v_lo2(s7b, s8b);
    s0c = v_hi2(s7b, s8b);
    s1c = _mm_add_pd(s9b, s0c);
    _mm_storeu_pd(((double  *) (dst + 20)), s1c);
    s2c = v_neg23(_mm_sub_pd(s9b, s0c));
    _mm_storeu_pd(((double  *) (dst + 44)), s2c);
    s3c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t3b), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t4b));
    s4c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t3b), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t4b));
    s5c = v_lo2(s3c, s4c);
    s6c = v_hi2(s3c, s4c);
    s7c = _mm_add_pd(s5c, s6c);
    _mm_storeu_pd(((double  *) (dst + 22)), s7c);
    s8c = v_neg23(_mm_sub_pd(s5c, s6c));
    _mm_storeu_pd(((double  *) (dst + 42)), s8c);
    s9c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t76), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t86));
    s0d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t76), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t86));
    s1d = v_lo2(s9c, s0d);
    s2d = v_hi2(s9c, s0d);
    s3d = _mm_add_pd(s1d, s2d);
    _mm_storeu_pd(((double  *) (dst + 24)), s3d);
    s4d = v_neg23(_mm_sub_pd(s1d, s2d));
    _mm_storeu_pd(((double  *) (dst + 40)), s4d);
    s5d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t1b), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t2b));
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t1b), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t2b));
    s7d = v_lo2(s5d, s6d);
    s8d = v_hi2(s5d, s6d);
    s9d = _mm_add_pd(s7d, s8d);
    _mm_storeu_pd(((double  *) (dst + 26)), s9d);
    s0e = v_neg23(_mm_sub_pd(s7d, s8d));
    _mm_storeu_pd(((double  *) (dst + 38)), s0e);
    s1e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t59), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t69));
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t59), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t69));
    s3e = v_lo2(s1e, s2e);
    s4e = v_hi2(s1e, s2e);
    s5e = _mm_add_pd(s3e, s4e);
    _mm_storeu_pd(((double  *) (dst + 28)), s5e);
    s6e = v_neg23(_mm_sub_pd(s3e, s4e));
    _mm_storeu_pd(((double  *) (dst + 36)), s6e);
    s7e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t97), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t08));
    s8e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t97), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t08));
    s9e = v_lo2(s7e, s8e);
    s0f = v_hi2(s7e, s8e);
    s1f = _mm_add_pd(s9e, s0f);
    _mm_storeu_pd(((double  *) (dst + 30)), s1f);
    s2f = v_neg23(_mm_sub_pd(s9e, s0f));
    _mm_storeu_pd(((double  *) (dst + 34)), s2f);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_64)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_64_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a01, a11, a2, a21, a3, a31, a4, a5, a6, a7, a8, a9, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s2
            , s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s3, s31, s32, s33, s34, s35, s36
            , s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d
            , s4e, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s6, s61, s62, s63, s64, s65
            , s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c
            , s7d, s7e, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s9, s91, s92, s93, s94
            , s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b
            , t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a
            , t2b, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t4, t41, t42, t43, t44, t45, t46, t47, t48
            , t49, t4a, t4b, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t6, t61, t62, t63, t64, t65, t66
            , t67, t68, t69, t6a, t6b, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a;
    __m128d  *a, *a41;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = *((a + 16));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = *((a + 8));
    s4 = *((a + 24));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = *((a + 4));
    s6 = *((a + 20));
    t5 = _mm_add_pd(s5, s6);
    s7 = *((a + 12));
    s8 = *((a + 28));
    t6 = _mm_add_pd(s7, s8);
    t7 = _mm_add_pd(t, t3);
    t8 = _mm_sub_pd(t, t3);
    t9 = _mm_add_pd(t5, t6);
    t01 = _mm_sub_pd(t5, t6);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
    a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
    s9 = _mm_add_pd(a2, a3);
    s01 = _mm_sub_pd(a3, a2);
    t11 = _mm_add_pd(t2, s9);
    t21 = _mm_sub_pd(s01, t4);
    t31 = _mm_sub_pd(t2, s9);
    t41 = _mm_add_pd(t4, s01);
    s11 = *((a + 1));
    s21 = *((a + 17));
    t51 = _mm_add_pd(s11, s21);
    t61 = _mm_sub_pd(s11, s21);
    s31 = *((a + 9));
    s41 = *((a + 25));
    t71 = _mm_add_pd(s31, s41);
    t81 = _mm_sub_pd(s31, s41);
    s51 = *((a + 5));
    s61 = *((a + 21));
    t91 = _mm_add_pd(s51, s61);
    s71 = *((a + 13));
    s81 = *((a + 29));
    t02 = _mm_add_pd(s71, s81);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_sub_pd(t51, t71);
    t32 = _mm_add_pd(t91, t02);
    t42 = _mm_sub_pd(t91, t02);
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
    a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
    s91 = _mm_add_pd(a4, a5);
    s02 = _mm_sub_pd(a5, a4);
    t52 = _mm_add_pd(t61, s91);
    t62 = _mm_sub_pd(s02, t81);
    t72 = _mm_sub_pd(t61, s91);
    t82 = _mm_add_pd(t81, s02);
    s12 = *((a + 2));
    s22 = *((a + 18));
    t92 = _mm_add_pd(s12, s22);
    t03 = _mm_sub_pd(s12, s22);
    s32 = *((a + 10));
    s42 = *((a + 26));
    t13 = _mm_add_pd(s32, s42);
    t23 = _mm_sub_pd(s32, s42);
    s52 = *((a + 6));
    s62 = *((a + 22));
    t33 = _mm_add_pd(s52, s62);
    s72 = *((a + 14));
    s82 = *((a + 30));
    t43 = _mm_add_pd(s72, s82);
    t53 = _mm_add_pd(t92, t13);
    t63 = _mm_add_pd(t33, t43);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
    a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
    s92 = _mm_add_pd(a6, a7);
    s03 = _mm_sub_pd(a7, a6);
    t73 = _mm_add_pd(t03, s92);
    t83 = _mm_sub_pd(s03, t23);
    t93 = _mm_sub_pd(t03, s92);
    t04 = _mm_add_pd(t23, s03);
    s13 = *((a + 3));
    s23 = *((a + 19));
    t14 = _mm_add_pd(s13, s23);
    t24 = _mm_sub_pd(s13, s23);
    s33 = *((a + 11));
    s43 = *((a + 27));
    t34 = _mm_add_pd(s33, s43);
    t44 = _mm_sub_pd(s33, s43);
    s53 = *((a + 7));
    s63 = *((a + 23));
    t54 = _mm_add_pd(s53, s63);
    s73 = *((a + 15));
    s83 = *((a + 31));
    t64 = _mm_add_pd(s73, s83);
    t74 = _mm_add_pd(t14, t34);
    t84 = _mm_sub_pd(t14, t34);
    t94 = _mm_add_pd(t54, t64);
    t05 = _mm_sub_pd(t54, t64);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
    s93 = _mm_add_pd(a8, a9);
    s04 = _mm_sub_pd(a9, a8);
    t15 = _mm_add_pd(t24, s93);
    t25 = _mm_sub_pd(s04, t44);
    t35 = _mm_sub_pd(t24, s93);
    t45 = _mm_add_pd(t44, s04);
    t55 = _mm_add_pd(t7, t9);
    t65 = _mm_sub_pd(t7, t9);
    t75 = _mm_add_pd(t53, t63);
    t85 = _mm_sub_pd(t53, t63);
    t95 = _mm_add_pd(t12, t32);
    t06 = _mm_add_pd(t74, t94);
    t16 = _mm_add_pd(t55, t75);
    t26 = _mm_sub_pd(t55, t75);
    t36 = _mm_add_pd(t95, t06);
    t46 = _mm_sub_pd(t95, t06);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
    s14 = _mm_add_pd(a01, a11);
    s24 = _mm_sub_pd(a11, a01);
    t56 = _mm_add_pd(t65, s14);
    t66 = _mm_sub_pd(s24, t85);
    t76 = _mm_sub_pd(t65, s14);
    t86 = _mm_add_pd(t85, s24);
    s34 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
    s44 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
    s54 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
    s64 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
    s74 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
    s84 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
    t96 = _mm_add_pd(t11, s54);
    t07 = _mm_add_pd(t21, s64);
    t17 = _mm_sub_pd(t11, s54);
    t27 = _mm_sub_pd(t21, s64);
    t37 = _mm_add_pd(s34, s74);
    t47 = _mm_add_pd(s44, s84);
    t57 = _mm_sub_pd(s34, s74);
    t67 = _mm_sub_pd(s44, s84);
    t77 = _mm_add_pd(t96, t37);
    t87 = _mm_add_pd(t07, t47);
    t97 = _mm_sub_pd(t96, t37);
    t08 = _mm_sub_pd(t07, t47);
    t18 = _mm_add_pd(t17, t67);
    t28 = _mm_sub_pd(t27, t57);
    t38 = _mm_sub_pd(t17, t67);
    t48 = _mm_add_pd(t27, t57);
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
    s15 = _mm_add_pd(a21, a31);
    s25 = _mm_sub_pd(a31, a21);
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
    s45 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
    t58 = _mm_add_pd(t8, s15);
    t68 = _mm_sub_pd(s25, t01);
    t78 = _mm_sub_pd(t8, s15);
    t88 = _mm_add_pd(t01, s25);
    t98 = _mm_add_pd(s94, s35);
    t09 = _mm_add_pd(s05, s45);
    t19 = _mm_sub_pd(s94, s35);
    t29 = _mm_sub_pd(s05, s45);
    t39 = _mm_add_pd(t58, t98);
    t49 = _mm_add_pd(t68, t09);
    t59 = _mm_sub_pd(t58, t98);
    t69 = _mm_sub_pd(t68, t09);
    t79 = _mm_add_pd(t78, t29);
    t89 = _mm_add_pd(t88, t19);
    t99 = _mm_sub_pd(t78, t29);
    t0a = _mm_sub_pd(t19, t88);
    s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
    s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
    s75 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
    s85 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
    s95 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
    s06 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
    t1a = _mm_add_pd(t31, s75);
    t2a = _mm_add_pd(t41, s85);
    t3a = _mm_sub_pd(t31, s75);
    t4a = _mm_sub_pd(t41, s85);
    t5a = _mm_add_pd(s55, s95);
    t6a = _mm_add_pd(s65, s06);
    t7a = _mm_sub_pd(s55, s95);
    t8a = _mm_sub_pd(s65, s06);
    t9a = _mm_add_pd(t1a, t5a);
    t0b = _mm_add_pd(t2a, t6a);
    t1b = _mm_sub_pd(t1a, t5a);
    t2b = _mm_sub_pd(t2a, t6a);
    t3b = _mm_add_pd(t3a, t8a);
    t4b = _mm_sub_pd(t4a, t7a);
    t5b = _mm_sub_pd(t3a, t8a);
    t6b = _mm_add_pd(t4a, t7a);
    t7b = _mm_add_pd(t16, t36);
    a41 = ((__m128d  *) dst);
    s16 = _mm_add_pd(v_neg03(v_hi2(t7b, t7b)), v_lo2(t7b, t7b));
    *(a41) = s16;
    s26 = v_neg23(_mm_sub_pd(t16, t36));
    *((a41 + 16)) = s26;
    s36 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t77), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t87));
    s46 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t77), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t87));
    s56 = v_lo2(s36, s46);
    s66 = v_hi2(s36, s46);
    s76 = _mm_add_pd(s56, s66);
    *((a41 + 1)) = s76;
    s86 = v_neg23(_mm_sub_pd(s56, s66));
    *((a41 + 31)) = s86;
    s96 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t39), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t49));
    s07 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t39), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t49));
    s17 = v_lo2(s96, s07);
    s27 = v_hi2(s96, s07);
    s37 = _mm_add_pd(s17, s27);
    *((a41 + 2)) = s37;
    s47 = v_neg23(_mm_sub_pd(s17, s27));
    *((a41 + 30)) = s47;
    s57 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t9a), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t0b));
    s67 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t9a), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t0b));
    s77 = v_lo2(s57, s67);
    s87 = v_hi2(s57, s67);
    s97 = _mm_add_pd(s77, s87);
    *((a41 + 3)) = s97;
    s08 = v_neg23(_mm_sub_pd(s77, s87));
    *((a41 + 29)) = s08;
    s18 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t56), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t66));
    s28 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t56), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t66));
    s38 = v_lo2(s18, s28);
    s48 = v_hi2(s18, s28);
    s58 = _mm_add_pd(s38, s48);
    *((a41 + 4)) = s58;
    s68 = v_neg23(_mm_sub_pd(s38, s48));
    *((a41 + 28)) = s68;
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t5b), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t6b));
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t5b), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t6b));
    s98 = v_lo2(s78, s88);
    s09 = v_hi2(s78, s88);
    s19 = _mm_add_pd(s98, s09);
    *((a41 + 5)) = s19;
    s29 = v_neg23(_mm_sub_pd(s98, s09));
    *((a41 + 27)) = s29;
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t99), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t0a));
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t99), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t0a));
    s59 = v_lo2(s39, s49);
    s69 = v_hi2(s39, s49);
    s79 = _mm_add_pd(s59, s69);
    *((a41 + 6)) = s79;
    s89 = v_neg23(_mm_sub_pd(s59, s69));
    *((a41 + 26)) = s89;
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t38), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t48));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t38), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t48));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    *((a41 + 7)) = s3a;
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    *((a41 + 25)) = s4a;
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t26), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t46));
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t26), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t46));
    s7a = v_lo2(s5a, s6a);
    s8a = v_hi2(s5a, s6a);
    s9a = _mm_add_pd(s7a, s8a);
    *((a41 + 8)) = s9a;
    s0b = v_neg23(_mm_sub_pd(s7a, s8a));
    *((a41 + 24)) = s0b;
    s1b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t18), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t28));
    s2b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t18), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t28));
    s3b = v_lo2(s1b, s2b);
    s4b = v_hi2(s1b, s2b);
    s5b = _mm_add_pd(s3b, s4b);
    *((a41 + 9)) = s5b;
    s6b = v_neg23(_mm_sub_pd(s3b, s4b));
    *((a41 + 23)) = s6b;
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t79), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t89));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t79), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t89));
    s9b = v_lo2(s7b, s8b);
    s0c = v_hi2(s7b, s8b);
    s1c = _mm_add_pd(s9b, s0c);
    *((a41 + 10)) = s1c;
    s2c = v_neg23(_mm_sub_pd(s9b, s0c));
    *((a41 + 22)) = s2c;
    s3c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t3b), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t4b));
    s4c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t3b), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t4b));
    s5c = v_lo2(s3c, s4c);
    s6c = v_hi2(s3c, s4c);
    s7c = _mm_add_pd(s5c, s6c);
    *((a41 + 11)) = s7c;
    s8c = v_neg23(_mm_sub_pd(s5c, s6c));
    *((a41 + 21)) = s8c;
    s9c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t76), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t86));
    s0d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t76), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t86));
    s1d = v_lo2(s9c, s0d);
    s2d = v_hi2(s9c, s0d);
    s3d = _mm_add_pd(s1d, s2d);
    *((a41 + 12)) = s3d;
    s4d = v_neg23(_mm_sub_pd(s1d, s2d));
    *((a41 + 20)) = s4d;
    s5d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t1b), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t2b));
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t1b), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t2b));
    s7d = v_lo2(s5d, s6d);
    s8d = v_hi2(s5d, s6d);
    s9d = _mm_add_pd(s7d, s8d);
    *((a41 + 13)) = s9d;
    s0e = v_neg23(_mm_sub_pd(s7d, s8d));
    *((a41 + 19)) = s0e;
    s1e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t59), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t69));
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t59), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t69));
    s3e = v_lo2(s1e, s2e);
    s4e = v_hi2(s1e, s2e);
    s5e = _mm_add_pd(s3e, s4e);
    *((a41 + 14)) = s5e;
    s6e = v_neg23(_mm_sub_pd(s3e, s4e));
    *((a41 + 18)) = s6e;
    s7e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t97), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t08));
    s8e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t97), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t08));
    s9e = v_lo2(s7e, s8e);
    s0f = v_hi2(s7e, s8e);
    s1f = _mm_add_pd(s9e, s0f);
    *((a41 + 15)) = s1f;
    s2f = v_neg23(_mm_sub_pd(s9e, s0f));
    *((a41 + 17)) = s2f;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_128_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a01, a02, a11, a2, a21, a3, a31, a4, a41, a5, a51, a6, a61, a7, a71, a8, a81, a9, a91, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n
            , s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d
            , s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s2, s21, s22
            , s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d
            , s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s4, s41, s42
            , s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o
            , s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d
            , s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s6, s61, s62
            , s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o
            , s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s8, s81, s82
            , s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o
            , s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d
            , s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, t, t01, t02, t03
            , t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p
            , t0q, t0r, t0s, t0t, t0u, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h
            , t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s, t1t, t1u, t2, t21, t22, t23, t24, t25, t26, t27, t28
            , t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t3
            , t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m
            , t3n, t3o, t3p, t3q, t3r, t3s, t3t, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e
            , t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t5, t51, t52, t53, t54, t55, t56
            , t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s
            , t5t, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k
            , t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q
            , t8r, t8s, t8t, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i
            , t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_loadu_pd(((const double  *) (src + 64)));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = _mm_loadu_pd(((const double  *) (src + 32)));
    s4 = _mm_loadu_pd(((const double  *) (src + 96)));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = _mm_loadu_pd(((const double  *) (src + 8)));
    s6 = _mm_loadu_pd(((const double  *) (src + 72)));
    t5 = _mm_add_pd(s5, s6);
    t6 = _mm_sub_pd(s5, s6);
    s7 = _mm_loadu_pd(((const double  *) (src + 40)));
    s8 = _mm_loadu_pd(((const double  *) (src + 104)));
    t7 = _mm_add_pd(s7, s8);
    t8 = _mm_sub_pd(s7, s8);
    s9 = _mm_loadu_pd(((const double  *) (src + 16)));
    s01 = _mm_loadu_pd(((const double  *) (src + 80)));
    t9 = _mm_add_pd(s9, s01);
    s11 = _mm_loadu_pd(((const double  *) (src + 48)));
    s21 = _mm_loadu_pd(((const double  *) (src + 112)));
    t01 = _mm_add_pd(s11, s21);
    s31 = _mm_loadu_pd(((const double  *) (src + 24)));
    s41 = _mm_loadu_pd(((const double  *) (src + 88)));
    t11 = _mm_add_pd(s31, s41);
    t21 = _mm_sub_pd(s31, s41);
    s51 = _mm_loadu_pd(((const double  *) (src + 56)));
    s61 = _mm_loadu_pd(((const double  *) (src + 120)));
    t31 = _mm_add_pd(s51, s61);
    t41 = _mm_sub_pd(s51, s61);
    t51 = _mm_add_pd(t, t3);
    t61 = _mm_sub_pd(t, t3);
    t71 = _mm_add_pd(t9, t01);
    t81 = _mm_sub_pd(t9, t01);
    t91 = _mm_add_pd(t5, t7);
    t02 = _mm_add_pd(t11, t31);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_sub_pd(t51, t71);
    t32 = _mm_add_pd(t91, t02);
    t42 = _mm_sub_pd(t91, t02);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
    a2 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
    s71 = _mm_add_pd(a, a2);
    s81 = _mm_sub_pd(a2, a);
    t52 = _mm_add_pd(t61, s71);
    t62 = _mm_sub_pd(s81, t81);
    t72 = _mm_sub_pd(t61, s71);
    t82 = _mm_add_pd(t81, s81);
    s91 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
    a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
    s12 = _mm_add_pd(a3, a4);
    s22 = _mm_sub_pd(a4, a3);
    s32 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
    s42 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
    t92 = _mm_add_pd(t2, s12);
    t03 = _mm_sub_pd(s22, t4);
    t13 = _mm_sub_pd(t2, s12);
    t23 = _mm_add_pd(t4, s22);
    t33 = _mm_add_pd(s91, s32);
    t43 = _mm_add_pd(s02, s42);
    t53 = _mm_sub_pd(s91, s32);
    t63 = _mm_sub_pd(s02, s42);
    t73 = _mm_add_pd(t92, t33);
    t83 = _mm_add_pd(t03, t43);
    t93 = _mm_sub_pd(t92, t33);
    t04 = _mm_sub_pd(t03, t43);
    t14 = _mm_add_pd(t13, t63);
    t24 = _mm_add_pd(t23, t53);
    t34 = _mm_sub_pd(t13, t63);
    t44 = _mm_sub_pd(t53, t23);
    s52 = _mm_loadu_pd(((const double  *) (src + 2)));
    s62 = _mm_loadu_pd(((const double  *) (src + 66)));
    t54 = _mm_add_pd(s52, s62);
    t64 = _mm_sub_pd(s52, s62);
    s72 = _mm_loadu_pd(((const double  *) (src + 34)));
    s82 = _mm_loadu_pd(((const double  *) (src + 98)));
    t74 = _mm_add_pd(s72, s82);
    t84 = _mm_sub_pd(s72, s82);
    s92 = _mm_loadu_pd(((const double  *) (src + 10)));
    s03 = _mm_loadu_pd(((const double  *) (src + 74)));
    t94 = _mm_add_pd(s92, s03);
    t05 = _mm_sub_pd(s92, s03);
    s13 = _mm_loadu_pd(((const double  *) (src + 42)));
    s23 = _mm_loadu_pd(((const double  *) (src + 106)));
    t15 = _mm_add_pd(s13, s23);
    t25 = _mm_sub_pd(s13, s23);
    s33 = _mm_loadu_pd(((const double  *) (src + 18)));
    s43 = _mm_loadu_pd(((const double  *) (src + 82)));
    t35 = _mm_add_pd(s33, s43);
    s53 = _mm_loadu_pd(((const double  *) (src + 50)));
    s63 = _mm_loadu_pd(((const double  *) (src + 114)));
    t45 = _mm_add_pd(s53, s63);
    s73 = _mm_loadu_pd(((const double  *) (src + 26)));
    s83 = _mm_loadu_pd(((const double  *) (src + 90)));
    t55 = _mm_add_pd(s73, s83);
    t65 = _mm_sub_pd(s73, s83);
    s93 = _mm_loadu_pd(((const double  *) (src + 58)));
    s04 = _mm_loadu_pd(((const double  *) (src + 122)));
    t75 = _mm_add_pd(s93, s04);
    t85 = _mm_sub_pd(s93, s04);
    t95 = _mm_add_pd(t54, t74);
    t06 = _mm_sub_pd(t54, t74);
    t16 = _mm_add_pd(t35, t45);
    t26 = _mm_sub_pd(t35, t45);
    t36 = _mm_add_pd(t94, t15);
    t46 = _mm_add_pd(t55, t75);
    t56 = _mm_add_pd(t95, t16);
    t66 = _mm_sub_pd(t95, t16);
    t76 = _mm_add_pd(t36, t46);
    t86 = _mm_sub_pd(t36, t46);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
    a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t55, t75));
    s14 = _mm_add_pd(a5, a6);
    s24 = _mm_sub_pd(a6, a5);
    t96 = _mm_add_pd(t06, s14);
    t07 = _mm_sub_pd(s24, t26);
    t17 = _mm_sub_pd(t06, s14);
    t27 = _mm_add_pd(t26, s24);
    s34 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
    a8 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
    s54 = _mm_add_pd(a7, a8);
    s64 = _mm_sub_pd(a8, a7);
    s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t85));
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    t37 = _mm_add_pd(t64, s54);
    t47 = _mm_sub_pd(s64, t84);
    t57 = _mm_sub_pd(t64, s54);
    t67 = _mm_add_pd(t84, s64);
    t77 = _mm_add_pd(s34, s74);
    t87 = _mm_add_pd(s44, s84);
    t97 = _mm_sub_pd(s34, s74);
    t08 = _mm_sub_pd(s44, s84);
    t18 = _mm_add_pd(t37, t77);
    t28 = _mm_add_pd(t47, t87);
    t38 = _mm_sub_pd(t37, t77);
    t48 = _mm_sub_pd(t47, t87);
    t58 = _mm_add_pd(t57, t08);
    t68 = _mm_add_pd(t67, t97);
    t78 = _mm_sub_pd(t57, t08);
    t88 = _mm_sub_pd(t97, t67);
    s94 = _mm_loadu_pd(((const double  *) (src + 4)));
    s05 = _mm_loadu_pd(((const double  *) (src + 68)));
    t98 = _mm_add_pd(s94, s05);
    t09 = _mm_sub_pd(s94, s05);
    s15 = _mm_loadu_pd(((const double  *) (src + 36)));
    s25 = _mm_loadu_pd(((const double  *) (src + 100)));
    t19 = _mm_add_pd(s15, s25);
    t29 = _mm_sub_pd(s15, s25);
    s35 = _mm_loadu_pd(((const double  *) (src + 12)));
    s45 = _mm_loadu_pd(((const double  *) (src + 76)));
    t39 = _mm_add_pd(s35, s45);
    t49 = _mm_sub_pd(s35, s45);
    s55 = _mm_loadu_pd(((const double  *) (src + 44)));
    s65 = _mm_loadu_pd(((const double  *) (src + 108)));
    t59 = _mm_add_pd(s55, s65);
    t69 = _mm_sub_pd(s55, s65);
    s75 = _mm_loadu_pd(((const double  *) (src + 20)));
    s85 = _mm_loadu_pd(((const double  *) (src + 84)));
    t79 = _mm_add_pd(s75, s85);
    s95 = _mm_loadu_pd(((const double  *) (src + 52)));
    s06 = _mm_loadu_pd(((const double  *) (src + 116)));
    t89 = _mm_add_pd(s95, s06);
    s16 = _mm_loadu_pd(((const double  *) (src + 28)));
    s26 = _mm_loadu_pd(((const double  *) (src + 92)));
    t99 = _mm_add_pd(s16, s26);
    t0a = _mm_sub_pd(s16, s26);
    s36 = _mm_loadu_pd(((const double  *) (src + 60)));
    s46 = _mm_loadu_pd(((const double  *) (src + 124)));
    t1a = _mm_add_pd(s36, s46);
    t2a = _mm_sub_pd(s36, s46);
    t3a = _mm_add_pd(t98, t19);
    t4a = _mm_sub_pd(t98, t19);
    t5a = _mm_add_pd(t79, t89);
    t6a = _mm_sub_pd(t79, t89);
    t7a = _mm_add_pd(t39, t59);
    t8a = _mm_add_pd(t99, t1a);
    t9a = _mm_add_pd(t3a, t5a);
    t0b = _mm_add_pd(t7a, t8a);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t39, t59));
    a01 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t99, t1a));
    s56 = _mm_add_pd(a9, a01);
    s66 = _mm_sub_pd(a01, a9);
    t1b = _mm_add_pd(t4a, s56);
    t2b = _mm_sub_pd(s66, t6a);
    t3b = _mm_sub_pd(t4a, s56);
    t4b = _mm_add_pd(t6a, s66);
    s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t49), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t69));
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t49), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t69));
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s75, s85));
    a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s95, s06));
    s96 = _mm_add_pd(a11, a21);
    s07 = _mm_sub_pd(a21, a11);
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0a), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2a));
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2a));
    t5b = _mm_add_pd(t09, s96);
    t6b = _mm_sub_pd(s07, t29);
    t7b = _mm_sub_pd(t09, s96);
    t8b = _mm_add_pd(t29, s07);
    t9b = _mm_add_pd(s76, s17);
    t0c = _mm_add_pd(s86, s27);
    t1c = _mm_sub_pd(s76, s17);
    t2c = _mm_sub_pd(s86, s27);
    t3c = _mm_add_pd(t5b, t9b);
    t4c = _mm_add_pd(t6b, t0c);
    t5c = _mm_sub_pd(t5b, t9b);
    t6c = _mm_sub_pd(t6b, t0c);
    t7c = _mm_add_pd(t7b, t2c);
    t8c = _mm_add_pd(t8b, t1c);
    t9c = _mm_sub_pd(t7b, t2c);
    t0d = _mm_sub_pd(t1c, t8b);
    s37 = _mm_loadu_pd(((const double  *) (src + 6)));
    s47 = _mm_loadu_pd(((const double  *) (src + 70)));
    t1d = _mm_add_pd(s37, s47);
    t2d = _mm_sub_pd(s37, s47);
    s57 = _mm_loadu_pd(((const double  *) (src + 38)));
    s67 = _mm_loadu_pd(((const double  *) (src + 102)));
    t3d = _mm_add_pd(s57, s67);
    t4d = _mm_sub_pd(s57, s67);
    s77 = _mm_loadu_pd(((const double  *) (src + 14)));
    s87 = _mm_loadu_pd(((const double  *) (src + 78)));
    t5d = _mm_add_pd(s77, s87);
    t6d = _mm_sub_pd(s77, s87);
    s97 = _mm_loadu_pd(((const double  *) (src + 46)));
    s08 = _mm_loadu_pd(((const double  *) (src + 110)));
    t7d = _mm_add_pd(s97, s08);
    t8d = _mm_sub_pd(s97, s08);
    s18 = _mm_loadu_pd(((const double  *) (src + 22)));
    s28 = _mm_loadu_pd(((const double  *) (src + 86)));
    t9d = _mm_add_pd(s18, s28);
    s38 = _mm_loadu_pd(((const double  *) (src + 54)));
    s48 = _mm_loadu_pd(((const double  *) (src + 118)));
    t0e = _mm_add_pd(s38, s48);
    s58 = _mm_loadu_pd(((const double  *) (src + 30)));
    s68 = _mm_loadu_pd(((const double  *) (src + 94)));
    t1e = _mm_add_pd(s58, s68);
    t2e = _mm_sub_pd(s58, s68);
    s78 = _mm_loadu_pd(((const double  *) (src + 62)));
    s88 = _mm_loadu_pd(((const double  *) (src + 126)));
    t3e = _mm_add_pd(s78, s88);
    t4e = _mm_sub_pd(s78, s88);
    t5e = _mm_add_pd(t1d, t3d);
    t6e = _mm_sub_pd(t1d, t3d);
    t7e = _mm_add_pd(t9d, t0e);
    t8e = _mm_sub_pd(t9d, t0e);
    t9e = _mm_add_pd(t5d, t7d);
    t0f = _mm_add_pd(t1e, t3e);
    t1f = _mm_add_pd(t5e, t7e);
    t2f = _mm_sub_pd(t5e, t7e);
    t3f = _mm_add_pd(t9e, t0f);
    t4f = _mm_sub_pd(t9e, t0f);
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t7d));
    a41 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1e, t3e));
    s98 = _mm_add_pd(a31, a41);
    s09 = _mm_sub_pd(a41, a31);
    t5f = _mm_add_pd(t6e, s98);
    t6f = _mm_sub_pd(s09, t8e);
    t7f = _mm_sub_pd(t6e, s98);
    t8f = _mm_add_pd(t8e, s09);
    s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8d));
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8d));
    a51 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s18, s28));
    a61 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s38, s48));
    s39 = _mm_add_pd(a51, a61);
    s49 = _mm_sub_pd(a61, a51);
    s59 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e));
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4e));
    t9f = _mm_add_pd(t2d, s39);
    t0g = _mm_sub_pd(s49, t4d);
    t1g = _mm_sub_pd(t2d, s39);
    t2g = _mm_add_pd(t4d, s49);
    t3g = _mm_add_pd(s19, s59);
    t4g = _mm_add_pd(s29, s69);
    t5g = _mm_sub_pd(s19, s59);
    t6g = _mm_sub_pd(s29, s69);
    t7g = _mm_add_pd(t9f, t3g);
    t8g = _mm_add_pd(t0g, t4g);
    t9g = _mm_sub_pd(t9f, t3g);
    t0h = _mm_sub_pd(t0g, t4g);
    t1h = _mm_add_pd(t1g, t6g);
    t2h = _mm_add_pd(t2g, t5g);
    t3h = _mm_sub_pd(t1g, t6g);
    t4h = _mm_sub_pd(t5g, t2g);
    t5h = _mm_add_pd(t12, t32);
    t6h = _mm_sub_pd(t12, t32);
    t7h = _mm_add_pd(t9a, t0b);
    t8h = _mm_sub_pd(t9a, t0b);
    t9h = _mm_add_pd(t56, t76);
    t0i = _mm_add_pd(t1f, t3f);
    t1i = _mm_add_pd(t5h, t7h);
    t2i = _mm_sub_pd(t5h, t7h);
    t3i = _mm_add_pd(t9h, t0i);
    t4i = _mm_sub_pd(t9h, t0i);
    t5i = _mm_add_pd(t1i, t3i);
    s79 = _mm_add_pd(v_neg03(v_hi2(t5i, t5i)), v_lo2(t5i, t5i));
    _mm_storeu_pd(((double  *) dst), s79);
    s89 = v_neg23(_mm_sub_pd(t1i, t3i));
    _mm_storeu_pd(((double  *) (dst + 64)), s89);
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t2i), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t4i));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t2i), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t4i));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    _mm_storeu_pd(((double  *) (dst + 32)), s3a);
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    _mm_storeu_pd(((double  *) (dst + 96)), s4a);
    a71 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t76));
    a81 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1f, t3f));
    s5a = _mm_add_pd(a71, a81);
    s6a = _mm_sub_pd(a81, a71);
    t6i = _mm_add_pd(t6h, s5a);
    t7i = _mm_sub_pd(s6a, t8h);
    t8i = _mm_sub_pd(t6h, s5a);
    t9i = _mm_add_pd(t8h, s6a);
    s7a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t6i), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t7i));
    s8a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t6i), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t7i));
    s9a = v_lo2(s7a, s8a);
    s0b = v_hi2(s7a, s8a);
    s1b = _mm_add_pd(s9a, s0b);
    _mm_storeu_pd(((double  *) (dst + 16)), s1b);
    s2b = v_neg23(_mm_sub_pd(s9a, s0b));
    _mm_storeu_pd(((double  *) (dst + 112)), s2b);
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t8i), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t9i));
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t8i), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t9i));
    s5b = v_lo2(s3b, s4b);
    s6b = v_hi2(s3b, s4b);
    s7b = _mm_add_pd(s5b, s6b);
    _mm_storeu_pd(((double  *) (dst + 80)), s7b);
    s8b = v_neg23(_mm_sub_pd(s5b, s6b));
    _mm_storeu_pd(((double  *) (dst + 48)), s8b);
    s9b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t18), _mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t28));
    s0c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t18), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t28));
    s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3c), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4c));
    s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4c));
    s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7g), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t8g));
    s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t7g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8g));
    t0j = _mm_add_pd(t73, s1c);
    t1j = _mm_add_pd(t83, s2c);
    t2j = _mm_sub_pd(t73, s1c);
    t3j = _mm_sub_pd(t83, s2c);
    t4j = _mm_add_pd(s9b, s3c);
    t5j = _mm_add_pd(s0c, s4c);
    t6j = _mm_sub_pd(s9b, s3c);
    t7j = _mm_sub_pd(s0c, s4c);
    t8j = _mm_add_pd(t0j, t4j);
    t9j = _mm_add_pd(t1j, t5j);
    t0k = _mm_sub_pd(t0j, t4j);
    t1k = _mm_sub_pd(t1j, t5j);
    t2k = _mm_add_pd(t2j, t7j);
    t3k = _mm_sub_pd(t3j, t6j);
    t4k = _mm_sub_pd(t2j, t7j);
    t5k = _mm_add_pd(t3j, t6j);
    s5c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99879545620517241, 1.0), t8j), _mm_mul_pd(_mm_set_pd((-0.049067674327418015), 0.0), t9j));
    s6c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.049067674327418015), 0.0), t8j), _mm_mul_pd(_mm_set_pd(0.99879545620517241, 1.0), t9j));
    s7c = v_lo2(s5c, s6c);
    s8c = v_hi2(s5c, s6c);
    s9c = _mm_add_pd(s7c, s8c);
    _mm_storeu_pd(((double  *) (dst + 2)), s9c);
    s0d = v_neg23(_mm_sub_pd(s7c, s8c));
    _mm_storeu_pd(((double  *) (dst + 126)), s0d);
    s1d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.67155895484701844, 1.0), t2k), _mm_mul_pd(_mm_set_pd((-0.74095112535495911), 0.0), t3k));
    s2d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.74095112535495911), 0.0), t2k), _mm_mul_pd(_mm_set_pd(0.67155895484701844, 1.0), t3k));
    s3d = v_lo2(s1d, s2d);
    s4d = v_hi2(s1d, s2d);
    s5d = _mm_add_pd(s3d, s4d);
    _mm_storeu_pd(((double  *) (dst + 34)), s5d);
    s6d = v_neg23(_mm_sub_pd(s3d, s4d));
    _mm_storeu_pd(((double  *) (dst + 94)), s6d);
    s7d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.049067674327418015), 1.0), t0k), _mm_mul_pd(_mm_set_pd((-0.99879545620517241), 0.0), t1k));
    s8d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.99879545620517241), 0.0), t0k), _mm_mul_pd(_mm_set_pd((-0.049067674327418015), 1.0), t1k));
    s9d = v_lo2(s7d, s8d);
    s0e = v_hi2(s7d, s8d);
    s1e = _mm_add_pd(s9d, s0e);
    _mm_storeu_pd(((double  *) (dst + 66)), s1e);
    s2e = v_neg23(_mm_sub_pd(s9d, s0e));
    _mm_storeu_pd(((double  *) (dst + 62)), s2e);
    s3e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.74095112535495911), 1.0), t4k), _mm_mul_pd(_mm_set_pd((-0.67155895484701844), 0.0), t5k));
    s4e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.67155895484701844), 0.0), t4k), _mm_mul_pd(_mm_set_pd((-0.74095112535495911), 1.0), t5k));
    s5e = v_lo2(s3e, s4e);
    s6e = v_hi2(s3e, s4e);
    s7e = _mm_add_pd(s5e, s6e);
    _mm_storeu_pd(((double  *) (dst + 98)), s7e);
    s8e = v_neg23(_mm_sub_pd(s5e, s6e));
    _mm_storeu_pd(((double  *) (dst + 30)), s8e);
    s9e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t96), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t07));
    s0f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t96), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t07));
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2b));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2b));
    s3f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5f), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6f));
    s4f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5f), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6f));
    t6k = _mm_add_pd(t52, s1f);
    t7k = _mm_add_pd(t62, s2f);
    t8k = _mm_sub_pd(t52, s1f);
    t9k = _mm_sub_pd(t62, s2f);
    t0l = _mm_add_pd(s9e, s3f);
    t1l = _mm_add_pd(s0f, s4f);
    t2l = _mm_sub_pd(s9e, s3f);
    t3l = _mm_sub_pd(s0f, s4f);
    t4l = _mm_add_pd(t6k, t0l);
    t5l = _mm_add_pd(t7k, t1l);
    t6l = _mm_sub_pd(t6k, t0l);
    t7l = _mm_sub_pd(t7k, t1l);
    t8l = _mm_add_pd(t8k, t3l);
    t9l = _mm_sub_pd(t9k, t2l);
    t0m = _mm_sub_pd(t8k, t3l);
    t1m = _mm_add_pd(t9k, t2l);
    s5f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t4l), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t5l));
    s6f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t4l), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t5l));
    s7f = v_lo2(s5f, s6f);
    s8f = v_hi2(s5f, s6f);
    s9f = _mm_add_pd(s7f, s8f);
    _mm_storeu_pd(((double  *) (dst + 4)), s9f);
    s0g = v_neg23(_mm_sub_pd(s7f, s8f));
    _mm_storeu_pd(((double  *) (dst + 124)), s0g);
    s1g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t8l), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t9l));
    s2g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t8l), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t9l));
    s3g = v_lo2(s1g, s2g);
    s4g = v_hi2(s1g, s2g);
    s5g = _mm_add_pd(s3g, s4g);
    _mm_storeu_pd(((double  *) (dst + 36)), s5g);
    s6g = v_neg23(_mm_sub_pd(s3g, s4g));
    _mm_storeu_pd(((double  *) (dst + 92)), s6g);
    s7g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 1.0), t6l), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t7l));
    s8g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t6l), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 1.0), t7l));
    s9g = v_lo2(s7g, s8g);
    s0h = v_hi2(s7g, s8g);
    s1h = _mm_add_pd(s9g, s0h);
    _mm_storeu_pd(((double  *) (dst + 68)), s1h);
    s2h = v_neg23(_mm_sub_pd(s9g, s0h));
    _mm_storeu_pd(((double  *) (dst + 60)), s2h);
    s3h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 1.0), t0m), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t1m));
    s4h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t0m), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 1.0), t1m));
    s5h = v_lo2(s3h, s4h);
    s6h = v_hi2(s3h, s4h);
    s7h = _mm_add_pd(s5h, s6h);
    _mm_storeu_pd(((double  *) (dst + 100)), s7h);
    s8h = v_neg23(_mm_sub_pd(s5h, s6h));
    _mm_storeu_pd(((double  *) (dst + 28)), s8h);
    s9h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t78), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t88));
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t78), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t88));
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9c), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t0d));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t9c), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0d));
    s3i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3h), _mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t4h));
    s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t3h), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4h));
    t2m = _mm_add_pd(t34, s1i);
    t3m = _mm_sub_pd(s2i, t44);
    t4m = _mm_sub_pd(t34, s1i);
    t5m = _mm_add_pd(t44, s2i);
    t6m = _mm_add_pd(s9h, s3i);
    t7m = _mm_add_pd(s0i, s4i);
    t8m = _mm_sub_pd(s9h, s3i);
    t9m = _mm_sub_pd(s0i, s4i);
    t0n = _mm_add_pd(t2m, t6m);
    t1n = _mm_add_pd(t3m, t7m);
    t2n = _mm_sub_pd(t2m, t6m);
    t3n = _mm_sub_pd(t3m, t7m);
    t4n = _mm_add_pd(t4m, t9m);
    t5n = _mm_add_pd(t5m, t8m);
    t6n = _mm_sub_pd(t4m, t9m);
    t7n = _mm_sub_pd(t8m, t5m);
    s5i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98917650996478101, 1.0), t0n), _mm_mul_pd(_mm_set_pd((-0.14673047445536175), 0.0), t1n));
    s6i = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.14673047445536175), 0.0), t0n), _mm_mul_pd(_mm_set_pd(0.98917650996478101, 1.0), t1n));
    s7i = v_lo2(s5i, s6i);
    s8i = v_hi2(s5i, s6i);
    s9i = _mm_add_pd(s7i, s8i);
    _mm_storeu_pd(((double  *) (dst + 6)), s9i);
    s0j = v_neg23(_mm_sub_pd(s7i, s8i));
    _mm_storeu_pd(((double  *) (dst + 122)), s0j);
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.59569930449243336, 1.0), t4n), _mm_mul_pd(_mm_set_pd((-0.80320753148064494), 0.0), t5n));
    s2j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.80320753148064494), 0.0), t4n), _mm_mul_pd(_mm_set_pd(0.59569930449243336, 1.0), t5n));
    s3j = v_lo2(s1j, s2j);
    s4j = v_hi2(s1j, s2j);
    s5j = _mm_add_pd(s3j, s4j);
    _mm_storeu_pd(((double  *) (dst + 38)), s5j);
    s6j = v_neg23(_mm_sub_pd(s3j, s4j));
    _mm_storeu_pd(((double  *) (dst + 90)), s6j);
    s7j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.14673047445536175), 1.0), t2n), _mm_mul_pd(_mm_set_pd((-0.98917650996478101), 0.0), t3n));
    s8j = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98917650996478101), 0.0), t2n), _mm_mul_pd(_mm_set_pd((-0.14673047445536175), 1.0), t3n));
    s9j = v_lo2(s7j, s8j);
    s0k = v_hi2(s7j, s8j);
    s1k = _mm_add_pd(s9j, s0k);
    _mm_storeu_pd(((double  *) (dst + 70)), s1k);
    s2k = v_neg23(_mm_sub_pd(s9j, s0k));
    _mm_storeu_pd(((double  *) (dst + 58)), s2k);
    s3k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.80320753148064494), 1.0), t6n), _mm_mul_pd(_mm_set_pd((-0.59569930449243336), 0.0), t7n));
    s4k = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.59569930449243336), 0.0), t6n), _mm_mul_pd(_mm_set_pd((-0.80320753148064494), 1.0), t7n));
    s5k = v_lo2(s3k, s4k);
    s6k = v_hi2(s3k, s4k);
    s7k = _mm_add_pd(s5k, s6k);
    _mm_storeu_pd(((double  *) (dst + 102)), s7k);
    s8k = v_neg23(_mm_sub_pd(s5k, s6k));
    _mm_storeu_pd(((double  *) (dst + 26)), s8k);
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t86));
    s0l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t86));
    a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3a, t5a));
    a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7a, t8a));
    s1l = _mm_add_pd(a91, a02);
    s2l = _mm_sub_pd(a02, a91);
    s3l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4f));
    s4l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
    t8n = _mm_add_pd(t22, s1l);
    t9n = _mm_sub_pd(s2l, t42);
    t0o = _mm_sub_pd(t22, s1l);
    t1o = _mm_add_pd(t42, s2l);
    t2o = _mm_add_pd(s9k, s3l);
    t3o = _mm_add_pd(s0l, s4l);
    t4o = _mm_sub_pd(s9k, s3l);
    t5o = _mm_sub_pd(s0l, s4l);
    t6o = _mm_add_pd(t8n, t2o);
    t7o = _mm_add_pd(t9n, t3o);
    t8o = _mm_sub_pd(t8n, t2o);
    t9o = _mm_sub_pd(t9n, t3o);
    t0p = _mm_add_pd(t0o, t5o);
    t1p = _mm_add_pd(t1o, t4o);
    t2p = _mm_sub_pd(t0o, t5o);
    t3p = _mm_sub_pd(t4o, t1o);
    s5l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t6o), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t7o));
    s6l = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t6o), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t7o));
    s7l = v_lo2(s5l, s6l);
    s8l = v_hi2(s5l, s6l);
    s9l = _mm_add_pd(s7l, s8l);
    _mm_storeu_pd(((double  *) (dst + 8)), s9l);
    s0m = v_neg23(_mm_sub_pd(s7l, s8l));
    _mm_storeu_pd(((double  *) (dst + 120)), s0m);
    s1m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t0p), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t1p));
    s2m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t0p), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t1p));
    s3m = v_lo2(s1m, s2m);
    s4m = v_hi2(s1m, s2m);
    s5m = _mm_add_pd(s3m, s4m);
    _mm_storeu_pd(((double  *) (dst + 40)), s5m);
    s6m = v_neg23(_mm_sub_pd(s3m, s4m));
    _mm_storeu_pd(((double  *) (dst + 88)), s6m);
    s7m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t8o), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t9o));
    s8m = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t8o), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t9o));
    s9m = v_lo2(s7m, s8m);
    s0n = v_hi2(s7m, s8m);
    s1n = _mm_add_pd(s9m, s0n);
    _mm_storeu_pd(((double  *) (dst + 72)), s1n);
    s2n = v_neg23(_mm_sub_pd(s9m, s0n));
    _mm_storeu_pd(((double  *) (dst + 56)), s2n);
    s3n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 1.0), t2p), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3p));
    s4n = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t2p), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 1.0), t3p));
    s5n = v_lo2(s3n, s4n);
    s6n = v_hi2(s3n, s4n);
    s7n = _mm_add_pd(s5n, s6n);
    _mm_storeu_pd(((double  *) (dst + 104)), s7n);
    s8n = v_neg23(_mm_sub_pd(s5n, s6n));
    _mm_storeu_pd(((double  *) (dst + 24)), s8n);
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t58), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t68));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t58), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t68));
    s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7c), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t8c));
    s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t7c), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8c));
    s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1h), _mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t2h));
    s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t1h), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2h));
    t4p = _mm_add_pd(t14, s1o);
    t5p = _mm_sub_pd(s2o, t24);
    t6p = _mm_sub_pd(t14, s1o);
    t7p = _mm_add_pd(t24, s2o);
    t8p = _mm_add_pd(s9n, s3o);
    t9p = _mm_add_pd(s0o, s4o);
    t0q = _mm_sub_pd(s9n, s3o);
    t1q = _mm_sub_pd(s0o, s4o);
    t2q = _mm_add_pd(t4p, t8p);
    t3q = _mm_add_pd(t5p, t9p);
    t4q = _mm_sub_pd(t4p, t8p);
    t5q = _mm_sub_pd(t5p, t9p);
    t6q = _mm_add_pd(t6p, t1q);
    t7q = _mm_add_pd(t7p, t0q);
    t8q = _mm_sub_pd(t6p, t1q);
    t9q = _mm_sub_pd(t0q, t7p);
    s5o = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.97003125319454397, 1.0), t2q), _mm_mul_pd(_mm_set_pd((-0.2429801799032639), 0.0), t3q));
    s6o = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.2429801799032639), 0.0), t2q), _mm_mul_pd(_mm_set_pd(0.97003125319454397, 1.0), t3q));
    s7o = v_lo2(s5o, s6o);
    s8o = v_hi2(s5o, s6o);
    s9o = _mm_add_pd(s7o, s8o);
    _mm_storeu_pd(((double  *) (dst + 10)), s9o);
    s0p = v_neg23(_mm_sub_pd(s7o, s8o));
    _mm_storeu_pd(((double  *) (dst + 118)), s0p);
    s1p = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.51410274419322177, 1.0), t6q), _mm_mul_pd(_mm_set_pd((-0.85772861000027212), 0.0), t7q));
    s2p = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85772861000027212), 0.0), t6q), _mm_mul_pd(_mm_set_pd(0.51410274419322177, 1.0), t7q));
    s3p = v_lo2(s1p, s2p);
    s4p = v_hi2(s1p, s2p);
    s5p = _mm_add_pd(s3p, s4p);
    _mm_storeu_pd(((double  *) (dst + 42)), s5p);
    s6p = v_neg23(_mm_sub_pd(s3p, s4p));
    _mm_storeu_pd(((double  *) (dst + 86)), s6p);
    s7p = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.2429801799032639), 1.0), t4q), _mm_mul_pd(_mm_set_pd((-0.97003125319454397), 0.0), t5q));
    s8p = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.97003125319454397), 0.0), t4q), _mm_mul_pd(_mm_set_pd((-0.2429801799032639), 1.0), t5q));
    s9p = v_lo2(s7p, s8p);
    s0q = v_hi2(s7p, s8p);
    s1q = _mm_add_pd(s9p, s0q);
    _mm_storeu_pd(((double  *) (dst + 74)), s1q);
    s2q = v_neg23(_mm_sub_pd(s9p, s0q));
    _mm_storeu_pd(((double  *) (dst + 54)), s2q);
    s3q = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85772861000027212), 1.0), t8q), _mm_mul_pd(_mm_set_pd((-0.51410274419322177), 0.0), t9q));
    s4q = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.51410274419322177), 0.0), t8q), _mm_mul_pd(_mm_set_pd((-0.85772861000027212), 1.0), t9q));
    s5q = v_lo2(s3q, s4q);
    s6q = v_hi2(s3q, s4q);
    s7q = _mm_add_pd(s5q, s6q);
    _mm_storeu_pd(((double  *) (dst + 106)), s7q);
    s8q = v_neg23(_mm_sub_pd(s5q, s6q));
    _mm_storeu_pd(((double  *) (dst + 22)), s8q);
    s9q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t17), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t27));
    s0r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t17), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t27));
    s1r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3b), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4b));
    s2r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4b));
    s3r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7f), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8f));
    s4r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7f), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8f));
    t0r = _mm_add_pd(t72, s1r);
    t1r = _mm_add_pd(t82, s2r);
    t2r = _mm_sub_pd(t72, s1r);
    t3r = _mm_sub_pd(t82, s2r);
    t4r = _mm_add_pd(s9q, s3r);
    t5r = _mm_add_pd(s0r, s4r);
    t6r = _mm_sub_pd(s9q, s3r);
    t7r = _mm_sub_pd(s0r, s4r);
    t8r = _mm_add_pd(t0r, t4r);
    t9r = _mm_add_pd(t1r, t5r);
    t0s = _mm_sub_pd(t0r, t4r);
    t1s = _mm_sub_pd(t1r, t5r);
    t2s = _mm_add_pd(t2r, t7r);
    t3s = _mm_sub_pd(t3r, t6r);
    t4s = _mm_sub_pd(t2r, t7r);
    t5s = _mm_add_pd(t3r, t6r);
    s5r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t8r), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t9r));
    s6r = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t8r), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t9r));
    s7r = v_lo2(s5r, s6r);
    s8r = v_hi2(s5r, s6r);
    s9r = _mm_add_pd(s7r, s8r);
    _mm_storeu_pd(((double  *) (dst + 12)), s9r);
    s0s = v_neg23(_mm_sub_pd(s7r, s8r));
    _mm_storeu_pd(((double  *) (dst + 116)), s0s);
    s1s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t2s), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t3s));
    s2s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t2s), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t3s));
    s3s = v_lo2(s1s, s2s);
    s4s = v_hi2(s1s, s2s);
    s5s = _mm_add_pd(s3s, s4s);
    _mm_storeu_pd(((double  *) (dst + 44)), s5s);
    s6s = v_neg23(_mm_sub_pd(s3s, s4s));
    _mm_storeu_pd(((double  *) (dst + 84)), s6s);
    s7s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 1.0), t0s), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t1s));
    s8s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t0s), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 1.0), t1s));
    s9s = v_lo2(s7s, s8s);
    s0t = v_hi2(s7s, s8s);
    s1t = _mm_add_pd(s9s, s0t);
    _mm_storeu_pd(((double  *) (dst + 76)), s1t);
    s2t = v_neg23(_mm_sub_pd(s9s, s0t));
    _mm_storeu_pd(((double  *) (dst + 52)), s2t);
    s3t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 1.0), t4s), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t5s));
    s4t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t4s), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 1.0), t5s));
    s5t = v_lo2(s3t, s4t);
    s6t = v_hi2(s3t, s4t);
    s7t = _mm_add_pd(s5t, s6t);
    _mm_storeu_pd(((double  *) (dst + 108)), s7t);
    s8t = v_neg23(_mm_sub_pd(s5t, s6t));
    _mm_storeu_pd(((double  *) (dst + 20)), s8t);
    s9t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t38), _mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t48));
    s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t38), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t48));
    s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5c), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t6c));
    s2u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t5c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6c));
    s3u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9g), _mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t0h));
    s4u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t9g), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0h));
    t6s = _mm_add_pd(t93, s1u);
    t7s = _mm_sub_pd(s2u, t04);
    t8s = _mm_sub_pd(t93, s1u);
    t9s = _mm_add_pd(t04, s2u);
    t0t = _mm_add_pd(s9t, s3u);
    t1t = _mm_add_pd(s0u, s4u);
    t2t = _mm_sub_pd(s9t, s3u);
    t3t = _mm_sub_pd(s0u, s4u);
    t4t = _mm_add_pd(t6s, t0t);
    t5t = _mm_add_pd(t7s, t1t);
    t6t = _mm_sub_pd(t6s, t0t);
    t7t = _mm_sub_pd(t7s, t1t);
    t8t = _mm_add_pd(t8s, t3t);
    t9t = _mm_add_pd(t9s, t2t);
    t0u = _mm_sub_pd(t8s, t3t);
    t1u = _mm_sub_pd(t2t, t9s);
    s5u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94154406518302081, 1.0), t4t), _mm_mul_pd(_mm_set_pd((-0.33688985339222005), 0.0), t5t));
    s6u = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.33688985339222005), 0.0), t4t), _mm_mul_pd(_mm_set_pd(0.94154406518302081, 1.0), t5t));
    s7u = v_lo2(s5u, s6u);
    s8u = v_hi2(s5u, s6u);
    s9u = _mm_add_pd(s7u, s8u);
    _mm_storeu_pd(((double  *) (dst + 14)), s9u);
    s0v = v_neg23(_mm_sub_pd(s7u, s8u));
    _mm_storeu_pd(((double  *) (dst + 114)), s0v);
    s1v = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.42755509343028208, 1.0), t8t), _mm_mul_pd(_mm_set_pd((-0.90398929312344334), 0.0), t9t));
    s2v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.90398929312344334), 0.0), t8t), _mm_mul_pd(_mm_set_pd(0.42755509343028208, 1.0), t9t));
    s3v = v_lo2(s1v, s2v);
    s4v = v_hi2(s1v, s2v);
    s5v = _mm_add_pd(s3v, s4v);
    _mm_storeu_pd(((double  *) (dst + 46)), s5v);
    s6v = v_neg23(_mm_sub_pd(s3v, s4v));
    _mm_storeu_pd(((double  *) (dst + 82)), s6v);
    s7v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.33688985339222005), 1.0), t6t), _mm_mul_pd(_mm_set_pd((-0.94154406518302081), 0.0), t7t));
    s8v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.94154406518302081), 0.0), t6t), _mm_mul_pd(_mm_set_pd((-0.33688985339222005), 1.0), t7t));
    s9v = v_lo2(s7v, s8v);
    s0w = v_hi2(s7v, s8v);
    s1w = _mm_add_pd(s9v, s0w);
    _mm_storeu_pd(((double  *) (dst + 78)), s1w);
    s2w = v_neg23(_mm_sub_pd(s9v, s0w));
    _mm_storeu_pd(((double  *) (dst + 50)), s2w);
    s3w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.90398929312344334), 1.0), t0u), _mm_mul_pd(_mm_set_pd((-0.42755509343028208), 0.0), t1u));
    s4w = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.42755509343028208), 0.0), t0u), _mm_mul_pd(_mm_set_pd((-0.90398929312344334), 1.0), t1u));
    s5w = v_lo2(s3w, s4w);
    s6w = v_hi2(s3w, s4w);
    s7w = _mm_add_pd(s5w, s6w);
    _mm_storeu_pd(((double  *) (dst + 110)), s7w);
    s8w = v_neg23(_mm_sub_pd(s5w, s6w));
    _mm_storeu_pd(((double  *) (dst + 18)), s8w);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_128)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_128_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a01, a02, a11, a12, a2, a21, a22, a3, a31, a4, a41, a5, a51, a6, a61, a7, a71, a8, a9, a91, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n
            , s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d
            , s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s2, s21, s22
            , s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d
            , s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s4, s41, s42
            , s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o
            , s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d
            , s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s6, s61, s62
            , s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o
            , s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s8, s81, s82
            , s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o
            , s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d
            , s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, t, t01, t02, t03
            , t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p
            , t0q, t0r, t0s, t0t, t0u, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h
            , t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s, t1t, t1u, t2, t21, t22, t23, t24, t25, t26, t27, t28
            , t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t3
            , t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m
            , t3n, t3o, t3p, t3q, t3r, t3s, t3t, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e
            , t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t5, t51, t52, t53, t54, t55, t56
            , t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s
            , t5t, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k
            , t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q
            , t8r, t8s, t8t, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i
            , t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t;
    __m128d  *a, *a81;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = *((a + 32));
    t = _mm_add_pd(s, s2);
    t2 = _mm_sub_pd(s, s2);
    s3 = *((a + 16));
    s4 = *((a + 48));
    t3 = _mm_add_pd(s3, s4);
    t4 = _mm_sub_pd(s3, s4);
    s5 = *((a + 4));
    s6 = *((a + 36));
    t5 = _mm_add_pd(s5, s6);
    t6 = _mm_sub_pd(s5, s6);
    s7 = *((a + 20));
    s8 = *((a + 52));
    t7 = _mm_add_pd(s7, s8);
    t8 = _mm_sub_pd(s7, s8);
    s9 = *((a + 8));
    s01 = *((a + 40));
    t9 = _mm_add_pd(s9, s01);
    s11 = *((a + 24));
    s21 = *((a + 56));
    t01 = _mm_add_pd(s11, s21);
    s31 = *((a + 12));
    s41 = *((a + 44));
    t11 = _mm_add_pd(s31, s41);
    t21 = _mm_sub_pd(s31, s41);
    s51 = *((a + 28));
    s61 = *((a + 60));
    t31 = _mm_add_pd(s51, s61);
    t41 = _mm_sub_pd(s51, s61);
    t51 = _mm_add_pd(t, t3);
    t61 = _mm_sub_pd(t, t3);
    t71 = _mm_add_pd(t9, t01);
    t81 = _mm_sub_pd(t9, t01);
    t91 = _mm_add_pd(t5, t7);
    t02 = _mm_add_pd(t11, t31);
    t12 = _mm_add_pd(t51, t71);
    t22 = _mm_sub_pd(t51, t71);
    t32 = _mm_add_pd(t91, t02);
    t42 = _mm_sub_pd(t91, t02);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
    a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
    s71 = _mm_add_pd(a2, a3);
    s81 = _mm_sub_pd(a3, a2);
    t52 = _mm_add_pd(t61, s71);
    t62 = _mm_sub_pd(s81, t81);
    t72 = _mm_sub_pd(t61, s71);
    t82 = _mm_add_pd(t81, s81);
    s91 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
    a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
    s12 = _mm_add_pd(a4, a5);
    s22 = _mm_sub_pd(a5, a4);
    s32 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
    s42 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
    t92 = _mm_add_pd(t2, s12);
    t03 = _mm_sub_pd(s22, t4);
    t13 = _mm_sub_pd(t2, s12);
    t23 = _mm_add_pd(t4, s22);
    t33 = _mm_add_pd(s91, s32);
    t43 = _mm_add_pd(s02, s42);
    t53 = _mm_sub_pd(s91, s32);
    t63 = _mm_sub_pd(s02, s42);
    t73 = _mm_add_pd(t92, t33);
    t83 = _mm_add_pd(t03, t43);
    t93 = _mm_sub_pd(t92, t33);
    t04 = _mm_sub_pd(t03, t43);
    t14 = _mm_add_pd(t13, t63);
    t24 = _mm_add_pd(t23, t53);
    t34 = _mm_sub_pd(t13, t63);
    t44 = _mm_sub_pd(t53, t23);
    s52 = *((a + 1));
    s62 = *((a + 33));
    t54 = _mm_add_pd(s52, s62);
    t64 = _mm_sub_pd(s52, s62);
    s72 = *((a + 17));
    s82 = *((a + 49));
    t74 = _mm_add_pd(s72, s82);
    t84 = _mm_sub_pd(s72, s82);
    s92 = *((a + 5));
    s03 = *((a + 37));
    t94 = _mm_add_pd(s92, s03);
    t05 = _mm_sub_pd(s92, s03);
    s13 = *((a + 21));
    s23 = *((a + 53));
    t15 = _mm_add_pd(s13, s23);
    t25 = _mm_sub_pd(s13, s23);
    s33 = *((a + 9));
    s43 = *((a + 41));
    t35 = _mm_add_pd(s33, s43);
    s53 = *((a + 25));
    s63 = *((a + 57));
    t45 = _mm_add_pd(s53, s63);
    s73 = *((a + 13));
    s83 = *((a + 45));
    t55 = _mm_add_pd(s73, s83);
    t65 = _mm_sub_pd(s73, s83);
    s93 = *((a + 29));
    s04 = *((a + 61));
    t75 = _mm_add_pd(s93, s04);
    t85 = _mm_sub_pd(s93, s04);
    t95 = _mm_add_pd(t54, t74);
    t06 = _mm_sub_pd(t54, t74);
    t16 = _mm_add_pd(t35, t45);
    t26 = _mm_sub_pd(t35, t45);
    t36 = _mm_add_pd(t94, t15);
    t46 = _mm_add_pd(t55, t75);
    t56 = _mm_add_pd(t95, t16);
    t66 = _mm_sub_pd(t95, t16);
    t76 = _mm_add_pd(t36, t46);
    t86 = _mm_sub_pd(t36, t46);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
    a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t55, t75));
    s14 = _mm_add_pd(a6, a7);
    s24 = _mm_sub_pd(a7, a6);
    t96 = _mm_add_pd(t06, s14);
    t07 = _mm_sub_pd(s24, t26);
    t17 = _mm_sub_pd(t06, s14);
    t27 = _mm_add_pd(t26, s24);
    s34 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
    s54 = _mm_add_pd(a8, a9);
    s64 = _mm_sub_pd(a9, a8);
    s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t85));
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    t37 = _mm_add_pd(t64, s54);
    t47 = _mm_sub_pd(s64, t84);
    t57 = _mm_sub_pd(t64, s54);
    t67 = _mm_add_pd(t84, s64);
    t77 = _mm_add_pd(s34, s74);
    t87 = _mm_add_pd(s44, s84);
    t97 = _mm_sub_pd(s34, s74);
    t08 = _mm_sub_pd(s44, s84);
    t18 = _mm_add_pd(t37, t77);
    t28 = _mm_add_pd(t47, t87);
    t38 = _mm_sub_pd(t37, t77);
    t48 = _mm_sub_pd(t47, t87);
    t58 = _mm_add_pd(t57, t08);
    t68 = _mm_add_pd(t67, t97);
    t78 = _mm_sub_pd(t57, t08);
    t88 = _mm_sub_pd(t97, t67);
    s94 = *((a + 2));
    s05 = *((a + 34));
    t98 = _mm_add_pd(s94, s05);
    t09 = _mm_sub_pd(s94, s05);
    s15 = *((a + 18));
    s25 = *((a + 50));
    t19 = _mm_add_pd(s15, s25);
    t29 = _mm_sub_pd(s15, s25);
    s35 = *((a + 6));
    s45 = *((a + 38));
    t39 = _mm_add_pd(s35, s45);
    t49 = _mm_sub_pd(s35, s45);
    s55 = *((a + 22));
    s65 = *((a + 54));
    t59 = _mm_add_pd(s55, s65);
    t69 = _mm_sub_pd(s55, s65);
    s75 = *((a + 10));
    s85 = *((a + 42));
    t79 = _mm_add_pd(s75, s85);
    s95 = *((a + 26));
    s06 = *((a + 58));
    t89 = _mm_add_pd(s95, s06);
    s16 = *((a + 14));
    s26 = *((a + 46));
    t99 = _mm_add_pd(s16, s26);
    t0a = _mm_sub_pd(s16, s26);
    s36 = *((a + 30));
    s46 = *((a + 62));
    t1a = _mm_add_pd(s36, s46);
    t2a = _mm_sub_pd(s36, s46);
    t3a = _mm_add_pd(t98, t19);
    t4a = _mm_sub_pd(t98, t19);
    t5a = _mm_add_pd(t79, t89);
    t6a = _mm_sub_pd(t79, t89);
    t7a = _mm_add_pd(t39, t59);
    t8a = _mm_add_pd(t99, t1a);
    t9a = _mm_add_pd(t3a, t5a);
    t0b = _mm_add_pd(t7a, t8a);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t39, t59));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t99, t1a));
    s56 = _mm_add_pd(a01, a11);
    s66 = _mm_sub_pd(a11, a01);
    t1b = _mm_add_pd(t4a, s56);
    t2b = _mm_sub_pd(s66, t6a);
    t3b = _mm_sub_pd(t4a, s56);
    t4b = _mm_add_pd(t6a, s66);
    s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t49), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t69));
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t49), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t69));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s75, s85));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s95, s06));
    s96 = _mm_add_pd(a21, a31);
    s07 = _mm_sub_pd(a31, a21);
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0a), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2a));
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2a));
    t5b = _mm_add_pd(t09, s96);
    t6b = _mm_sub_pd(s07, t29);
    t7b = _mm_sub_pd(t09, s96);
    t8b = _mm_add_pd(t29, s07);
    t9b = _mm_add_pd(s76, s17);
    t0c = _mm_add_pd(s86, s27);
    t1c = _mm_sub_pd(s76, s17);
    t2c = _mm_sub_pd(s86, s27);
    t3c = _mm_add_pd(t5b, t9b);
    t4c = _mm_add_pd(t6b, t0c);
    t5c = _mm_sub_pd(t5b, t9b);
    t6c = _mm_sub_pd(t6b, t0c);
    t7c = _mm_add_pd(t7b, t2c);
    t8c = _mm_add_pd(t8b, t1c);
    t9c = _mm_sub_pd(t7b, t2c);
    t0d = _mm_sub_pd(t1c, t8b);
    s37 = *((a + 3));
    s47 = *((a + 35));
    t1d = _mm_add_pd(s37, s47);
    t2d = _mm_sub_pd(s37, s47);
    s57 = *((a + 19));
    s67 = *((a + 51));
    t3d = _mm_add_pd(s57, s67);
    t4d = _mm_sub_pd(s57, s67);
    s77 = *((a + 7));
    s87 = *((a + 39));
    t5d = _mm_add_pd(s77, s87);
    t6d = _mm_sub_pd(s77, s87);
    s97 = *((a + 23));
    s08 = *((a + 55));
    t7d = _mm_add_pd(s97, s08);
    t8d = _mm_sub_pd(s97, s08);
    s18 = *((a + 11));
    s28 = *((a + 43));
    t9d = _mm_add_pd(s18, s28);
    s38 = *((a + 27));
    s48 = *((a + 59));
    t0e = _mm_add_pd(s38, s48);
    s58 = *((a + 15));
    s68 = *((a + 47));
    t1e = _mm_add_pd(s58, s68);
    t2e = _mm_sub_pd(s58, s68);
    s78 = *((a + 31));
    s88 = *((a + 63));
    t3e = _mm_add_pd(s78, s88);
    t4e = _mm_sub_pd(s78, s88);
    t5e = _mm_add_pd(t1d, t3d);
    t6e = _mm_sub_pd(t1d, t3d);
    t7e = _mm_add_pd(t9d, t0e);
    t8e = _mm_sub_pd(t9d, t0e);
    t9e = _mm_add_pd(t5d, t7d);
    t0f = _mm_add_pd(t1e, t3e);
    t1f = _mm_add_pd(t5e, t7e);
    t2f = _mm_sub_pd(t5e, t7e);
    t3f = _mm_add_pd(t9e, t0f);
    t4f = _mm_sub_pd(t9e, t0f);
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t7d));
    a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1e, t3e));
    s98 = _mm_add_pd(a41, a51);
    s09 = _mm_sub_pd(a51, a41);
    t5f = _mm_add_pd(t6e, s98);
    t6f = _mm_sub_pd(s09, t8e);
    t7f = _mm_sub_pd(t6e, s98);
    t8f = _mm_add_pd(t8e, s09);
    s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8d));
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8d));
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s18, s28));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s38, s48));
    s39 = _mm_add_pd(a61, a71);
    s49 = _mm_sub_pd(a71, a61);
    s59 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e));
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4e));
    t9f = _mm_add_pd(t2d, s39);
    t0g = _mm_sub_pd(s49, t4d);
    t1g = _mm_sub_pd(t2d, s39);
    t2g = _mm_add_pd(t4d, s49);
    t3g = _mm_add_pd(s19, s59);
    t4g = _mm_add_pd(s29, s69);
    t5g = _mm_sub_pd(s19, s59);
    t6g = _mm_sub_pd(s29, s69);
    t7g = _mm_add_pd(t9f, t3g);
    t8g = _mm_add_pd(t0g, t4g);
    t9g = _mm_sub_pd(t9f, t3g);
    t0h = _mm_sub_pd(t0g, t4g);
    t1h = _mm_add_pd(t1g, t6g);
    t2h = _mm_add_pd(t2g, t5g);
    t3h = _mm_sub_pd(t1g, t6g);
    t4h = _mm_sub_pd(t5g, t2g);
    t5h = _mm_add_pd(t12, t32);
    t6h = _mm_sub_pd(t12, t32);
    t7h = _mm_add_pd(t9a, t0b);
    t8h = _mm_sub_pd(t9a, t0b);
    t9h = _mm_add_pd(t56, t76);
    t0i = _mm_add_pd(t1f, t3f);
    t1i = _mm_add_pd(t5h, t7h);
    t2i = _mm_sub_pd(t5h, t7h);
    t3i = _mm_add_pd(t9h, t0i);
    t4i = _mm_sub_pd(t9h, t0i);
    t5i = _mm_add_pd(t1i, t3i);
    a81 = ((__m128d  *) dst);
    s79 = _mm_add_pd(v_neg03(v_hi2(t5i, t5i)), v_lo2(t5i, t5i));
    *(a81) = s79;
    s89 = v_neg23(_mm_sub_pd(t1i, t3i));
    *((a81 + 32)) = s89;
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t2i), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t4i));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t2i), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t4i));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    *((a81 + 16)) = s3a;
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    *((a81 + 48)) = s4a;
    a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t76));
    a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1f, t3f));
    s5a = _mm_add_pd(a91, a02);
    s6a = _mm_sub_pd(a02, a91);
    t6i = _mm_add_pd(t6h, s5a);
    t7i = _mm_sub_pd(s6a, t8h);
    t8i = _mm_sub_pd(t6h, s5a);
    t9i = _mm_add_pd(t8h, s6a);
    s7a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t6i), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t7i));
    s8a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t6i), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t7i));
    s9a = v_lo2(s7a, s8a);
    s0b = v_hi2(s7a, s8a);
    s1b = _mm_add_pd(s9a, s0b);
    *((a81 + 8)) = s1b;
    s2b = v_neg23(_mm_sub_pd(s9a, s0b));
    *((a81 + 56)) = s2b;
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t8i), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t9i));
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t8i), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t9i));
    s5b = v_lo2(s3b, s4b);
    s6b = v_hi2(s3b, s4b);
    s7b = _mm_add_pd(s5b, s6b);
    *((a81 + 40)) = s7b;
    s8b = v_neg23(_mm_sub_pd(s5b, s6b));
    *((a81 + 24)) = s8b;
    s9b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t18), _mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t28));
    s0c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t18), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t28));
    s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3c), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4c));
    s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4c));
    s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7g), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t8g));
    s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t7g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8g));
    t0j = _mm_add_pd(t73, s1c);
    t1j = _mm_add_pd(t83, s2c);
    t2j = _mm_sub_pd(t73, s1c);
    t3j = _mm_sub_pd(t83, s2c);
    t4j = _mm_add_pd(s9b, s3c);
    t5j = _mm_add_pd(s0c, s4c);
    t6j = _mm_sub_pd(s9b, s3c);
    t7j = _mm_sub_pd(s0c, s4c);
    t8j = _mm_add_pd(t0j, t4j);
    t9j = _mm_add_pd(t1j, t5j);
    t0k = _mm_sub_pd(t0j, t4j);
    t1k = _mm_sub_pd(t1j, t5j);
    t2k = _mm_add_pd(t2j, t7j);
    t3k = _mm_sub_pd(t3j, t6j);
    t4k = _mm_sub_pd(t2j, t7j);
    t5k = _mm_add_pd(t3j, t6j);
    s5c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99879545620517241, 1.0), t8j), _mm_mul_pd(_mm_set_pd((-0.049067674327418015), 0.0), t9j));
    s6c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.049067674327418015), 0.0), t8j), _mm_mul_pd(_mm_set_pd(0.99879545620517241, 1.0), t9j));
    s7c = v_lo2(s5c, s6c);
    s8c = v_hi2(s5c, s6c);
    s9c = _mm_add_pd(s7c, s8c);
    *((a81 + 1)) = s9c;
    s0d = v_neg23(_mm_sub_pd(s7c, s8c));
    *((a81 + 63)) = s0d;
    s1d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.67155895484701844, 1.0), t2k), _mm_mul_pd(_mm_set_pd((-0.74095112535495911), 0.0), t3k));
    s2d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.74095112535495911), 0.0), t2k), _mm_mul_pd(_mm_set_pd(0.67155895484701844, 1.0), t3k));
    s3d = v_lo2(s1d, s2d);
    s4d = v_hi2(s1d, s2d);
    s5d = _mm_add_pd(s3d, s4d);
    *((a81 + 17)) = s5d;
    s6d = v_neg23(_mm_sub_pd(s3d, s4d));
    *((a81 + 47)) = s6d;
    s7d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.049067674327418015), 1.0), t0k), _mm_mul_pd(_mm_set_pd((-0.99879545620517241), 0.0), t1k));
    s8d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.99879545620517241), 0.0), t0k), _mm_mul_pd(_mm_set_pd((-0.049067674327418015), 1.0), t1k));
    s9d = v_lo2(s7d, s8d);
    s0e = v_hi2(s7d, s8d);
    s1e = _mm_add_pd(s9d, s0e);
    *((a81 + 33)) = s1e;
    s2e = v_neg23(_mm_sub_pd(s9d, s0e));
    *((a81 + 31)) = s2e;
    s3e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.74095112535495911), 1.0), t4k), _mm_mul_pd(_mm_set_pd((-0.67155895484701844), 0.0), t5k));
    s4e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.67155895484701844), 0.0), t4k), _mm_mul_pd(_mm_set_pd((-0.74095112535495911), 1.0), t5k));
    s5e = v_lo2(s3e, s4e);
    s6e = v_hi2(s3e, s4e);
    s7e = _mm_add_pd(s5e, s6e);
    *((a81 + 49)) = s7e;
    s8e = v_neg23(_mm_sub_pd(s5e, s6e));
    *((a81 + 15)) = s8e;
    s9e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t96), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t07));
    s0f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t96), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t07));
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2b));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2b));
    s3f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5f), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6f));
    s4f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5f), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6f));
    t6k = _mm_add_pd(t52, s1f);
    t7k = _mm_add_pd(t62, s2f);
    t8k = _mm_sub_pd(t52, s1f);
    t9k = _mm_sub_pd(t62, s2f);
    t0l = _mm_add_pd(s9e, s3f);
    t1l = _mm_add_pd(s0f, s4f);
    t2l = _mm_sub_pd(s9e, s3f);
    t3l = _mm_sub_pd(s0f, s4f);
    t4l = _mm_add_pd(t6k, t0l);
    t5l = _mm_add_pd(t7k, t1l);
    t6l = _mm_sub_pd(t6k, t0l);
    t7l = _mm_sub_pd(t7k, t1l);
    t8l = _mm_add_pd(t8k, t3l);
    t9l = _mm_sub_pd(t9k, t2l);
    t0m = _mm_sub_pd(t8k, t3l);
    t1m = _mm_add_pd(t9k, t2l);
    s5f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t4l), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t5l));
    s6f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t4l), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t5l));
    s7f = v_lo2(s5f, s6f);
    s8f = v_hi2(s5f, s6f);
    s9f = _mm_add_pd(s7f, s8f);
    *((a81 + 2)) = s9f;
    s0g = v_neg23(_mm_sub_pd(s7f, s8f));
    *((a81 + 62)) = s0g;
    s1g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t8l), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t9l));
    s2g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t8l), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t9l));
    s3g = v_lo2(s1g, s2g);
    s4g = v_hi2(s1g, s2g);
    s5g = _mm_add_pd(s3g, s4g);
    *((a81 + 18)) = s5g;
    s6g = v_neg23(_mm_sub_pd(s3g, s4g));
    *((a81 + 46)) = s6g;
    s7g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 1.0), t6l), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t7l));
    s8g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t6l), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 1.0), t7l));
    s9g = v_lo2(s7g, s8g);
    s0h = v_hi2(s7g, s8g);
    s1h = _mm_add_pd(s9g, s0h);
    *((a81 + 34)) = s1h;
    s2h = v_neg23(_mm_sub_pd(s9g, s0h));
    *((a81 + 30)) = s2h;
    s3h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 1.0), t0m), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t1m));
    s4h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t0m), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 1.0), t1m));
    s5h = v_lo2(s3h, s4h);
    s6h = v_hi2(s3h, s4h);
    s7h = _mm_add_pd(s5h, s6h);
    *((a81 + 50)) = s7h;
    s8h = v_neg23(_mm_sub_pd(s5h, s6h));
    *((a81 + 14)) = s8h;
    s9h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t78), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t88));
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t78), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t88));
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9c), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t0d));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t9c), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0d));
    s3i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3h), _mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t4h));
    s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t3h), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4h));
    t2m = _mm_add_pd(t34, s1i);
    t3m = _mm_sub_pd(s2i, t44);
    t4m = _mm_sub_pd(t34, s1i);
    t5m = _mm_add_pd(t44, s2i);
    t6m = _mm_add_pd(s9h, s3i);
    t7m = _mm_add_pd(s0i, s4i);
    t8m = _mm_sub_pd(s9h, s3i);
    t9m = _mm_sub_pd(s0i, s4i);
    t0n = _mm_add_pd(t2m, t6m);
    t1n = _mm_add_pd(t3m, t7m);
    t2n = _mm_sub_pd(t2m, t6m);
    t3n = _mm_sub_pd(t3m, t7m);
    t4n = _mm_add_pd(t4m, t9m);
    t5n = _mm_add_pd(t5m, t8m);
    t6n = _mm_sub_pd(t4m, t9m);
    t7n = _mm_sub_pd(t8m, t5m);
    s5i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98917650996478101, 1.0), t0n), _mm_mul_pd(_mm_set_pd((-0.14673047445536175), 0.0), t1n));
    s6i = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.14673047445536175), 0.0), t0n), _mm_mul_pd(_mm_set_pd(0.98917650996478101, 1.0), t1n));
    s7i = v_lo2(s5i, s6i);
    s8i = v_hi2(s5i, s6i);
    s9i = _mm_add_pd(s7i, s8i);
    *((a81 + 3)) = s9i;
    s0j = v_neg23(_mm_sub_pd(s7i, s8i));
    *((a81 + 61)) = s0j;
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.59569930449243336, 1.0), t4n), _mm_mul_pd(_mm_set_pd((-0.80320753148064494), 0.0), t5n));
    s2j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.80320753148064494), 0.0), t4n), _mm_mul_pd(_mm_set_pd(0.59569930449243336, 1.0), t5n));
    s3j = v_lo2(s1j, s2j);
    s4j = v_hi2(s1j, s2j);
    s5j = _mm_add_pd(s3j, s4j);
    *((a81 + 19)) = s5j;
    s6j = v_neg23(_mm_sub_pd(s3j, s4j));
    *((a81 + 45)) = s6j;
    s7j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.14673047445536175), 1.0), t2n), _mm_mul_pd(_mm_set_pd((-0.98917650996478101), 0.0), t3n));
    s8j = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98917650996478101), 0.0), t2n), _mm_mul_pd(_mm_set_pd((-0.14673047445536175), 1.0), t3n));
    s9j = v_lo2(s7j, s8j);
    s0k = v_hi2(s7j, s8j);
    s1k = _mm_add_pd(s9j, s0k);
    *((a81 + 35)) = s1k;
    s2k = v_neg23(_mm_sub_pd(s9j, s0k));
    *((a81 + 29)) = s2k;
    s3k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.80320753148064494), 1.0), t6n), _mm_mul_pd(_mm_set_pd((-0.59569930449243336), 0.0), t7n));
    s4k = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.59569930449243336), 0.0), t6n), _mm_mul_pd(_mm_set_pd((-0.80320753148064494), 1.0), t7n));
    s5k = v_lo2(s3k, s4k);
    s6k = v_hi2(s3k, s4k);
    s7k = _mm_add_pd(s5k, s6k);
    *((a81 + 51)) = s7k;
    s8k = v_neg23(_mm_sub_pd(s5k, s6k));
    *((a81 + 13)) = s8k;
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t86));
    s0l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t86));
    a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3a, t5a));
    a22 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7a, t8a));
    s1l = _mm_add_pd(a12, a22);
    s2l = _mm_sub_pd(a22, a12);
    s3l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4f));
    s4l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
    t8n = _mm_add_pd(t22, s1l);
    t9n = _mm_sub_pd(s2l, t42);
    t0o = _mm_sub_pd(t22, s1l);
    t1o = _mm_add_pd(t42, s2l);
    t2o = _mm_add_pd(s9k, s3l);
    t3o = _mm_add_pd(s0l, s4l);
    t4o = _mm_sub_pd(s9k, s3l);
    t5o = _mm_sub_pd(s0l, s4l);
    t6o = _mm_add_pd(t8n, t2o);
    t7o = _mm_add_pd(t9n, t3o);
    t8o = _mm_sub_pd(t8n, t2o);
    t9o = _mm_sub_pd(t9n, t3o);
    t0p = _mm_add_pd(t0o, t5o);
    t1p = _mm_add_pd(t1o, t4o);
    t2p = _mm_sub_pd(t0o, t5o);
    t3p = _mm_sub_pd(t4o, t1o);
    s5l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t6o), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t7o));
    s6l = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t6o), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t7o));
    s7l = v_lo2(s5l, s6l);
    s8l = v_hi2(s5l, s6l);
    s9l = _mm_add_pd(s7l, s8l);
    *((a81 + 4)) = s9l;
    s0m = v_neg23(_mm_sub_pd(s7l, s8l));
    *((a81 + 60)) = s0m;
    s1m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t0p), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t1p));
    s2m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t0p), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t1p));
    s3m = v_lo2(s1m, s2m);
    s4m = v_hi2(s1m, s2m);
    s5m = _mm_add_pd(s3m, s4m);
    *((a81 + 20)) = s5m;
    s6m = v_neg23(_mm_sub_pd(s3m, s4m));
    *((a81 + 44)) = s6m;
    s7m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t8o), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t9o));
    s8m = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t8o), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t9o));
    s9m = v_lo2(s7m, s8m);
    s0n = v_hi2(s7m, s8m);
    s1n = _mm_add_pd(s9m, s0n);
    *((a81 + 36)) = s1n;
    s2n = v_neg23(_mm_sub_pd(s9m, s0n));
    *((a81 + 28)) = s2n;
    s3n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 1.0), t2p), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3p));
    s4n = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t2p), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 1.0), t3p));
    s5n = v_lo2(s3n, s4n);
    s6n = v_hi2(s3n, s4n);
    s7n = _mm_add_pd(s5n, s6n);
    *((a81 + 52)) = s7n;
    s8n = v_neg23(_mm_sub_pd(s5n, s6n));
    *((a81 + 12)) = s8n;
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t58), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t68));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t58), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t68));
    s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7c), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t8c));
    s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t7c), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8c));
    s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1h), _mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t2h));
    s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t1h), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2h));
    t4p = _mm_add_pd(t14, s1o);
    t5p = _mm_sub_pd(s2o, t24);
    t6p = _mm_sub_pd(t14, s1o);
    t7p = _mm_add_pd(t24, s2o);
    t8p = _mm_add_pd(s9n, s3o);
    t9p = _mm_add_pd(s0o, s4o);
    t0q = _mm_sub_pd(s9n, s3o);
    t1q = _mm_sub_pd(s0o, s4o);
    t2q = _mm_add_pd(t4p, t8p);
    t3q = _mm_add_pd(t5p, t9p);
    t4q = _mm_sub_pd(t4p, t8p);
    t5q = _mm_sub_pd(t5p, t9p);
    t6q = _mm_add_pd(t6p, t1q);
    t7q = _mm_add_pd(t7p, t0q);
    t8q = _mm_sub_pd(t6p, t1q);
    t9q = _mm_sub_pd(t0q, t7p);
    s5o = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.97003125319454397, 1.0), t2q), _mm_mul_pd(_mm_set_pd((-0.2429801799032639), 0.0), t3q));
    s6o = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.2429801799032639), 0.0), t2q), _mm_mul_pd(_mm_set_pd(0.97003125319454397, 1.0), t3q));
    s7o = v_lo2(s5o, s6o);
    s8o = v_hi2(s5o, s6o);
    s9o = _mm_add_pd(s7o, s8o);
    *((a81 + 5)) = s9o;
    s0p = v_neg23(_mm_sub_pd(s7o, s8o));
    *((a81 + 59)) = s0p;
    s1p = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.51410274419322177, 1.0), t6q), _mm_mul_pd(_mm_set_pd((-0.85772861000027212), 0.0), t7q));
    s2p = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85772861000027212), 0.0), t6q), _mm_mul_pd(_mm_set_pd(0.51410274419322177, 1.0), t7q));
    s3p = v_lo2(s1p, s2p);
    s4p = v_hi2(s1p, s2p);
    s5p = _mm_add_pd(s3p, s4p);
    *((a81 + 21)) = s5p;
    s6p = v_neg23(_mm_sub_pd(s3p, s4p));
    *((a81 + 43)) = s6p;
    s7p = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.2429801799032639), 1.0), t4q), _mm_mul_pd(_mm_set_pd((-0.97003125319454397), 0.0), t5q));
    s8p = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.97003125319454397), 0.0), t4q), _mm_mul_pd(_mm_set_pd((-0.2429801799032639), 1.0), t5q));
    s9p = v_lo2(s7p, s8p);
    s0q = v_hi2(s7p, s8p);
    s1q = _mm_add_pd(s9p, s0q);
    *((a81 + 37)) = s1q;
    s2q = v_neg23(_mm_sub_pd(s9p, s0q));
    *((a81 + 27)) = s2q;
    s3q = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85772861000027212), 1.0), t8q), _mm_mul_pd(_mm_set_pd((-0.51410274419322177), 0.0), t9q));
    s4q = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.51410274419322177), 0.0), t8q), _mm_mul_pd(_mm_set_pd((-0.85772861000027212), 1.0), t9q));
    s5q = v_lo2(s3q, s4q);
    s6q = v_hi2(s3q, s4q);
    s7q = _mm_add_pd(s5q, s6q);
    *((a81 + 53)) = s7q;
    s8q = v_neg23(_mm_sub_pd(s5q, s6q));
    *((a81 + 11)) = s8q;
    s9q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t17), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t27));
    s0r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t17), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t27));
    s1r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3b), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4b));
    s2r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4b));
    s3r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7f), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8f));
    s4r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7f), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8f));
    t0r = _mm_add_pd(t72, s1r);
    t1r = _mm_add_pd(t82, s2r);
    t2r = _mm_sub_pd(t72, s1r);
    t3r = _mm_sub_pd(t82, s2r);
    t4r = _mm_add_pd(s9q, s3r);
    t5r = _mm_add_pd(s0r, s4r);
    t6r = _mm_sub_pd(s9q, s3r);
    t7r = _mm_sub_pd(s0r, s4r);
    t8r = _mm_add_pd(t0r, t4r);
    t9r = _mm_add_pd(t1r, t5r);
    t0s = _mm_sub_pd(t0r, t4r);
    t1s = _mm_sub_pd(t1r, t5r);
    t2s = _mm_add_pd(t2r, t7r);
    t3s = _mm_sub_pd(t3r, t6r);
    t4s = _mm_sub_pd(t2r, t7r);
    t5s = _mm_add_pd(t3r, t6r);
    s5r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t8r), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t9r));
    s6r = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t8r), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t9r));
    s7r = v_lo2(s5r, s6r);
    s8r = v_hi2(s5r, s6r);
    s9r = _mm_add_pd(s7r, s8r);
    *((a81 + 6)) = s9r;
    s0s = v_neg23(_mm_sub_pd(s7r, s8r));
    *((a81 + 58)) = s0s;
    s1s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t2s), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t3s));
    s2s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t2s), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t3s));
    s3s = v_lo2(s1s, s2s);
    s4s = v_hi2(s1s, s2s);
    s5s = _mm_add_pd(s3s, s4s);
    *((a81 + 22)) = s5s;
    s6s = v_neg23(_mm_sub_pd(s3s, s4s));
    *((a81 + 42)) = s6s;
    s7s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 1.0), t0s), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t1s));
    s8s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t0s), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 1.0), t1s));
    s9s = v_lo2(s7s, s8s);
    s0t = v_hi2(s7s, s8s);
    s1t = _mm_add_pd(s9s, s0t);
    *((a81 + 38)) = s1t;
    s2t = v_neg23(_mm_sub_pd(s9s, s0t));
    *((a81 + 26)) = s2t;
    s3t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 1.0), t4s), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t5s));
    s4t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t4s), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 1.0), t5s));
    s5t = v_lo2(s3t, s4t);
    s6t = v_hi2(s3t, s4t);
    s7t = _mm_add_pd(s5t, s6t);
    *((a81 + 54)) = s7t;
    s8t = v_neg23(_mm_sub_pd(s5t, s6t));
    *((a81 + 10)) = s8t;
    s9t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t38), _mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t48));
    s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t38), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t48));
    s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5c), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t6c));
    s2u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t5c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6c));
    s3u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9g), _mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t0h));
    s4u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t9g), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0h));
    t6s = _mm_add_pd(t93, s1u);
    t7s = _mm_sub_pd(s2u, t04);
    t8s = _mm_sub_pd(t93, s1u);
    t9s = _mm_add_pd(t04, s2u);
    t0t = _mm_add_pd(s9t, s3u);
    t1t = _mm_add_pd(s0u, s4u);
    t2t = _mm_sub_pd(s9t, s3u);
    t3t = _mm_sub_pd(s0u, s4u);
    t4t = _mm_add_pd(t6s, t0t);
    t5t = _mm_add_pd(t7s, t1t);
    t6t = _mm_sub_pd(t6s, t0t);
    t7t = _mm_sub_pd(t7s, t1t);
    t8t = _mm_add_pd(t8s, t3t);
    t9t = _mm_add_pd(t9s, t2t);
    t0u = _mm_sub_pd(t8s, t3t);
    t1u = _mm_sub_pd(t2t, t9s);
    s5u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94154406518302081, 1.0), t4t), _mm_mul_pd(_mm_set_pd((-0.33688985339222005), 0.0), t5t));
    s6u = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.33688985339222005), 0.0), t4t), _mm_mul_pd(_mm_set_pd(0.94154406518302081, 1.0), t5t));
    s7u = v_lo2(s5u, s6u);
    s8u = v_hi2(s5u, s6u);
    s9u = _mm_add_pd(s7u, s8u);
    *((a81 + 7)) = s9u;
    s0v = v_neg23(_mm_sub_pd(s7u, s8u));
    *((a81 + 57)) = s0v;
    s1v = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.42755509343028208, 1.0), t8t), _mm_mul_pd(_mm_set_pd((-0.90398929312344334), 0.0), t9t));
    s2v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.90398929312344334), 0.0), t8t), _mm_mul_pd(_mm_set_pd(0.42755509343028208, 1.0), t9t));
    s3v = v_lo2(s1v, s2v);
    s4v = v_hi2(s1v, s2v);
    s5v = _mm_add_pd(s3v, s4v);
    *((a81 + 23)) = s5v;
    s6v = v_neg23(_mm_sub_pd(s3v, s4v));
    *((a81 + 41)) = s6v;
    s7v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.33688985339222005), 1.0), t6t), _mm_mul_pd(_mm_set_pd((-0.94154406518302081), 0.0), t7t));
    s8v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.94154406518302081), 0.0), t6t), _mm_mul_pd(_mm_set_pd((-0.33688985339222005), 1.0), t7t));
    s9v = v_lo2(s7v, s8v);
    s0w = v_hi2(s7v, s8v);
    s1w = _mm_add_pd(s9v, s0w);
    *((a81 + 39)) = s1w;
    s2w = v_neg23(_mm_sub_pd(s9v, s0w));
    *((a81 + 25)) = s2w;
    s3w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.90398929312344334), 1.0), t0u), _mm_mul_pd(_mm_set_pd((-0.42755509343028208), 0.0), t1u));
    s4w = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.42755509343028208), 0.0), t0u), _mm_mul_pd(_mm_set_pd((-0.90398929312344334), 1.0), t1u));
    s5w = v_lo2(s3w, s4w);
    s6w = v_hi2(s3w, s4w);
    s7w = _mm_add_pd(s5w, s6w);
    *((a81 + 55)) = s7w;
    s8w = v_neg23(_mm_sub_pd(s5w, s6w));
    *((a81 + 9)) = s8w;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_256_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[256]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a09, a11, a12, a13, a14, a15, a16, a17, a18, a19, a21, a22, a23, a24
            , a25, a26, a27, a28, a29, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a4, a41, a42, a43, a44, a45, a47
            , a48, a49, a51, a52, a53, a54, a55, a56, a57, a58, a59, a6, a61, a62, a63, a64, a65, a66, a67, a68, a69, a7
            , a71, a72, a73, a74, a75, a77, a78, a79, a8, a82, a83, a84, a85, a86, a87, a88, a9, a92, a93, a94, a95, a96
            , a97, a98, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j
            , s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16
            , s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s
            , s1t, s1u, s1v, s1w, s1x, s1y, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f
            , s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s3, s31, s32
            , s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o
            , s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b
            , s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x
            , s4y, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k
            , s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s6, s61, s62, s63, s64, s65, s66, s67
            , s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t
            , s6u, s6v, s6w, s6x, s6y, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g
            , s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s8, s81, s82, s83
            , s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p
            , s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c
            , s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y
            , t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l
            , t0m, t0n, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k
            , t1l, t1m, t1n, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i
            , t2j, t2k, t2l, t2m, t2n, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g
            , t3h, t3i, t3j, t3k, t3l, t3m, t3n, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e
            , t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t7, t71, t72, t73, t74, t75, t76, t77, t78
            , t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t8, t81, t82, t83, t84, t85, t86
            , t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t9, t91, t92, t93, t94
            , t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n;
    __m128d  *a2, *a46, *a5, *a91, *b2;
    double  *b3, *b4;
    const double  *b;
    int a, a76, a81;
    {long i; for(i = 0; i <= 15; i++) {
        a = (2 * i);
        s = _mm_loadu_pd(((const double  *) (a + src)));
        b = (src + a);
        s2 = _mm_loadu_pd(((const double  *) (b + 128)));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = _mm_loadu_pd(((const double  *) (b + 64)));
        s4 = _mm_loadu_pd(((const double  *) (b + 192)));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = _mm_loadu_pd(((const double  *) (b + 32)));
        s6 = _mm_loadu_pd(((const double  *) (b + 160)));
        t5 = _mm_add_pd(s5, s6);
        s7 = _mm_loadu_pd(((const double  *) (b + 96)));
        s8 = _mm_loadu_pd(((const double  *) (b + 224)));
        t6 = _mm_add_pd(s7, s8);
        a2 = (((__m128d  *) T) + i);
        s9 = _mm_add_pd(t, t3);
        *(a2) = s9;
        s01 = _mm_sub_pd(t, t3);
        *((a2 + 64)) = s01;
        s11 = _mm_add_pd(t5, t6);
        *((a2 + 16)) = s11;
        s21 = _mm_sub_pd(t6, t5);
        *((a2 + 80)) = s21;
        a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
        a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
        s31 = _mm_add_pd(a3, a4);
        s41 = _mm_sub_pd(a4, a3);
        s51 = _mm_add_pd(t2, s31);
        *((a2 + 32)) = s51;
        s61 = _mm_sub_pd(s41, t4);
        *((a2 + 48)) = s61;
        s71 = _mm_sub_pd(t2, s31);
        *((a2 + 96)) = s71;
        s81 = _mm_add_pd(t4, s41);
        *((a2 + 112)) = s81;
    }}
    a5 = ((__m128d  *) T);
    s91 = *(a5);
    s02 = *((a5 + 16));
    t7 = _mm_add_pd(s91, s02);
    t8 = _mm_sub_pd(s91, s02);
    s12 = *((a5 + 8));
    s22 = *((a5 + 24));
    t9 = _mm_add_pd(s12, s22);
    t01 = _mm_sub_pd(s12, s22);
    s32 = *((a5 + 4));
    s42 = *((a5 + 20));
    t11 = _mm_add_pd(s32, s42);
    s52 = *((a5 + 12));
    s62 = *((a5 + 28));
    t21 = _mm_add_pd(s52, s62);
    t31 = _mm_add_pd(t7, t9);
    t41 = _mm_sub_pd(t7, t9);
    t51 = _mm_add_pd(t11, t21);
    t61 = _mm_sub_pd(t11, t21);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s32, s42));
    a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s52, s62));
    s72 = _mm_add_pd(a6, a7);
    s82 = _mm_sub_pd(a7, a6);
    t71 = _mm_add_pd(t8, s72);
    t81 = _mm_sub_pd(s82, t01);
    t91 = _mm_sub_pd(t8, s72);
    t02 = _mm_add_pd(t01, s82);
    s92 = *((a5 + 1));
    s03 = *((a5 + 17));
    t12 = _mm_add_pd(s92, s03);
    t22 = _mm_sub_pd(s92, s03);
    s13 = *((a5 + 9));
    s23 = *((a5 + 25));
    t32 = _mm_add_pd(s13, s23);
    t42 = _mm_sub_pd(s13, s23);
    s33 = *((a5 + 5));
    s43 = *((a5 + 21));
    t52 = _mm_add_pd(s33, s43);
    s53 = *((a5 + 13));
    s63 = *((a5 + 29));
    t62 = _mm_add_pd(s53, s63);
    t72 = _mm_add_pd(t12, t32);
    t82 = _mm_sub_pd(t12, t32);
    t92 = _mm_add_pd(t52, t62);
    t03 = _mm_sub_pd(t52, t62);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
    s73 = _mm_add_pd(a8, a9);
    s83 = _mm_sub_pd(a9, a8);
    t13 = _mm_add_pd(t22, s73);
    t23 = _mm_sub_pd(s83, t42);
    t33 = _mm_sub_pd(t22, s73);
    t43 = _mm_add_pd(t42, s83);
    s93 = *((a5 + 2));
    s04 = *((a5 + 18));
    t53 = _mm_add_pd(s93, s04);
    t63 = _mm_sub_pd(s93, s04);
    s14 = *((a5 + 10));
    s24 = *((a5 + 26));
    t73 = _mm_add_pd(s14, s24);
    t83 = _mm_sub_pd(s14, s24);
    s34 = *((a5 + 6));
    s44 = *((a5 + 22));
    t93 = _mm_add_pd(s34, s44);
    s54 = *((a5 + 14));
    s64 = *((a5 + 30));
    t04 = _mm_add_pd(s54, s64);
    t14 = _mm_add_pd(t53, t73);
    t24 = _mm_add_pd(t93, t04);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s34, s44));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s54, s64));
    s74 = _mm_add_pd(a01, a11);
    s84 = _mm_sub_pd(a11, a01);
    t34 = _mm_add_pd(t63, s74);
    t44 = _mm_sub_pd(s84, t83);
    t54 = _mm_sub_pd(t63, s74);
    t64 = _mm_add_pd(t83, s84);
    s94 = *((a5 + 3));
    s05 = *((a5 + 19));
    t74 = _mm_add_pd(s94, s05);
    t84 = _mm_sub_pd(s94, s05);
    s15 = *((a5 + 11));
    s25 = *((a5 + 27));
    t94 = _mm_add_pd(s15, s25);
    t05 = _mm_sub_pd(s15, s25);
    s35 = *((a5 + 7));
    s45 = *((a5 + 23));
    t15 = _mm_add_pd(s35, s45);
    s55 = *((a5 + 15));
    s65 = *((a5 + 31));
    t25 = _mm_add_pd(s55, s65);
    t35 = _mm_add_pd(t74, t94);
    t45 = _mm_sub_pd(t74, t94);
    t55 = _mm_add_pd(t15, t25);
    t65 = _mm_sub_pd(t15, t25);
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s35, s45));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s55, s65));
    s75 = _mm_add_pd(a21, a31);
    s85 = _mm_sub_pd(a31, a21);
    t75 = _mm_add_pd(t84, s75);
    t85 = _mm_sub_pd(s85, t05);
    t95 = _mm_sub_pd(t84, s75);
    t06 = _mm_add_pd(t05, s85);
    t16 = _mm_add_pd(t31, t51);
    t26 = _mm_sub_pd(t31, t51);
    t36 = _mm_add_pd(t14, t24);
    t46 = _mm_sub_pd(t14, t24);
    t56 = _mm_add_pd(t72, t92);
    t66 = _mm_add_pd(t35, t55);
    t76 = _mm_add_pd(t16, t36);
    t86 = _mm_sub_pd(t16, t36);
    t96 = _mm_add_pd(t56, t66);
    t07 = _mm_sub_pd(t56, t66);
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t72, t92));
    a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t35, t55));
    s95 = _mm_add_pd(a41, a51);
    s06 = _mm_sub_pd(a51, a41);
    t17 = _mm_add_pd(t26, s95);
    t27 = _mm_sub_pd(s06, t46);
    t37 = _mm_sub_pd(t26, s95);
    t47 = _mm_add_pd(t46, s06);
    s16 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t13), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t23));
    s26 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t13), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t23));
    s36 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t44));
    s46 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s56 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t75), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t85));
    s66 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t75), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t85));
    t57 = _mm_add_pd(t71, s36);
    t67 = _mm_add_pd(t81, s46);
    t77 = _mm_sub_pd(t71, s36);
    t87 = _mm_sub_pd(t81, s46);
    t97 = _mm_add_pd(s16, s56);
    t08 = _mm_add_pd(s26, s66);
    t18 = _mm_sub_pd(s16, s56);
    t28 = _mm_sub_pd(s26, s66);
    t38 = _mm_add_pd(t57, t97);
    t48 = _mm_add_pd(t67, t08);
    t58 = _mm_sub_pd(t57, t97);
    t68 = _mm_sub_pd(t67, t08);
    t78 = _mm_add_pd(t77, t28);
    t88 = _mm_sub_pd(t87, t18);
    t98 = _mm_sub_pd(t77, t28);
    t09 = _mm_add_pd(t87, t18);
    s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t82), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t03));
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t82), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t03));
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t53, t73));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t93, t04));
    s96 = _mm_add_pd(a61, a71);
    s07 = _mm_sub_pd(a71, a61);
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t45), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65));
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t45), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65));
    t19 = _mm_add_pd(t41, s96);
    t29 = _mm_sub_pd(s07, t61);
    t39 = _mm_sub_pd(t41, s96);
    t49 = _mm_add_pd(t61, s07);
    t59 = _mm_add_pd(s76, s17);
    t69 = _mm_add_pd(s86, s27);
    t79 = _mm_sub_pd(s76, s17);
    t89 = _mm_sub_pd(s86, s27);
    t99 = _mm_add_pd(t19, t59);
    t0a = _mm_add_pd(t29, t69);
    t1a = _mm_sub_pd(t19, t59);
    t2a = _mm_sub_pd(t29, t69);
    t3a = _mm_add_pd(t39, t89);
    t4a = _mm_add_pd(t49, t79);
    t5a = _mm_sub_pd(t39, t89);
    t6a = _mm_sub_pd(t79, t49);
    s37 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t33), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t43));
    s47 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t33), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t43));
    s57 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t54), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t64));
    s67 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t54), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t64));
    s77 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t95), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t06));
    s87 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t95), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t06));
    t7a = _mm_add_pd(t91, s57);
    t8a = _mm_add_pd(t02, s67);
    t9a = _mm_sub_pd(t91, s57);
    t0b = _mm_sub_pd(t02, s67);
    t1b = _mm_add_pd(s37, s77);
    t2b = _mm_add_pd(s47, s87);
    t3b = _mm_sub_pd(s37, s77);
    t4b = _mm_sub_pd(s47, s87);
    t5b = _mm_add_pd(t7a, t1b);
    t6b = _mm_add_pd(t8a, t2b);
    t7b = _mm_sub_pd(t7a, t1b);
    t8b = _mm_sub_pd(t8a, t2b);
    t9b = _mm_add_pd(t9a, t4b);
    t0c = _mm_sub_pd(t0b, t3b);
    t1c = _mm_sub_pd(t9a, t4b);
    t2c = _mm_add_pd(t0b, t3b);
    t3c = _mm_add_pd(t76, t96);
    s97 = _mm_add_pd(v_neg03(v_hi2(t3c, t3c)), v_lo2(t3c, t3c));
    _mm_storeu_pd(((double  *) dst), s97);
    s08 = v_neg23(_mm_sub_pd(t76, t96));
    _mm_storeu_pd(((double  *) (dst + 128)), s08);
    s18 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t38), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t48));
    s28 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t38), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t48));
    s38 = v_lo2(s18, s28);
    s48 = v_hi2(s18, s28);
    s58 = _mm_add_pd(s38, s48);
    _mm_storeu_pd(((double  *) (dst + 8)), s58);
    s68 = v_neg23(_mm_sub_pd(s38, s48));
    _mm_storeu_pd(((double  *) (dst + 248)), s68);
    s78 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t99), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t0a));
    s88 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t99), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t0a));
    s98 = v_lo2(s78, s88);
    s09 = v_hi2(s78, s88);
    s19 = _mm_add_pd(s98, s09);
    _mm_storeu_pd(((double  *) (dst + 16)), s19);
    s29 = v_neg23(_mm_sub_pd(s98, s09));
    _mm_storeu_pd(((double  *) (dst + 240)), s29);
    s39 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t5b), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t6b));
    s49 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t5b), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t6b));
    s59 = v_lo2(s39, s49);
    s69 = v_hi2(s39, s49);
    s79 = _mm_add_pd(s59, s69);
    _mm_storeu_pd(((double  *) (dst + 24)), s79);
    s89 = v_neg23(_mm_sub_pd(s59, s69));
    _mm_storeu_pd(((double  *) (dst + 232)), s89);
    s99 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t17), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t27));
    s0a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t17), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t27));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    _mm_storeu_pd(((double  *) (dst + 32)), s3a);
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    _mm_storeu_pd(((double  *) (dst + 224)), s4a);
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t1c), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t2c));
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t1c), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t2c));
    s7a = v_lo2(s5a, s6a);
    s8a = v_hi2(s5a, s6a);
    s9a = _mm_add_pd(s7a, s8a);
    _mm_storeu_pd(((double  *) (dst + 40)), s9a);
    s0b = v_neg23(_mm_sub_pd(s7a, s8a));
    _mm_storeu_pd(((double  *) (dst + 216)), s0b);
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t5a), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6a));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t5a), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6a));
    s3b = v_lo2(s1b, s2b);
    s4b = v_hi2(s1b, s2b);
    s5b = _mm_add_pd(s3b, s4b);
    _mm_storeu_pd(((double  *) (dst + 48)), s5b);
    s6b = v_neg23(_mm_sub_pd(s3b, s4b));
    _mm_storeu_pd(((double  *) (dst + 208)), s6b);
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t98), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t09));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t98), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t09));
    s9b = v_lo2(s7b, s8b);
    s0c = v_hi2(s7b, s8b);
    s1c = _mm_add_pd(s9b, s0c);
    _mm_storeu_pd(((double  *) (dst + 56)), s1c);
    s2c = v_neg23(_mm_sub_pd(s9b, s0c));
    _mm_storeu_pd(((double  *) (dst + 200)), s2c);
    s3c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t86), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t07));
    s4c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t86), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t07));
    s5c = v_lo2(s3c, s4c);
    s6c = v_hi2(s3c, s4c);
    s7c = _mm_add_pd(s5c, s6c);
    _mm_storeu_pd(((double  *) (dst + 64)), s7c);
    s8c = v_neg23(_mm_sub_pd(s5c, s6c));
    _mm_storeu_pd(((double  *) (dst + 192)), s8c);
    s9c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t78), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t88));
    s0d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t78), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t88));
    s1d = v_lo2(s9c, s0d);
    s2d = v_hi2(s9c, s0d);
    s3d = _mm_add_pd(s1d, s2d);
    _mm_storeu_pd(((double  *) (dst + 72)), s3d);
    s4d = v_neg23(_mm_sub_pd(s1d, s2d));
    _mm_storeu_pd(((double  *) (dst + 184)), s4d);
    s5d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t3a), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4a));
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t3a), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t4a));
    s7d = v_lo2(s5d, s6d);
    s8d = v_hi2(s5d, s6d);
    s9d = _mm_add_pd(s7d, s8d);
    _mm_storeu_pd(((double  *) (dst + 80)), s9d);
    s0e = v_neg23(_mm_sub_pd(s7d, s8d));
    _mm_storeu_pd(((double  *) (dst + 176)), s0e);
    s1e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t9b), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t0c));
    s2e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t9b), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t0c));
    s3e = v_lo2(s1e, s2e);
    s4e = v_hi2(s1e, s2e);
    s5e = _mm_add_pd(s3e, s4e);
    _mm_storeu_pd(((double  *) (dst + 88)), s5e);
    s6e = v_neg23(_mm_sub_pd(s3e, s4e));
    _mm_storeu_pd(((double  *) (dst + 168)), s6e);
    s7e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t37), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t47));
    s8e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t37), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t47));
    s9e = v_lo2(s7e, s8e);
    s0f = v_hi2(s7e, s8e);
    s1f = _mm_add_pd(s9e, s0f);
    _mm_storeu_pd(((double  *) (dst + 96)), s1f);
    s2f = v_neg23(_mm_sub_pd(s9e, s0f));
    _mm_storeu_pd(((double  *) (dst + 160)), s2f);
    s3f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t7b), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t8b));
    s4f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t7b), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t8b));
    s5f = v_lo2(s3f, s4f);
    s6f = v_hi2(s3f, s4f);
    s7f = _mm_add_pd(s5f, s6f);
    _mm_storeu_pd(((double  *) (dst + 104)), s7f);
    s8f = v_neg23(_mm_sub_pd(s5f, s6f));
    _mm_storeu_pd(((double  *) (dst + 152)), s8f);
    s9f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t1a), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t2a));
    s0g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1a), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t2a));
    s1g = v_lo2(s9f, s0g);
    s2g = v_hi2(s9f, s0g);
    s3g = _mm_add_pd(s1g, s2g);
    _mm_storeu_pd(((double  *) (dst + 112)), s3g);
    s4g = v_neg23(_mm_sub_pd(s1g, s2g));
    _mm_storeu_pd(((double  *) (dst + 144)), s4g);
    s5g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t58), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t68));
    s6g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t58), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t68));
    s7g = v_lo2(s5g, s6g);
    s8g = v_hi2(s5g, s6g);
    s9g = _mm_add_pd(s7g, s8g);
    _mm_storeu_pd(((double  *) (dst + 120)), s9g);
    s0h = v_neg23(_mm_sub_pd(s7g, s8g));
    _mm_storeu_pd(((double  *) (dst + 136)), s0h);
    {long i2; for(i2 = 0; i2 <= 2; i2++) {
        a81 = (32 * i2);
        b2 = (((__m128d  *) T) + a81);
        s1h = *((b2 + 32));
        s2h = *((b2 + 48));
        s3h = *((b2 + 33));
        s4h = *((b2 + 49));
        s5h = *((b2 + 34));
        s6h = *((b2 + 50));
        s7h = *((b2 + 35));
        s8h = *((b2 + 51));
        s9h = *((b2 + 36));
        s0i = *((b2 + 52));
        s1i = *((b2 + 37));
        s2i = *((b2 + 53));
        s3i = *((b2 + 38));
        s4i = *((b2 + 54));
        s5i = *((b2 + 39));
        s6i = *((b2 + 55));
        s7i = *((b2 + 40));
        s8i = *((b2 + 56));
        s9i = *((b2 + 41));
        s0j = *((b2 + 57));
        s1j = *((b2 + 42));
        s2j = *((b2 + 58));
        s3j = *((b2 + 43));
        s4j = *((b2 + 59));
        s5j = *((b2 + 44));
        s6j = *((b2 + 60));
        s7j = *((b2 + 45));
        s8j = *((b2 + 61));
        s9j = *((b2 + 46));
        s0k = *((b2 + 62));
        s1k = *((b2 + 47));
        s2k = *((b2 + 63));
        a91 = (D38 + a81);
        a02 = *(a91);
        a12 = *((a91 + 1));
        s3k = _mm_sub_pd(_mm_mul_pd(a02, s1h), _mm_mul_pd(a12, s2h));
        s4k = _mm_add_pd(_mm_mul_pd(a12, s1h), _mm_mul_pd(a02, s2h));
        a22 = *((a91 + 2));
        a32 = *((a91 + 3));
        s5k = _mm_sub_pd(_mm_mul_pd(a22, s3h), _mm_mul_pd(a32, s4h));
        s6k = _mm_add_pd(_mm_mul_pd(a32, s3h), _mm_mul_pd(a22, s4h));
        a42 = *((a91 + 4));
        a52 = *((a91 + 5));
        s7k = _mm_sub_pd(_mm_mul_pd(a42, s5h), _mm_mul_pd(a52, s6h));
        s8k = _mm_add_pd(_mm_mul_pd(a52, s5h), _mm_mul_pd(a42, s6h));
        a62 = *((a91 + 6));
        a72 = *((a91 + 7));
        s9k = _mm_sub_pd(_mm_mul_pd(a62, s7h), _mm_mul_pd(a72, s8h));
        s0l = _mm_add_pd(_mm_mul_pd(a72, s7h), _mm_mul_pd(a62, s8h));
        a82 = *((a91 + 8));
        a92 = *((a91 + 9));
        s1l = _mm_sub_pd(_mm_mul_pd(a82, s9h), _mm_mul_pd(a92, s0i));
        s2l = _mm_add_pd(_mm_mul_pd(a92, s9h), _mm_mul_pd(a82, s0i));
        a03 = *((a91 + 10));
        a13 = *((a91 + 11));
        s3l = _mm_sub_pd(_mm_mul_pd(a03, s1i), _mm_mul_pd(a13, s2i));
        s4l = _mm_add_pd(_mm_mul_pd(a13, s1i), _mm_mul_pd(a03, s2i));
        a23 = *((a91 + 12));
        a33 = *((a91 + 13));
        s5l = _mm_sub_pd(_mm_mul_pd(a23, s3i), _mm_mul_pd(a33, s4i));
        s6l = _mm_add_pd(_mm_mul_pd(a33, s3i), _mm_mul_pd(a23, s4i));
        a43 = *((a91 + 14));
        a53 = *((a91 + 15));
        s7l = _mm_sub_pd(_mm_mul_pd(a43, s5i), _mm_mul_pd(a53, s6i));
        s8l = _mm_add_pd(_mm_mul_pd(a53, s5i), _mm_mul_pd(a43, s6i));
        a63 = *((a91 + 16));
        a73 = *((a91 + 17));
        s9l = _mm_sub_pd(_mm_mul_pd(a63, s7i), _mm_mul_pd(a73, s8i));
        s0m = _mm_add_pd(_mm_mul_pd(a73, s7i), _mm_mul_pd(a63, s8i));
        a83 = *((a91 + 18));
        a93 = *((a91 + 19));
        s1m = _mm_sub_pd(_mm_mul_pd(a83, s9i), _mm_mul_pd(a93, s0j));
        s2m = _mm_add_pd(_mm_mul_pd(a93, s9i), _mm_mul_pd(a83, s0j));
        a04 = *((a91 + 20));
        a14 = *((a91 + 21));
        s3m = _mm_sub_pd(_mm_mul_pd(a04, s1j), _mm_mul_pd(a14, s2j));
        s4m = _mm_add_pd(_mm_mul_pd(a14, s1j), _mm_mul_pd(a04, s2j));
        a24 = *((a91 + 22));
        a34 = *((a91 + 23));
        s5m = _mm_sub_pd(_mm_mul_pd(a24, s3j), _mm_mul_pd(a34, s4j));
        s6m = _mm_add_pd(_mm_mul_pd(a34, s3j), _mm_mul_pd(a24, s4j));
        a44 = *((a91 + 24));
        a54 = *((a91 + 25));
        s7m = _mm_sub_pd(_mm_mul_pd(a44, s5j), _mm_mul_pd(a54, s6j));
        s8m = _mm_add_pd(_mm_mul_pd(a54, s5j), _mm_mul_pd(a44, s6j));
        a64 = *((a91 + 26));
        a74 = *((a91 + 27));
        s9m = _mm_sub_pd(_mm_mul_pd(a64, s7j), _mm_mul_pd(a74, s8j));
        s0n = _mm_add_pd(_mm_mul_pd(a74, s7j), _mm_mul_pd(a64, s8j));
        a84 = *((a91 + 28));
        a94 = *((a91 + 29));
        s1n = _mm_sub_pd(_mm_mul_pd(a84, s9j), _mm_mul_pd(a94, s0k));
        s2n = _mm_add_pd(_mm_mul_pd(a94, s9j), _mm_mul_pd(a84, s0k));
        a05 = *((a91 + 30));
        a15 = *((a91 + 31));
        s3n = _mm_sub_pd(_mm_mul_pd(a05, s1k), _mm_mul_pd(a15, s2k));
        s4n = _mm_add_pd(_mm_mul_pd(a15, s1k), _mm_mul_pd(a05, s2k));
        t4c = _mm_add_pd(s3k, s9l);
        t5c = _mm_add_pd(s4k, s0m);
        t6c = _mm_sub_pd(s3k, s9l);
        t7c = _mm_sub_pd(s4k, s0m);
        t8c = _mm_add_pd(s5k, s1m);
        t9c = _mm_add_pd(s6k, s2m);
        t0d = _mm_sub_pd(s5k, s1m);
        t1d = _mm_sub_pd(s6k, s2m);
        s5n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1d));
        s6n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d));
        t2d = _mm_add_pd(s7k, s3m);
        t3d = _mm_add_pd(s8k, s4m);
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7k, s3m));
        a35 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8k, s4m));
        s7n = _mm_sub_pd(a25, a35);
        s8n = _mm_add_pd(a25, a35);
        t4d = _mm_add_pd(s9k, s5m);
        t5d = _mm_add_pd(s0l, s6m);
        t6d = _mm_sub_pd(s9k, s5m);
        t7d = _mm_sub_pd(s0l, s6m);
        s9n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7d));
        s0o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7d));
        t8d = _mm_add_pd(s1l, s7m);
        t9d = _mm_add_pd(s2l, s8m);
        t0e = _mm_sub_pd(s1l, s7m);
        t1e = _mm_sub_pd(s2l, s8m);
        t2e = _mm_add_pd(s3l, s9m);
        t3e = _mm_add_pd(s4l, s0n);
        t4e = _mm_sub_pd(s3l, s9m);
        t5e = _mm_sub_pd(s4l, s0n);
        s1o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5e));
        s2o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5e));
        t6e = _mm_add_pd(s5l, s1n);
        t7e = _mm_add_pd(s6l, s2n);
        a45 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5l, s1n));
        a55 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s6l, s2n));
        s3o = _mm_sub_pd(a45, a55);
        s4o = _mm_add_pd(a45, a55);
        t8e = _mm_add_pd(s7l, s3n);
        t9e = _mm_add_pd(s8l, s4n);
        t0f = _mm_sub_pd(s7l, s3n);
        t1f = _mm_sub_pd(s8l, s4n);
        s5o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0f), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1f));
        s6o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1f));
        t2f = _mm_add_pd(t4c, t8d);
        t3f = _mm_add_pd(t5c, t9d);
        t4f = _mm_sub_pd(t4c, t8d);
        t5f = _mm_sub_pd(t5c, t9d);
        t6f = _mm_add_pd(t2d, t6e);
        t7f = _mm_add_pd(t3d, t7e);
        t8f = _mm_sub_pd(t2d, t6e);
        t9f = _mm_sub_pd(t3d, t7e);
        t0g = _mm_add_pd(t2f, t6f);
        t1g = _mm_add_pd(t3f, t7f);
        t2g = _mm_sub_pd(t2f, t6f);
        t3g = _mm_sub_pd(t3f, t7f);
        t4g = _mm_add_pd(t4f, t9f);
        t5g = _mm_sub_pd(t5f, t8f);
        t6g = _mm_sub_pd(t4f, t9f);
        t7g = _mm_add_pd(t5f, t8f);
        t8g = _mm_add_pd(t8c, t2e);
        t9g = _mm_add_pd(t9c, t3e);
        t0h = _mm_sub_pd(t8c, t2e);
        t1h = _mm_sub_pd(t9c, t3e);
        t2h = _mm_add_pd(t4d, t8e);
        t3h = _mm_add_pd(t5d, t9e);
        t4h = _mm_sub_pd(t4d, t8e);
        t5h = _mm_sub_pd(t5d, t9e);
        t6h = _mm_add_pd(t8g, t2h);
        t7h = _mm_add_pd(t9g, t3h);
        t8h = _mm_sub_pd(t8g, t2h);
        t9h = _mm_sub_pd(t9g, t3h);
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0h, t5h));
        a75 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1h, t4h));
        s7o = _mm_sub_pd(a65, a75);
        s8o = _mm_add_pd(a65, a75);
        a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0h, t5h));
        a95 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1h, t4h));
        s9o = _mm_sub_pd(a85, a95);
        s0p = _mm_add_pd(a85, a95);
        t0i = _mm_add_pd(t0g, t6h);
        t1i = _mm_add_pd(t1g, t7h);
        t2i = _mm_sub_pd(t0g, t6h);
        t3i = _mm_sub_pd(t1g, t7h);
        t4i = _mm_add_pd(t4g, s7o);
        t5i = _mm_sub_pd(t5g, s8o);
        t6i = _mm_sub_pd(t4g, s7o);
        t7i = _mm_add_pd(t5g, s8o);
        t8i = _mm_add_pd(t2g, t9h);
        t9i = _mm_sub_pd(t3g, t8h);
        t0j = _mm_sub_pd(t2g, t9h);
        t1j = _mm_add_pd(t3g, t8h);
        t2j = _mm_add_pd(t6g, s9o);
        t3j = _mm_add_pd(t7g, s0p);
        t4j = _mm_sub_pd(t6g, s9o);
        t5j = _mm_sub_pd(t7g, s0p);
        t6j = _mm_add_pd(t6c, t1e);
        t7j = _mm_sub_pd(t7c, t0e);
        t8j = _mm_sub_pd(t6c, t1e);
        t9j = _mm_add_pd(t7c, t0e);
        t0k = _mm_add_pd(s7n, s3o);
        t1k = _mm_sub_pd(s4o, s8n);
        t2k = _mm_sub_pd(s7n, s3o);
        t3k = _mm_add_pd(s8n, s4o);
        t4k = _mm_add_pd(t6j, t0k);
        t5k = _mm_add_pd(t7j, t1k);
        t6k = _mm_sub_pd(t6j, t0k);
        t7k = _mm_sub_pd(t7j, t1k);
        t8k = _mm_sub_pd(t8j, t3k);
        t9k = _mm_sub_pd(t9j, t2k);
        t0l = _mm_add_pd(t8j, t3k);
        t1l = _mm_add_pd(t9j, t2k);
        t2l = _mm_add_pd(s5n, s1o);
        t3l = _mm_add_pd(s6n, s2o);
        t4l = _mm_sub_pd(s5n, s1o);
        t5l = _mm_sub_pd(s6n, s2o);
        t6l = _mm_add_pd(s9n, s5o);
        t7l = _mm_add_pd(s0o, s6o);
        t8l = _mm_sub_pd(s9n, s5o);
        t9l = _mm_sub_pd(s0o, s6o);
        t0m = _mm_add_pd(t2l, t6l);
        t1m = _mm_add_pd(t3l, t7l);
        t2m = _mm_sub_pd(t2l, t6l);
        t3m = _mm_sub_pd(t3l, t7l);
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4l, t9l));
        a16 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t8l));
        s1p = _mm_sub_pd(a06, a16);
        s2p = _mm_add_pd(a06, a16);
        a26 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4l, t9l));
        a36 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5l, t8l));
        s3p = _mm_sub_pd(a26, a36);
        s4p = _mm_add_pd(a26, a36);
        t4m = _mm_add_pd(t4k, t0m);
        t5m = _mm_add_pd(t5k, t1m);
        t6m = _mm_sub_pd(t4k, t0m);
        t7m = _mm_sub_pd(t5k, t1m);
        t8m = _mm_add_pd(t8k, s1p);
        t9m = _mm_sub_pd(t9k, s2p);
        t0n = _mm_sub_pd(t8k, s1p);
        t1n = _mm_add_pd(t9k, s2p);
        t2n = _mm_add_pd(t6k, t3m);
        t3n = _mm_sub_pd(t7k, t2m);
        t4n = _mm_sub_pd(t6k, t3m);
        t5n = _mm_add_pd(t7k, t2m);
        t6n = _mm_add_pd(t0l, s3p);
        t7n = _mm_add_pd(t1l, s4p);
        t8n = _mm_sub_pd(t0l, s3p);
        t9n = _mm_sub_pd(t1l, s4p);
        a46 = (D37 + a81);
        a56 = *(a46);
        a66 = *((a46 + 1));
        s5p = _mm_sub_pd(_mm_mul_pd(a56, t0i), _mm_mul_pd(a66, t1i));
        s6p = _mm_add_pd(_mm_mul_pd(a66, t0i), _mm_mul_pd(a56, t1i));
        s7p = v_lo2(s5p, s6p);
        s8p = v_hi2(s5p, s6p);
        a76 = (2 * i2);
        b3 = (dst + a76);
        s9p = _mm_add_pd(s7p, s8p);
        _mm_storeu_pd(((double  *) (b3 + 2)), s9p);
        b4 = (dst - a76);
        s0q = v_neg23(_mm_sub_pd(s7p, s8p));
        _mm_storeu_pd(((double  *) (b4 + 254)), s0q);
        a86 = *((a46 + 2));
        a96 = *((a46 + 3));
        s1q = _mm_sub_pd(_mm_mul_pd(a86, t4m), _mm_mul_pd(a96, t5m));
        s2q = _mm_add_pd(_mm_mul_pd(a96, t4m), _mm_mul_pd(a86, t5m));
        s3q = v_lo2(s1q, s2q);
        s4q = v_hi2(s1q, s2q);
        s5q = _mm_add_pd(s3q, s4q);
        _mm_storeu_pd(((double  *) (b3 + 18)), s5q);
        s6q = v_neg23(_mm_sub_pd(s3q, s4q));
        _mm_storeu_pd(((double  *) (b4 + 238)), s6q);
        a07 = *((a46 + 4));
        a17 = *((a46 + 5));
        s7q = _mm_sub_pd(_mm_mul_pd(a07, t4i), _mm_mul_pd(a17, t5i));
        s8q = _mm_add_pd(_mm_mul_pd(a17, t4i), _mm_mul_pd(a07, t5i));
        s9q = v_lo2(s7q, s8q);
        s0r = v_hi2(s7q, s8q);
        s1r = _mm_add_pd(s9q, s0r);
        _mm_storeu_pd(((double  *) (b3 + 34)), s1r);
        s2r = v_neg23(_mm_sub_pd(s9q, s0r));
        _mm_storeu_pd(((double  *) (b4 + 222)), s2r);
        a27 = *((a46 + 6));
        a37 = *((a46 + 7));
        s3r = _mm_sub_pd(_mm_mul_pd(a27, t8m), _mm_mul_pd(a37, t9m));
        s4r = _mm_add_pd(_mm_mul_pd(a37, t8m), _mm_mul_pd(a27, t9m));
        s5r = v_lo2(s3r, s4r);
        s6r = v_hi2(s3r, s4r);
        s7r = _mm_add_pd(s5r, s6r);
        _mm_storeu_pd(((double  *) (b3 + 50)), s7r);
        s8r = v_neg23(_mm_sub_pd(s5r, s6r));
        _mm_storeu_pd(((double  *) (b4 + 206)), s8r);
        a47 = *((a46 + 8));
        a57 = *((a46 + 9));
        s9r = _mm_sub_pd(_mm_mul_pd(a47, t8i), _mm_mul_pd(a57, t9i));
        s0s = _mm_add_pd(_mm_mul_pd(a57, t8i), _mm_mul_pd(a47, t9i));
        s1s = v_lo2(s9r, s0s);
        s2s = v_hi2(s9r, s0s);
        s3s = _mm_add_pd(s1s, s2s);
        _mm_storeu_pd(((double  *) (b3 + 66)), s3s);
        s4s = v_neg23(_mm_sub_pd(s1s, s2s));
        _mm_storeu_pd(((double  *) (b4 + 190)), s4s);
        a67 = *((a46 + 10));
        a77 = *((a46 + 11));
        s5s = _mm_sub_pd(_mm_mul_pd(a67, t2n), _mm_mul_pd(a77, t3n));
        s6s = _mm_add_pd(_mm_mul_pd(a77, t2n), _mm_mul_pd(a67, t3n));
        s7s = v_lo2(s5s, s6s);
        s8s = v_hi2(s5s, s6s);
        s9s = _mm_add_pd(s7s, s8s);
        _mm_storeu_pd(((double  *) (b3 + 82)), s9s);
        s0t = v_neg23(_mm_sub_pd(s7s, s8s));
        _mm_storeu_pd(((double  *) (b4 + 174)), s0t);
        a87 = *((a46 + 12));
        a97 = *((a46 + 13));
        s1t = _mm_sub_pd(_mm_mul_pd(a87, t2j), _mm_mul_pd(a97, t3j));
        s2t = _mm_add_pd(_mm_mul_pd(a97, t2j), _mm_mul_pd(a87, t3j));
        s3t = v_lo2(s1t, s2t);
        s4t = v_hi2(s1t, s2t);
        s5t = _mm_add_pd(s3t, s4t);
        _mm_storeu_pd(((double  *) (b3 + 98)), s5t);
        s6t = v_neg23(_mm_sub_pd(s3t, s4t));
        _mm_storeu_pd(((double  *) (b4 + 158)), s6t);
        a08 = *((a46 + 14));
        a18 = *((a46 + 15));
        s7t = _mm_sub_pd(_mm_mul_pd(a08, t6n), _mm_mul_pd(a18, t7n));
        s8t = _mm_add_pd(_mm_mul_pd(a18, t6n), _mm_mul_pd(a08, t7n));
        s9t = v_lo2(s7t, s8t);
        s0u = v_hi2(s7t, s8t);
        s1u = _mm_add_pd(s9t, s0u);
        _mm_storeu_pd(((double  *) (b3 + 114)), s1u);
        s2u = v_neg23(_mm_sub_pd(s9t, s0u));
        _mm_storeu_pd(((double  *) (b4 + 142)), s2u);
        a28 = *((a46 + 16));
        a38 = *((a46 + 17));
        s3u = _mm_sub_pd(_mm_mul_pd(a28, t2i), _mm_mul_pd(a38, t3i));
        s4u = _mm_add_pd(_mm_mul_pd(a38, t2i), _mm_mul_pd(a28, t3i));
        s5u = v_lo2(s3u, s4u);
        s6u = v_hi2(s3u, s4u);
        s7u = _mm_add_pd(s5u, s6u);
        _mm_storeu_pd(((double  *) (b3 + 130)), s7u);
        s8u = v_neg23(_mm_sub_pd(s5u, s6u));
        _mm_storeu_pd(((double  *) (b4 + 126)), s8u);
        a48 = *((a46 + 18));
        a58 = *((a46 + 19));
        s9u = _mm_sub_pd(_mm_mul_pd(a48, t6m), _mm_mul_pd(a58, t7m));
        s0v = _mm_add_pd(_mm_mul_pd(a58, t6m), _mm_mul_pd(a48, t7m));
        s1v = v_lo2(s9u, s0v);
        s2v = v_hi2(s9u, s0v);
        s3v = _mm_add_pd(s1v, s2v);
        _mm_storeu_pd(((double  *) (b3 + 146)), s3v);
        s4v = v_neg23(_mm_sub_pd(s1v, s2v));
        _mm_storeu_pd(((double  *) (b4 + 110)), s4v);
        a68 = *((a46 + 20));
        a78 = *((a46 + 21));
        s5v = _mm_sub_pd(_mm_mul_pd(a68, t6i), _mm_mul_pd(a78, t7i));
        s6v = _mm_add_pd(_mm_mul_pd(a78, t6i), _mm_mul_pd(a68, t7i));
        s7v = v_lo2(s5v, s6v);
        s8v = v_hi2(s5v, s6v);
        s9v = _mm_add_pd(s7v, s8v);
        _mm_storeu_pd(((double  *) (b3 + 162)), s9v);
        s0w = v_neg23(_mm_sub_pd(s7v, s8v));
        _mm_storeu_pd(((double  *) (b4 + 94)), s0w);
        a88 = *((a46 + 22));
        a98 = *((a46 + 23));
        s1w = _mm_sub_pd(_mm_mul_pd(a88, t0n), _mm_mul_pd(a98, t1n));
        s2w = _mm_add_pd(_mm_mul_pd(a98, t0n), _mm_mul_pd(a88, t1n));
        s3w = v_lo2(s1w, s2w);
        s4w = v_hi2(s1w, s2w);
        s5w = _mm_add_pd(s3w, s4w);
        _mm_storeu_pd(((double  *) (b3 + 178)), s5w);
        s6w = v_neg23(_mm_sub_pd(s3w, s4w));
        _mm_storeu_pd(((double  *) (b4 + 78)), s6w);
        a09 = *((a46 + 24));
        a19 = *((a46 + 25));
        s7w = _mm_sub_pd(_mm_mul_pd(a09, t0j), _mm_mul_pd(a19, t1j));
        s8w = _mm_add_pd(_mm_mul_pd(a19, t0j), _mm_mul_pd(a09, t1j));
        s9w = v_lo2(s7w, s8w);
        s0x = v_hi2(s7w, s8w);
        s1x = _mm_add_pd(s9w, s0x);
        _mm_storeu_pd(((double  *) (b3 + 194)), s1x);
        s2x = v_neg23(_mm_sub_pd(s9w, s0x));
        _mm_storeu_pd(((double  *) (b4 + 62)), s2x);
        a29 = *((a46 + 26));
        a39 = *((a46 + 27));
        s3x = _mm_sub_pd(_mm_mul_pd(a29, t4n), _mm_mul_pd(a39, t5n));
        s4x = _mm_add_pd(_mm_mul_pd(a39, t4n), _mm_mul_pd(a29, t5n));
        s5x = v_lo2(s3x, s4x);
        s6x = v_hi2(s3x, s4x);
        s7x = _mm_add_pd(s5x, s6x);
        _mm_storeu_pd(((double  *) (b3 + 210)), s7x);
        s8x = v_neg23(_mm_sub_pd(s5x, s6x));
        _mm_storeu_pd(((double  *) (b4 + 46)), s8x);
        a49 = *((a46 + 28));
        a59 = *((a46 + 29));
        s9x = _mm_sub_pd(_mm_mul_pd(a49, t4j), _mm_mul_pd(a59, t5j));
        s0y = _mm_add_pd(_mm_mul_pd(a59, t4j), _mm_mul_pd(a49, t5j));
        s1y = v_lo2(s9x, s0y);
        s2y = v_hi2(s9x, s0y);
        s3y = _mm_add_pd(s1y, s2y);
        _mm_storeu_pd(((double  *) (b3 + 226)), s3y);
        s4y = v_neg23(_mm_sub_pd(s1y, s2y));
        _mm_storeu_pd(((double  *) (b4 + 30)), s4y);
        a69 = *((a46 + 30));
        a79 = *((a46 + 31));
        s5y = _mm_sub_pd(_mm_mul_pd(a69, t8n), _mm_mul_pd(a79, t9n));
        s6y = _mm_add_pd(_mm_mul_pd(a79, t8n), _mm_mul_pd(a69, t9n));
        s7y = v_lo2(s5y, s6y);
        s8y = v_hi2(s5y, s6y);
        s9y = _mm_add_pd(s7y, s8y);
        _mm_storeu_pd(((double  *) (b3 + 242)), s9y);
        s0z = v_neg23(_mm_sub_pd(s7y, s8y));
        _mm_storeu_pd(((double  *) (b4 + 14)), s0z);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_256)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_256_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[256]);
    __m128d a01, a03, a04, a05, a06, a07, a08, a09, a11, a12, a13, a14, a15, a16, a17, a18, a19, a21, a22, a23, a24, a25
            , a26, a27, a28, a29, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a4, a41, a42, a43, a44, a45, a46, a47
            , a48, a49, a51, a52, a53, a54, a55, a57, a58, a59, a6, a61, a62, a63, a64, a65, a66, a67, a68, a69, a7, a71
            , a72, a73, a74, a75, a76, a77, a78, a79, a8, a82, a83, a84, a85, a87, a88, a89, a9, a92, a93, a94, a95, a96
            , a97, a98, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j
            , s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16
            , s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s
            , s1t, s1u, s1v, s1w, s1x, s1y, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f
            , s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s3, s31, s32
            , s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o
            , s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b
            , s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x
            , s4y, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k
            , s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s6, s61, s62, s63, s64, s65, s66, s67
            , s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t
            , s6u, s6v, s6w, s6x, s6y, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g
            , s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s8, s81, s82, s83
            , s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p
            , s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c
            , s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y
            , t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l
            , t0m, t0n, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k
            , t1l, t1m, t1n, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i
            , t2j, t2k, t2l, t2m, t2n, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g
            , t3h, t3i, t3j, t3k, t3l, t3m, t3n, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e
            , t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t7, t71, t72, t73, t74, t75, t76, t77, t78
            , t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t8, t81, t82, t83, t84, t85, t86
            , t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t9, t91, t92, t93, t94
            , t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n;
    __m128d  *a, *a02, *a2, *a5, *a56, *a81, *a86, *b, *b2, *b3;
    int a91;
    {long i; for(i = 0; i <= 15; i++) {
        a = (((__m128d  *) src) + i);
        s = *(a);
        s2 = *((a + 64));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = *((a + 32));
        s4 = *((a + 96));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = *((a + 16));
        s6 = *((a + 80));
        t5 = _mm_add_pd(s5, s6);
        s7 = *((a + 48));
        s8 = *((a + 112));
        t6 = _mm_add_pd(s7, s8);
        a2 = (((__m128d  *) T) + i);
        s9 = _mm_add_pd(t, t3);
        *(a2) = s9;
        s01 = _mm_sub_pd(t, t3);
        *((a2 + 64)) = s01;
        s11 = _mm_add_pd(t5, t6);
        *((a2 + 16)) = s11;
        s21 = _mm_sub_pd(t6, t5);
        *((a2 + 80)) = s21;
        a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
        a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
        s31 = _mm_add_pd(a3, a4);
        s41 = _mm_sub_pd(a4, a3);
        s51 = _mm_add_pd(t2, s31);
        *((a2 + 32)) = s51;
        s61 = _mm_sub_pd(s41, t4);
        *((a2 + 48)) = s61;
        s71 = _mm_sub_pd(t2, s31);
        *((a2 + 96)) = s71;
        s81 = _mm_add_pd(t4, s41);
        *((a2 + 112)) = s81;
    }}
    a5 = ((__m128d  *) T);
    s91 = *(a5);
    s02 = *((a5 + 16));
    t7 = _mm_add_pd(s91, s02);
    t8 = _mm_sub_pd(s91, s02);
    s12 = *((a5 + 8));
    s22 = *((a5 + 24));
    t9 = _mm_add_pd(s12, s22);
    t01 = _mm_sub_pd(s12, s22);
    s32 = *((a5 + 4));
    s42 = *((a5 + 20));
    t11 = _mm_add_pd(s32, s42);
    s52 = *((a5 + 12));
    s62 = *((a5 + 28));
    t21 = _mm_add_pd(s52, s62);
    t31 = _mm_add_pd(t7, t9);
    t41 = _mm_sub_pd(t7, t9);
    t51 = _mm_add_pd(t11, t21);
    t61 = _mm_sub_pd(t11, t21);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s32, s42));
    a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s52, s62));
    s72 = _mm_add_pd(a6, a7);
    s82 = _mm_sub_pd(a7, a6);
    t71 = _mm_add_pd(t8, s72);
    t81 = _mm_sub_pd(s82, t01);
    t91 = _mm_sub_pd(t8, s72);
    t02 = _mm_add_pd(t01, s82);
    s92 = *((a5 + 1));
    s03 = *((a5 + 17));
    t12 = _mm_add_pd(s92, s03);
    t22 = _mm_sub_pd(s92, s03);
    s13 = *((a5 + 9));
    s23 = *((a5 + 25));
    t32 = _mm_add_pd(s13, s23);
    t42 = _mm_sub_pd(s13, s23);
    s33 = *((a5 + 5));
    s43 = *((a5 + 21));
    t52 = _mm_add_pd(s33, s43);
    s53 = *((a5 + 13));
    s63 = *((a5 + 29));
    t62 = _mm_add_pd(s53, s63);
    t72 = _mm_add_pd(t12, t32);
    t82 = _mm_sub_pd(t12, t32);
    t92 = _mm_add_pd(t52, t62);
    t03 = _mm_sub_pd(t52, t62);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
    s73 = _mm_add_pd(a8, a9);
    s83 = _mm_sub_pd(a9, a8);
    t13 = _mm_add_pd(t22, s73);
    t23 = _mm_sub_pd(s83, t42);
    t33 = _mm_sub_pd(t22, s73);
    t43 = _mm_add_pd(t42, s83);
    s93 = *((a5 + 2));
    s04 = *((a5 + 18));
    t53 = _mm_add_pd(s93, s04);
    t63 = _mm_sub_pd(s93, s04);
    s14 = *((a5 + 10));
    s24 = *((a5 + 26));
    t73 = _mm_add_pd(s14, s24);
    t83 = _mm_sub_pd(s14, s24);
    s34 = *((a5 + 6));
    s44 = *((a5 + 22));
    t93 = _mm_add_pd(s34, s44);
    s54 = *((a5 + 14));
    s64 = *((a5 + 30));
    t04 = _mm_add_pd(s54, s64);
    t14 = _mm_add_pd(t53, t73);
    t24 = _mm_add_pd(t93, t04);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s34, s44));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s54, s64));
    s74 = _mm_add_pd(a01, a11);
    s84 = _mm_sub_pd(a11, a01);
    t34 = _mm_add_pd(t63, s74);
    t44 = _mm_sub_pd(s84, t83);
    t54 = _mm_sub_pd(t63, s74);
    t64 = _mm_add_pd(t83, s84);
    s94 = *((a5 + 3));
    s05 = *((a5 + 19));
    t74 = _mm_add_pd(s94, s05);
    t84 = _mm_sub_pd(s94, s05);
    s15 = *((a5 + 11));
    s25 = *((a5 + 27));
    t94 = _mm_add_pd(s15, s25);
    t05 = _mm_sub_pd(s15, s25);
    s35 = *((a5 + 7));
    s45 = *((a5 + 23));
    t15 = _mm_add_pd(s35, s45);
    s55 = *((a5 + 15));
    s65 = *((a5 + 31));
    t25 = _mm_add_pd(s55, s65);
    t35 = _mm_add_pd(t74, t94);
    t45 = _mm_sub_pd(t74, t94);
    t55 = _mm_add_pd(t15, t25);
    t65 = _mm_sub_pd(t15, t25);
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s35, s45));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s55, s65));
    s75 = _mm_add_pd(a21, a31);
    s85 = _mm_sub_pd(a31, a21);
    t75 = _mm_add_pd(t84, s75);
    t85 = _mm_sub_pd(s85, t05);
    t95 = _mm_sub_pd(t84, s75);
    t06 = _mm_add_pd(t05, s85);
    t16 = _mm_add_pd(t31, t51);
    t26 = _mm_sub_pd(t31, t51);
    t36 = _mm_add_pd(t14, t24);
    t46 = _mm_sub_pd(t14, t24);
    t56 = _mm_add_pd(t72, t92);
    t66 = _mm_add_pd(t35, t55);
    t76 = _mm_add_pd(t16, t36);
    t86 = _mm_sub_pd(t16, t36);
    t96 = _mm_add_pd(t56, t66);
    t07 = _mm_sub_pd(t56, t66);
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t72, t92));
    a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t35, t55));
    s95 = _mm_add_pd(a41, a51);
    s06 = _mm_sub_pd(a51, a41);
    t17 = _mm_add_pd(t26, s95);
    t27 = _mm_sub_pd(s06, t46);
    t37 = _mm_sub_pd(t26, s95);
    t47 = _mm_add_pd(t46, s06);
    s16 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t13), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t23));
    s26 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t13), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t23));
    s36 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t44));
    s46 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s56 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t75), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t85));
    s66 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t75), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t85));
    t57 = _mm_add_pd(t71, s36);
    t67 = _mm_add_pd(t81, s46);
    t77 = _mm_sub_pd(t71, s36);
    t87 = _mm_sub_pd(t81, s46);
    t97 = _mm_add_pd(s16, s56);
    t08 = _mm_add_pd(s26, s66);
    t18 = _mm_sub_pd(s16, s56);
    t28 = _mm_sub_pd(s26, s66);
    t38 = _mm_add_pd(t57, t97);
    t48 = _mm_add_pd(t67, t08);
    t58 = _mm_sub_pd(t57, t97);
    t68 = _mm_sub_pd(t67, t08);
    t78 = _mm_add_pd(t77, t28);
    t88 = _mm_sub_pd(t87, t18);
    t98 = _mm_sub_pd(t77, t28);
    t09 = _mm_add_pd(t87, t18);
    s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t82), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t03));
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t82), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t03));
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t53, t73));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t93, t04));
    s96 = _mm_add_pd(a61, a71);
    s07 = _mm_sub_pd(a71, a61);
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t45), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65));
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t45), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65));
    t19 = _mm_add_pd(t41, s96);
    t29 = _mm_sub_pd(s07, t61);
    t39 = _mm_sub_pd(t41, s96);
    t49 = _mm_add_pd(t61, s07);
    t59 = _mm_add_pd(s76, s17);
    t69 = _mm_add_pd(s86, s27);
    t79 = _mm_sub_pd(s76, s17);
    t89 = _mm_sub_pd(s86, s27);
    t99 = _mm_add_pd(t19, t59);
    t0a = _mm_add_pd(t29, t69);
    t1a = _mm_sub_pd(t19, t59);
    t2a = _mm_sub_pd(t29, t69);
    t3a = _mm_add_pd(t39, t89);
    t4a = _mm_add_pd(t49, t79);
    t5a = _mm_sub_pd(t39, t89);
    t6a = _mm_sub_pd(t79, t49);
    s37 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t33), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t43));
    s47 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t33), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t43));
    s57 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t54), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t64));
    s67 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t54), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t64));
    s77 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t95), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t06));
    s87 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t95), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t06));
    t7a = _mm_add_pd(t91, s57);
    t8a = _mm_add_pd(t02, s67);
    t9a = _mm_sub_pd(t91, s57);
    t0b = _mm_sub_pd(t02, s67);
    t1b = _mm_add_pd(s37, s77);
    t2b = _mm_add_pd(s47, s87);
    t3b = _mm_sub_pd(s37, s77);
    t4b = _mm_sub_pd(s47, s87);
    t5b = _mm_add_pd(t7a, t1b);
    t6b = _mm_add_pd(t8a, t2b);
    t7b = _mm_sub_pd(t7a, t1b);
    t8b = _mm_sub_pd(t8a, t2b);
    t9b = _mm_add_pd(t9a, t4b);
    t0c = _mm_sub_pd(t0b, t3b);
    t1c = _mm_sub_pd(t9a, t4b);
    t2c = _mm_add_pd(t0b, t3b);
    t3c = _mm_add_pd(t76, t96);
    a81 = ((__m128d  *) dst);
    s97 = _mm_add_pd(v_neg03(v_hi2(t3c, t3c)), v_lo2(t3c, t3c));
    *(a81) = s97;
    s08 = v_neg23(_mm_sub_pd(t76, t96));
    *((a81 + 64)) = s08;
    s18 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t38), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t48));
    s28 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t38), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t48));
    s38 = v_lo2(s18, s28);
    s48 = v_hi2(s18, s28);
    s58 = _mm_add_pd(s38, s48);
    *((a81 + 4)) = s58;
    s68 = v_neg23(_mm_sub_pd(s38, s48));
    *((a81 + 124)) = s68;
    s78 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t99), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t0a));
    s88 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t99), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t0a));
    s98 = v_lo2(s78, s88);
    s09 = v_hi2(s78, s88);
    s19 = _mm_add_pd(s98, s09);
    *((a81 + 8)) = s19;
    s29 = v_neg23(_mm_sub_pd(s98, s09));
    *((a81 + 120)) = s29;
    s39 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t5b), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t6b));
    s49 = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t5b), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t6b));
    s59 = v_lo2(s39, s49);
    s69 = v_hi2(s39, s49);
    s79 = _mm_add_pd(s59, s69);
    *((a81 + 12)) = s79;
    s89 = v_neg23(_mm_sub_pd(s59, s69));
    *((a81 + 116)) = s89;
    s99 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t17), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t27));
    s0a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t17), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t27));
    s1a = v_lo2(s99, s0a);
    s2a = v_hi2(s99, s0a);
    s3a = _mm_add_pd(s1a, s2a);
    *((a81 + 16)) = s3a;
    s4a = v_neg23(_mm_sub_pd(s1a, s2a));
    *((a81 + 112)) = s4a;
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t1c), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t2c));
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t1c), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t2c));
    s7a = v_lo2(s5a, s6a);
    s8a = v_hi2(s5a, s6a);
    s9a = _mm_add_pd(s7a, s8a);
    *((a81 + 20)) = s9a;
    s0b = v_neg23(_mm_sub_pd(s7a, s8a));
    *((a81 + 108)) = s0b;
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t5a), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6a));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t5a), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6a));
    s3b = v_lo2(s1b, s2b);
    s4b = v_hi2(s1b, s2b);
    s5b = _mm_add_pd(s3b, s4b);
    *((a81 + 24)) = s5b;
    s6b = v_neg23(_mm_sub_pd(s3b, s4b));
    *((a81 + 104)) = s6b;
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t98), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t09));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t98), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t09));
    s9b = v_lo2(s7b, s8b);
    s0c = v_hi2(s7b, s8b);
    s1c = _mm_add_pd(s9b, s0c);
    *((a81 + 28)) = s1c;
    s2c = v_neg23(_mm_sub_pd(s9b, s0c));
    *((a81 + 100)) = s2c;
    s3c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t86), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t07));
    s4c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t86), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t07));
    s5c = v_lo2(s3c, s4c);
    s6c = v_hi2(s3c, s4c);
    s7c = _mm_add_pd(s5c, s6c);
    *((a81 + 32)) = s7c;
    s8c = v_neg23(_mm_sub_pd(s5c, s6c));
    *((a81 + 96)) = s8c;
    s9c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t78), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t88));
    s0d = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t78), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t88));
    s1d = v_lo2(s9c, s0d);
    s2d = v_hi2(s9c, s0d);
    s3d = _mm_add_pd(s1d, s2d);
    *((a81 + 36)) = s3d;
    s4d = v_neg23(_mm_sub_pd(s1d, s2d));
    *((a81 + 92)) = s4d;
    s5d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t3a), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4a));
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t3a), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t4a));
    s7d = v_lo2(s5d, s6d);
    s8d = v_hi2(s5d, s6d);
    s9d = _mm_add_pd(s7d, s8d);
    *((a81 + 40)) = s9d;
    s0e = v_neg23(_mm_sub_pd(s7d, s8d));
    *((a81 + 88)) = s0e;
    s1e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t9b), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t0c));
    s2e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t9b), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t0c));
    s3e = v_lo2(s1e, s2e);
    s4e = v_hi2(s1e, s2e);
    s5e = _mm_add_pd(s3e, s4e);
    *((a81 + 44)) = s5e;
    s6e = v_neg23(_mm_sub_pd(s3e, s4e));
    *((a81 + 84)) = s6e;
    s7e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t37), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t47));
    s8e = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t37), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t47));
    s9e = v_lo2(s7e, s8e);
    s0f = v_hi2(s7e, s8e);
    s1f = _mm_add_pd(s9e, s0f);
    *((a81 + 48)) = s1f;
    s2f = v_neg23(_mm_sub_pd(s9e, s0f));
    *((a81 + 80)) = s2f;
    s3f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t7b), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t8b));
    s4f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t7b), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t8b));
    s5f = v_lo2(s3f, s4f);
    s6f = v_hi2(s3f, s4f);
    s7f = _mm_add_pd(s5f, s6f);
    *((a81 + 52)) = s7f;
    s8f = v_neg23(_mm_sub_pd(s5f, s6f));
    *((a81 + 76)) = s8f;
    s9f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t1a), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t2a));
    s0g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1a), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t2a));
    s1g = v_lo2(s9f, s0g);
    s2g = v_hi2(s9f, s0g);
    s3g = _mm_add_pd(s1g, s2g);
    *((a81 + 56)) = s3g;
    s4g = v_neg23(_mm_sub_pd(s1g, s2g));
    *((a81 + 72)) = s4g;
    s5g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t58), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t68));
    s6g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t58), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t68));
    s7g = v_lo2(s5g, s6g);
    s8g = v_hi2(s5g, s6g);
    s9g = _mm_add_pd(s7g, s8g);
    *((a81 + 60)) = s9g;
    s0h = v_neg23(_mm_sub_pd(s7g, s8g));
    *((a81 + 68)) = s0h;
    {long i2; for(i2 = 0; i2 <= 2; i2++) {
        a91 = (32 * i2);
        b = (((__m128d  *) T) + a91);
        s1h = *((b + 32));
        s2h = *((b + 48));
        s3h = *((b + 33));
        s4h = *((b + 49));
        s5h = *((b + 34));
        s6h = *((b + 50));
        s7h = *((b + 35));
        s8h = *((b + 51));
        s9h = *((b + 36));
        s0i = *((b + 52));
        s1i = *((b + 37));
        s2i = *((b + 53));
        s3i = *((b + 38));
        s4i = *((b + 54));
        s5i = *((b + 39));
        s6i = *((b + 55));
        s7i = *((b + 40));
        s8i = *((b + 56));
        s9i = *((b + 41));
        s0j = *((b + 57));
        s1j = *((b + 42));
        s2j = *((b + 58));
        s3j = *((b + 43));
        s4j = *((b + 59));
        s5j = *((b + 44));
        s6j = *((b + 60));
        s7j = *((b + 45));
        s8j = *((b + 61));
        s9j = *((b + 46));
        s0k = *((b + 62));
        s1k = *((b + 47));
        s2k = *((b + 63));
        a02 = (D39 + a91);
        a12 = *(a02);
        a22 = *((a02 + 1));
        s3k = _mm_sub_pd(_mm_mul_pd(a12, s1h), _mm_mul_pd(a22, s2h));
        s4k = _mm_add_pd(_mm_mul_pd(a22, s1h), _mm_mul_pd(a12, s2h));
        a32 = *((a02 + 2));
        a42 = *((a02 + 3));
        s5k = _mm_sub_pd(_mm_mul_pd(a32, s3h), _mm_mul_pd(a42, s4h));
        s6k = _mm_add_pd(_mm_mul_pd(a42, s3h), _mm_mul_pd(a32, s4h));
        a52 = *((a02 + 4));
        a62 = *((a02 + 5));
        s7k = _mm_sub_pd(_mm_mul_pd(a52, s5h), _mm_mul_pd(a62, s6h));
        s8k = _mm_add_pd(_mm_mul_pd(a62, s5h), _mm_mul_pd(a52, s6h));
        a72 = *((a02 + 6));
        a82 = *((a02 + 7));
        s9k = _mm_sub_pd(_mm_mul_pd(a72, s7h), _mm_mul_pd(a82, s8h));
        s0l = _mm_add_pd(_mm_mul_pd(a82, s7h), _mm_mul_pd(a72, s8h));
        a92 = *((a02 + 8));
        a03 = *((a02 + 9));
        s1l = _mm_sub_pd(_mm_mul_pd(a92, s9h), _mm_mul_pd(a03, s0i));
        s2l = _mm_add_pd(_mm_mul_pd(a03, s9h), _mm_mul_pd(a92, s0i));
        a13 = *((a02 + 10));
        a23 = *((a02 + 11));
        s3l = _mm_sub_pd(_mm_mul_pd(a13, s1i), _mm_mul_pd(a23, s2i));
        s4l = _mm_add_pd(_mm_mul_pd(a23, s1i), _mm_mul_pd(a13, s2i));
        a33 = *((a02 + 12));
        a43 = *((a02 + 13));
        s5l = _mm_sub_pd(_mm_mul_pd(a33, s3i), _mm_mul_pd(a43, s4i));
        s6l = _mm_add_pd(_mm_mul_pd(a43, s3i), _mm_mul_pd(a33, s4i));
        a53 = *((a02 + 14));
        a63 = *((a02 + 15));
        s7l = _mm_sub_pd(_mm_mul_pd(a53, s5i), _mm_mul_pd(a63, s6i));
        s8l = _mm_add_pd(_mm_mul_pd(a63, s5i), _mm_mul_pd(a53, s6i));
        a73 = *((a02 + 16));
        a83 = *((a02 + 17));
        s9l = _mm_sub_pd(_mm_mul_pd(a73, s7i), _mm_mul_pd(a83, s8i));
        s0m = _mm_add_pd(_mm_mul_pd(a83, s7i), _mm_mul_pd(a73, s8i));
        a93 = *((a02 + 18));
        a04 = *((a02 + 19));
        s1m = _mm_sub_pd(_mm_mul_pd(a93, s9i), _mm_mul_pd(a04, s0j));
        s2m = _mm_add_pd(_mm_mul_pd(a04, s9i), _mm_mul_pd(a93, s0j));
        a14 = *((a02 + 20));
        a24 = *((a02 + 21));
        s3m = _mm_sub_pd(_mm_mul_pd(a14, s1j), _mm_mul_pd(a24, s2j));
        s4m = _mm_add_pd(_mm_mul_pd(a24, s1j), _mm_mul_pd(a14, s2j));
        a34 = *((a02 + 22));
        a44 = *((a02 + 23));
        s5m = _mm_sub_pd(_mm_mul_pd(a34, s3j), _mm_mul_pd(a44, s4j));
        s6m = _mm_add_pd(_mm_mul_pd(a44, s3j), _mm_mul_pd(a34, s4j));
        a54 = *((a02 + 24));
        a64 = *((a02 + 25));
        s7m = _mm_sub_pd(_mm_mul_pd(a54, s5j), _mm_mul_pd(a64, s6j));
        s8m = _mm_add_pd(_mm_mul_pd(a64, s5j), _mm_mul_pd(a54, s6j));
        a74 = *((a02 + 26));
        a84 = *((a02 + 27));
        s9m = _mm_sub_pd(_mm_mul_pd(a74, s7j), _mm_mul_pd(a84, s8j));
        s0n = _mm_add_pd(_mm_mul_pd(a84, s7j), _mm_mul_pd(a74, s8j));
        a94 = *((a02 + 28));
        a05 = *((a02 + 29));
        s1n = _mm_sub_pd(_mm_mul_pd(a94, s9j), _mm_mul_pd(a05, s0k));
        s2n = _mm_add_pd(_mm_mul_pd(a05, s9j), _mm_mul_pd(a94, s0k));
        a15 = *((a02 + 30));
        a25 = *((a02 + 31));
        s3n = _mm_sub_pd(_mm_mul_pd(a15, s1k), _mm_mul_pd(a25, s2k));
        s4n = _mm_add_pd(_mm_mul_pd(a25, s1k), _mm_mul_pd(a15, s2k));
        t4c = _mm_add_pd(s3k, s9l);
        t5c = _mm_add_pd(s4k, s0m);
        t6c = _mm_sub_pd(s3k, s9l);
        t7c = _mm_sub_pd(s4k, s0m);
        t8c = _mm_add_pd(s5k, s1m);
        t9c = _mm_add_pd(s6k, s2m);
        t0d = _mm_sub_pd(s5k, s1m);
        t1d = _mm_sub_pd(s6k, s2m);
        s5n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1d));
        s6n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d));
        t2d = _mm_add_pd(s7k, s3m);
        t3d = _mm_add_pd(s8k, s4m);
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7k, s3m));
        a45 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8k, s4m));
        s7n = _mm_sub_pd(a35, a45);
        s8n = _mm_add_pd(a35, a45);
        t4d = _mm_add_pd(s9k, s5m);
        t5d = _mm_add_pd(s0l, s6m);
        t6d = _mm_sub_pd(s9k, s5m);
        t7d = _mm_sub_pd(s0l, s6m);
        s9n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7d));
        s0o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7d));
        t8d = _mm_add_pd(s1l, s7m);
        t9d = _mm_add_pd(s2l, s8m);
        t0e = _mm_sub_pd(s1l, s7m);
        t1e = _mm_sub_pd(s2l, s8m);
        t2e = _mm_add_pd(s3l, s9m);
        t3e = _mm_add_pd(s4l, s0n);
        t4e = _mm_sub_pd(s3l, s9m);
        t5e = _mm_sub_pd(s4l, s0n);
        s1o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5e));
        s2o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5e));
        t6e = _mm_add_pd(s5l, s1n);
        t7e = _mm_add_pd(s6l, s2n);
        a55 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5l, s1n));
        a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s6l, s2n));
        s3o = _mm_sub_pd(a55, a65);
        s4o = _mm_add_pd(a55, a65);
        t8e = _mm_add_pd(s7l, s3n);
        t9e = _mm_add_pd(s8l, s4n);
        t0f = _mm_sub_pd(s7l, s3n);
        t1f = _mm_sub_pd(s8l, s4n);
        s5o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0f), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1f));
        s6o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1f));
        t2f = _mm_add_pd(t4c, t8d);
        t3f = _mm_add_pd(t5c, t9d);
        t4f = _mm_sub_pd(t4c, t8d);
        t5f = _mm_sub_pd(t5c, t9d);
        t6f = _mm_add_pd(t2d, t6e);
        t7f = _mm_add_pd(t3d, t7e);
        t8f = _mm_sub_pd(t2d, t6e);
        t9f = _mm_sub_pd(t3d, t7e);
        t0g = _mm_add_pd(t2f, t6f);
        t1g = _mm_add_pd(t3f, t7f);
        t2g = _mm_sub_pd(t2f, t6f);
        t3g = _mm_sub_pd(t3f, t7f);
        t4g = _mm_add_pd(t4f, t9f);
        t5g = _mm_sub_pd(t5f, t8f);
        t6g = _mm_sub_pd(t4f, t9f);
        t7g = _mm_add_pd(t5f, t8f);
        t8g = _mm_add_pd(t8c, t2e);
        t9g = _mm_add_pd(t9c, t3e);
        t0h = _mm_sub_pd(t8c, t2e);
        t1h = _mm_sub_pd(t9c, t3e);
        t2h = _mm_add_pd(t4d, t8e);
        t3h = _mm_add_pd(t5d, t9e);
        t4h = _mm_sub_pd(t4d, t8e);
        t5h = _mm_sub_pd(t5d, t9e);
        t6h = _mm_add_pd(t8g, t2h);
        t7h = _mm_add_pd(t9g, t3h);
        t8h = _mm_sub_pd(t8g, t2h);
        t9h = _mm_sub_pd(t9g, t3h);
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0h, t5h));
        a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1h, t4h));
        s7o = _mm_sub_pd(a75, a85);
        s8o = _mm_add_pd(a75, a85);
        a95 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0h, t5h));
        a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1h, t4h));
        s9o = _mm_sub_pd(a95, a06);
        s0p = _mm_add_pd(a95, a06);
        t0i = _mm_add_pd(t0g, t6h);
        t1i = _mm_add_pd(t1g, t7h);
        t2i = _mm_sub_pd(t0g, t6h);
        t3i = _mm_sub_pd(t1g, t7h);
        t4i = _mm_add_pd(t4g, s7o);
        t5i = _mm_sub_pd(t5g, s8o);
        t6i = _mm_sub_pd(t4g, s7o);
        t7i = _mm_add_pd(t5g, s8o);
        t8i = _mm_add_pd(t2g, t9h);
        t9i = _mm_sub_pd(t3g, t8h);
        t0j = _mm_sub_pd(t2g, t9h);
        t1j = _mm_add_pd(t3g, t8h);
        t2j = _mm_add_pd(t6g, s9o);
        t3j = _mm_add_pd(t7g, s0p);
        t4j = _mm_sub_pd(t6g, s9o);
        t5j = _mm_sub_pd(t7g, s0p);
        t6j = _mm_add_pd(t6c, t1e);
        t7j = _mm_sub_pd(t7c, t0e);
        t8j = _mm_sub_pd(t6c, t1e);
        t9j = _mm_add_pd(t7c, t0e);
        t0k = _mm_add_pd(s7n, s3o);
        t1k = _mm_sub_pd(s4o, s8n);
        t2k = _mm_sub_pd(s7n, s3o);
        t3k = _mm_add_pd(s8n, s4o);
        t4k = _mm_add_pd(t6j, t0k);
        t5k = _mm_add_pd(t7j, t1k);
        t6k = _mm_sub_pd(t6j, t0k);
        t7k = _mm_sub_pd(t7j, t1k);
        t8k = _mm_sub_pd(t8j, t3k);
        t9k = _mm_sub_pd(t9j, t2k);
        t0l = _mm_add_pd(t8j, t3k);
        t1l = _mm_add_pd(t9j, t2k);
        t2l = _mm_add_pd(s5n, s1o);
        t3l = _mm_add_pd(s6n, s2o);
        t4l = _mm_sub_pd(s5n, s1o);
        t5l = _mm_sub_pd(s6n, s2o);
        t6l = _mm_add_pd(s9n, s5o);
        t7l = _mm_add_pd(s0o, s6o);
        t8l = _mm_sub_pd(s9n, s5o);
        t9l = _mm_sub_pd(s0o, s6o);
        t0m = _mm_add_pd(t2l, t6l);
        t1m = _mm_add_pd(t3l, t7l);
        t2m = _mm_sub_pd(t2l, t6l);
        t3m = _mm_sub_pd(t3l, t7l);
        a16 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4l, t9l));
        a26 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t8l));
        s1p = _mm_sub_pd(a16, a26);
        s2p = _mm_add_pd(a16, a26);
        a36 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4l, t9l));
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5l, t8l));
        s3p = _mm_sub_pd(a36, a46);
        s4p = _mm_add_pd(a36, a46);
        t4m = _mm_add_pd(t4k, t0m);
        t5m = _mm_add_pd(t5k, t1m);
        t6m = _mm_sub_pd(t4k, t0m);
        t7m = _mm_sub_pd(t5k, t1m);
        t8m = _mm_add_pd(t8k, s1p);
        t9m = _mm_sub_pd(t9k, s2p);
        t0n = _mm_sub_pd(t8k, s1p);
        t1n = _mm_add_pd(t9k, s2p);
        t2n = _mm_add_pd(t6k, t3m);
        t3n = _mm_sub_pd(t7k, t2m);
        t4n = _mm_sub_pd(t6k, t3m);
        t5n = _mm_add_pd(t7k, t2m);
        t6n = _mm_add_pd(t0l, s3p);
        t7n = _mm_add_pd(t1l, s4p);
        t8n = _mm_sub_pd(t0l, s3p);
        t9n = _mm_sub_pd(t1l, s4p);
        a56 = (D37 + a91);
        a66 = *(a56);
        a76 = *((a56 + 1));
        s5p = _mm_sub_pd(_mm_mul_pd(a66, t0i), _mm_mul_pd(a76, t1i));
        s6p = _mm_add_pd(_mm_mul_pd(a76, t0i), _mm_mul_pd(a66, t1i));
        s7p = v_lo2(s5p, s6p);
        s8p = v_hi2(s5p, s6p);
        a86 = ((__m128d  *) dst);
        b2 = (a86 + i2);
        s9p = _mm_add_pd(s7p, s8p);
        *((b2 + 1)) = s9p;
        b3 = (a86 - i2);
        s0q = v_neg23(_mm_sub_pd(s7p, s8p));
        *((b3 + 127)) = s0q;
        a96 = *((a56 + 2));
        a07 = *((a56 + 3));
        s1q = _mm_sub_pd(_mm_mul_pd(a96, t4m), _mm_mul_pd(a07, t5m));
        s2q = _mm_add_pd(_mm_mul_pd(a07, t4m), _mm_mul_pd(a96, t5m));
        s3q = v_lo2(s1q, s2q);
        s4q = v_hi2(s1q, s2q);
        s5q = _mm_add_pd(s3q, s4q);
        *((b2 + 9)) = s5q;
        s6q = v_neg23(_mm_sub_pd(s3q, s4q));
        *((b3 + 119)) = s6q;
        a17 = *((a56 + 4));
        a27 = *((a56 + 5));
        s7q = _mm_sub_pd(_mm_mul_pd(a17, t4i), _mm_mul_pd(a27, t5i));
        s8q = _mm_add_pd(_mm_mul_pd(a27, t4i), _mm_mul_pd(a17, t5i));
        s9q = v_lo2(s7q, s8q);
        s0r = v_hi2(s7q, s8q);
        s1r = _mm_add_pd(s9q, s0r);
        *((b2 + 17)) = s1r;
        s2r = v_neg23(_mm_sub_pd(s9q, s0r));
        *((b3 + 111)) = s2r;
        a37 = *((a56 + 6));
        a47 = *((a56 + 7));
        s3r = _mm_sub_pd(_mm_mul_pd(a37, t8m), _mm_mul_pd(a47, t9m));
        s4r = _mm_add_pd(_mm_mul_pd(a47, t8m), _mm_mul_pd(a37, t9m));
        s5r = v_lo2(s3r, s4r);
        s6r = v_hi2(s3r, s4r);
        s7r = _mm_add_pd(s5r, s6r);
        *((b2 + 25)) = s7r;
        s8r = v_neg23(_mm_sub_pd(s5r, s6r));
        *((b3 + 103)) = s8r;
        a57 = *((a56 + 8));
        a67 = *((a56 + 9));
        s9r = _mm_sub_pd(_mm_mul_pd(a57, t8i), _mm_mul_pd(a67, t9i));
        s0s = _mm_add_pd(_mm_mul_pd(a67, t8i), _mm_mul_pd(a57, t9i));
        s1s = v_lo2(s9r, s0s);
        s2s = v_hi2(s9r, s0s);
        s3s = _mm_add_pd(s1s, s2s);
        *((b2 + 33)) = s3s;
        s4s = v_neg23(_mm_sub_pd(s1s, s2s));
        *((b3 + 95)) = s4s;
        a77 = *((a56 + 10));
        a87 = *((a56 + 11));
        s5s = _mm_sub_pd(_mm_mul_pd(a77, t2n), _mm_mul_pd(a87, t3n));
        s6s = _mm_add_pd(_mm_mul_pd(a87, t2n), _mm_mul_pd(a77, t3n));
        s7s = v_lo2(s5s, s6s);
        s8s = v_hi2(s5s, s6s);
        s9s = _mm_add_pd(s7s, s8s);
        *((b2 + 41)) = s9s;
        s0t = v_neg23(_mm_sub_pd(s7s, s8s));
        *((b3 + 87)) = s0t;
        a97 = *((a56 + 12));
        a08 = *((a56 + 13));
        s1t = _mm_sub_pd(_mm_mul_pd(a97, t2j), _mm_mul_pd(a08, t3j));
        s2t = _mm_add_pd(_mm_mul_pd(a08, t2j), _mm_mul_pd(a97, t3j));
        s3t = v_lo2(s1t, s2t);
        s4t = v_hi2(s1t, s2t);
        s5t = _mm_add_pd(s3t, s4t);
        *((b2 + 49)) = s5t;
        s6t = v_neg23(_mm_sub_pd(s3t, s4t));
        *((b3 + 79)) = s6t;
        a18 = *((a56 + 14));
        a28 = *((a56 + 15));
        s7t = _mm_sub_pd(_mm_mul_pd(a18, t6n), _mm_mul_pd(a28, t7n));
        s8t = _mm_add_pd(_mm_mul_pd(a28, t6n), _mm_mul_pd(a18, t7n));
        s9t = v_lo2(s7t, s8t);
        s0u = v_hi2(s7t, s8t);
        s1u = _mm_add_pd(s9t, s0u);
        *((b2 + 57)) = s1u;
        s2u = v_neg23(_mm_sub_pd(s9t, s0u));
        *((b3 + 71)) = s2u;
        a38 = *((a56 + 16));
        a48 = *((a56 + 17));
        s3u = _mm_sub_pd(_mm_mul_pd(a38, t2i), _mm_mul_pd(a48, t3i));
        s4u = _mm_add_pd(_mm_mul_pd(a48, t2i), _mm_mul_pd(a38, t3i));
        s5u = v_lo2(s3u, s4u);
        s6u = v_hi2(s3u, s4u);
        s7u = _mm_add_pd(s5u, s6u);
        *((b2 + 65)) = s7u;
        s8u = v_neg23(_mm_sub_pd(s5u, s6u));
        *((b3 + 63)) = s8u;
        a58 = *((a56 + 18));
        a68 = *((a56 + 19));
        s9u = _mm_sub_pd(_mm_mul_pd(a58, t6m), _mm_mul_pd(a68, t7m));
        s0v = _mm_add_pd(_mm_mul_pd(a68, t6m), _mm_mul_pd(a58, t7m));
        s1v = v_lo2(s9u, s0v);
        s2v = v_hi2(s9u, s0v);
        s3v = _mm_add_pd(s1v, s2v);
        *((b2 + 73)) = s3v;
        s4v = v_neg23(_mm_sub_pd(s1v, s2v));
        *((b3 + 55)) = s4v;
        a78 = *((a56 + 20));
        a88 = *((a56 + 21));
        s5v = _mm_sub_pd(_mm_mul_pd(a78, t6i), _mm_mul_pd(a88, t7i));
        s6v = _mm_add_pd(_mm_mul_pd(a88, t6i), _mm_mul_pd(a78, t7i));
        s7v = v_lo2(s5v, s6v);
        s8v = v_hi2(s5v, s6v);
        s9v = _mm_add_pd(s7v, s8v);
        *((b2 + 81)) = s9v;
        s0w = v_neg23(_mm_sub_pd(s7v, s8v));
        *((b3 + 47)) = s0w;
        a98 = *((a56 + 22));
        a09 = *((a56 + 23));
        s1w = _mm_sub_pd(_mm_mul_pd(a98, t0n), _mm_mul_pd(a09, t1n));
        s2w = _mm_add_pd(_mm_mul_pd(a09, t0n), _mm_mul_pd(a98, t1n));
        s3w = v_lo2(s1w, s2w);
        s4w = v_hi2(s1w, s2w);
        s5w = _mm_add_pd(s3w, s4w);
        *((b2 + 89)) = s5w;
        s6w = v_neg23(_mm_sub_pd(s3w, s4w));
        *((b3 + 39)) = s6w;
        a19 = *((a56 + 24));
        a29 = *((a56 + 25));
        s7w = _mm_sub_pd(_mm_mul_pd(a19, t0j), _mm_mul_pd(a29, t1j));
        s8w = _mm_add_pd(_mm_mul_pd(a29, t0j), _mm_mul_pd(a19, t1j));
        s9w = v_lo2(s7w, s8w);
        s0x = v_hi2(s7w, s8w);
        s1x = _mm_add_pd(s9w, s0x);
        *((b2 + 97)) = s1x;
        s2x = v_neg23(_mm_sub_pd(s9w, s0x));
        *((b3 + 31)) = s2x;
        a39 = *((a56 + 26));
        a49 = *((a56 + 27));
        s3x = _mm_sub_pd(_mm_mul_pd(a39, t4n), _mm_mul_pd(a49, t5n));
        s4x = _mm_add_pd(_mm_mul_pd(a49, t4n), _mm_mul_pd(a39, t5n));
        s5x = v_lo2(s3x, s4x);
        s6x = v_hi2(s3x, s4x);
        s7x = _mm_add_pd(s5x, s6x);
        *((b2 + 105)) = s7x;
        s8x = v_neg23(_mm_sub_pd(s5x, s6x));
        *((b3 + 23)) = s8x;
        a59 = *((a56 + 28));
        a69 = *((a56 + 29));
        s9x = _mm_sub_pd(_mm_mul_pd(a59, t4j), _mm_mul_pd(a69, t5j));
        s0y = _mm_add_pd(_mm_mul_pd(a69, t4j), _mm_mul_pd(a59, t5j));
        s1y = v_lo2(s9x, s0y);
        s2y = v_hi2(s9x, s0y);
        s3y = _mm_add_pd(s1y, s2y);
        *((b2 + 113)) = s3y;
        s4y = v_neg23(_mm_sub_pd(s1y, s2y));
        *((b3 + 15)) = s4y;
        a79 = *((a56 + 30));
        a89 = *((a56 + 31));
        s5y = _mm_sub_pd(_mm_mul_pd(a79, t8n), _mm_mul_pd(a89, t9n));
        s6y = _mm_add_pd(_mm_mul_pd(a89, t8n), _mm_mul_pd(a79, t9n));
        s7y = v_lo2(s5y, s6y);
        s8y = v_hi2(s5y, s6y);
        s9y = _mm_add_pd(s7y, s8y);
        *((b2 + 121)) = s9y;
        s0z = v_neg23(_mm_sub_pd(s7y, s8y));
        *((b3 + 7)) = s0z;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_512_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[512]);
    __m128d a01, a03, a04, a05, a06, a07, a08, a09, a11, a13, a14, a15, a16, a17, a18, a19, a21, a22, a23, a24, a25, a26
            , a27, a28, a29, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a4, a41, a42, a43, a44, a45, a46, a47, a48
            , a49, a5, a51, a52, a53, a54, a55, a56, a57, a58, a59, a6, a61, a62, a63, a64, a65, a67, a68, a69, a71, a72
            , a73, a74, a75, a76, a77, a78, a79, a8, a81, a82, a83, a84, a85, a86, a87, a88, a89, a9, a91, a92, a93, a94
            , a95, a97, a98, a99, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0a, s0b, s0c, s0d, s0e, s0f
            , s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12
            , s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m
            , s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2A, s2B, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s
            , s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3a, s3b, s3c, s3d
            , s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z
            , s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k
            , s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56
            , s57, s58, s59, s5A, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r
            , s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85
            , s86, s87, s88, s89, s8A, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q
            , s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9a, s9b
            , s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x
            , s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j
            , t0k, t0l, t0m, t0n, t0o, t0p, t0q, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f
            , t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a
            , t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t3, t31, t32, t33, t34, t35, t36
            , t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t4, t41, t42
            , t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o
            , t4p, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g
            , t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t8, t81, t82, t83, t84, t85, t86, t87, t88
            , t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t9, t91, t92, t93, t94
            , t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p;
    __m128d  *a12, *a2, *a66, *a7, *b2;
    double  *b3, *b4;
    const double  *b;
    int a, a02, a96;
    {long i; for(i = 0; i <= 15; i++) {
        a = (2 * i);
        s = _mm_loadu_pd(((const double  *) (a + src)));
        b = (src + a);
        s2 = _mm_loadu_pd(((const double  *) (b + 256)));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = _mm_loadu_pd(((const double  *) (b + 128)));
        s4 = _mm_loadu_pd(((const double  *) (b + 384)));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = _mm_loadu_pd(((const double  *) (b + 32)));
        s6 = _mm_loadu_pd(((const double  *) (b + 288)));
        t5 = _mm_add_pd(s5, s6);
        t6 = _mm_sub_pd(s5, s6);
        s7 = _mm_loadu_pd(((const double  *) (b + 160)));
        s8 = _mm_loadu_pd(((const double  *) (b + 416)));
        t7 = _mm_add_pd(s7, s8);
        t8 = _mm_sub_pd(s7, s8);
        s9 = _mm_loadu_pd(((const double  *) (b + 64)));
        s01 = _mm_loadu_pd(((const double  *) (b + 320)));
        t9 = _mm_add_pd(s9, s01);
        s11 = _mm_loadu_pd(((const double  *) (b + 192)));
        s21 = _mm_loadu_pd(((const double  *) (b + 448)));
        t01 = _mm_add_pd(s11, s21);
        s31 = _mm_loadu_pd(((const double  *) (b + 96)));
        s41 = _mm_loadu_pd(((const double  *) (b + 352)));
        t11 = _mm_add_pd(s31, s41);
        t21 = _mm_sub_pd(s31, s41);
        s51 = _mm_loadu_pd(((const double  *) (b + 224)));
        s61 = _mm_loadu_pd(((const double  *) (b + 480)));
        t31 = _mm_add_pd(s51, s61);
        t41 = _mm_sub_pd(s51, s61);
        t51 = _mm_add_pd(t, t3);
        t61 = _mm_sub_pd(t, t3);
        t71 = _mm_add_pd(t9, t01);
        t81 = _mm_sub_pd(t9, t01);
        t91 = _mm_add_pd(t5, t7);
        t02 = _mm_add_pd(t11, t31);
        a2 = (((__m128d  *) T) + i);
        s71 = _mm_add_pd(t51, t71);
        *(a2) = s71;
        s81 = _mm_sub_pd(t51, t71);
        *((a2 + 128)) = s81;
        s91 = _mm_add_pd(t91, t02);
        *((a2 + 16)) = s91;
        s02 = _mm_sub_pd(t02, t91);
        *((a2 + 144)) = s02;
        a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
        a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
        s12 = _mm_add_pd(a3, a4);
        s22 = _mm_sub_pd(a4, a3);
        s32 = _mm_add_pd(t61, s12);
        *((a2 + 64)) = s32;
        s42 = _mm_sub_pd(s22, t81);
        *((a2 + 80)) = s42;
        s52 = _mm_sub_pd(t61, s12);
        *((a2 + 192)) = s52;
        s62 = _mm_add_pd(t81, s22);
        *((a2 + 208)) = s62;
        s72 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
        s82 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
        a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
        a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
        s92 = _mm_add_pd(a5, a6);
        s03 = _mm_sub_pd(a6, a5);
        s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
        s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
        t12 = _mm_add_pd(t2, s92);
        t22 = _mm_sub_pd(s03, t4);
        t32 = _mm_sub_pd(t2, s92);
        t42 = _mm_add_pd(t4, s03);
        t52 = _mm_add_pd(s72, s13);
        t62 = _mm_add_pd(s82, s23);
        t72 = _mm_sub_pd(s72, s13);
        t82 = _mm_sub_pd(s82, s23);
        s33 = _mm_add_pd(t12, t52);
        *((a2 + 32)) = s33;
        s43 = _mm_add_pd(t22, t62);
        *((a2 + 48)) = s43;
        s53 = _mm_sub_pd(t12, t52);
        *((a2 + 224)) = s53;
        s63 = _mm_sub_pd(t62, t22);
        *((a2 + 240)) = s63;
        s73 = _mm_add_pd(t32, t82);
        *((a2 + 160)) = s73;
        s83 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t42, t72));
        *((a2 + 176)) = s83;
        s93 = _mm_sub_pd(t32, t82);
        *((a2 + 96)) = s93;
        s04 = _mm_sub_pd(t42, t72);
        *((a2 + 112)) = s04;
    }}
    a7 = ((__m128d  *) T);
    s14 = *(a7);
    s24 = *((a7 + 16));
    t92 = _mm_add_pd(s14, s24);
    t03 = _mm_sub_pd(s14, s24);
    s34 = *((a7 + 8));
    s44 = *((a7 + 24));
    t13 = _mm_add_pd(s34, s44);
    t23 = _mm_sub_pd(s34, s44);
    s54 = *((a7 + 4));
    s64 = *((a7 + 20));
    t33 = _mm_add_pd(s54, s64);
    s74 = *((a7 + 12));
    s84 = *((a7 + 28));
    t43 = _mm_add_pd(s74, s84);
    t53 = _mm_add_pd(t92, t13);
    t63 = _mm_sub_pd(t92, t13);
    t73 = _mm_add_pd(t33, t43);
    t83 = _mm_sub_pd(t33, t43);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s54, s64));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s74, s84));
    s94 = _mm_add_pd(a8, a9);
    s05 = _mm_sub_pd(a9, a8);
    t93 = _mm_add_pd(t03, s94);
    t04 = _mm_sub_pd(s05, t23);
    t14 = _mm_sub_pd(t03, s94);
    t24 = _mm_add_pd(t23, s05);
    s15 = *((a7 + 1));
    s25 = *((a7 + 17));
    t34 = _mm_add_pd(s15, s25);
    t44 = _mm_sub_pd(s15, s25);
    s35 = *((a7 + 9));
    s45 = *((a7 + 25));
    t54 = _mm_add_pd(s35, s45);
    t64 = _mm_sub_pd(s35, s45);
    s55 = *((a7 + 5));
    s65 = *((a7 + 21));
    t74 = _mm_add_pd(s55, s65);
    s75 = *((a7 + 13));
    s85 = *((a7 + 29));
    t84 = _mm_add_pd(s75, s85);
    t94 = _mm_add_pd(t34, t54);
    t05 = _mm_sub_pd(t34, t54);
    t15 = _mm_add_pd(t74, t84);
    t25 = _mm_sub_pd(t74, t84);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s55, s65));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s75, s85));
    s95 = _mm_add_pd(a01, a11);
    s06 = _mm_sub_pd(a11, a01);
    t35 = _mm_add_pd(t44, s95);
    t45 = _mm_sub_pd(s06, t64);
    t55 = _mm_sub_pd(t44, s95);
    t65 = _mm_add_pd(t64, s06);
    s16 = *((a7 + 2));
    s26 = *((a7 + 18));
    t75 = _mm_add_pd(s16, s26);
    t85 = _mm_sub_pd(s16, s26);
    s36 = *((a7 + 10));
    s46 = *((a7 + 26));
    t95 = _mm_add_pd(s36, s46);
    t06 = _mm_sub_pd(s36, s46);
    s56 = *((a7 + 6));
    s66 = *((a7 + 22));
    t16 = _mm_add_pd(s56, s66);
    s76 = *((a7 + 14));
    s86 = *((a7 + 30));
    t26 = _mm_add_pd(s76, s86);
    t36 = _mm_add_pd(t75, t95);
    t46 = _mm_add_pd(t16, t26);
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s56, s66));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s76, s86));
    s96 = _mm_add_pd(a21, a31);
    s07 = _mm_sub_pd(a31, a21);
    t56 = _mm_add_pd(t85, s96);
    t66 = _mm_sub_pd(s07, t06);
    t76 = _mm_sub_pd(t85, s96);
    t86 = _mm_add_pd(t06, s07);
    s17 = *((a7 + 3));
    s27 = *((a7 + 19));
    t96 = _mm_add_pd(s17, s27);
    t07 = _mm_sub_pd(s17, s27);
    s37 = *((a7 + 11));
    s47 = *((a7 + 27));
    t17 = _mm_add_pd(s37, s47);
    t27 = _mm_sub_pd(s37, s47);
    s57 = *((a7 + 7));
    s67 = *((a7 + 23));
    t37 = _mm_add_pd(s57, s67);
    s77 = *((a7 + 15));
    s87 = *((a7 + 31));
    t47 = _mm_add_pd(s77, s87);
    t57 = _mm_add_pd(t96, t17);
    t67 = _mm_sub_pd(t96, t17);
    t77 = _mm_add_pd(t37, t47);
    t87 = _mm_sub_pd(t37, t47);
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s57, s67));
    a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s77, s87));
    s97 = _mm_add_pd(a41, a51);
    s08 = _mm_sub_pd(a51, a41);
    t97 = _mm_add_pd(t07, s97);
    t08 = _mm_sub_pd(s08, t27);
    t18 = _mm_sub_pd(t07, s97);
    t28 = _mm_add_pd(t27, s08);
    t38 = _mm_add_pd(t53, t73);
    t48 = _mm_sub_pd(t53, t73);
    t58 = _mm_add_pd(t36, t46);
    t68 = _mm_sub_pd(t36, t46);
    t78 = _mm_add_pd(t94, t15);
    t88 = _mm_add_pd(t57, t77);
    t98 = _mm_add_pd(t38, t58);
    t09 = _mm_sub_pd(t38, t58);
    t19 = _mm_add_pd(t78, t88);
    t29 = _mm_sub_pd(t78, t88);
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t57, t77));
    s18 = _mm_add_pd(a61, a71);
    s28 = _mm_sub_pd(a71, a61);
    t39 = _mm_add_pd(t48, s18);
    t49 = _mm_sub_pd(s28, t68);
    t59 = _mm_sub_pd(t48, s18);
    t69 = _mm_add_pd(t68, s28);
    s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
    s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t45));
    s58 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t56), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66));
    s68 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t56), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66));
    s78 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t97), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t08));
    s88 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t97), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t08));
    t79 = _mm_add_pd(t93, s58);
    t89 = _mm_add_pd(t04, s68);
    t99 = _mm_sub_pd(t93, s58);
    t0a = _mm_sub_pd(t04, s68);
    t1a = _mm_add_pd(s38, s78);
    t2a = _mm_add_pd(s48, s88);
    t3a = _mm_sub_pd(s38, s78);
    t4a = _mm_sub_pd(s48, s88);
    t5a = _mm_add_pd(t79, t1a);
    t6a = _mm_add_pd(t89, t2a);
    t7a = _mm_sub_pd(t79, t1a);
    t8a = _mm_sub_pd(t89, t2a);
    t9a = _mm_add_pd(t99, t4a);
    t0b = _mm_sub_pd(t0a, t3a);
    t1b = _mm_sub_pd(t99, t4a);
    t2b = _mm_add_pd(t0a, t3a);
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
    s09 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t75, t95));
    a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t16, t26));
    s19 = _mm_add_pd(a81, a91);
    s29 = _mm_sub_pd(a91, a81);
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t87));
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t67), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
    t3b = _mm_add_pd(t63, s19);
    t4b = _mm_sub_pd(s29, t83);
    t5b = _mm_sub_pd(t63, s19);
    t6b = _mm_add_pd(t83, s29);
    t7b = _mm_add_pd(s98, s39);
    t8b = _mm_add_pd(s09, s49);
    t9b = _mm_sub_pd(s98, s39);
    t0c = _mm_sub_pd(s09, s49);
    t1c = _mm_add_pd(t3b, t7b);
    t2c = _mm_add_pd(t4b, t8b);
    t3c = _mm_sub_pd(t3b, t7b);
    t4c = _mm_sub_pd(t4b, t8b);
    t5c = _mm_add_pd(t5b, t0c);
    t6c = _mm_add_pd(t6b, t9b);
    t7c = _mm_sub_pd(t5b, t0c);
    t8c = _mm_sub_pd(t9b, t6b);
    s59 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t55), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t65));
    s69 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t55), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t65));
    s79 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t76), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t86));
    s89 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t76), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t86));
    s99 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t18), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t28));
    s0a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t18), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t28));
    t9c = _mm_add_pd(t14, s79);
    t0d = _mm_add_pd(t24, s89);
    t1d = _mm_sub_pd(t14, s79);
    t2d = _mm_sub_pd(t24, s89);
    t3d = _mm_add_pd(s59, s99);
    t4d = _mm_add_pd(s69, s0a);
    t5d = _mm_sub_pd(s59, s99);
    t6d = _mm_sub_pd(s69, s0a);
    t7d = _mm_add_pd(t9c, t3d);
    t8d = _mm_add_pd(t0d, t4d);
    t9d = _mm_sub_pd(t9c, t3d);
    t0e = _mm_sub_pd(t0d, t4d);
    t1e = _mm_add_pd(t1d, t6d);
    t2e = _mm_sub_pd(t2d, t5d);
    t3e = _mm_sub_pd(t1d, t6d);
    t4e = _mm_add_pd(t2d, t5d);
    t5e = _mm_add_pd(t98, t19);
    s1a = _mm_add_pd(v_neg03(v_hi2(t5e, t5e)), v_lo2(t5e, t5e));
    _mm_storeu_pd(((double  *) dst), s1a);
    s2a = v_neg23(_mm_sub_pd(t98, t19));
    _mm_storeu_pd(((double  *) (dst + 256)), s2a);
    s3a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t5a), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t6a));
    s4a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t5a), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t6a));
    s5a = v_lo2(s3a, s4a);
    s6a = v_hi2(s3a, s4a);
    s7a = _mm_add_pd(s5a, s6a);
    _mm_storeu_pd(((double  *) (dst + 16)), s7a);
    s8a = v_neg23(_mm_sub_pd(s5a, s6a));
    _mm_storeu_pd(((double  *) (dst + 496)), s8a);
    s9a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t1c), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t2c));
    s0b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t1c), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t2c));
    s1b = v_lo2(s9a, s0b);
    s2b = v_hi2(s9a, s0b);
    s3b = _mm_add_pd(s1b, s2b);
    _mm_storeu_pd(((double  *) (dst + 32)), s3b);
    s4b = v_neg23(_mm_sub_pd(s1b, s2b));
    _mm_storeu_pd(((double  *) (dst + 480)), s4b);
    s5b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t7d), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t8d));
    s6b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t7d), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t8d));
    s7b = v_lo2(s5b, s6b);
    s8b = v_hi2(s5b, s6b);
    s9b = _mm_add_pd(s7b, s8b);
    _mm_storeu_pd(((double  *) (dst + 48)), s9b);
    s0c = v_neg23(_mm_sub_pd(s7b, s8b));
    _mm_storeu_pd(((double  *) (dst + 464)), s0c);
    s1c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t39), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t49));
    s2c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t39), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t49));
    s3c = v_lo2(s1c, s2c);
    s4c = v_hi2(s1c, s2c);
    s5c = _mm_add_pd(s3c, s4c);
    _mm_storeu_pd(((double  *) (dst + 64)), s5c);
    s6c = v_neg23(_mm_sub_pd(s3c, s4c));
    _mm_storeu_pd(((double  *) (dst + 448)), s6c);
    s7c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t3e), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t4e));
    s8c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t3e), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t4e));
    s9c = v_lo2(s7c, s8c);
    s0d = v_hi2(s7c, s8c);
    s1d = _mm_add_pd(s9c, s0d);
    _mm_storeu_pd(((double  *) (dst + 80)), s1d);
    s2d = v_neg23(_mm_sub_pd(s9c, s0d));
    _mm_storeu_pd(((double  *) (dst + 432)), s2d);
    s3d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t7c), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t8c));
    s4d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t7c), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t8c));
    s5d = v_lo2(s3d, s4d);
    s6d = v_hi2(s3d, s4d);
    s7d = _mm_add_pd(s5d, s6d);
    _mm_storeu_pd(((double  *) (dst + 96)), s7d);
    s8d = v_neg23(_mm_sub_pd(s5d, s6d));
    _mm_storeu_pd(((double  *) (dst + 416)), s8d);
    s9d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t1b), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t2b));
    s0e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t1b), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t2b));
    s1e = v_lo2(s9d, s0e);
    s2e = v_hi2(s9d, s0e);
    s3e = _mm_add_pd(s1e, s2e);
    _mm_storeu_pd(((double  *) (dst + 112)), s3e);
    s4e = v_neg23(_mm_sub_pd(s1e, s2e));
    _mm_storeu_pd(((double  *) (dst + 400)), s4e);
    s5e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t09), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t29));
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t09), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t29));
    s7e = v_lo2(s5e, s6e);
    s8e = v_hi2(s5e, s6e);
    s9e = _mm_add_pd(s7e, s8e);
    _mm_storeu_pd(((double  *) (dst + 128)), s9e);
    s0f = v_neg23(_mm_sub_pd(s7e, s8e));
    _mm_storeu_pd(((double  *) (dst + 384)), s0f);
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t9a), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t0b));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t9a), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t0b));
    s3f = v_lo2(s1f, s2f);
    s4f = v_hi2(s1f, s2f);
    s5f = _mm_add_pd(s3f, s4f);
    _mm_storeu_pd(((double  *) (dst + 144)), s5f);
    s6f = v_neg23(_mm_sub_pd(s3f, s4f));
    _mm_storeu_pd(((double  *) (dst + 368)), s6f);
    s7f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t5c), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t6c));
    s8f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t5c), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t6c));
    s9f = v_lo2(s7f, s8f);
    s0g = v_hi2(s7f, s8f);
    s1g = _mm_add_pd(s9f, s0g);
    _mm_storeu_pd(((double  *) (dst + 160)), s1g);
    s2g = v_neg23(_mm_sub_pd(s9f, s0g));
    _mm_storeu_pd(((double  *) (dst + 352)), s2g);
    s3g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t1e), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t2e));
    s4g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t1e), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t2e));
    s5g = v_lo2(s3g, s4g);
    s6g = v_hi2(s3g, s4g);
    s7g = _mm_add_pd(s5g, s6g);
    _mm_storeu_pd(((double  *) (dst + 176)), s7g);
    s8g = v_neg23(_mm_sub_pd(s5g, s6g));
    _mm_storeu_pd(((double  *) (dst + 336)), s8g);
    s9g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t59), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t69));
    s0h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t59), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t69));
    s1h = v_lo2(s9g, s0h);
    s2h = v_hi2(s9g, s0h);
    s3h = _mm_add_pd(s1h, s2h);
    _mm_storeu_pd(((double  *) (dst + 192)), s3h);
    s4h = v_neg23(_mm_sub_pd(s1h, s2h));
    _mm_storeu_pd(((double  *) (dst + 320)), s4h);
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t9d), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t0e));
    s6h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t9d), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t0e));
    s7h = v_lo2(s5h, s6h);
    s8h = v_hi2(s5h, s6h);
    s9h = _mm_add_pd(s7h, s8h);
    _mm_storeu_pd(((double  *) (dst + 208)), s9h);
    s0i = v_neg23(_mm_sub_pd(s7h, s8h));
    _mm_storeu_pd(((double  *) (dst + 304)), s0i);
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t3c), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t4c));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t3c), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t4c));
    s3i = v_lo2(s1i, s2i);
    s4i = v_hi2(s1i, s2i);
    s5i = _mm_add_pd(s3i, s4i);
    _mm_storeu_pd(((double  *) (dst + 224)), s5i);
    s6i = v_neg23(_mm_sub_pd(s3i, s4i));
    _mm_storeu_pd(((double  *) (dst + 288)), s6i);
    s7i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t7a), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t8a));
    s8i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t7a), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t8a));
    s9i = v_lo2(s7i, s8i);
    s0j = v_hi2(s7i, s8i);
    s1j = _mm_add_pd(s9i, s0j);
    _mm_storeu_pd(((double  *) (dst + 240)), s1j);
    s2j = v_neg23(_mm_sub_pd(s9i, s0j));
    _mm_storeu_pd(((double  *) (dst + 272)), s2j);
    {long i2; for(i2 = 0; i2 <= 6; i2++) {
        a02 = (32 * i2);
        b2 = (((__m128d  *) T) + a02);
        s3j = *((b2 + 32));
        s4j = *((b2 + 48));
        s5j = *((b2 + 33));
        s6j = *((b2 + 49));
        s7j = *((b2 + 34));
        s8j = *((b2 + 50));
        s9j = *((b2 + 35));
        s0k = *((b2 + 51));
        s1k = *((b2 + 36));
        s2k = *((b2 + 52));
        s3k = *((b2 + 37));
        s4k = *((b2 + 53));
        s5k = *((b2 + 38));
        s6k = *((b2 + 54));
        s7k = *((b2 + 39));
        s8k = *((b2 + 55));
        s9k = *((b2 + 40));
        s0l = *((b2 + 56));
        s1l = *((b2 + 41));
        s2l = *((b2 + 57));
        s3l = *((b2 + 42));
        s4l = *((b2 + 58));
        s5l = *((b2 + 43));
        s6l = *((b2 + 59));
        s7l = *((b2 + 44));
        s8l = *((b2 + 60));
        s9l = *((b2 + 45));
        s0m = *((b2 + 61));
        s1m = *((b2 + 46));
        s2m = *((b2 + 62));
        s3m = *((b2 + 47));
        s4m = *((b2 + 63));
        a12 = (D41 + a02);
        a22 = *(a12);
        a32 = *((a12 + 1));
        s5m = _mm_sub_pd(_mm_mul_pd(a22, s3j), _mm_mul_pd(a32, s4j));
        s6m = _mm_add_pd(_mm_mul_pd(a32, s3j), _mm_mul_pd(a22, s4j));
        a42 = *((a12 + 2));
        a52 = *((a12 + 3));
        s7m = _mm_sub_pd(_mm_mul_pd(a42, s5j), _mm_mul_pd(a52, s6j));
        s8m = _mm_add_pd(_mm_mul_pd(a52, s5j), _mm_mul_pd(a42, s6j));
        a62 = *((a12 + 4));
        a72 = *((a12 + 5));
        s9m = _mm_sub_pd(_mm_mul_pd(a62, s7j), _mm_mul_pd(a72, s8j));
        s0n = _mm_add_pd(_mm_mul_pd(a72, s7j), _mm_mul_pd(a62, s8j));
        a82 = *((a12 + 6));
        a92 = *((a12 + 7));
        s1n = _mm_sub_pd(_mm_mul_pd(a82, s9j), _mm_mul_pd(a92, s0k));
        s2n = _mm_add_pd(_mm_mul_pd(a92, s9j), _mm_mul_pd(a82, s0k));
        a03 = *((a12 + 8));
        a13 = *((a12 + 9));
        s3n = _mm_sub_pd(_mm_mul_pd(a03, s1k), _mm_mul_pd(a13, s2k));
        s4n = _mm_add_pd(_mm_mul_pd(a13, s1k), _mm_mul_pd(a03, s2k));
        a23 = *((a12 + 10));
        a33 = *((a12 + 11));
        s5n = _mm_sub_pd(_mm_mul_pd(a23, s3k), _mm_mul_pd(a33, s4k));
        s6n = _mm_add_pd(_mm_mul_pd(a33, s3k), _mm_mul_pd(a23, s4k));
        a43 = *((a12 + 12));
        a53 = *((a12 + 13));
        s7n = _mm_sub_pd(_mm_mul_pd(a43, s5k), _mm_mul_pd(a53, s6k));
        s8n = _mm_add_pd(_mm_mul_pd(a53, s5k), _mm_mul_pd(a43, s6k));
        a63 = *((a12 + 14));
        a73 = *((a12 + 15));
        s9n = _mm_sub_pd(_mm_mul_pd(a63, s7k), _mm_mul_pd(a73, s8k));
        s0o = _mm_add_pd(_mm_mul_pd(a73, s7k), _mm_mul_pd(a63, s8k));
        a83 = *((a12 + 16));
        a93 = *((a12 + 17));
        s1o = _mm_sub_pd(_mm_mul_pd(a83, s9k), _mm_mul_pd(a93, s0l));
        s2o = _mm_add_pd(_mm_mul_pd(a93, s9k), _mm_mul_pd(a83, s0l));
        a04 = *((a12 + 18));
        a14 = *((a12 + 19));
        s3o = _mm_sub_pd(_mm_mul_pd(a04, s1l), _mm_mul_pd(a14, s2l));
        s4o = _mm_add_pd(_mm_mul_pd(a14, s1l), _mm_mul_pd(a04, s2l));
        a24 = *((a12 + 20));
        a34 = *((a12 + 21));
        s5o = _mm_sub_pd(_mm_mul_pd(a24, s3l), _mm_mul_pd(a34, s4l));
        s6o = _mm_add_pd(_mm_mul_pd(a34, s3l), _mm_mul_pd(a24, s4l));
        a44 = *((a12 + 22));
        a54 = *((a12 + 23));
        s7o = _mm_sub_pd(_mm_mul_pd(a44, s5l), _mm_mul_pd(a54, s6l));
        s8o = _mm_add_pd(_mm_mul_pd(a54, s5l), _mm_mul_pd(a44, s6l));
        a64 = *((a12 + 24));
        a74 = *((a12 + 25));
        s9o = _mm_sub_pd(_mm_mul_pd(a64, s7l), _mm_mul_pd(a74, s8l));
        s0p = _mm_add_pd(_mm_mul_pd(a74, s7l), _mm_mul_pd(a64, s8l));
        a84 = *((a12 + 26));
        a94 = *((a12 + 27));
        s1p = _mm_sub_pd(_mm_mul_pd(a84, s9l), _mm_mul_pd(a94, s0m));
        s2p = _mm_add_pd(_mm_mul_pd(a94, s9l), _mm_mul_pd(a84, s0m));
        a05 = *((a12 + 28));
        a15 = *((a12 + 29));
        s3p = _mm_sub_pd(_mm_mul_pd(a05, s1m), _mm_mul_pd(a15, s2m));
        s4p = _mm_add_pd(_mm_mul_pd(a15, s1m), _mm_mul_pd(a05, s2m));
        a25 = *((a12 + 30));
        a35 = *((a12 + 31));
        s5p = _mm_sub_pd(_mm_mul_pd(a25, s3m), _mm_mul_pd(a35, s4m));
        s6p = _mm_add_pd(_mm_mul_pd(a35, s3m), _mm_mul_pd(a25, s4m));
        t6e = _mm_add_pd(s5m, s1o);
        t7e = _mm_add_pd(s6m, s2o);
        t8e = _mm_sub_pd(s5m, s1o);
        t9e = _mm_sub_pd(s6m, s2o);
        t0f = _mm_add_pd(s7m, s3o);
        t1f = _mm_add_pd(s8m, s4o);
        t2f = _mm_sub_pd(s7m, s3o);
        t3f = _mm_sub_pd(s8m, s4o);
        s7p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2f), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3f));
        s8p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3f));
        t4f = _mm_add_pd(s9m, s5o);
        t5f = _mm_add_pd(s0n, s6o);
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9m, s5o));
        a55 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0n, s6o));
        s9p = _mm_sub_pd(a45, a55);
        s0q = _mm_add_pd(a45, a55);
        t6f = _mm_add_pd(s1n, s7o);
        t7f = _mm_add_pd(s2n, s8o);
        t8f = _mm_sub_pd(s1n, s7o);
        t9f = _mm_sub_pd(s2n, s8o);
        s1q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9f));
        s2q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9f));
        t0g = _mm_add_pd(s3n, s9o);
        t1g = _mm_add_pd(s4n, s0p);
        t2g = _mm_sub_pd(s3n, s9o);
        t3g = _mm_sub_pd(s4n, s0p);
        t4g = _mm_add_pd(s5n, s1p);
        t5g = _mm_add_pd(s6n, s2p);
        t6g = _mm_sub_pd(s5n, s1p);
        t7g = _mm_sub_pd(s6n, s2p);
        s3q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6g), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7g));
        s4q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6g), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t7g));
        t8g = _mm_add_pd(s7n, s3p);
        t9g = _mm_add_pd(s8n, s4p);
        a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7n, s3p));
        a75 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8n, s4p));
        s5q = _mm_sub_pd(a65, a75);
        s6q = _mm_add_pd(a65, a75);
        t0h = _mm_add_pd(s9n, s5p);
        t1h = _mm_add_pd(s0o, s6p);
        t2h = _mm_sub_pd(s9n, s5p);
        t3h = _mm_sub_pd(s0o, s6p);
        s7q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2h), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3h));
        s8q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2h), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3h));
        t4h = _mm_add_pd(t6e, t0g);
        t5h = _mm_add_pd(t7e, t1g);
        t6h = _mm_sub_pd(t6e, t0g);
        t7h = _mm_sub_pd(t7e, t1g);
        t8h = _mm_add_pd(t4f, t8g);
        t9h = _mm_add_pd(t5f, t9g);
        t0i = _mm_sub_pd(t4f, t8g);
        t1i = _mm_sub_pd(t5f, t9g);
        t2i = _mm_add_pd(t4h, t8h);
        t3i = _mm_add_pd(t5h, t9h);
        t4i = _mm_sub_pd(t4h, t8h);
        t5i = _mm_sub_pd(t5h, t9h);
        t6i = _mm_add_pd(t6h, t1i);
        t7i = _mm_sub_pd(t7h, t0i);
        t8i = _mm_sub_pd(t6h, t1i);
        t9i = _mm_add_pd(t7h, t0i);
        t0j = _mm_add_pd(t0f, t4g);
        t1j = _mm_add_pd(t1f, t5g);
        t2j = _mm_sub_pd(t0f, t4g);
        t3j = _mm_sub_pd(t1f, t5g);
        t4j = _mm_add_pd(t6f, t0h);
        t5j = _mm_add_pd(t7f, t1h);
        t6j = _mm_sub_pd(t6f, t0h);
        t7j = _mm_sub_pd(t7f, t1h);
        t8j = _mm_add_pd(t0j, t4j);
        t9j = _mm_add_pd(t1j, t5j);
        t0k = _mm_sub_pd(t0j, t4j);
        t1k = _mm_sub_pd(t1j, t5j);
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2j, t7j));
        a95 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3j, t6j));
        s9q = _mm_sub_pd(a85, a95);
        s0r = _mm_add_pd(a85, a95);
        a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t2j, t7j));
        a16 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3j, t6j));
        s1r = _mm_sub_pd(a06, a16);
        s2r = _mm_add_pd(a06, a16);
        t2k = _mm_add_pd(t2i, t8j);
        t3k = _mm_add_pd(t3i, t9j);
        t4k = _mm_sub_pd(t2i, t8j);
        t5k = _mm_sub_pd(t3i, t9j);
        t6k = _mm_add_pd(t6i, s9q);
        t7k = _mm_sub_pd(t7i, s0r);
        t8k = _mm_sub_pd(t6i, s9q);
        t9k = _mm_add_pd(t7i, s0r);
        t0l = _mm_add_pd(t4i, t1k);
        t1l = _mm_sub_pd(t5i, t0k);
        t2l = _mm_sub_pd(t4i, t1k);
        t3l = _mm_add_pd(t5i, t0k);
        t4l = _mm_add_pd(t8i, s1r);
        t5l = _mm_add_pd(t9i, s2r);
        t6l = _mm_sub_pd(t8i, s1r);
        t7l = _mm_sub_pd(t9i, s2r);
        t8l = _mm_add_pd(t8e, t3g);
        t9l = _mm_sub_pd(t9e, t2g);
        t0m = _mm_sub_pd(t8e, t3g);
        t1m = _mm_add_pd(t9e, t2g);
        t2m = _mm_add_pd(s9p, s5q);
        t3m = _mm_sub_pd(s6q, s0q);
        t4m = _mm_sub_pd(s9p, s5q);
        t5m = _mm_add_pd(s0q, s6q);
        t6m = _mm_add_pd(t8l, t2m);
        t7m = _mm_add_pd(t9l, t3m);
        t8m = _mm_sub_pd(t8l, t2m);
        t9m = _mm_sub_pd(t9l, t3m);
        t0n = _mm_sub_pd(t0m, t5m);
        t1n = _mm_sub_pd(t1m, t4m);
        t2n = _mm_add_pd(t0m, t5m);
        t3n = _mm_add_pd(t1m, t4m);
        t4n = _mm_add_pd(s7p, s3q);
        t5n = _mm_add_pd(s8p, s4q);
        t6n = _mm_sub_pd(s7p, s3q);
        t7n = _mm_sub_pd(s8p, s4q);
        t8n = _mm_add_pd(s1q, s7q);
        t9n = _mm_add_pd(s2q, s8q);
        t0o = _mm_sub_pd(s1q, s7q);
        t1o = _mm_sub_pd(s2q, s8q);
        t2o = _mm_add_pd(t4n, t8n);
        t3o = _mm_add_pd(t5n, t9n);
        t4o = _mm_sub_pd(t4n, t8n);
        t5o = _mm_sub_pd(t5n, t9n);
        a26 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6n, t1o));
        a36 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7n, t0o));
        s3r = _mm_sub_pd(a26, a36);
        s4r = _mm_add_pd(a26, a36);
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t6n, t1o));
        a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t7n, t0o));
        s5r = _mm_sub_pd(a46, a56);
        s6r = _mm_add_pd(a46, a56);
        t6o = _mm_add_pd(t6m, t2o);
        t7o = _mm_add_pd(t7m, t3o);
        t8o = _mm_sub_pd(t6m, t2o);
        t9o = _mm_sub_pd(t7m, t3o);
        t0p = _mm_add_pd(t0n, s3r);
        t1p = _mm_sub_pd(t1n, s4r);
        t2p = _mm_sub_pd(t0n, s3r);
        t3p = _mm_add_pd(t1n, s4r);
        t4p = _mm_add_pd(t8m, t5o);
        t5p = _mm_sub_pd(t9m, t4o);
        t6p = _mm_sub_pd(t8m, t5o);
        t7p = _mm_add_pd(t9m, t4o);
        t8p = _mm_add_pd(t2n, s5r);
        t9p = _mm_add_pd(t3n, s6r);
        t0q = _mm_sub_pd(t2n, s5r);
        t1q = _mm_sub_pd(t3n, s6r);
        a66 = (D40 + a02);
        a76 = *(a66);
        a86 = *((a66 + 1));
        s7r = _mm_sub_pd(_mm_mul_pd(a76, t2k), _mm_mul_pd(a86, t3k));
        s8r = _mm_add_pd(_mm_mul_pd(a86, t2k), _mm_mul_pd(a76, t3k));
        s9r = v_lo2(s7r, s8r);
        s0s = v_hi2(s7r, s8r);
        a96 = (2 * i2);
        b3 = (dst + a96);
        s1s = _mm_add_pd(s9r, s0s);
        _mm_storeu_pd(((double  *) (b3 + 2)), s1s);
        b4 = (dst - a96);
        s2s = v_neg23(_mm_sub_pd(s9r, s0s));
        _mm_storeu_pd(((double  *) (b4 + 510)), s2s);
        a07 = *((a66 + 2));
        a17 = *((a66 + 3));
        s3s = _mm_sub_pd(_mm_mul_pd(a07, t6o), _mm_mul_pd(a17, t7o));
        s4s = _mm_add_pd(_mm_mul_pd(a17, t6o), _mm_mul_pd(a07, t7o));
        s5s = v_lo2(s3s, s4s);
        s6s = v_hi2(s3s, s4s);
        s7s = _mm_add_pd(s5s, s6s);
        _mm_storeu_pd(((double  *) (b3 + 34)), s7s);
        s8s = v_neg23(_mm_sub_pd(s5s, s6s));
        _mm_storeu_pd(((double  *) (b4 + 478)), s8s);
        a27 = *((a66 + 4));
        a37 = *((a66 + 5));
        s9s = _mm_sub_pd(_mm_mul_pd(a27, t6k), _mm_mul_pd(a37, t7k));
        s0t = _mm_add_pd(_mm_mul_pd(a37, t6k), _mm_mul_pd(a27, t7k));
        s1t = v_lo2(s9s, s0t);
        s2t = v_hi2(s9s, s0t);
        s3t = _mm_add_pd(s1t, s2t);
        _mm_storeu_pd(((double  *) (b3 + 66)), s3t);
        s4t = v_neg23(_mm_sub_pd(s1t, s2t));
        _mm_storeu_pd(((double  *) (b4 + 446)), s4t);
        a47 = *((a66 + 6));
        a57 = *((a66 + 7));
        s5t = _mm_sub_pd(_mm_mul_pd(a47, t0p), _mm_mul_pd(a57, t1p));
        s6t = _mm_add_pd(_mm_mul_pd(a57, t0p), _mm_mul_pd(a47, t1p));
        s7t = v_lo2(s5t, s6t);
        s8t = v_hi2(s5t, s6t);
        s9t = _mm_add_pd(s7t, s8t);
        _mm_storeu_pd(((double  *) (b3 + 98)), s9t);
        s0u = v_neg23(_mm_sub_pd(s7t, s8t));
        _mm_storeu_pd(((double  *) (b4 + 414)), s0u);
        a67 = *((a66 + 8));
        a77 = *((a66 + 9));
        s1u = _mm_sub_pd(_mm_mul_pd(a67, t0l), _mm_mul_pd(a77, t1l));
        s2u = _mm_add_pd(_mm_mul_pd(a77, t0l), _mm_mul_pd(a67, t1l));
        s3u = v_lo2(s1u, s2u);
        s4u = v_hi2(s1u, s2u);
        s5u = _mm_add_pd(s3u, s4u);
        _mm_storeu_pd(((double  *) (b3 + 130)), s5u);
        s6u = v_neg23(_mm_sub_pd(s3u, s4u));
        _mm_storeu_pd(((double  *) (b4 + 382)), s6u);
        a87 = *((a66 + 10));
        a97 = *((a66 + 11));
        s7u = _mm_sub_pd(_mm_mul_pd(a87, t4p), _mm_mul_pd(a97, t5p));
        s8u = _mm_add_pd(_mm_mul_pd(a97, t4p), _mm_mul_pd(a87, t5p));
        s9u = v_lo2(s7u, s8u);
        s0v = v_hi2(s7u, s8u);
        s1v = _mm_add_pd(s9u, s0v);
        _mm_storeu_pd(((double  *) (b3 + 162)), s1v);
        s2v = v_neg23(_mm_sub_pd(s9u, s0v));
        _mm_storeu_pd(((double  *) (b4 + 350)), s2v);
        a08 = *((a66 + 12));
        a18 = *((a66 + 13));
        s3v = _mm_sub_pd(_mm_mul_pd(a08, t4l), _mm_mul_pd(a18, t5l));
        s4v = _mm_add_pd(_mm_mul_pd(a18, t4l), _mm_mul_pd(a08, t5l));
        s5v = v_lo2(s3v, s4v);
        s6v = v_hi2(s3v, s4v);
        s7v = _mm_add_pd(s5v, s6v);
        _mm_storeu_pd(((double  *) (b3 + 194)), s7v);
        s8v = v_neg23(_mm_sub_pd(s5v, s6v));
        _mm_storeu_pd(((double  *) (b4 + 318)), s8v);
        a28 = *((a66 + 14));
        a38 = *((a66 + 15));
        s9v = _mm_sub_pd(_mm_mul_pd(a28, t8p), _mm_mul_pd(a38, t9p));
        s0w = _mm_add_pd(_mm_mul_pd(a38, t8p), _mm_mul_pd(a28, t9p));
        s1w = v_lo2(s9v, s0w);
        s2w = v_hi2(s9v, s0w);
        s3w = _mm_add_pd(s1w, s2w);
        _mm_storeu_pd(((double  *) (b3 + 226)), s3w);
        s4w = v_neg23(_mm_sub_pd(s1w, s2w));
        _mm_storeu_pd(((double  *) (b4 + 286)), s4w);
        a48 = *((a66 + 16));
        a58 = *((a66 + 17));
        s5w = _mm_sub_pd(_mm_mul_pd(a48, t4k), _mm_mul_pd(a58, t5k));
        s6w = _mm_add_pd(_mm_mul_pd(a58, t4k), _mm_mul_pd(a48, t5k));
        s7w = v_lo2(s5w, s6w);
        s8w = v_hi2(s5w, s6w);
        s9w = _mm_add_pd(s7w, s8w);
        _mm_storeu_pd(((double  *) (b3 + 258)), s9w);
        s0x = v_neg23(_mm_sub_pd(s7w, s8w));
        _mm_storeu_pd(((double  *) (b4 + 254)), s0x);
        a68 = *((a66 + 18));
        a78 = *((a66 + 19));
        s1x = _mm_sub_pd(_mm_mul_pd(a68, t8o), _mm_mul_pd(a78, t9o));
        s2x = _mm_add_pd(_mm_mul_pd(a78, t8o), _mm_mul_pd(a68, t9o));
        s3x = v_lo2(s1x, s2x);
        s4x = v_hi2(s1x, s2x);
        s5x = _mm_add_pd(s3x, s4x);
        _mm_storeu_pd(((double  *) (b3 + 290)), s5x);
        s6x = v_neg23(_mm_sub_pd(s3x, s4x));
        _mm_storeu_pd(((double  *) (b4 + 222)), s6x);
        a88 = *((a66 + 20));
        a98 = *((a66 + 21));
        s7x = _mm_sub_pd(_mm_mul_pd(a88, t8k), _mm_mul_pd(a98, t9k));
        s8x = _mm_add_pd(_mm_mul_pd(a98, t8k), _mm_mul_pd(a88, t9k));
        s9x = v_lo2(s7x, s8x);
        s0y = v_hi2(s7x, s8x);
        s1y = _mm_add_pd(s9x, s0y);
        _mm_storeu_pd(((double  *) (b3 + 322)), s1y);
        s2y = v_neg23(_mm_sub_pd(s9x, s0y));
        _mm_storeu_pd(((double  *) (b4 + 190)), s2y);
        a09 = *((a66 + 22));
        a19 = *((a66 + 23));
        s3y = _mm_sub_pd(_mm_mul_pd(a09, t2p), _mm_mul_pd(a19, t3p));
        s4y = _mm_add_pd(_mm_mul_pd(a19, t2p), _mm_mul_pd(a09, t3p));
        s5y = v_lo2(s3y, s4y);
        s6y = v_hi2(s3y, s4y);
        s7y = _mm_add_pd(s5y, s6y);
        _mm_storeu_pd(((double  *) (b3 + 354)), s7y);
        s8y = v_neg23(_mm_sub_pd(s5y, s6y));
        _mm_storeu_pd(((double  *) (b4 + 158)), s8y);
        a29 = *((a66 + 24));
        a39 = *((a66 + 25));
        s9y = _mm_sub_pd(_mm_mul_pd(a29, t2l), _mm_mul_pd(a39, t3l));
        s0z = _mm_add_pd(_mm_mul_pd(a39, t2l), _mm_mul_pd(a29, t3l));
        s1z = v_lo2(s9y, s0z);
        s2z = v_hi2(s9y, s0z);
        s3z = _mm_add_pd(s1z, s2z);
        _mm_storeu_pd(((double  *) (b3 + 386)), s3z);
        s4z = v_neg23(_mm_sub_pd(s1z, s2z));
        _mm_storeu_pd(((double  *) (b4 + 126)), s4z);
        a49 = *((a66 + 26));
        a59 = *((a66 + 27));
        s5z = _mm_sub_pd(_mm_mul_pd(a49, t6p), _mm_mul_pd(a59, t7p));
        s6z = _mm_add_pd(_mm_mul_pd(a59, t6p), _mm_mul_pd(a49, t7p));
        s7z = v_lo2(s5z, s6z);
        s8z = v_hi2(s5z, s6z);
        s9z = _mm_add_pd(s7z, s8z);
        _mm_storeu_pd(((double  *) (b3 + 418)), s9z);
        s0A = v_neg23(_mm_sub_pd(s7z, s8z));
        _mm_storeu_pd(((double  *) (b4 + 94)), s0A);
        a69 = *((a66 + 28));
        a79 = *((a66 + 29));
        s1A = _mm_sub_pd(_mm_mul_pd(a69, t6l), _mm_mul_pd(a79, t7l));
        s2A = _mm_add_pd(_mm_mul_pd(a79, t6l), _mm_mul_pd(a69, t7l));
        s3A = v_lo2(s1A, s2A);
        s4A = v_hi2(s1A, s2A);
        s5A = _mm_add_pd(s3A, s4A);
        _mm_storeu_pd(((double  *) (b3 + 450)), s5A);
        s6A = v_neg23(_mm_sub_pd(s3A, s4A));
        _mm_storeu_pd(((double  *) (b4 + 62)), s6A);
        a89 = *((a66 + 30));
        a99 = *((a66 + 31));
        s7A = _mm_sub_pd(_mm_mul_pd(a89, t0q), _mm_mul_pd(a99, t1q));
        s8A = _mm_add_pd(_mm_mul_pd(a99, t0q), _mm_mul_pd(a89, t1q));
        s9A = v_lo2(s7A, s8A);
        s0B = v_hi2(s7A, s8A);
        s1B = _mm_add_pd(s9A, s0B);
        _mm_storeu_pd(((double  *) (b3 + 482)), s1B);
        s2B = v_neg23(_mm_sub_pd(s9A, s0B));
        _mm_storeu_pd(((double  *) (b4 + 30)), s2B);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_512)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_512_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[512]);
    __m128d a01, a03, a04, a05, a06, a08, a09, a0a, a11, a13, a14, a15, a16, a17, a18, a19, a21, a23, a24, a25, a26, a27
            , a28, a29, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a4, a41, a42, a43, a44, a45, a46, a47, a48, a49
            , a5, a51, a52, a53, a54, a55, a56, a57, a58, a59, a6, a61, a62, a63, a64, a65, a66, a67, a68, a69, a71, a72
            , a73, a74, a75, a77, a78, a79, a8, a81, a82, a83, a84, a85, a86, a87, a88, a89, a9, a91, a92, a93, a94, a95
            , a96, a97, a98, a99, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0a, s0b, s0c, s0d, s0e, s0f
            , s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12
            , s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m
            , s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2A, s2B, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s
            , s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3a, s3b, s3c, s3d
            , s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z
            , s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k
            , s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56
            , s57, s58, s59, s5A, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r
            , s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85
            , s86, s87, s88, s89, s8A, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q
            , s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9a, s9b
            , s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x
            , s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j
            , t0k, t0l, t0m, t0n, t0o, t0p, t0q, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f
            , t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a
            , t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t3, t31, t32, t33, t34, t35, t36
            , t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t4, t41, t42
            , t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o
            , t4p, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g
            , t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t8, t81, t82, t83, t84, t85, t86, t87, t88
            , t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t9, t91, t92, t93, t94
            , t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p;
    __m128d  *a, *a02, *a07, *a2, *a22, *a7, *a76, *b, *b2, *b3;
    int a12;
    {long i; for(i = 0; i <= 15; i++) {
        a = (((__m128d  *) src) + i);
        s = *(a);
        s2 = *((a + 128));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = *((a + 64));
        s4 = *((a + 192));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = *((a + 16));
        s6 = *((a + 144));
        t5 = _mm_add_pd(s5, s6);
        t6 = _mm_sub_pd(s5, s6);
        s7 = *((a + 80));
        s8 = *((a + 208));
        t7 = _mm_add_pd(s7, s8);
        t8 = _mm_sub_pd(s7, s8);
        s9 = *((a + 32));
        s01 = *((a + 160));
        t9 = _mm_add_pd(s9, s01);
        s11 = *((a + 96));
        s21 = *((a + 224));
        t01 = _mm_add_pd(s11, s21);
        s31 = *((a + 48));
        s41 = *((a + 176));
        t11 = _mm_add_pd(s31, s41);
        t21 = _mm_sub_pd(s31, s41);
        s51 = *((a + 112));
        s61 = *((a + 240));
        t31 = _mm_add_pd(s51, s61);
        t41 = _mm_sub_pd(s51, s61);
        t51 = _mm_add_pd(t, t3);
        t61 = _mm_sub_pd(t, t3);
        t71 = _mm_add_pd(t9, t01);
        t81 = _mm_sub_pd(t9, t01);
        t91 = _mm_add_pd(t5, t7);
        t02 = _mm_add_pd(t11, t31);
        a2 = (((__m128d  *) T) + i);
        s71 = _mm_add_pd(t51, t71);
        *(a2) = s71;
        s81 = _mm_sub_pd(t51, t71);
        *((a2 + 128)) = s81;
        s91 = _mm_add_pd(t91, t02);
        *((a2 + 16)) = s91;
        s02 = _mm_sub_pd(t02, t91);
        *((a2 + 144)) = s02;
        a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
        a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
        s12 = _mm_add_pd(a3, a4);
        s22 = _mm_sub_pd(a4, a3);
        s32 = _mm_add_pd(t61, s12);
        *((a2 + 64)) = s32;
        s42 = _mm_sub_pd(s22, t81);
        *((a2 + 80)) = s42;
        s52 = _mm_sub_pd(t61, s12);
        *((a2 + 192)) = s52;
        s62 = _mm_add_pd(t81, s22);
        *((a2 + 208)) = s62;
        s72 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
        s82 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
        a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
        a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
        s92 = _mm_add_pd(a5, a6);
        s03 = _mm_sub_pd(a6, a5);
        s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
        s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
        t12 = _mm_add_pd(t2, s92);
        t22 = _mm_sub_pd(s03, t4);
        t32 = _mm_sub_pd(t2, s92);
        t42 = _mm_add_pd(t4, s03);
        t52 = _mm_add_pd(s72, s13);
        t62 = _mm_add_pd(s82, s23);
        t72 = _mm_sub_pd(s72, s13);
        t82 = _mm_sub_pd(s82, s23);
        s33 = _mm_add_pd(t12, t52);
        *((a2 + 32)) = s33;
        s43 = _mm_add_pd(t22, t62);
        *((a2 + 48)) = s43;
        s53 = _mm_sub_pd(t12, t52);
        *((a2 + 224)) = s53;
        s63 = _mm_sub_pd(t62, t22);
        *((a2 + 240)) = s63;
        s73 = _mm_add_pd(t32, t82);
        *((a2 + 160)) = s73;
        s83 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t42, t72));
        *((a2 + 176)) = s83;
        s93 = _mm_sub_pd(t32, t82);
        *((a2 + 96)) = s93;
        s04 = _mm_sub_pd(t42, t72);
        *((a2 + 112)) = s04;
    }}
    a7 = ((__m128d  *) T);
    s14 = *(a7);
    s24 = *((a7 + 16));
    t92 = _mm_add_pd(s14, s24);
    t03 = _mm_sub_pd(s14, s24);
    s34 = *((a7 + 8));
    s44 = *((a7 + 24));
    t13 = _mm_add_pd(s34, s44);
    t23 = _mm_sub_pd(s34, s44);
    s54 = *((a7 + 4));
    s64 = *((a7 + 20));
    t33 = _mm_add_pd(s54, s64);
    s74 = *((a7 + 12));
    s84 = *((a7 + 28));
    t43 = _mm_add_pd(s74, s84);
    t53 = _mm_add_pd(t92, t13);
    t63 = _mm_sub_pd(t92, t13);
    t73 = _mm_add_pd(t33, t43);
    t83 = _mm_sub_pd(t33, t43);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s54, s64));
    a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s74, s84));
    s94 = _mm_add_pd(a8, a9);
    s05 = _mm_sub_pd(a9, a8);
    t93 = _mm_add_pd(t03, s94);
    t04 = _mm_sub_pd(s05, t23);
    t14 = _mm_sub_pd(t03, s94);
    t24 = _mm_add_pd(t23, s05);
    s15 = *((a7 + 1));
    s25 = *((a7 + 17));
    t34 = _mm_add_pd(s15, s25);
    t44 = _mm_sub_pd(s15, s25);
    s35 = *((a7 + 9));
    s45 = *((a7 + 25));
    t54 = _mm_add_pd(s35, s45);
    t64 = _mm_sub_pd(s35, s45);
    s55 = *((a7 + 5));
    s65 = *((a7 + 21));
    t74 = _mm_add_pd(s55, s65);
    s75 = *((a7 + 13));
    s85 = *((a7 + 29));
    t84 = _mm_add_pd(s75, s85);
    t94 = _mm_add_pd(t34, t54);
    t05 = _mm_sub_pd(t34, t54);
    t15 = _mm_add_pd(t74, t84);
    t25 = _mm_sub_pd(t74, t84);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s55, s65));
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s75, s85));
    s95 = _mm_add_pd(a01, a11);
    s06 = _mm_sub_pd(a11, a01);
    t35 = _mm_add_pd(t44, s95);
    t45 = _mm_sub_pd(s06, t64);
    t55 = _mm_sub_pd(t44, s95);
    t65 = _mm_add_pd(t64, s06);
    s16 = *((a7 + 2));
    s26 = *((a7 + 18));
    t75 = _mm_add_pd(s16, s26);
    t85 = _mm_sub_pd(s16, s26);
    s36 = *((a7 + 10));
    s46 = *((a7 + 26));
    t95 = _mm_add_pd(s36, s46);
    t06 = _mm_sub_pd(s36, s46);
    s56 = *((a7 + 6));
    s66 = *((a7 + 22));
    t16 = _mm_add_pd(s56, s66);
    s76 = *((a7 + 14));
    s86 = *((a7 + 30));
    t26 = _mm_add_pd(s76, s86);
    t36 = _mm_add_pd(t75, t95);
    t46 = _mm_add_pd(t16, t26);
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s56, s66));
    a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s76, s86));
    s96 = _mm_add_pd(a21, a31);
    s07 = _mm_sub_pd(a31, a21);
    t56 = _mm_add_pd(t85, s96);
    t66 = _mm_sub_pd(s07, t06);
    t76 = _mm_sub_pd(t85, s96);
    t86 = _mm_add_pd(t06, s07);
    s17 = *((a7 + 3));
    s27 = *((a7 + 19));
    t96 = _mm_add_pd(s17, s27);
    t07 = _mm_sub_pd(s17, s27);
    s37 = *((a7 + 11));
    s47 = *((a7 + 27));
    t17 = _mm_add_pd(s37, s47);
    t27 = _mm_sub_pd(s37, s47);
    s57 = *((a7 + 7));
    s67 = *((a7 + 23));
    t37 = _mm_add_pd(s57, s67);
    s77 = *((a7 + 15));
    s87 = *((a7 + 31));
    t47 = _mm_add_pd(s77, s87);
    t57 = _mm_add_pd(t96, t17);
    t67 = _mm_sub_pd(t96, t17);
    t77 = _mm_add_pd(t37, t47);
    t87 = _mm_sub_pd(t37, t47);
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s57, s67));
    a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s77, s87));
    s97 = _mm_add_pd(a41, a51);
    s08 = _mm_sub_pd(a51, a41);
    t97 = _mm_add_pd(t07, s97);
    t08 = _mm_sub_pd(s08, t27);
    t18 = _mm_sub_pd(t07, s97);
    t28 = _mm_add_pd(t27, s08);
    t38 = _mm_add_pd(t53, t73);
    t48 = _mm_sub_pd(t53, t73);
    t58 = _mm_add_pd(t36, t46);
    t68 = _mm_sub_pd(t36, t46);
    t78 = _mm_add_pd(t94, t15);
    t88 = _mm_add_pd(t57, t77);
    t98 = _mm_add_pd(t38, t58);
    t09 = _mm_sub_pd(t38, t58);
    t19 = _mm_add_pd(t78, t88);
    t29 = _mm_sub_pd(t78, t88);
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t57, t77));
    s18 = _mm_add_pd(a61, a71);
    s28 = _mm_sub_pd(a71, a61);
    t39 = _mm_add_pd(t48, s18);
    t49 = _mm_sub_pd(s28, t68);
    t59 = _mm_sub_pd(t48, s18);
    t69 = _mm_add_pd(t68, s28);
    s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
    s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t45));
    s58 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t56), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66));
    s68 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t56), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66));
    s78 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t97), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t08));
    s88 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t97), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t08));
    t79 = _mm_add_pd(t93, s58);
    t89 = _mm_add_pd(t04, s68);
    t99 = _mm_sub_pd(t93, s58);
    t0a = _mm_sub_pd(t04, s68);
    t1a = _mm_add_pd(s38, s78);
    t2a = _mm_add_pd(s48, s88);
    t3a = _mm_sub_pd(s38, s78);
    t4a = _mm_sub_pd(s48, s88);
    t5a = _mm_add_pd(t79, t1a);
    t6a = _mm_add_pd(t89, t2a);
    t7a = _mm_sub_pd(t79, t1a);
    t8a = _mm_sub_pd(t89, t2a);
    t9a = _mm_add_pd(t99, t4a);
    t0b = _mm_sub_pd(t0a, t3a);
    t1b = _mm_sub_pd(t99, t4a);
    t2b = _mm_add_pd(t0a, t3a);
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
    s09 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t75, t95));
    a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t16, t26));
    s19 = _mm_add_pd(a81, a91);
    s29 = _mm_sub_pd(a91, a81);
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t87));
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t67), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
    t3b = _mm_add_pd(t63, s19);
    t4b = _mm_sub_pd(s29, t83);
    t5b = _mm_sub_pd(t63, s19);
    t6b = _mm_add_pd(t83, s29);
    t7b = _mm_add_pd(s98, s39);
    t8b = _mm_add_pd(s09, s49);
    t9b = _mm_sub_pd(s98, s39);
    t0c = _mm_sub_pd(s09, s49);
    t1c = _mm_add_pd(t3b, t7b);
    t2c = _mm_add_pd(t4b, t8b);
    t3c = _mm_sub_pd(t3b, t7b);
    t4c = _mm_sub_pd(t4b, t8b);
    t5c = _mm_add_pd(t5b, t0c);
    t6c = _mm_add_pd(t6b, t9b);
    t7c = _mm_sub_pd(t5b, t0c);
    t8c = _mm_sub_pd(t9b, t6b);
    s59 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t55), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t65));
    s69 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t55), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t65));
    s79 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t76), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t86));
    s89 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t76), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t86));
    s99 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t18), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t28));
    s0a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t18), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t28));
    t9c = _mm_add_pd(t14, s79);
    t0d = _mm_add_pd(t24, s89);
    t1d = _mm_sub_pd(t14, s79);
    t2d = _mm_sub_pd(t24, s89);
    t3d = _mm_add_pd(s59, s99);
    t4d = _mm_add_pd(s69, s0a);
    t5d = _mm_sub_pd(s59, s99);
    t6d = _mm_sub_pd(s69, s0a);
    t7d = _mm_add_pd(t9c, t3d);
    t8d = _mm_add_pd(t0d, t4d);
    t9d = _mm_sub_pd(t9c, t3d);
    t0e = _mm_sub_pd(t0d, t4d);
    t1e = _mm_add_pd(t1d, t6d);
    t2e = _mm_sub_pd(t2d, t5d);
    t3e = _mm_sub_pd(t1d, t6d);
    t4e = _mm_add_pd(t2d, t5d);
    t5e = _mm_add_pd(t98, t19);
    a02 = ((__m128d  *) dst);
    s1a = _mm_add_pd(v_neg03(v_hi2(t5e, t5e)), v_lo2(t5e, t5e));
    *(a02) = s1a;
    s2a = v_neg23(_mm_sub_pd(t98, t19));
    *((a02 + 128)) = s2a;
    s3a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t5a), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t6a));
    s4a = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t5a), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t6a));
    s5a = v_lo2(s3a, s4a);
    s6a = v_hi2(s3a, s4a);
    s7a = _mm_add_pd(s5a, s6a);
    *((a02 + 8)) = s7a;
    s8a = v_neg23(_mm_sub_pd(s5a, s6a));
    *((a02 + 248)) = s8a;
    s9a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t1c), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t2c));
    s0b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t1c), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t2c));
    s1b = v_lo2(s9a, s0b);
    s2b = v_hi2(s9a, s0b);
    s3b = _mm_add_pd(s1b, s2b);
    *((a02 + 16)) = s3b;
    s4b = v_neg23(_mm_sub_pd(s1b, s2b));
    *((a02 + 240)) = s4b;
    s5b = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t7d), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t8d));
    s6b = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t7d), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t8d));
    s7b = v_lo2(s5b, s6b);
    s8b = v_hi2(s5b, s6b);
    s9b = _mm_add_pd(s7b, s8b);
    *((a02 + 24)) = s9b;
    s0c = v_neg23(_mm_sub_pd(s7b, s8b));
    *((a02 + 232)) = s0c;
    s1c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t39), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t49));
    s2c = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t39), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t49));
    s3c = v_lo2(s1c, s2c);
    s4c = v_hi2(s1c, s2c);
    s5c = _mm_add_pd(s3c, s4c);
    *((a02 + 32)) = s5c;
    s6c = v_neg23(_mm_sub_pd(s3c, s4c));
    *((a02 + 224)) = s6c;
    s7c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t3e), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t4e));
    s8c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t3e), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t4e));
    s9c = v_lo2(s7c, s8c);
    s0d = v_hi2(s7c, s8c);
    s1d = _mm_add_pd(s9c, s0d);
    *((a02 + 40)) = s1d;
    s2d = v_neg23(_mm_sub_pd(s9c, s0d));
    *((a02 + 216)) = s2d;
    s3d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t7c), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t8c));
    s4d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t7c), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t8c));
    s5d = v_lo2(s3d, s4d);
    s6d = v_hi2(s3d, s4d);
    s7d = _mm_add_pd(s5d, s6d);
    *((a02 + 48)) = s7d;
    s8d = v_neg23(_mm_sub_pd(s5d, s6d));
    *((a02 + 208)) = s8d;
    s9d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t1b), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t2b));
    s0e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t1b), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t2b));
    s1e = v_lo2(s9d, s0e);
    s2e = v_hi2(s9d, s0e);
    s3e = _mm_add_pd(s1e, s2e);
    *((a02 + 56)) = s3e;
    s4e = v_neg23(_mm_sub_pd(s1e, s2e));
    *((a02 + 200)) = s4e;
    s5e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t09), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t29));
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t09), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t29));
    s7e = v_lo2(s5e, s6e);
    s8e = v_hi2(s5e, s6e);
    s9e = _mm_add_pd(s7e, s8e);
    *((a02 + 64)) = s9e;
    s0f = v_neg23(_mm_sub_pd(s7e, s8e));
    *((a02 + 192)) = s0f;
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t9a), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t0b));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t9a), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t0b));
    s3f = v_lo2(s1f, s2f);
    s4f = v_hi2(s1f, s2f);
    s5f = _mm_add_pd(s3f, s4f);
    *((a02 + 72)) = s5f;
    s6f = v_neg23(_mm_sub_pd(s3f, s4f));
    *((a02 + 184)) = s6f;
    s7f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t5c), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t6c));
    s8f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t5c), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t6c));
    s9f = v_lo2(s7f, s8f);
    s0g = v_hi2(s7f, s8f);
    s1g = _mm_add_pd(s9f, s0g);
    *((a02 + 80)) = s1g;
    s2g = v_neg23(_mm_sub_pd(s9f, s0g));
    *((a02 + 176)) = s2g;
    s3g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t1e), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t2e));
    s4g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t1e), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t2e));
    s5g = v_lo2(s3g, s4g);
    s6g = v_hi2(s3g, s4g);
    s7g = _mm_add_pd(s5g, s6g);
    *((a02 + 88)) = s7g;
    s8g = v_neg23(_mm_sub_pd(s5g, s6g));
    *((a02 + 168)) = s8g;
    s9g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t59), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t69));
    s0h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t59), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t69));
    s1h = v_lo2(s9g, s0h);
    s2h = v_hi2(s9g, s0h);
    s3h = _mm_add_pd(s1h, s2h);
    *((a02 + 96)) = s3h;
    s4h = v_neg23(_mm_sub_pd(s1h, s2h));
    *((a02 + 160)) = s4h;
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t9d), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t0e));
    s6h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t9d), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t0e));
    s7h = v_lo2(s5h, s6h);
    s8h = v_hi2(s5h, s6h);
    s9h = _mm_add_pd(s7h, s8h);
    *((a02 + 104)) = s9h;
    s0i = v_neg23(_mm_sub_pd(s7h, s8h));
    *((a02 + 152)) = s0i;
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t3c), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t4c));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t3c), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t4c));
    s3i = v_lo2(s1i, s2i);
    s4i = v_hi2(s1i, s2i);
    s5i = _mm_add_pd(s3i, s4i);
    *((a02 + 112)) = s5i;
    s6i = v_neg23(_mm_sub_pd(s3i, s4i));
    *((a02 + 144)) = s6i;
    s7i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t7a), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t8a));
    s8i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t7a), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t8a));
    s9i = v_lo2(s7i, s8i);
    s0j = v_hi2(s7i, s8i);
    s1j = _mm_add_pd(s9i, s0j);
    *((a02 + 120)) = s1j;
    s2j = v_neg23(_mm_sub_pd(s9i, s0j));
    *((a02 + 136)) = s2j;
    {long i2; for(i2 = 0; i2 <= 6; i2++) {
        a12 = (32 * i2);
        b = (((__m128d  *) T) + a12);
        s3j = *((b + 32));
        s4j = *((b + 48));
        s5j = *((b + 33));
        s6j = *((b + 49));
        s7j = *((b + 34));
        s8j = *((b + 50));
        s9j = *((b + 35));
        s0k = *((b + 51));
        s1k = *((b + 36));
        s2k = *((b + 52));
        s3k = *((b + 37));
        s4k = *((b + 53));
        s5k = *((b + 38));
        s6k = *((b + 54));
        s7k = *((b + 39));
        s8k = *((b + 55));
        s9k = *((b + 40));
        s0l = *((b + 56));
        s1l = *((b + 41));
        s2l = *((b + 57));
        s3l = *((b + 42));
        s4l = *((b + 58));
        s5l = *((b + 43));
        s6l = *((b + 59));
        s7l = *((b + 44));
        s8l = *((b + 60));
        s9l = *((b + 45));
        s0m = *((b + 61));
        s1m = *((b + 46));
        s2m = *((b + 62));
        s3m = *((b + 47));
        s4m = *((b + 63));
        a22 = (D42 + a12);
        a32 = *(a22);
        a42 = *((a22 + 1));
        s5m = _mm_sub_pd(_mm_mul_pd(a32, s3j), _mm_mul_pd(a42, s4j));
        s6m = _mm_add_pd(_mm_mul_pd(a42, s3j), _mm_mul_pd(a32, s4j));
        a52 = *((a22 + 2));
        a62 = *((a22 + 3));
        s7m = _mm_sub_pd(_mm_mul_pd(a52, s5j), _mm_mul_pd(a62, s6j));
        s8m = _mm_add_pd(_mm_mul_pd(a62, s5j), _mm_mul_pd(a52, s6j));
        a72 = *((a22 + 4));
        a82 = *((a22 + 5));
        s9m = _mm_sub_pd(_mm_mul_pd(a72, s7j), _mm_mul_pd(a82, s8j));
        s0n = _mm_add_pd(_mm_mul_pd(a82, s7j), _mm_mul_pd(a72, s8j));
        a92 = *((a22 + 6));
        a03 = *((a22 + 7));
        s1n = _mm_sub_pd(_mm_mul_pd(a92, s9j), _mm_mul_pd(a03, s0k));
        s2n = _mm_add_pd(_mm_mul_pd(a03, s9j), _mm_mul_pd(a92, s0k));
        a13 = *((a22 + 8));
        a23 = *((a22 + 9));
        s3n = _mm_sub_pd(_mm_mul_pd(a13, s1k), _mm_mul_pd(a23, s2k));
        s4n = _mm_add_pd(_mm_mul_pd(a23, s1k), _mm_mul_pd(a13, s2k));
        a33 = *((a22 + 10));
        a43 = *((a22 + 11));
        s5n = _mm_sub_pd(_mm_mul_pd(a33, s3k), _mm_mul_pd(a43, s4k));
        s6n = _mm_add_pd(_mm_mul_pd(a43, s3k), _mm_mul_pd(a33, s4k));
        a53 = *((a22 + 12));
        a63 = *((a22 + 13));
        s7n = _mm_sub_pd(_mm_mul_pd(a53, s5k), _mm_mul_pd(a63, s6k));
        s8n = _mm_add_pd(_mm_mul_pd(a63, s5k), _mm_mul_pd(a53, s6k));
        a73 = *((a22 + 14));
        a83 = *((a22 + 15));
        s9n = _mm_sub_pd(_mm_mul_pd(a73, s7k), _mm_mul_pd(a83, s8k));
        s0o = _mm_add_pd(_mm_mul_pd(a83, s7k), _mm_mul_pd(a73, s8k));
        a93 = *((a22 + 16));
        a04 = *((a22 + 17));
        s1o = _mm_sub_pd(_mm_mul_pd(a93, s9k), _mm_mul_pd(a04, s0l));
        s2o = _mm_add_pd(_mm_mul_pd(a04, s9k), _mm_mul_pd(a93, s0l));
        a14 = *((a22 + 18));
        a24 = *((a22 + 19));
        s3o = _mm_sub_pd(_mm_mul_pd(a14, s1l), _mm_mul_pd(a24, s2l));
        s4o = _mm_add_pd(_mm_mul_pd(a24, s1l), _mm_mul_pd(a14, s2l));
        a34 = *((a22 + 20));
        a44 = *((a22 + 21));
        s5o = _mm_sub_pd(_mm_mul_pd(a34, s3l), _mm_mul_pd(a44, s4l));
        s6o = _mm_add_pd(_mm_mul_pd(a44, s3l), _mm_mul_pd(a34, s4l));
        a54 = *((a22 + 22));
        a64 = *((a22 + 23));
        s7o = _mm_sub_pd(_mm_mul_pd(a54, s5l), _mm_mul_pd(a64, s6l));
        s8o = _mm_add_pd(_mm_mul_pd(a64, s5l), _mm_mul_pd(a54, s6l));
        a74 = *((a22 + 24));
        a84 = *((a22 + 25));
        s9o = _mm_sub_pd(_mm_mul_pd(a74, s7l), _mm_mul_pd(a84, s8l));
        s0p = _mm_add_pd(_mm_mul_pd(a84, s7l), _mm_mul_pd(a74, s8l));
        a94 = *((a22 + 26));
        a05 = *((a22 + 27));
        s1p = _mm_sub_pd(_mm_mul_pd(a94, s9l), _mm_mul_pd(a05, s0m));
        s2p = _mm_add_pd(_mm_mul_pd(a05, s9l), _mm_mul_pd(a94, s0m));
        a15 = *((a22 + 28));
        a25 = *((a22 + 29));
        s3p = _mm_sub_pd(_mm_mul_pd(a15, s1m), _mm_mul_pd(a25, s2m));
        s4p = _mm_add_pd(_mm_mul_pd(a25, s1m), _mm_mul_pd(a15, s2m));
        a35 = *((a22 + 30));
        a45 = *((a22 + 31));
        s5p = _mm_sub_pd(_mm_mul_pd(a35, s3m), _mm_mul_pd(a45, s4m));
        s6p = _mm_add_pd(_mm_mul_pd(a45, s3m), _mm_mul_pd(a35, s4m));
        t6e = _mm_add_pd(s5m, s1o);
        t7e = _mm_add_pd(s6m, s2o);
        t8e = _mm_sub_pd(s5m, s1o);
        t9e = _mm_sub_pd(s6m, s2o);
        t0f = _mm_add_pd(s7m, s3o);
        t1f = _mm_add_pd(s8m, s4o);
        t2f = _mm_sub_pd(s7m, s3o);
        t3f = _mm_sub_pd(s8m, s4o);
        s7p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2f), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3f));
        s8p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3f));
        t4f = _mm_add_pd(s9m, s5o);
        t5f = _mm_add_pd(s0n, s6o);
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9m, s5o));
        a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0n, s6o));
        s9p = _mm_sub_pd(a55, a65);
        s0q = _mm_add_pd(a55, a65);
        t6f = _mm_add_pd(s1n, s7o);
        t7f = _mm_add_pd(s2n, s8o);
        t8f = _mm_sub_pd(s1n, s7o);
        t9f = _mm_sub_pd(s2n, s8o);
        s1q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9f));
        s2q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9f));
        t0g = _mm_add_pd(s3n, s9o);
        t1g = _mm_add_pd(s4n, s0p);
        t2g = _mm_sub_pd(s3n, s9o);
        t3g = _mm_sub_pd(s4n, s0p);
        t4g = _mm_add_pd(s5n, s1p);
        t5g = _mm_add_pd(s6n, s2p);
        t6g = _mm_sub_pd(s5n, s1p);
        t7g = _mm_sub_pd(s6n, s2p);
        s3q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6g), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7g));
        s4q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6g), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t7g));
        t8g = _mm_add_pd(s7n, s3p);
        t9g = _mm_add_pd(s8n, s4p);
        a75 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7n, s3p));
        a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8n, s4p));
        s5q = _mm_sub_pd(a75, a85);
        s6q = _mm_add_pd(a75, a85);
        t0h = _mm_add_pd(s9n, s5p);
        t1h = _mm_add_pd(s0o, s6p);
        t2h = _mm_sub_pd(s9n, s5p);
        t3h = _mm_sub_pd(s0o, s6p);
        s7q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2h), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3h));
        s8q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2h), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3h));
        t4h = _mm_add_pd(t6e, t0g);
        t5h = _mm_add_pd(t7e, t1g);
        t6h = _mm_sub_pd(t6e, t0g);
        t7h = _mm_sub_pd(t7e, t1g);
        t8h = _mm_add_pd(t4f, t8g);
        t9h = _mm_add_pd(t5f, t9g);
        t0i = _mm_sub_pd(t4f, t8g);
        t1i = _mm_sub_pd(t5f, t9g);
        t2i = _mm_add_pd(t4h, t8h);
        t3i = _mm_add_pd(t5h, t9h);
        t4i = _mm_sub_pd(t4h, t8h);
        t5i = _mm_sub_pd(t5h, t9h);
        t6i = _mm_add_pd(t6h, t1i);
        t7i = _mm_sub_pd(t7h, t0i);
        t8i = _mm_sub_pd(t6h, t1i);
        t9i = _mm_add_pd(t7h, t0i);
        t0j = _mm_add_pd(t0f, t4g);
        t1j = _mm_add_pd(t1f, t5g);
        t2j = _mm_sub_pd(t0f, t4g);
        t3j = _mm_sub_pd(t1f, t5g);
        t4j = _mm_add_pd(t6f, t0h);
        t5j = _mm_add_pd(t7f, t1h);
        t6j = _mm_sub_pd(t6f, t0h);
        t7j = _mm_sub_pd(t7f, t1h);
        t8j = _mm_add_pd(t0j, t4j);
        t9j = _mm_add_pd(t1j, t5j);
        t0k = _mm_sub_pd(t0j, t4j);
        t1k = _mm_sub_pd(t1j, t5j);
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2j, t7j));
        a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3j, t6j));
        s9q = _mm_sub_pd(a95, a06);
        s0r = _mm_add_pd(a95, a06);
        a16 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t2j, t7j));
        a26 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3j, t6j));
        s1r = _mm_sub_pd(a16, a26);
        s2r = _mm_add_pd(a16, a26);
        t2k = _mm_add_pd(t2i, t8j);
        t3k = _mm_add_pd(t3i, t9j);
        t4k = _mm_sub_pd(t2i, t8j);
        t5k = _mm_sub_pd(t3i, t9j);
        t6k = _mm_add_pd(t6i, s9q);
        t7k = _mm_sub_pd(t7i, s0r);
        t8k = _mm_sub_pd(t6i, s9q);
        t9k = _mm_add_pd(t7i, s0r);
        t0l = _mm_add_pd(t4i, t1k);
        t1l = _mm_sub_pd(t5i, t0k);
        t2l = _mm_sub_pd(t4i, t1k);
        t3l = _mm_add_pd(t5i, t0k);
        t4l = _mm_add_pd(t8i, s1r);
        t5l = _mm_add_pd(t9i, s2r);
        t6l = _mm_sub_pd(t8i, s1r);
        t7l = _mm_sub_pd(t9i, s2r);
        t8l = _mm_add_pd(t8e, t3g);
        t9l = _mm_sub_pd(t9e, t2g);
        t0m = _mm_sub_pd(t8e, t3g);
        t1m = _mm_add_pd(t9e, t2g);
        t2m = _mm_add_pd(s9p, s5q);
        t3m = _mm_sub_pd(s6q, s0q);
        t4m = _mm_sub_pd(s9p, s5q);
        t5m = _mm_add_pd(s0q, s6q);
        t6m = _mm_add_pd(t8l, t2m);
        t7m = _mm_add_pd(t9l, t3m);
        t8m = _mm_sub_pd(t8l, t2m);
        t9m = _mm_sub_pd(t9l, t3m);
        t0n = _mm_sub_pd(t0m, t5m);
        t1n = _mm_sub_pd(t1m, t4m);
        t2n = _mm_add_pd(t0m, t5m);
        t3n = _mm_add_pd(t1m, t4m);
        t4n = _mm_add_pd(s7p, s3q);
        t5n = _mm_add_pd(s8p, s4q);
        t6n = _mm_sub_pd(s7p, s3q);
        t7n = _mm_sub_pd(s8p, s4q);
        t8n = _mm_add_pd(s1q, s7q);
        t9n = _mm_add_pd(s2q, s8q);
        t0o = _mm_sub_pd(s1q, s7q);
        t1o = _mm_sub_pd(s2q, s8q);
        t2o = _mm_add_pd(t4n, t8n);
        t3o = _mm_add_pd(t5n, t9n);
        t4o = _mm_sub_pd(t4n, t8n);
        t5o = _mm_sub_pd(t5n, t9n);
        a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6n, t1o));
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7n, t0o));
        s3r = _mm_sub_pd(a36, a46);
        s4r = _mm_add_pd(a36, a46);
        a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t6n, t1o));
        a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t7n, t0o));
        s5r = _mm_sub_pd(a56, a66);
        s6r = _mm_add_pd(a56, a66);
        t6o = _mm_add_pd(t6m, t2o);
        t7o = _mm_add_pd(t7m, t3o);
        t8o = _mm_sub_pd(t6m, t2o);
        t9o = _mm_sub_pd(t7m, t3o);
        t0p = _mm_add_pd(t0n, s3r);
        t1p = _mm_sub_pd(t1n, s4r);
        t2p = _mm_sub_pd(t0n, s3r);
        t3p = _mm_add_pd(t1n, s4r);
        t4p = _mm_add_pd(t8m, t5o);
        t5p = _mm_sub_pd(t9m, t4o);
        t6p = _mm_sub_pd(t8m, t5o);
        t7p = _mm_add_pd(t9m, t4o);
        t8p = _mm_add_pd(t2n, s5r);
        t9p = _mm_add_pd(t3n, s6r);
        t0q = _mm_sub_pd(t2n, s5r);
        t1q = _mm_sub_pd(t3n, s6r);
        a76 = (D40 + a12);
        a86 = *(a76);
        a96 = *((a76 + 1));
        s7r = _mm_sub_pd(_mm_mul_pd(a86, t2k), _mm_mul_pd(a96, t3k));
        s8r = _mm_add_pd(_mm_mul_pd(a96, t2k), _mm_mul_pd(a86, t3k));
        s9r = v_lo2(s7r, s8r);
        s0s = v_hi2(s7r, s8r);
        a07 = ((__m128d  *) dst);
        b2 = (a07 + i2);
        s1s = _mm_add_pd(s9r, s0s);
        *((b2 + 1)) = s1s;
        b3 = (a07 - i2);
        s2s = v_neg23(_mm_sub_pd(s9r, s0s));
        *((b3 + 255)) = s2s;
        a17 = *((a76 + 2));
        a27 = *((a76 + 3));
        s3s = _mm_sub_pd(_mm_mul_pd(a17, t6o), _mm_mul_pd(a27, t7o));
        s4s = _mm_add_pd(_mm_mul_pd(a27, t6o), _mm_mul_pd(a17, t7o));
        s5s = v_lo2(s3s, s4s);
        s6s = v_hi2(s3s, s4s);
        s7s = _mm_add_pd(s5s, s6s);
        *((b2 + 17)) = s7s;
        s8s = v_neg23(_mm_sub_pd(s5s, s6s));
        *((b3 + 239)) = s8s;
        a37 = *((a76 + 4));
        a47 = *((a76 + 5));
        s9s = _mm_sub_pd(_mm_mul_pd(a37, t6k), _mm_mul_pd(a47, t7k));
        s0t = _mm_add_pd(_mm_mul_pd(a47, t6k), _mm_mul_pd(a37, t7k));
        s1t = v_lo2(s9s, s0t);
        s2t = v_hi2(s9s, s0t);
        s3t = _mm_add_pd(s1t, s2t);
        *((b2 + 33)) = s3t;
        s4t = v_neg23(_mm_sub_pd(s1t, s2t));
        *((b3 + 223)) = s4t;
        a57 = *((a76 + 6));
        a67 = *((a76 + 7));
        s5t = _mm_sub_pd(_mm_mul_pd(a57, t0p), _mm_mul_pd(a67, t1p));
        s6t = _mm_add_pd(_mm_mul_pd(a67, t0p), _mm_mul_pd(a57, t1p));
        s7t = v_lo2(s5t, s6t);
        s8t = v_hi2(s5t, s6t);
        s9t = _mm_add_pd(s7t, s8t);
        *((b2 + 49)) = s9t;
        s0u = v_neg23(_mm_sub_pd(s7t, s8t));
        *((b3 + 207)) = s0u;
        a77 = *((a76 + 8));
        a87 = *((a76 + 9));
        s1u = _mm_sub_pd(_mm_mul_pd(a77, t0l), _mm_mul_pd(a87, t1l));
        s2u = _mm_add_pd(_mm_mul_pd(a87, t0l), _mm_mul_pd(a77, t1l));
        s3u = v_lo2(s1u, s2u);
        s4u = v_hi2(s1u, s2u);
        s5u = _mm_add_pd(s3u, s4u);
        *((b2 + 65)) = s5u;
        s6u = v_neg23(_mm_sub_pd(s3u, s4u));
        *((b3 + 191)) = s6u;
        a97 = *((a76 + 10));
        a08 = *((a76 + 11));
        s7u = _mm_sub_pd(_mm_mul_pd(a97, t4p), _mm_mul_pd(a08, t5p));
        s8u = _mm_add_pd(_mm_mul_pd(a08, t4p), _mm_mul_pd(a97, t5p));
        s9u = v_lo2(s7u, s8u);
        s0v = v_hi2(s7u, s8u);
        s1v = _mm_add_pd(s9u, s0v);
        *((b2 + 81)) = s1v;
        s2v = v_neg23(_mm_sub_pd(s9u, s0v));
        *((b3 + 175)) = s2v;
        a18 = *((a76 + 12));
        a28 = *((a76 + 13));
        s3v = _mm_sub_pd(_mm_mul_pd(a18, t4l), _mm_mul_pd(a28, t5l));
        s4v = _mm_add_pd(_mm_mul_pd(a28, t4l), _mm_mul_pd(a18, t5l));
        s5v = v_lo2(s3v, s4v);
        s6v = v_hi2(s3v, s4v);
        s7v = _mm_add_pd(s5v, s6v);
        *((b2 + 97)) = s7v;
        s8v = v_neg23(_mm_sub_pd(s5v, s6v));
        *((b3 + 159)) = s8v;
        a38 = *((a76 + 14));
        a48 = *((a76 + 15));
        s9v = _mm_sub_pd(_mm_mul_pd(a38, t8p), _mm_mul_pd(a48, t9p));
        s0w = _mm_add_pd(_mm_mul_pd(a48, t8p), _mm_mul_pd(a38, t9p));
        s1w = v_lo2(s9v, s0w);
        s2w = v_hi2(s9v, s0w);
        s3w = _mm_add_pd(s1w, s2w);
        *((b2 + 113)) = s3w;
        s4w = v_neg23(_mm_sub_pd(s1w, s2w));
        *((b3 + 143)) = s4w;
        a58 = *((a76 + 16));
        a68 = *((a76 + 17));
        s5w = _mm_sub_pd(_mm_mul_pd(a58, t4k), _mm_mul_pd(a68, t5k));
        s6w = _mm_add_pd(_mm_mul_pd(a68, t4k), _mm_mul_pd(a58, t5k));
        s7w = v_lo2(s5w, s6w);
        s8w = v_hi2(s5w, s6w);
        s9w = _mm_add_pd(s7w, s8w);
        *((b2 + 129)) = s9w;
        s0x = v_neg23(_mm_sub_pd(s7w, s8w));
        *((b3 + 127)) = s0x;
        a78 = *((a76 + 18));
        a88 = *((a76 + 19));
        s1x = _mm_sub_pd(_mm_mul_pd(a78, t8o), _mm_mul_pd(a88, t9o));
        s2x = _mm_add_pd(_mm_mul_pd(a88, t8o), _mm_mul_pd(a78, t9o));
        s3x = v_lo2(s1x, s2x);
        s4x = v_hi2(s1x, s2x);
        s5x = _mm_add_pd(s3x, s4x);
        *((b2 + 145)) = s5x;
        s6x = v_neg23(_mm_sub_pd(s3x, s4x));
        *((b3 + 111)) = s6x;
        a98 = *((a76 + 20));
        a09 = *((a76 + 21));
        s7x = _mm_sub_pd(_mm_mul_pd(a98, t8k), _mm_mul_pd(a09, t9k));
        s8x = _mm_add_pd(_mm_mul_pd(a09, t8k), _mm_mul_pd(a98, t9k));
        s9x = v_lo2(s7x, s8x);
        s0y = v_hi2(s7x, s8x);
        s1y = _mm_add_pd(s9x, s0y);
        *((b2 + 161)) = s1y;
        s2y = v_neg23(_mm_sub_pd(s9x, s0y));
        *((b3 + 95)) = s2y;
        a19 = *((a76 + 22));
        a29 = *((a76 + 23));
        s3y = _mm_sub_pd(_mm_mul_pd(a19, t2p), _mm_mul_pd(a29, t3p));
        s4y = _mm_add_pd(_mm_mul_pd(a29, t2p), _mm_mul_pd(a19, t3p));
        s5y = v_lo2(s3y, s4y);
        s6y = v_hi2(s3y, s4y);
        s7y = _mm_add_pd(s5y, s6y);
        *((b2 + 177)) = s7y;
        s8y = v_neg23(_mm_sub_pd(s5y, s6y));
        *((b3 + 79)) = s8y;
        a39 = *((a76 + 24));
        a49 = *((a76 + 25));
        s9y = _mm_sub_pd(_mm_mul_pd(a39, t2l), _mm_mul_pd(a49, t3l));
        s0z = _mm_add_pd(_mm_mul_pd(a49, t2l), _mm_mul_pd(a39, t3l));
        s1z = v_lo2(s9y, s0z);
        s2z = v_hi2(s9y, s0z);
        s3z = _mm_add_pd(s1z, s2z);
        *((b2 + 193)) = s3z;
        s4z = v_neg23(_mm_sub_pd(s1z, s2z));
        *((b3 + 63)) = s4z;
        a59 = *((a76 + 26));
        a69 = *((a76 + 27));
        s5z = _mm_sub_pd(_mm_mul_pd(a59, t6p), _mm_mul_pd(a69, t7p));
        s6z = _mm_add_pd(_mm_mul_pd(a69, t6p), _mm_mul_pd(a59, t7p));
        s7z = v_lo2(s5z, s6z);
        s8z = v_hi2(s5z, s6z);
        s9z = _mm_add_pd(s7z, s8z);
        *((b2 + 209)) = s9z;
        s0A = v_neg23(_mm_sub_pd(s7z, s8z));
        *((b3 + 47)) = s0A;
        a79 = *((a76 + 28));
        a89 = *((a76 + 29));
        s1A = _mm_sub_pd(_mm_mul_pd(a79, t6l), _mm_mul_pd(a89, t7l));
        s2A = _mm_add_pd(_mm_mul_pd(a89, t6l), _mm_mul_pd(a79, t7l));
        s3A = v_lo2(s1A, s2A);
        s4A = v_hi2(s1A, s2A);
        s5A = _mm_add_pd(s3A, s4A);
        *((b2 + 225)) = s5A;
        s6A = v_neg23(_mm_sub_pd(s3A, s4A));
        *((b3 + 31)) = s6A;
        a99 = *((a76 + 30));
        a0a = *((a76 + 31));
        s7A = _mm_sub_pd(_mm_mul_pd(a99, t0q), _mm_mul_pd(a0a, t1q));
        s8A = _mm_add_pd(_mm_mul_pd(a0a, t0q), _mm_mul_pd(a99, t1q));
        s9A = v_lo2(s7A, s8A);
        s0B = v_hi2(s7A, s8A);
        s1B = _mm_add_pd(s9A, s0B);
        *((b2 + 241)) = s1B;
        s2B = v_neg23(_mm_sub_pd(s9A, s0B));
        *((b3 + 15)) = s2B;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_1024_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[1024]);
    __m128d a02, a03, a04, a05, a06, a07, a08, a09, a0a, a11, a12, a13, a14, a15, a16, a17, a18, a19, a1a, a2, a21, a22
            , a23, a24, a25, a26, a27, a28, a29, a2a, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a3a, a4, a41, a42
            , a43, a44, a45, a46, a48, a49, a4a, a5, a52, a53, a54, a55, a56, a57, a58, a59, a5a, a6, a61, a62, a63, a64
            , a65, a66, a67, a68, a69, a6a, a7, a71, a72, a73, a74, a75, a76, a78, a79, a7a, a8, a81, a83, a84, a85, a86
            , a87, a88, a89, a9, a91, a93, a94, a95, a96, a97, a98, a99, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o
            , s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B
            , s1C, s1D, s1E, s1F, s1G, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2G, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r
            , s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D
            , s3E, s3F, s3G, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s
            , s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E
            , s4F, s4G, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t
            , s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F
            , s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v
            , s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6a, s6b
            , s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x
            , s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z
            , s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8a, s8b, s8c, s8d, s8e, s8f
            , s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91
            , s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h
            , s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03
            , t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p
            , t0q, t0r, t0s, t0t, t0u, t0v, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g
            , t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s, t1t, t1u, t1v, t2, t21, t22, t23, t24, t25, t26
            , t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s
            , t2t, t2u, t2v, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i
            , t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t4, t41, t42, t43, t44, t45, t46, t47, t48
            , t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u
            , t4v, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t7
            , t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m
            , t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c
            , t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t9, t91, t92, t93
            , t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p
            , t9q, t9r, t9s, t9t, t9u;
    __m128d  *a01, *a47, *a51, *a92, *b2;
    double  *b3, *b4;
    const double  *b;
    int a, a77, a82;
    {long i; for(i = 0; i <= 15; i++) {
        a = (2 * i);
        s = _mm_loadu_pd(((const double  *) (a + src)));
        b = (src + a);
        s2 = _mm_loadu_pd(((const double  *) (b + 512)));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = _mm_loadu_pd(((const double  *) (b + 256)));
        s4 = _mm_loadu_pd(((const double  *) (b + 768)));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = _mm_loadu_pd(((const double  *) (b + 128)));
        s6 = _mm_loadu_pd(((const double  *) (b + 640)));
        t5 = _mm_add_pd(s5, s6);
        s7 = _mm_loadu_pd(((const double  *) (b + 384)));
        s8 = _mm_loadu_pd(((const double  *) (b + 896)));
        t6 = _mm_add_pd(s7, s8);
        t7 = _mm_add_pd(t, t3);
        t8 = _mm_sub_pd(t, t3);
        t9 = _mm_add_pd(t5, t6);
        t01 = _mm_sub_pd(t5, t6);
        a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
        a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
        s9 = _mm_add_pd(a2, a3);
        s01 = _mm_sub_pd(a3, a2);
        t11 = _mm_add_pd(t2, s9);
        t21 = _mm_sub_pd(s01, t4);
        t31 = _mm_sub_pd(t2, s9);
        t41 = _mm_add_pd(t4, s01);
        s11 = _mm_loadu_pd(((const double  *) (b + 32)));
        s21 = _mm_loadu_pd(((const double  *) (b + 544)));
        t51 = _mm_add_pd(s11, s21);
        t61 = _mm_sub_pd(s11, s21);
        s31 = _mm_loadu_pd(((const double  *) (b + 288)));
        s41 = _mm_loadu_pd(((const double  *) (b + 800)));
        t71 = _mm_add_pd(s31, s41);
        t81 = _mm_sub_pd(s31, s41);
        s51 = _mm_loadu_pd(((const double  *) (b + 160)));
        s61 = _mm_loadu_pd(((const double  *) (b + 672)));
        t91 = _mm_add_pd(s51, s61);
        s71 = _mm_loadu_pd(((const double  *) (b + 416)));
        s81 = _mm_loadu_pd(((const double  *) (b + 928)));
        t02 = _mm_add_pd(s71, s81);
        t12 = _mm_add_pd(t51, t71);
        t22 = _mm_sub_pd(t51, t71);
        t32 = _mm_add_pd(t91, t02);
        t42 = _mm_sub_pd(t91, t02);
        a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
        a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
        s91 = _mm_add_pd(a4, a5);
        s02 = _mm_sub_pd(a5, a4);
        t52 = _mm_add_pd(t61, s91);
        t62 = _mm_sub_pd(s02, t81);
        t72 = _mm_sub_pd(t61, s91);
        t82 = _mm_add_pd(t81, s02);
        s12 = _mm_loadu_pd(((const double  *) (b + 64)));
        s22 = _mm_loadu_pd(((const double  *) (b + 576)));
        t92 = _mm_add_pd(s12, s22);
        t03 = _mm_sub_pd(s12, s22);
        s32 = _mm_loadu_pd(((const double  *) (b + 320)));
        s42 = _mm_loadu_pd(((const double  *) (b + 832)));
        t13 = _mm_add_pd(s32, s42);
        t23 = _mm_sub_pd(s32, s42);
        s52 = _mm_loadu_pd(((const double  *) (b + 192)));
        s62 = _mm_loadu_pd(((const double  *) (b + 704)));
        t33 = _mm_add_pd(s52, s62);
        s72 = _mm_loadu_pd(((const double  *) (b + 448)));
        s82 = _mm_loadu_pd(((const double  *) (b + 960)));
        t43 = _mm_add_pd(s72, s82);
        t53 = _mm_add_pd(t92, t13);
        t63 = _mm_add_pd(t33, t43);
        a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
        a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
        s92 = _mm_add_pd(a6, a7);
        s03 = _mm_sub_pd(a7, a6);
        t73 = _mm_add_pd(t03, s92);
        t83 = _mm_sub_pd(s03, t23);
        t93 = _mm_sub_pd(t03, s92);
        t04 = _mm_add_pd(t23, s03);
        s13 = _mm_loadu_pd(((const double  *) (b + 96)));
        s23 = _mm_loadu_pd(((const double  *) (b + 608)));
        t14 = _mm_add_pd(s13, s23);
        t24 = _mm_sub_pd(s13, s23);
        s33 = _mm_loadu_pd(((const double  *) (b + 352)));
        s43 = _mm_loadu_pd(((const double  *) (b + 864)));
        t34 = _mm_add_pd(s33, s43);
        t44 = _mm_sub_pd(s33, s43);
        s53 = _mm_loadu_pd(((const double  *) (b + 224)));
        s63 = _mm_loadu_pd(((const double  *) (b + 736)));
        t54 = _mm_add_pd(s53, s63);
        s73 = _mm_loadu_pd(((const double  *) (b + 480)));
        s83 = _mm_loadu_pd(((const double  *) (b + 992)));
        t64 = _mm_add_pd(s73, s83);
        t74 = _mm_add_pd(t14, t34);
        t84 = _mm_sub_pd(t14, t34);
        t94 = _mm_add_pd(t54, t64);
        t05 = _mm_sub_pd(t54, t64);
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
        s93 = _mm_add_pd(a8, a9);
        s04 = _mm_sub_pd(a9, a8);
        t15 = _mm_add_pd(t24, s93);
        t25 = _mm_sub_pd(s04, t44);
        t35 = _mm_sub_pd(t24, s93);
        t45 = _mm_add_pd(t44, s04);
        t55 = _mm_add_pd(t7, t9);
        t65 = _mm_sub_pd(t7, t9);
        t75 = _mm_add_pd(t53, t63);
        t85 = _mm_sub_pd(t53, t63);
        t95 = _mm_add_pd(t12, t32);
        t06 = _mm_add_pd(t74, t94);
        a01 = (((__m128d  *) T) + i);
        s14 = _mm_add_pd(t55, t75);
        *(a01) = s14;
        s24 = _mm_sub_pd(t55, t75);
        *((a01 + 256)) = s24;
        s34 = _mm_add_pd(t95, t06);
        *((a01 + 16)) = s34;
        s44 = _mm_sub_pd(t06, t95);
        *((a01 + 272)) = s44;
        a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
        a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
        s54 = _mm_add_pd(a11, a21);
        s64 = _mm_sub_pd(a21, a11);
        s74 = _mm_add_pd(t65, s54);
        *((a01 + 128)) = s74;
        s84 = _mm_sub_pd(s64, t85);
        *((a01 + 144)) = s84;
        s94 = _mm_sub_pd(t65, s54);
        *((a01 + 384)) = s94;
        s05 = _mm_add_pd(t85, s64);
        *((a01 + 400)) = s05;
        s15 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
        s25 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
        s35 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
        s45 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
        s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
        s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
        t16 = _mm_add_pd(t11, s35);
        t26 = _mm_add_pd(t21, s45);
        t36 = _mm_sub_pd(t11, s35);
        t46 = _mm_sub_pd(t21, s45);
        t56 = _mm_add_pd(s15, s55);
        t66 = _mm_add_pd(s25, s65);
        t76 = _mm_sub_pd(s15, s55);
        t86 = _mm_sub_pd(s25, s65);
        s75 = _mm_add_pd(t16, t56);
        *((a01 + 32)) = s75;
        s85 = _mm_add_pd(t26, t66);
        *((a01 + 48)) = s85;
        s95 = _mm_sub_pd(t16, t56);
        *((a01 + 480)) = s95;
        s06 = _mm_sub_pd(t66, t26);
        *((a01 + 496)) = s06;
        s16 = _mm_add_pd(t36, t86);
        *((a01 + 288)) = s16;
        s26 = _mm_sub_pd(t46, t76);
        *((a01 + 304)) = s26;
        s36 = _mm_sub_pd(t36, t86);
        *((a01 + 224)) = s36;
        s46 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t46, t76));
        *((a01 + 240)) = s46;
        s56 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
        s66 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
        a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
        a41 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
        s76 = _mm_add_pd(a31, a41);
        s86 = _mm_sub_pd(a41, a31);
        s96 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
        s07 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
        t96 = _mm_add_pd(t8, s76);
        t07 = _mm_sub_pd(s86, t01);
        t17 = _mm_sub_pd(t8, s76);
        t27 = _mm_add_pd(t01, s86);
        t37 = _mm_add_pd(s56, s96);
        t47 = _mm_add_pd(s66, s07);
        t57 = _mm_sub_pd(s56, s96);
        t67 = _mm_sub_pd(s66, s07);
        s17 = _mm_add_pd(t96, t37);
        *((a01 + 64)) = s17;
        s27 = _mm_add_pd(t07, t47);
        *((a01 + 80)) = s27;
        s37 = _mm_sub_pd(t96, t37);
        *((a01 + 448)) = s37;
        s47 = _mm_sub_pd(t47, t07);
        *((a01 + 464)) = s47;
        s57 = _mm_add_pd(t17, t67);
        *((a01 + 320)) = s57;
        s67 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t27, t57));
        *((a01 + 336)) = s67;
        s77 = _mm_sub_pd(t17, t67);
        *((a01 + 192)) = s77;
        s87 = _mm_sub_pd(t27, t57);
        *((a01 + 208)) = s87;
        s97 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
        s08 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
        s18 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
        s28 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
        s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
        s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
        t77 = _mm_add_pd(t31, s18);
        t87 = _mm_add_pd(t41, s28);
        t97 = _mm_sub_pd(t31, s18);
        t08 = _mm_sub_pd(t41, s28);
        t18 = _mm_add_pd(s97, s38);
        t28 = _mm_add_pd(s08, s48);
        t38 = _mm_sub_pd(s97, s38);
        t48 = _mm_sub_pd(s08, s48);
        s58 = _mm_add_pd(t77, t18);
        *((a01 + 96)) = s58;
        s68 = _mm_add_pd(t87, t28);
        *((a01 + 112)) = s68;
        s78 = _mm_sub_pd(t77, t18);
        *((a01 + 416)) = s78;
        s88 = _mm_sub_pd(t28, t87);
        *((a01 + 432)) = s88;
        s98 = _mm_add_pd(t97, t48);
        *((a01 + 352)) = s98;
        s09 = _mm_sub_pd(t08, t38);
        *((a01 + 368)) = s09;
        s19 = _mm_sub_pd(t97, t48);
        *((a01 + 160)) = s19;
        s29 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t08, t38));
        *((a01 + 176)) = s29;
    }}
    a51 = ((__m128d  *) T);
    s39 = *(a51);
    s49 = *((a51 + 16));
    t58 = _mm_add_pd(s39, s49);
    t68 = _mm_sub_pd(s39, s49);
    s59 = *((a51 + 8));
    s69 = *((a51 + 24));
    t78 = _mm_add_pd(s59, s69);
    t88 = _mm_sub_pd(s59, s69);
    s79 = *((a51 + 4));
    s89 = *((a51 + 20));
    t98 = _mm_add_pd(s79, s89);
    s99 = *((a51 + 12));
    s0a = *((a51 + 28));
    t09 = _mm_add_pd(s99, s0a);
    t19 = _mm_add_pd(t58, t78);
    t29 = _mm_sub_pd(t58, t78);
    t39 = _mm_add_pd(t98, t09);
    t49 = _mm_sub_pd(t98, t09);
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s79, s89));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s99, s0a));
    s1a = _mm_add_pd(a61, a71);
    s2a = _mm_sub_pd(a71, a61);
    t59 = _mm_add_pd(t68, s1a);
    t69 = _mm_sub_pd(s2a, t88);
    t79 = _mm_sub_pd(t68, s1a);
    t89 = _mm_add_pd(t88, s2a);
    s3a = *((a51 + 1));
    s4a = *((a51 + 17));
    t99 = _mm_add_pd(s3a, s4a);
    t0a = _mm_sub_pd(s3a, s4a);
    s5a = *((a51 + 9));
    s6a = *((a51 + 25));
    t1a = _mm_add_pd(s5a, s6a);
    t2a = _mm_sub_pd(s5a, s6a);
    s7a = *((a51 + 5));
    s8a = *((a51 + 21));
    t3a = _mm_add_pd(s7a, s8a);
    s9a = *((a51 + 13));
    s0b = *((a51 + 29));
    t4a = _mm_add_pd(s9a, s0b);
    t5a = _mm_add_pd(t99, t1a);
    t6a = _mm_sub_pd(t99, t1a);
    t7a = _mm_add_pd(t3a, t4a);
    t8a = _mm_sub_pd(t3a, t4a);
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7a, s8a));
    a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9a, s0b));
    s1b = _mm_add_pd(a81, a91);
    s2b = _mm_sub_pd(a91, a81);
    t9a = _mm_add_pd(t0a, s1b);
    t0b = _mm_sub_pd(s2b, t2a);
    t1b = _mm_sub_pd(t0a, s1b);
    t2b = _mm_add_pd(t2a, s2b);
    s3b = *((a51 + 2));
    s4b = *((a51 + 18));
    t3b = _mm_add_pd(s3b, s4b);
    t4b = _mm_sub_pd(s3b, s4b);
    s5b = *((a51 + 10));
    s6b = *((a51 + 26));
    t5b = _mm_add_pd(s5b, s6b);
    t6b = _mm_sub_pd(s5b, s6b);
    s7b = *((a51 + 6));
    s8b = *((a51 + 22));
    t7b = _mm_add_pd(s7b, s8b);
    s9b = *((a51 + 14));
    s0c = *((a51 + 30));
    t8b = _mm_add_pd(s9b, s0c);
    t9b = _mm_add_pd(t3b, t5b);
    t0c = _mm_add_pd(t7b, t8b);
    a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7b, s8b));
    a12 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9b, s0c));
    s1c = _mm_add_pd(a02, a12);
    s2c = _mm_sub_pd(a12, a02);
    t1c = _mm_add_pd(t4b, s1c);
    t2c = _mm_sub_pd(s2c, t6b);
    t3c = _mm_sub_pd(t4b, s1c);
    t4c = _mm_add_pd(t6b, s2c);
    s3c = *((a51 + 3));
    s4c = *((a51 + 19));
    t5c = _mm_add_pd(s3c, s4c);
    t6c = _mm_sub_pd(s3c, s4c);
    s5c = *((a51 + 11));
    s6c = *((a51 + 27));
    t7c = _mm_add_pd(s5c, s6c);
    t8c = _mm_sub_pd(s5c, s6c);
    s7c = *((a51 + 7));
    s8c = *((a51 + 23));
    t9c = _mm_add_pd(s7c, s8c);
    s9c = *((a51 + 15));
    s0d = *((a51 + 31));
    t0d = _mm_add_pd(s9c, s0d);
    t1d = _mm_add_pd(t5c, t7c);
    t2d = _mm_sub_pd(t5c, t7c);
    t3d = _mm_add_pd(t9c, t0d);
    t4d = _mm_sub_pd(t9c, t0d);
    a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7c, s8c));
    a32 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9c, s0d));
    s1d = _mm_add_pd(a22, a32);
    s2d = _mm_sub_pd(a32, a22);
    t5d = _mm_add_pd(t6c, s1d);
    t6d = _mm_sub_pd(s2d, t8c);
    t7d = _mm_sub_pd(t6c, s1d);
    t8d = _mm_add_pd(t8c, s2d);
    t9d = _mm_add_pd(t19, t39);
    t0e = _mm_sub_pd(t19, t39);
    t1e = _mm_add_pd(t9b, t0c);
    t2e = _mm_sub_pd(t9b, t0c);
    t3e = _mm_add_pd(t5a, t7a);
    t4e = _mm_add_pd(t1d, t3d);
    t5e = _mm_add_pd(t9d, t1e);
    t6e = _mm_sub_pd(t9d, t1e);
    t7e = _mm_add_pd(t3e, t4e);
    t8e = _mm_sub_pd(t3e, t4e);
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t7a));
    a52 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1d, t3d));
    s3d = _mm_add_pd(a42, a52);
    s4d = _mm_sub_pd(a52, a42);
    t9e = _mm_add_pd(t0e, s3d);
    t0f = _mm_sub_pd(s4d, t2e);
    t1f = _mm_sub_pd(t0e, s3d);
    t2f = _mm_add_pd(t2e, s4d);
    s5d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
    s6d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
    s7d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1c), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2c));
    s8d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2c));
    s9d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5d), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6d));
    s0e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6d));
    t3f = _mm_add_pd(t59, s7d);
    t4f = _mm_add_pd(t69, s8d);
    t5f = _mm_sub_pd(t59, s7d);
    t6f = _mm_sub_pd(t69, s8d);
    t7f = _mm_add_pd(s5d, s9d);
    t8f = _mm_add_pd(s6d, s0e);
    t9f = _mm_sub_pd(s5d, s9d);
    t0g = _mm_sub_pd(s6d, s0e);
    t1g = _mm_add_pd(t3f, t7f);
    t2g = _mm_add_pd(t4f, t8f);
    t3g = _mm_sub_pd(t3f, t7f);
    t4g = _mm_sub_pd(t4f, t8f);
    t5g = _mm_add_pd(t5f, t0g);
    t6g = _mm_sub_pd(t6f, t9f);
    t7g = _mm_sub_pd(t5f, t0g);
    t8g = _mm_add_pd(t6f, t9f);
    s1e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8a));
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3b, t5b));
    a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7b, t8b));
    s3e = _mm_add_pd(a62, a72);
    s4e = _mm_sub_pd(a72, a62);
    s5e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4d));
    t9g = _mm_add_pd(t29, s3e);
    t0h = _mm_sub_pd(s4e, t49);
    t1h = _mm_sub_pd(t29, s3e);
    t2h = _mm_add_pd(t49, s4e);
    t3h = _mm_add_pd(s1e, s5e);
    t4h = _mm_add_pd(s2e, s6e);
    t5h = _mm_sub_pd(s1e, s5e);
    t6h = _mm_sub_pd(s2e, s6e);
    t7h = _mm_add_pd(t9g, t3h);
    t8h = _mm_add_pd(t0h, t4h);
    t9h = _mm_sub_pd(t9g, t3h);
    t0i = _mm_sub_pd(t0h, t4h);
    t1i = _mm_add_pd(t1h, t6h);
    t2i = _mm_add_pd(t2h, t5h);
    t3i = _mm_sub_pd(t1h, t6h);
    t4i = _mm_sub_pd(t5h, t2h);
    s7e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1b), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t2b));
    s8e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t1b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2b));
    s9e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4c));
    s0f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4c));
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7d), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8d));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7d), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8d));
    t5i = _mm_add_pd(t79, s9e);
    t6i = _mm_add_pd(t89, s0f);
    t7i = _mm_sub_pd(t79, s9e);
    t8i = _mm_sub_pd(t89, s0f);
    t9i = _mm_add_pd(s7e, s1f);
    t0j = _mm_add_pd(s8e, s2f);
    t1j = _mm_sub_pd(s7e, s1f);
    t2j = _mm_sub_pd(s8e, s2f);
    t3j = _mm_add_pd(t5i, t9i);
    t4j = _mm_add_pd(t6i, t0j);
    t5j = _mm_sub_pd(t5i, t9i);
    t6j = _mm_sub_pd(t6i, t0j);
    t7j = _mm_add_pd(t7i, t2j);
    t8j = _mm_sub_pd(t8i, t1j);
    t9j = _mm_sub_pd(t7i, t2j);
    t0k = _mm_add_pd(t8i, t1j);
    t1k = _mm_add_pd(t5e, t7e);
    s3f = _mm_add_pd(v_neg03(v_hi2(t1k, t1k)), v_lo2(t1k, t1k));
    _mm_storeu_pd(((double  *) dst), s3f);
    s4f = v_neg23(_mm_sub_pd(t5e, t7e));
    _mm_storeu_pd(((double  *) (dst + 512)), s4f);
    s5f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t1g), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t2g));
    s6f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t1g), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t2g));
    s7f = v_lo2(s5f, s6f);
    s8f = v_hi2(s5f, s6f);
    s9f = _mm_add_pd(s7f, s8f);
    _mm_storeu_pd(((double  *) (dst + 32)), s9f);
    s0g = v_neg23(_mm_sub_pd(s7f, s8f));
    _mm_storeu_pd(((double  *) (dst + 992)), s0g);
    s1g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t7h), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t8h));
    s2g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t7h), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t8h));
    s3g = v_lo2(s1g, s2g);
    s4g = v_hi2(s1g, s2g);
    s5g = _mm_add_pd(s3g, s4g);
    _mm_storeu_pd(((double  *) (dst + 64)), s5g);
    s6g = v_neg23(_mm_sub_pd(s3g, s4g));
    _mm_storeu_pd(((double  *) (dst + 960)), s6g);
    s7g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t3j), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t4j));
    s8g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t3j), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t4j));
    s9g = v_lo2(s7g, s8g);
    s0h = v_hi2(s7g, s8g);
    s1h = _mm_add_pd(s9g, s0h);
    _mm_storeu_pd(((double  *) (dst + 96)), s1h);
    s2h = v_neg23(_mm_sub_pd(s9g, s0h));
    _mm_storeu_pd(((double  *) (dst + 928)), s2h);
    s3h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t9e), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t0f));
    s4h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t9e), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t0f));
    s5h = v_lo2(s3h, s4h);
    s6h = v_hi2(s3h, s4h);
    s7h = _mm_add_pd(s5h, s6h);
    _mm_storeu_pd(((double  *) (dst + 128)), s7h);
    s8h = v_neg23(_mm_sub_pd(s5h, s6h));
    _mm_storeu_pd(((double  *) (dst + 896)), s8h);
    s9h = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t9j), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t0k));
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t9j), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t0k));
    s1i = v_lo2(s9h, s0i);
    s2i = v_hi2(s9h, s0i);
    s3i = _mm_add_pd(s1i, s2i);
    _mm_storeu_pd(((double  *) (dst + 160)), s3i);
    s4i = v_neg23(_mm_sub_pd(s1i, s2i));
    _mm_storeu_pd(((double  *) (dst + 864)), s4i);
    s5i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t3i), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t4i));
    s6i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3i), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t4i));
    s7i = v_lo2(s5i, s6i);
    s8i = v_hi2(s5i, s6i);
    s9i = _mm_add_pd(s7i, s8i);
    _mm_storeu_pd(((double  *) (dst + 192)), s9i);
    s0j = v_neg23(_mm_sub_pd(s7i, s8i));
    _mm_storeu_pd(((double  *) (dst + 832)), s0j);
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t7g), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t8g));
    s2j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t7g), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t8g));
    s3j = v_lo2(s1j, s2j);
    s4j = v_hi2(s1j, s2j);
    s5j = _mm_add_pd(s3j, s4j);
    _mm_storeu_pd(((double  *) (dst + 224)), s5j);
    s6j = v_neg23(_mm_sub_pd(s3j, s4j));
    _mm_storeu_pd(((double  *) (dst + 800)), s6j);
    s7j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t6e), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8e));
    s8j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t6e), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8e));
    s9j = v_lo2(s7j, s8j);
    s0k = v_hi2(s7j, s8j);
    s1k = _mm_add_pd(s9j, s0k);
    _mm_storeu_pd(((double  *) (dst + 256)), s1k);
    s2k = v_neg23(_mm_sub_pd(s9j, s0k));
    _mm_storeu_pd(((double  *) (dst + 768)), s2k);
    s3k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t5g), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t6g));
    s4k = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t5g), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t6g));
    s5k = v_lo2(s3k, s4k);
    s6k = v_hi2(s3k, s4k);
    s7k = _mm_add_pd(s5k, s6k);
    _mm_storeu_pd(((double  *) (dst + 288)), s7k);
    s8k = v_neg23(_mm_sub_pd(s5k, s6k));
    _mm_storeu_pd(((double  *) (dst + 736)), s8k);
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t1i), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t2i));
    s0l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t1i), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t2i));
    s1l = v_lo2(s9k, s0l);
    s2l = v_hi2(s9k, s0l);
    s3l = _mm_add_pd(s1l, s2l);
    _mm_storeu_pd(((double  *) (dst + 320)), s3l);
    s4l = v_neg23(_mm_sub_pd(s1l, s2l));
    _mm_storeu_pd(((double  *) (dst + 704)), s4l);
    s5l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t7j), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t8j));
    s6l = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t7j), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t8j));
    s7l = v_lo2(s5l, s6l);
    s8l = v_hi2(s5l, s6l);
    s9l = _mm_add_pd(s7l, s8l);
    _mm_storeu_pd(((double  *) (dst + 352)), s9l);
    s0m = v_neg23(_mm_sub_pd(s7l, s8l));
    _mm_storeu_pd(((double  *) (dst + 672)), s0m);
    s1m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t1f), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t2f));
    s2m = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t1f), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t2f));
    s3m = v_lo2(s1m, s2m);
    s4m = v_hi2(s1m, s2m);
    s5m = _mm_add_pd(s3m, s4m);
    _mm_storeu_pd(((double  *) (dst + 384)), s5m);
    s6m = v_neg23(_mm_sub_pd(s3m, s4m));
    _mm_storeu_pd(((double  *) (dst + 640)), s6m);
    s7m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t5j), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t6j));
    s8m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t5j), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t6j));
    s9m = v_lo2(s7m, s8m);
    s0n = v_hi2(s7m, s8m);
    s1n = _mm_add_pd(s9m, s0n);
    _mm_storeu_pd(((double  *) (dst + 416)), s1n);
    s2n = v_neg23(_mm_sub_pd(s9m, s0n));
    _mm_storeu_pd(((double  *) (dst + 608)), s2n);
    s3n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t9h), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t0i));
    s4n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t9h), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t0i));
    s5n = v_lo2(s3n, s4n);
    s6n = v_hi2(s3n, s4n);
    s7n = _mm_add_pd(s5n, s6n);
    _mm_storeu_pd(((double  *) (dst + 448)), s7n);
    s8n = v_neg23(_mm_sub_pd(s5n, s6n));
    _mm_storeu_pd(((double  *) (dst + 576)), s8n);
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t3g), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t4g));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t3g), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t4g));
    s1o = v_lo2(s9n, s0o);
    s2o = v_hi2(s9n, s0o);
    s3o = _mm_add_pd(s1o, s2o);
    _mm_storeu_pd(((double  *) (dst + 480)), s3o);
    s4o = v_neg23(_mm_sub_pd(s1o, s2o));
    _mm_storeu_pd(((double  *) (dst + 544)), s4o);
    {long i2; for(i2 = 0; i2 <= 14; i2++) {
        a82 = (32 * i2);
        b2 = (((__m128d  *) T) + a82);
        s5o = *((b2 + 32));
        s6o = *((b2 + 48));
        s7o = *((b2 + 33));
        s8o = *((b2 + 49));
        s9o = *((b2 + 34));
        s0p = *((b2 + 50));
        s1p = *((b2 + 35));
        s2p = *((b2 + 51));
        s3p = *((b2 + 36));
        s4p = *((b2 + 52));
        s5p = *((b2 + 37));
        s6p = *((b2 + 53));
        s7p = *((b2 + 38));
        s8p = *((b2 + 54));
        s9p = *((b2 + 39));
        s0q = *((b2 + 55));
        s1q = *((b2 + 40));
        s2q = *((b2 + 56));
        s3q = *((b2 + 41));
        s4q = *((b2 + 57));
        s5q = *((b2 + 42));
        s6q = *((b2 + 58));
        s7q = *((b2 + 43));
        s8q = *((b2 + 59));
        s9q = *((b2 + 44));
        s0r = *((b2 + 60));
        s1r = *((b2 + 45));
        s2r = *((b2 + 61));
        s3r = *((b2 + 46));
        s4r = *((b2 + 62));
        s5r = *((b2 + 47));
        s6r = *((b2 + 63));
        a92 = (D44 + a82);
        a03 = *(a92);
        a13 = *((a92 + 1));
        s7r = _mm_sub_pd(_mm_mul_pd(a03, s5o), _mm_mul_pd(a13, s6o));
        s8r = _mm_add_pd(_mm_mul_pd(a13, s5o), _mm_mul_pd(a03, s6o));
        a23 = *((a92 + 2));
        a33 = *((a92 + 3));
        s9r = _mm_sub_pd(_mm_mul_pd(a23, s7o), _mm_mul_pd(a33, s8o));
        s0s = _mm_add_pd(_mm_mul_pd(a33, s7o), _mm_mul_pd(a23, s8o));
        a43 = *((a92 + 4));
        a53 = *((a92 + 5));
        s1s = _mm_sub_pd(_mm_mul_pd(a43, s9o), _mm_mul_pd(a53, s0p));
        s2s = _mm_add_pd(_mm_mul_pd(a53, s9o), _mm_mul_pd(a43, s0p));
        a63 = *((a92 + 6));
        a73 = *((a92 + 7));
        s3s = _mm_sub_pd(_mm_mul_pd(a63, s1p), _mm_mul_pd(a73, s2p));
        s4s = _mm_add_pd(_mm_mul_pd(a73, s1p), _mm_mul_pd(a63, s2p));
        a83 = *((a92 + 8));
        a93 = *((a92 + 9));
        s5s = _mm_sub_pd(_mm_mul_pd(a83, s3p), _mm_mul_pd(a93, s4p));
        s6s = _mm_add_pd(_mm_mul_pd(a93, s3p), _mm_mul_pd(a83, s4p));
        a04 = *((a92 + 10));
        a14 = *((a92 + 11));
        s7s = _mm_sub_pd(_mm_mul_pd(a04, s5p), _mm_mul_pd(a14, s6p));
        s8s = _mm_add_pd(_mm_mul_pd(a14, s5p), _mm_mul_pd(a04, s6p));
        a24 = *((a92 + 12));
        a34 = *((a92 + 13));
        s9s = _mm_sub_pd(_mm_mul_pd(a24, s7p), _mm_mul_pd(a34, s8p));
        s0t = _mm_add_pd(_mm_mul_pd(a34, s7p), _mm_mul_pd(a24, s8p));
        a44 = *((a92 + 14));
        a54 = *((a92 + 15));
        s1t = _mm_sub_pd(_mm_mul_pd(a44, s9p), _mm_mul_pd(a54, s0q));
        s2t = _mm_add_pd(_mm_mul_pd(a54, s9p), _mm_mul_pd(a44, s0q));
        a64 = *((a92 + 16));
        a74 = *((a92 + 17));
        s3t = _mm_sub_pd(_mm_mul_pd(a64, s1q), _mm_mul_pd(a74, s2q));
        s4t = _mm_add_pd(_mm_mul_pd(a74, s1q), _mm_mul_pd(a64, s2q));
        a84 = *((a92 + 18));
        a94 = *((a92 + 19));
        s5t = _mm_sub_pd(_mm_mul_pd(a84, s3q), _mm_mul_pd(a94, s4q));
        s6t = _mm_add_pd(_mm_mul_pd(a94, s3q), _mm_mul_pd(a84, s4q));
        a05 = *((a92 + 20));
        a15 = *((a92 + 21));
        s7t = _mm_sub_pd(_mm_mul_pd(a05, s5q), _mm_mul_pd(a15, s6q));
        s8t = _mm_add_pd(_mm_mul_pd(a15, s5q), _mm_mul_pd(a05, s6q));
        a25 = *((a92 + 22));
        a35 = *((a92 + 23));
        s9t = _mm_sub_pd(_mm_mul_pd(a25, s7q), _mm_mul_pd(a35, s8q));
        s0u = _mm_add_pd(_mm_mul_pd(a35, s7q), _mm_mul_pd(a25, s8q));
        a45 = *((a92 + 24));
        a55 = *((a92 + 25));
        s1u = _mm_sub_pd(_mm_mul_pd(a45, s9q), _mm_mul_pd(a55, s0r));
        s2u = _mm_add_pd(_mm_mul_pd(a55, s9q), _mm_mul_pd(a45, s0r));
        a65 = *((a92 + 26));
        a75 = *((a92 + 27));
        s3u = _mm_sub_pd(_mm_mul_pd(a65, s1r), _mm_mul_pd(a75, s2r));
        s4u = _mm_add_pd(_mm_mul_pd(a75, s1r), _mm_mul_pd(a65, s2r));
        a85 = *((a92 + 28));
        a95 = *((a92 + 29));
        s5u = _mm_sub_pd(_mm_mul_pd(a85, s3r), _mm_mul_pd(a95, s4r));
        s6u = _mm_add_pd(_mm_mul_pd(a95, s3r), _mm_mul_pd(a85, s4r));
        a06 = *((a92 + 30));
        a16 = *((a92 + 31));
        s7u = _mm_sub_pd(_mm_mul_pd(a06, s5r), _mm_mul_pd(a16, s6r));
        s8u = _mm_add_pd(_mm_mul_pd(a16, s5r), _mm_mul_pd(a06, s6r));
        t2k = _mm_add_pd(s7r, s3t);
        t3k = _mm_add_pd(s8r, s4t);
        t4k = _mm_sub_pd(s7r, s3t);
        t5k = _mm_sub_pd(s8r, s4t);
        t6k = _mm_add_pd(s9r, s5t);
        t7k = _mm_add_pd(s0s, s6t);
        t8k = _mm_sub_pd(s9r, s5t);
        t9k = _mm_sub_pd(s0s, s6t);
        s9u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9k));
        s0v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9k));
        t0l = _mm_add_pd(s1s, s7t);
        t1l = _mm_add_pd(s2s, s8t);
        a26 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1s, s7t));
        a36 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2s, s8t));
        s1v = _mm_sub_pd(a26, a36);
        s2v = _mm_add_pd(a26, a36);
        t2l = _mm_add_pd(s3s, s9t);
        t3l = _mm_add_pd(s4s, s0u);
        t4l = _mm_sub_pd(s3s, s9t);
        t5l = _mm_sub_pd(s4s, s0u);
        s3v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4l), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5l));
        s4v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4l), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5l));
        t6l = _mm_add_pd(s5s, s1u);
        t7l = _mm_add_pd(s6s, s2u);
        t8l = _mm_sub_pd(s5s, s1u);
        t9l = _mm_sub_pd(s6s, s2u);
        t0m = _mm_add_pd(s7s, s3u);
        t1m = _mm_add_pd(s8s, s4u);
        t2m = _mm_sub_pd(s7s, s3u);
        t3m = _mm_sub_pd(s8s, s4u);
        s5v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3m));
        s6v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2m), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3m));
        t4m = _mm_add_pd(s9s, s5u);
        t5m = _mm_add_pd(s0t, s6u);
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9s, s5u));
        a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0t, s6u));
        s7v = _mm_sub_pd(a46, a56);
        s8v = _mm_add_pd(a46, a56);
        t6m = _mm_add_pd(s1t, s7u);
        t7m = _mm_add_pd(s2t, s8u);
        t8m = _mm_sub_pd(s1t, s7u);
        t9m = _mm_sub_pd(s2t, s8u);
        s9v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8m), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9m));
        s0w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9m));
        t0n = _mm_add_pd(t2k, t6l);
        t1n = _mm_add_pd(t3k, t7l);
        t2n = _mm_sub_pd(t2k, t6l);
        t3n = _mm_sub_pd(t3k, t7l);
        t4n = _mm_add_pd(t0l, t4m);
        t5n = _mm_add_pd(t1l, t5m);
        t6n = _mm_sub_pd(t0l, t4m);
        t7n = _mm_sub_pd(t1l, t5m);
        t8n = _mm_add_pd(t0n, t4n);
        t9n = _mm_add_pd(t1n, t5n);
        t0o = _mm_sub_pd(t0n, t4n);
        t1o = _mm_sub_pd(t1n, t5n);
        t2o = _mm_add_pd(t2n, t7n);
        t3o = _mm_sub_pd(t3n, t6n);
        t4o = _mm_sub_pd(t2n, t7n);
        t5o = _mm_add_pd(t3n, t6n);
        t6o = _mm_add_pd(t6k, t0m);
        t7o = _mm_add_pd(t7k, t1m);
        t8o = _mm_sub_pd(t6k, t0m);
        t9o = _mm_sub_pd(t7k, t1m);
        t0p = _mm_add_pd(t2l, t6m);
        t1p = _mm_add_pd(t3l, t7m);
        t2p = _mm_sub_pd(t2l, t6m);
        t3p = _mm_sub_pd(t3l, t7m);
        t4p = _mm_add_pd(t6o, t0p);
        t5p = _mm_add_pd(t7o, t1p);
        t6p = _mm_sub_pd(t6o, t0p);
        t7p = _mm_sub_pd(t7o, t1p);
        a66 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8o, t3p));
        a76 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9o, t2p));
        s1w = _mm_sub_pd(a66, a76);
        s2w = _mm_add_pd(a66, a76);
        a86 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t8o, t3p));
        a96 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t9o, t2p));
        s3w = _mm_sub_pd(a86, a96);
        s4w = _mm_add_pd(a86, a96);
        t8p = _mm_add_pd(t8n, t4p);
        t9p = _mm_add_pd(t9n, t5p);
        t0q = _mm_sub_pd(t8n, t4p);
        t1q = _mm_sub_pd(t9n, t5p);
        t2q = _mm_add_pd(t2o, s1w);
        t3q = _mm_sub_pd(t3o, s2w);
        t4q = _mm_sub_pd(t2o, s1w);
        t5q = _mm_add_pd(t3o, s2w);
        t6q = _mm_add_pd(t0o, t7p);
        t7q = _mm_sub_pd(t1o, t6p);
        t8q = _mm_sub_pd(t0o, t7p);
        t9q = _mm_add_pd(t1o, t6p);
        t0r = _mm_add_pd(t4o, s3w);
        t1r = _mm_add_pd(t5o, s4w);
        t2r = _mm_sub_pd(t4o, s3w);
        t3r = _mm_sub_pd(t5o, s4w);
        t4r = _mm_add_pd(t4k, t9l);
        t5r = _mm_sub_pd(t5k, t8l);
        t6r = _mm_sub_pd(t4k, t9l);
        t7r = _mm_add_pd(t5k, t8l);
        t8r = _mm_add_pd(s1v, s7v);
        t9r = _mm_sub_pd(s8v, s2v);
        t0s = _mm_sub_pd(s1v, s7v);
        t1s = _mm_add_pd(s2v, s8v);
        t2s = _mm_add_pd(t4r, t8r);
        t3s = _mm_add_pd(t5r, t9r);
        t4s = _mm_sub_pd(t4r, t8r);
        t5s = _mm_sub_pd(t5r, t9r);
        t6s = _mm_sub_pd(t6r, t1s);
        t7s = _mm_sub_pd(t7r, t0s);
        t8s = _mm_add_pd(t6r, t1s);
        t9s = _mm_add_pd(t7r, t0s);
        t0t = _mm_add_pd(s9u, s5v);
        t1t = _mm_add_pd(s0v, s6v);
        t2t = _mm_sub_pd(s9u, s5v);
        t3t = _mm_sub_pd(s0v, s6v);
        t4t = _mm_add_pd(s3v, s9v);
        t5t = _mm_add_pd(s4v, s0w);
        t6t = _mm_sub_pd(s3v, s9v);
        t7t = _mm_sub_pd(s4v, s0w);
        t8t = _mm_add_pd(t0t, t4t);
        t9t = _mm_add_pd(t1t, t5t);
        t0u = _mm_sub_pd(t0t, t4t);
        t1u = _mm_sub_pd(t1t, t5t);
        a07 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2t, t7t));
        a17 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3t, t6t));
        s5w = _mm_sub_pd(a07, a17);
        s6w = _mm_add_pd(a07, a17);
        a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t2t, t7t));
        a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3t, t6t));
        s7w = _mm_sub_pd(a27, a37);
        s8w = _mm_add_pd(a27, a37);
        t2u = _mm_add_pd(t2s, t8t);
        t3u = _mm_add_pd(t3s, t9t);
        t4u = _mm_sub_pd(t2s, t8t);
        t5u = _mm_sub_pd(t3s, t9t);
        t6u = _mm_add_pd(t6s, s5w);
        t7u = _mm_sub_pd(t7s, s6w);
        t8u = _mm_sub_pd(t6s, s5w);
        t9u = _mm_add_pd(t7s, s6w);
        t0v = _mm_add_pd(t4s, t1u);
        t1v = _mm_sub_pd(t5s, t0u);
        t2v = _mm_sub_pd(t4s, t1u);
        t3v = _mm_add_pd(t5s, t0u);
        t4v = _mm_add_pd(t8s, s7w);
        t5v = _mm_add_pd(t9s, s8w);
        t6v = _mm_sub_pd(t8s, s7w);
        t7v = _mm_sub_pd(t9s, s8w);
        a47 = (D43 + a82);
        a57 = *(a47);
        a67 = *((a47 + 1));
        s9w = _mm_sub_pd(_mm_mul_pd(a57, t8p), _mm_mul_pd(a67, t9p));
        s0x = _mm_add_pd(_mm_mul_pd(a67, t8p), _mm_mul_pd(a57, t9p));
        s1x = v_lo2(s9w, s0x);
        s2x = v_hi2(s9w, s0x);
        a77 = (2 * i2);
        b3 = (dst + a77);
        s3x = _mm_add_pd(s1x, s2x);
        _mm_storeu_pd(((double  *) (b3 + 2)), s3x);
        b4 = (dst - a77);
        s4x = v_neg23(_mm_sub_pd(s1x, s2x));
        _mm_storeu_pd(((double  *) (b4 + 1022)), s4x);
        a87 = *((a47 + 2));
        a97 = *((a47 + 3));
        s5x = _mm_sub_pd(_mm_mul_pd(a87, t2u), _mm_mul_pd(a97, t3u));
        s6x = _mm_add_pd(_mm_mul_pd(a97, t2u), _mm_mul_pd(a87, t3u));
        s7x = v_lo2(s5x, s6x);
        s8x = v_hi2(s5x, s6x);
        s9x = _mm_add_pd(s7x, s8x);
        _mm_storeu_pd(((double  *) (b3 + 66)), s9x);
        s0y = v_neg23(_mm_sub_pd(s7x, s8x));
        _mm_storeu_pd(((double  *) (b4 + 958)), s0y);
        a08 = *((a47 + 4));
        a18 = *((a47 + 5));
        s1y = _mm_sub_pd(_mm_mul_pd(a08, t2q), _mm_mul_pd(a18, t3q));
        s2y = _mm_add_pd(_mm_mul_pd(a18, t2q), _mm_mul_pd(a08, t3q));
        s3y = v_lo2(s1y, s2y);
        s4y = v_hi2(s1y, s2y);
        s5y = _mm_add_pd(s3y, s4y);
        _mm_storeu_pd(((double  *) (b3 + 130)), s5y);
        s6y = v_neg23(_mm_sub_pd(s3y, s4y));
        _mm_storeu_pd(((double  *) (b4 + 894)), s6y);
        a28 = *((a47 + 6));
        a38 = *((a47 + 7));
        s7y = _mm_sub_pd(_mm_mul_pd(a28, t6u), _mm_mul_pd(a38, t7u));
        s8y = _mm_add_pd(_mm_mul_pd(a38, t6u), _mm_mul_pd(a28, t7u));
        s9y = v_lo2(s7y, s8y);
        s0z = v_hi2(s7y, s8y);
        s1z = _mm_add_pd(s9y, s0z);
        _mm_storeu_pd(((double  *) (b3 + 194)), s1z);
        s2z = v_neg23(_mm_sub_pd(s9y, s0z));
        _mm_storeu_pd(((double  *) (b4 + 830)), s2z);
        a48 = *((a47 + 8));
        a58 = *((a47 + 9));
        s3z = _mm_sub_pd(_mm_mul_pd(a48, t6q), _mm_mul_pd(a58, t7q));
        s4z = _mm_add_pd(_mm_mul_pd(a58, t6q), _mm_mul_pd(a48, t7q));
        s5z = v_lo2(s3z, s4z);
        s6z = v_hi2(s3z, s4z);
        s7z = _mm_add_pd(s5z, s6z);
        _mm_storeu_pd(((double  *) (b3 + 258)), s7z);
        s8z = v_neg23(_mm_sub_pd(s5z, s6z));
        _mm_storeu_pd(((double  *) (b4 + 766)), s8z);
        a68 = *((a47 + 10));
        a78 = *((a47 + 11));
        s9z = _mm_sub_pd(_mm_mul_pd(a68, t0v), _mm_mul_pd(a78, t1v));
        s0A = _mm_add_pd(_mm_mul_pd(a78, t0v), _mm_mul_pd(a68, t1v));
        s1A = v_lo2(s9z, s0A);
        s2A = v_hi2(s9z, s0A);
        s3A = _mm_add_pd(s1A, s2A);
        _mm_storeu_pd(((double  *) (b3 + 322)), s3A);
        s4A = v_neg23(_mm_sub_pd(s1A, s2A));
        _mm_storeu_pd(((double  *) (b4 + 702)), s4A);
        a88 = *((a47 + 12));
        a98 = *((a47 + 13));
        s5A = _mm_sub_pd(_mm_mul_pd(a88, t0r), _mm_mul_pd(a98, t1r));
        s6A = _mm_add_pd(_mm_mul_pd(a98, t0r), _mm_mul_pd(a88, t1r));
        s7A = v_lo2(s5A, s6A);
        s8A = v_hi2(s5A, s6A);
        s9A = _mm_add_pd(s7A, s8A);
        _mm_storeu_pd(((double  *) (b3 + 386)), s9A);
        s0B = v_neg23(_mm_sub_pd(s7A, s8A));
        _mm_storeu_pd(((double  *) (b4 + 638)), s0B);
        a09 = *((a47 + 14));
        a19 = *((a47 + 15));
        s1B = _mm_sub_pd(_mm_mul_pd(a09, t4v), _mm_mul_pd(a19, t5v));
        s2B = _mm_add_pd(_mm_mul_pd(a19, t4v), _mm_mul_pd(a09, t5v));
        s3B = v_lo2(s1B, s2B);
        s4B = v_hi2(s1B, s2B);
        s5B = _mm_add_pd(s3B, s4B);
        _mm_storeu_pd(((double  *) (b3 + 450)), s5B);
        s6B = v_neg23(_mm_sub_pd(s3B, s4B));
        _mm_storeu_pd(((double  *) (b4 + 574)), s6B);
        a29 = *((a47 + 16));
        a39 = *((a47 + 17));
        s7B = _mm_sub_pd(_mm_mul_pd(a29, t0q), _mm_mul_pd(a39, t1q));
        s8B = _mm_add_pd(_mm_mul_pd(a39, t0q), _mm_mul_pd(a29, t1q));
        s9B = v_lo2(s7B, s8B);
        s0C = v_hi2(s7B, s8B);
        s1C = _mm_add_pd(s9B, s0C);
        _mm_storeu_pd(((double  *) (b3 + 514)), s1C);
        s2C = v_neg23(_mm_sub_pd(s9B, s0C));
        _mm_storeu_pd(((double  *) (b4 + 510)), s2C);
        a49 = *((a47 + 18));
        a59 = *((a47 + 19));
        s3C = _mm_sub_pd(_mm_mul_pd(a49, t4u), _mm_mul_pd(a59, t5u));
        s4C = _mm_add_pd(_mm_mul_pd(a59, t4u), _mm_mul_pd(a49, t5u));
        s5C = v_lo2(s3C, s4C);
        s6C = v_hi2(s3C, s4C);
        s7C = _mm_add_pd(s5C, s6C);
        _mm_storeu_pd(((double  *) (b3 + 578)), s7C);
        s8C = v_neg23(_mm_sub_pd(s5C, s6C));
        _mm_storeu_pd(((double  *) (b4 + 446)), s8C);
        a69 = *((a47 + 20));
        a79 = *((a47 + 21));
        s9C = _mm_sub_pd(_mm_mul_pd(a69, t4q), _mm_mul_pd(a79, t5q));
        s0D = _mm_add_pd(_mm_mul_pd(a79, t4q), _mm_mul_pd(a69, t5q));
        s1D = v_lo2(s9C, s0D);
        s2D = v_hi2(s9C, s0D);
        s3D = _mm_add_pd(s1D, s2D);
        _mm_storeu_pd(((double  *) (b3 + 642)), s3D);
        s4D = v_neg23(_mm_sub_pd(s1D, s2D));
        _mm_storeu_pd(((double  *) (b4 + 382)), s4D);
        a89 = *((a47 + 22));
        a99 = *((a47 + 23));
        s5D = _mm_sub_pd(_mm_mul_pd(a89, t8u), _mm_mul_pd(a99, t9u));
        s6D = _mm_add_pd(_mm_mul_pd(a99, t8u), _mm_mul_pd(a89, t9u));
        s7D = v_lo2(s5D, s6D);
        s8D = v_hi2(s5D, s6D);
        s9D = _mm_add_pd(s7D, s8D);
        _mm_storeu_pd(((double  *) (b3 + 706)), s9D);
        s0E = v_neg23(_mm_sub_pd(s7D, s8D));
        _mm_storeu_pd(((double  *) (b4 + 318)), s0E);
        a0a = *((a47 + 24));
        a1a = *((a47 + 25));
        s1E = _mm_sub_pd(_mm_mul_pd(a0a, t8q), _mm_mul_pd(a1a, t9q));
        s2E = _mm_add_pd(_mm_mul_pd(a1a, t8q), _mm_mul_pd(a0a, t9q));
        s3E = v_lo2(s1E, s2E);
        s4E = v_hi2(s1E, s2E);
        s5E = _mm_add_pd(s3E, s4E);
        _mm_storeu_pd(((double  *) (b3 + 770)), s5E);
        s6E = v_neg23(_mm_sub_pd(s3E, s4E));
        _mm_storeu_pd(((double  *) (b4 + 254)), s6E);
        a2a = *((a47 + 26));
        a3a = *((a47 + 27));
        s7E = _mm_sub_pd(_mm_mul_pd(a2a, t2v), _mm_mul_pd(a3a, t3v));
        s8E = _mm_add_pd(_mm_mul_pd(a3a, t2v), _mm_mul_pd(a2a, t3v));
        s9E = v_lo2(s7E, s8E);
        s0F = v_hi2(s7E, s8E);
        s1F = _mm_add_pd(s9E, s0F);
        _mm_storeu_pd(((double  *) (b3 + 834)), s1F);
        s2F = v_neg23(_mm_sub_pd(s9E, s0F));
        _mm_storeu_pd(((double  *) (b4 + 190)), s2F);
        a4a = *((a47 + 28));
        a5a = *((a47 + 29));
        s3F = _mm_sub_pd(_mm_mul_pd(a4a, t2r), _mm_mul_pd(a5a, t3r));
        s4F = _mm_add_pd(_mm_mul_pd(a5a, t2r), _mm_mul_pd(a4a, t3r));
        s5F = v_lo2(s3F, s4F);
        s6F = v_hi2(s3F, s4F);
        s7F = _mm_add_pd(s5F, s6F);
        _mm_storeu_pd(((double  *) (b3 + 898)), s7F);
        s8F = v_neg23(_mm_sub_pd(s5F, s6F));
        _mm_storeu_pd(((double  *) (b4 + 126)), s8F);
        a6a = *((a47 + 30));
        a7a = *((a47 + 31));
        s9F = _mm_sub_pd(_mm_mul_pd(a6a, t6v), _mm_mul_pd(a7a, t7v));
        s0G = _mm_add_pd(_mm_mul_pd(a7a, t6v), _mm_mul_pd(a6a, t7v));
        s1G = v_lo2(s9F, s0G);
        s2G = v_hi2(s9F, s0G);
        s3G = _mm_add_pd(s1G, s2G);
        _mm_storeu_pd(((double  *) (b3 + 962)), s3G);
        s4G = v_neg23(_mm_sub_pd(s1G, s2G));
        _mm_storeu_pd(((double  *) (b4 + 62)), s4G);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_1024)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_1024_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[1024]);
    __m128d a02, a04, a05, a06, a07, a08, a09, a0a, a11, a12, a13, a14, a15, a16, a17, a18, a19, a1a, a2, a21, a22, a23
            , a24, a25, a26, a27, a28, a29, a2a, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a3a, a4, a41, a42, a43
            , a44, a45, a46, a47, a48, a49, a4a, a5, a52, a53, a54, a55, a56, a58, a59, a5a, a6, a61, a62, a63, a64, a65
            , a66, a67, a68, a69, a6a, a7, a71, a72, a73, a74, a75, a76, a77, a78, a79, a7a, a8, a81, a83, a84, a85, a86
            , a88, a89, a8a, a9, a91, a93, a94, a95, a96, a97, a98, a99, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o
            , s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B
            , s1C, s1D, s1E, s1F, s1G, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2G, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r
            , s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D
            , s3E, s3F, s3G, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s
            , s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E
            , s4F, s4G, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t
            , s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F
            , s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v
            , s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6a, s6b
            , s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x
            , s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z
            , s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8a, s8b, s8c, s8d, s8e, s8f
            , s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91
            , s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h
            , s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03
            , t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p
            , t0q, t0r, t0s, t0t, t0u, t0v, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g
            , t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s, t1t, t1u, t1v, t2, t21, t22, t23, t24, t25, t26
            , t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s
            , t2t, t2u, t2v, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i
            , t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t4, t41, t42, t43, t44, t45, t46, t47, t48
            , t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u
            , t4v, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t7
            , t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m
            , t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c
            , t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t9, t91, t92, t93
            , t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p
            , t9q, t9r, t9s, t9t, t9u;
    __m128d  *a, *a01, *a03, *a51, *a57, *a82, *a87, *b, *b2, *b3;
    int a92;
    {long i; for(i = 0; i <= 15; i++) {
        a = (((__m128d  *) src) + i);
        s = *(a);
        s2 = *((a + 256));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = *((a + 128));
        s4 = *((a + 384));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = *((a + 64));
        s6 = *((a + 320));
        t5 = _mm_add_pd(s5, s6);
        s7 = *((a + 192));
        s8 = *((a + 448));
        t6 = _mm_add_pd(s7, s8);
        t7 = _mm_add_pd(t, t3);
        t8 = _mm_sub_pd(t, t3);
        t9 = _mm_add_pd(t5, t6);
        t01 = _mm_sub_pd(t5, t6);
        a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
        a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
        s9 = _mm_add_pd(a2, a3);
        s01 = _mm_sub_pd(a3, a2);
        t11 = _mm_add_pd(t2, s9);
        t21 = _mm_sub_pd(s01, t4);
        t31 = _mm_sub_pd(t2, s9);
        t41 = _mm_add_pd(t4, s01);
        s11 = *((a + 16));
        s21 = *((a + 272));
        t51 = _mm_add_pd(s11, s21);
        t61 = _mm_sub_pd(s11, s21);
        s31 = *((a + 144));
        s41 = *((a + 400));
        t71 = _mm_add_pd(s31, s41);
        t81 = _mm_sub_pd(s31, s41);
        s51 = *((a + 80));
        s61 = *((a + 336));
        t91 = _mm_add_pd(s51, s61);
        s71 = *((a + 208));
        s81 = *((a + 464));
        t02 = _mm_add_pd(s71, s81);
        t12 = _mm_add_pd(t51, t71);
        t22 = _mm_sub_pd(t51, t71);
        t32 = _mm_add_pd(t91, t02);
        t42 = _mm_sub_pd(t91, t02);
        a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
        a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
        s91 = _mm_add_pd(a4, a5);
        s02 = _mm_sub_pd(a5, a4);
        t52 = _mm_add_pd(t61, s91);
        t62 = _mm_sub_pd(s02, t81);
        t72 = _mm_sub_pd(t61, s91);
        t82 = _mm_add_pd(t81, s02);
        s12 = *((a + 32));
        s22 = *((a + 288));
        t92 = _mm_add_pd(s12, s22);
        t03 = _mm_sub_pd(s12, s22);
        s32 = *((a + 160));
        s42 = *((a + 416));
        t13 = _mm_add_pd(s32, s42);
        t23 = _mm_sub_pd(s32, s42);
        s52 = *((a + 96));
        s62 = *((a + 352));
        t33 = _mm_add_pd(s52, s62);
        s72 = *((a + 224));
        s82 = *((a + 480));
        t43 = _mm_add_pd(s72, s82);
        t53 = _mm_add_pd(t92, t13);
        t63 = _mm_add_pd(t33, t43);
        a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
        a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
        s92 = _mm_add_pd(a6, a7);
        s03 = _mm_sub_pd(a7, a6);
        t73 = _mm_add_pd(t03, s92);
        t83 = _mm_sub_pd(s03, t23);
        t93 = _mm_sub_pd(t03, s92);
        t04 = _mm_add_pd(t23, s03);
        s13 = *((a + 48));
        s23 = *((a + 304));
        t14 = _mm_add_pd(s13, s23);
        t24 = _mm_sub_pd(s13, s23);
        s33 = *((a + 176));
        s43 = *((a + 432));
        t34 = _mm_add_pd(s33, s43);
        t44 = _mm_sub_pd(s33, s43);
        s53 = *((a + 112));
        s63 = *((a + 368));
        t54 = _mm_add_pd(s53, s63);
        s73 = *((a + 240));
        s83 = *((a + 496));
        t64 = _mm_add_pd(s73, s83);
        t74 = _mm_add_pd(t14, t34);
        t84 = _mm_sub_pd(t14, t34);
        t94 = _mm_add_pd(t54, t64);
        t05 = _mm_sub_pd(t54, t64);
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
        s93 = _mm_add_pd(a8, a9);
        s04 = _mm_sub_pd(a9, a8);
        t15 = _mm_add_pd(t24, s93);
        t25 = _mm_sub_pd(s04, t44);
        t35 = _mm_sub_pd(t24, s93);
        t45 = _mm_add_pd(t44, s04);
        t55 = _mm_add_pd(t7, t9);
        t65 = _mm_sub_pd(t7, t9);
        t75 = _mm_add_pd(t53, t63);
        t85 = _mm_sub_pd(t53, t63);
        t95 = _mm_add_pd(t12, t32);
        t06 = _mm_add_pd(t74, t94);
        a01 = (((__m128d  *) T) + i);
        s14 = _mm_add_pd(t55, t75);
        *(a01) = s14;
        s24 = _mm_sub_pd(t55, t75);
        *((a01 + 256)) = s24;
        s34 = _mm_add_pd(t95, t06);
        *((a01 + 16)) = s34;
        s44 = _mm_sub_pd(t06, t95);
        *((a01 + 272)) = s44;
        a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
        a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
        s54 = _mm_add_pd(a11, a21);
        s64 = _mm_sub_pd(a21, a11);
        s74 = _mm_add_pd(t65, s54);
        *((a01 + 128)) = s74;
        s84 = _mm_sub_pd(s64, t85);
        *((a01 + 144)) = s84;
        s94 = _mm_sub_pd(t65, s54);
        *((a01 + 384)) = s94;
        s05 = _mm_add_pd(t85, s64);
        *((a01 + 400)) = s05;
        s15 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
        s25 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
        s35 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
        s45 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
        s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
        s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
        t16 = _mm_add_pd(t11, s35);
        t26 = _mm_add_pd(t21, s45);
        t36 = _mm_sub_pd(t11, s35);
        t46 = _mm_sub_pd(t21, s45);
        t56 = _mm_add_pd(s15, s55);
        t66 = _mm_add_pd(s25, s65);
        t76 = _mm_sub_pd(s15, s55);
        t86 = _mm_sub_pd(s25, s65);
        s75 = _mm_add_pd(t16, t56);
        *((a01 + 32)) = s75;
        s85 = _mm_add_pd(t26, t66);
        *((a01 + 48)) = s85;
        s95 = _mm_sub_pd(t16, t56);
        *((a01 + 480)) = s95;
        s06 = _mm_sub_pd(t66, t26);
        *((a01 + 496)) = s06;
        s16 = _mm_add_pd(t36, t86);
        *((a01 + 288)) = s16;
        s26 = _mm_sub_pd(t46, t76);
        *((a01 + 304)) = s26;
        s36 = _mm_sub_pd(t36, t86);
        *((a01 + 224)) = s36;
        s46 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t46, t76));
        *((a01 + 240)) = s46;
        s56 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
        s66 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
        a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
        a41 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
        s76 = _mm_add_pd(a31, a41);
        s86 = _mm_sub_pd(a41, a31);
        s96 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
        s07 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
        t96 = _mm_add_pd(t8, s76);
        t07 = _mm_sub_pd(s86, t01);
        t17 = _mm_sub_pd(t8, s76);
        t27 = _mm_add_pd(t01, s86);
        t37 = _mm_add_pd(s56, s96);
        t47 = _mm_add_pd(s66, s07);
        t57 = _mm_sub_pd(s56, s96);
        t67 = _mm_sub_pd(s66, s07);
        s17 = _mm_add_pd(t96, t37);
        *((a01 + 64)) = s17;
        s27 = _mm_add_pd(t07, t47);
        *((a01 + 80)) = s27;
        s37 = _mm_sub_pd(t96, t37);
        *((a01 + 448)) = s37;
        s47 = _mm_sub_pd(t47, t07);
        *((a01 + 464)) = s47;
        s57 = _mm_add_pd(t17, t67);
        *((a01 + 320)) = s57;
        s67 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t27, t57));
        *((a01 + 336)) = s67;
        s77 = _mm_sub_pd(t17, t67);
        *((a01 + 192)) = s77;
        s87 = _mm_sub_pd(t27, t57);
        *((a01 + 208)) = s87;
        s97 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
        s08 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
        s18 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
        s28 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
        s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
        s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
        t77 = _mm_add_pd(t31, s18);
        t87 = _mm_add_pd(t41, s28);
        t97 = _mm_sub_pd(t31, s18);
        t08 = _mm_sub_pd(t41, s28);
        t18 = _mm_add_pd(s97, s38);
        t28 = _mm_add_pd(s08, s48);
        t38 = _mm_sub_pd(s97, s38);
        t48 = _mm_sub_pd(s08, s48);
        s58 = _mm_add_pd(t77, t18);
        *((a01 + 96)) = s58;
        s68 = _mm_add_pd(t87, t28);
        *((a01 + 112)) = s68;
        s78 = _mm_sub_pd(t77, t18);
        *((a01 + 416)) = s78;
        s88 = _mm_sub_pd(t28, t87);
        *((a01 + 432)) = s88;
        s98 = _mm_add_pd(t97, t48);
        *((a01 + 352)) = s98;
        s09 = _mm_sub_pd(t08, t38);
        *((a01 + 368)) = s09;
        s19 = _mm_sub_pd(t97, t48);
        *((a01 + 160)) = s19;
        s29 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t08, t38));
        *((a01 + 176)) = s29;
    }}
    a51 = ((__m128d  *) T);
    s39 = *(a51);
    s49 = *((a51 + 16));
    t58 = _mm_add_pd(s39, s49);
    t68 = _mm_sub_pd(s39, s49);
    s59 = *((a51 + 8));
    s69 = *((a51 + 24));
    t78 = _mm_add_pd(s59, s69);
    t88 = _mm_sub_pd(s59, s69);
    s79 = *((a51 + 4));
    s89 = *((a51 + 20));
    t98 = _mm_add_pd(s79, s89);
    s99 = *((a51 + 12));
    s0a = *((a51 + 28));
    t09 = _mm_add_pd(s99, s0a);
    t19 = _mm_add_pd(t58, t78);
    t29 = _mm_sub_pd(t58, t78);
    t39 = _mm_add_pd(t98, t09);
    t49 = _mm_sub_pd(t98, t09);
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s79, s89));
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s99, s0a));
    s1a = _mm_add_pd(a61, a71);
    s2a = _mm_sub_pd(a71, a61);
    t59 = _mm_add_pd(t68, s1a);
    t69 = _mm_sub_pd(s2a, t88);
    t79 = _mm_sub_pd(t68, s1a);
    t89 = _mm_add_pd(t88, s2a);
    s3a = *((a51 + 1));
    s4a = *((a51 + 17));
    t99 = _mm_add_pd(s3a, s4a);
    t0a = _mm_sub_pd(s3a, s4a);
    s5a = *((a51 + 9));
    s6a = *((a51 + 25));
    t1a = _mm_add_pd(s5a, s6a);
    t2a = _mm_sub_pd(s5a, s6a);
    s7a = *((a51 + 5));
    s8a = *((a51 + 21));
    t3a = _mm_add_pd(s7a, s8a);
    s9a = *((a51 + 13));
    s0b = *((a51 + 29));
    t4a = _mm_add_pd(s9a, s0b);
    t5a = _mm_add_pd(t99, t1a);
    t6a = _mm_sub_pd(t99, t1a);
    t7a = _mm_add_pd(t3a, t4a);
    t8a = _mm_sub_pd(t3a, t4a);
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7a, s8a));
    a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9a, s0b));
    s1b = _mm_add_pd(a81, a91);
    s2b = _mm_sub_pd(a91, a81);
    t9a = _mm_add_pd(t0a, s1b);
    t0b = _mm_sub_pd(s2b, t2a);
    t1b = _mm_sub_pd(t0a, s1b);
    t2b = _mm_add_pd(t2a, s2b);
    s3b = *((a51 + 2));
    s4b = *((a51 + 18));
    t3b = _mm_add_pd(s3b, s4b);
    t4b = _mm_sub_pd(s3b, s4b);
    s5b = *((a51 + 10));
    s6b = *((a51 + 26));
    t5b = _mm_add_pd(s5b, s6b);
    t6b = _mm_sub_pd(s5b, s6b);
    s7b = *((a51 + 6));
    s8b = *((a51 + 22));
    t7b = _mm_add_pd(s7b, s8b);
    s9b = *((a51 + 14));
    s0c = *((a51 + 30));
    t8b = _mm_add_pd(s9b, s0c);
    t9b = _mm_add_pd(t3b, t5b);
    t0c = _mm_add_pd(t7b, t8b);
    a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7b, s8b));
    a12 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9b, s0c));
    s1c = _mm_add_pd(a02, a12);
    s2c = _mm_sub_pd(a12, a02);
    t1c = _mm_add_pd(t4b, s1c);
    t2c = _mm_sub_pd(s2c, t6b);
    t3c = _mm_sub_pd(t4b, s1c);
    t4c = _mm_add_pd(t6b, s2c);
    s3c = *((a51 + 3));
    s4c = *((a51 + 19));
    t5c = _mm_add_pd(s3c, s4c);
    t6c = _mm_sub_pd(s3c, s4c);
    s5c = *((a51 + 11));
    s6c = *((a51 + 27));
    t7c = _mm_add_pd(s5c, s6c);
    t8c = _mm_sub_pd(s5c, s6c);
    s7c = *((a51 + 7));
    s8c = *((a51 + 23));
    t9c = _mm_add_pd(s7c, s8c);
    s9c = *((a51 + 15));
    s0d = *((a51 + 31));
    t0d = _mm_add_pd(s9c, s0d);
    t1d = _mm_add_pd(t5c, t7c);
    t2d = _mm_sub_pd(t5c, t7c);
    t3d = _mm_add_pd(t9c, t0d);
    t4d = _mm_sub_pd(t9c, t0d);
    a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7c, s8c));
    a32 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9c, s0d));
    s1d = _mm_add_pd(a22, a32);
    s2d = _mm_sub_pd(a32, a22);
    t5d = _mm_add_pd(t6c, s1d);
    t6d = _mm_sub_pd(s2d, t8c);
    t7d = _mm_sub_pd(t6c, s1d);
    t8d = _mm_add_pd(t8c, s2d);
    t9d = _mm_add_pd(t19, t39);
    t0e = _mm_sub_pd(t19, t39);
    t1e = _mm_add_pd(t9b, t0c);
    t2e = _mm_sub_pd(t9b, t0c);
    t3e = _mm_add_pd(t5a, t7a);
    t4e = _mm_add_pd(t1d, t3d);
    t5e = _mm_add_pd(t9d, t1e);
    t6e = _mm_sub_pd(t9d, t1e);
    t7e = _mm_add_pd(t3e, t4e);
    t8e = _mm_sub_pd(t3e, t4e);
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t7a));
    a52 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1d, t3d));
    s3d = _mm_add_pd(a42, a52);
    s4d = _mm_sub_pd(a52, a42);
    t9e = _mm_add_pd(t0e, s3d);
    t0f = _mm_sub_pd(s4d, t2e);
    t1f = _mm_sub_pd(t0e, s3d);
    t2f = _mm_add_pd(t2e, s4d);
    s5d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
    s6d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
    s7d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1c), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2c));
    s8d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2c));
    s9d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5d), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6d));
    s0e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6d));
    t3f = _mm_add_pd(t59, s7d);
    t4f = _mm_add_pd(t69, s8d);
    t5f = _mm_sub_pd(t59, s7d);
    t6f = _mm_sub_pd(t69, s8d);
    t7f = _mm_add_pd(s5d, s9d);
    t8f = _mm_add_pd(s6d, s0e);
    t9f = _mm_sub_pd(s5d, s9d);
    t0g = _mm_sub_pd(s6d, s0e);
    t1g = _mm_add_pd(t3f, t7f);
    t2g = _mm_add_pd(t4f, t8f);
    t3g = _mm_sub_pd(t3f, t7f);
    t4g = _mm_sub_pd(t4f, t8f);
    t5g = _mm_add_pd(t5f, t0g);
    t6g = _mm_sub_pd(t6f, t9f);
    t7g = _mm_sub_pd(t5f, t0g);
    t8g = _mm_add_pd(t6f, t9f);
    s1e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8a));
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3b, t5b));
    a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7b, t8b));
    s3e = _mm_add_pd(a62, a72);
    s4e = _mm_sub_pd(a72, a62);
    s5e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4d));
    t9g = _mm_add_pd(t29, s3e);
    t0h = _mm_sub_pd(s4e, t49);
    t1h = _mm_sub_pd(t29, s3e);
    t2h = _mm_add_pd(t49, s4e);
    t3h = _mm_add_pd(s1e, s5e);
    t4h = _mm_add_pd(s2e, s6e);
    t5h = _mm_sub_pd(s1e, s5e);
    t6h = _mm_sub_pd(s2e, s6e);
    t7h = _mm_add_pd(t9g, t3h);
    t8h = _mm_add_pd(t0h, t4h);
    t9h = _mm_sub_pd(t9g, t3h);
    t0i = _mm_sub_pd(t0h, t4h);
    t1i = _mm_add_pd(t1h, t6h);
    t2i = _mm_add_pd(t2h, t5h);
    t3i = _mm_sub_pd(t1h, t6h);
    t4i = _mm_sub_pd(t5h, t2h);
    s7e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1b), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t2b));
    s8e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t1b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2b));
    s9e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4c));
    s0f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4c));
    s1f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7d), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8d));
    s2f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7d), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8d));
    t5i = _mm_add_pd(t79, s9e);
    t6i = _mm_add_pd(t89, s0f);
    t7i = _mm_sub_pd(t79, s9e);
    t8i = _mm_sub_pd(t89, s0f);
    t9i = _mm_add_pd(s7e, s1f);
    t0j = _mm_add_pd(s8e, s2f);
    t1j = _mm_sub_pd(s7e, s1f);
    t2j = _mm_sub_pd(s8e, s2f);
    t3j = _mm_add_pd(t5i, t9i);
    t4j = _mm_add_pd(t6i, t0j);
    t5j = _mm_sub_pd(t5i, t9i);
    t6j = _mm_sub_pd(t6i, t0j);
    t7j = _mm_add_pd(t7i, t2j);
    t8j = _mm_sub_pd(t8i, t1j);
    t9j = _mm_sub_pd(t7i, t2j);
    t0k = _mm_add_pd(t8i, t1j);
    t1k = _mm_add_pd(t5e, t7e);
    a82 = ((__m128d  *) dst);
    s3f = _mm_add_pd(v_neg03(v_hi2(t1k, t1k)), v_lo2(t1k, t1k));
    *(a82) = s3f;
    s4f = v_neg23(_mm_sub_pd(t5e, t7e));
    *((a82 + 256)) = s4f;
    s5f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t1g), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t2g));
    s6f = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t1g), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t2g));
    s7f = v_lo2(s5f, s6f);
    s8f = v_hi2(s5f, s6f);
    s9f = _mm_add_pd(s7f, s8f);
    *((a82 + 16)) = s9f;
    s0g = v_neg23(_mm_sub_pd(s7f, s8f));
    *((a82 + 496)) = s0g;
    s1g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t7h), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t8h));
    s2g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t7h), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t8h));
    s3g = v_lo2(s1g, s2g);
    s4g = v_hi2(s1g, s2g);
    s5g = _mm_add_pd(s3g, s4g);
    *((a82 + 32)) = s5g;
    s6g = v_neg23(_mm_sub_pd(s3g, s4g));
    *((a82 + 480)) = s6g;
    s7g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t3j), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t4j));
    s8g = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t3j), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t4j));
    s9g = v_lo2(s7g, s8g);
    s0h = v_hi2(s7g, s8g);
    s1h = _mm_add_pd(s9g, s0h);
    *((a82 + 48)) = s1h;
    s2h = v_neg23(_mm_sub_pd(s9g, s0h));
    *((a82 + 464)) = s2h;
    s3h = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t9e), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t0f));
    s4h = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t9e), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t0f));
    s5h = v_lo2(s3h, s4h);
    s6h = v_hi2(s3h, s4h);
    s7h = _mm_add_pd(s5h, s6h);
    *((a82 + 64)) = s7h;
    s8h = v_neg23(_mm_sub_pd(s5h, s6h));
    *((a82 + 448)) = s8h;
    s9h = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t9j), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t0k));
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t9j), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t0k));
    s1i = v_lo2(s9h, s0i);
    s2i = v_hi2(s9h, s0i);
    s3i = _mm_add_pd(s1i, s2i);
    *((a82 + 80)) = s3i;
    s4i = v_neg23(_mm_sub_pd(s1i, s2i));
    *((a82 + 432)) = s4i;
    s5i = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t3i), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t4i));
    s6i = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3i), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t4i));
    s7i = v_lo2(s5i, s6i);
    s8i = v_hi2(s5i, s6i);
    s9i = _mm_add_pd(s7i, s8i);
    *((a82 + 96)) = s9i;
    s0j = v_neg23(_mm_sub_pd(s7i, s8i));
    *((a82 + 416)) = s0j;
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t7g), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t8g));
    s2j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t7g), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t8g));
    s3j = v_lo2(s1j, s2j);
    s4j = v_hi2(s1j, s2j);
    s5j = _mm_add_pd(s3j, s4j);
    *((a82 + 112)) = s5j;
    s6j = v_neg23(_mm_sub_pd(s3j, s4j));
    *((a82 + 400)) = s6j;
    s7j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t6e), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8e));
    s8j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t6e), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8e));
    s9j = v_lo2(s7j, s8j);
    s0k = v_hi2(s7j, s8j);
    s1k = _mm_add_pd(s9j, s0k);
    *((a82 + 128)) = s1k;
    s2k = v_neg23(_mm_sub_pd(s9j, s0k));
    *((a82 + 384)) = s2k;
    s3k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t5g), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t6g));
    s4k = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t5g), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t6g));
    s5k = v_lo2(s3k, s4k);
    s6k = v_hi2(s3k, s4k);
    s7k = _mm_add_pd(s5k, s6k);
    *((a82 + 144)) = s7k;
    s8k = v_neg23(_mm_sub_pd(s5k, s6k));
    *((a82 + 368)) = s8k;
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t1i), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t2i));
    s0l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t1i), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t2i));
    s1l = v_lo2(s9k, s0l);
    s2l = v_hi2(s9k, s0l);
    s3l = _mm_add_pd(s1l, s2l);
    *((a82 + 160)) = s3l;
    s4l = v_neg23(_mm_sub_pd(s1l, s2l));
    *((a82 + 352)) = s4l;
    s5l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t7j), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t8j));
    s6l = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t7j), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t8j));
    s7l = v_lo2(s5l, s6l);
    s8l = v_hi2(s5l, s6l);
    s9l = _mm_add_pd(s7l, s8l);
    *((a82 + 176)) = s9l;
    s0m = v_neg23(_mm_sub_pd(s7l, s8l));
    *((a82 + 336)) = s0m;
    s1m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t1f), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t2f));
    s2m = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t1f), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t2f));
    s3m = v_lo2(s1m, s2m);
    s4m = v_hi2(s1m, s2m);
    s5m = _mm_add_pd(s3m, s4m);
    *((a82 + 192)) = s5m;
    s6m = v_neg23(_mm_sub_pd(s3m, s4m));
    *((a82 + 320)) = s6m;
    s7m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t5j), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t6j));
    s8m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t5j), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t6j));
    s9m = v_lo2(s7m, s8m);
    s0n = v_hi2(s7m, s8m);
    s1n = _mm_add_pd(s9m, s0n);
    *((a82 + 208)) = s1n;
    s2n = v_neg23(_mm_sub_pd(s9m, s0n));
    *((a82 + 304)) = s2n;
    s3n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t9h), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t0i));
    s4n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t9h), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t0i));
    s5n = v_lo2(s3n, s4n);
    s6n = v_hi2(s3n, s4n);
    s7n = _mm_add_pd(s5n, s6n);
    *((a82 + 224)) = s7n;
    s8n = v_neg23(_mm_sub_pd(s5n, s6n));
    *((a82 + 288)) = s8n;
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t3g), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t4g));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t3g), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t4g));
    s1o = v_lo2(s9n, s0o);
    s2o = v_hi2(s9n, s0o);
    s3o = _mm_add_pd(s1o, s2o);
    *((a82 + 240)) = s3o;
    s4o = v_neg23(_mm_sub_pd(s1o, s2o));
    *((a82 + 272)) = s4o;
    {long i2; for(i2 = 0; i2 <= 14; i2++) {
        a92 = (32 * i2);
        b = (((__m128d  *) T) + a92);
        s5o = *((b + 32));
        s6o = *((b + 48));
        s7o = *((b + 33));
        s8o = *((b + 49));
        s9o = *((b + 34));
        s0p = *((b + 50));
        s1p = *((b + 35));
        s2p = *((b + 51));
        s3p = *((b + 36));
        s4p = *((b + 52));
        s5p = *((b + 37));
        s6p = *((b + 53));
        s7p = *((b + 38));
        s8p = *((b + 54));
        s9p = *((b + 39));
        s0q = *((b + 55));
        s1q = *((b + 40));
        s2q = *((b + 56));
        s3q = *((b + 41));
        s4q = *((b + 57));
        s5q = *((b + 42));
        s6q = *((b + 58));
        s7q = *((b + 43));
        s8q = *((b + 59));
        s9q = *((b + 44));
        s0r = *((b + 60));
        s1r = *((b + 45));
        s2r = *((b + 61));
        s3r = *((b + 46));
        s4r = *((b + 62));
        s5r = *((b + 47));
        s6r = *((b + 63));
        a03 = (D45 + a92);
        a13 = *(a03);
        a23 = *((a03 + 1));
        s7r = _mm_sub_pd(_mm_mul_pd(a13, s5o), _mm_mul_pd(a23, s6o));
        s8r = _mm_add_pd(_mm_mul_pd(a23, s5o), _mm_mul_pd(a13, s6o));
        a33 = *((a03 + 2));
        a43 = *((a03 + 3));
        s9r = _mm_sub_pd(_mm_mul_pd(a33, s7o), _mm_mul_pd(a43, s8o));
        s0s = _mm_add_pd(_mm_mul_pd(a43, s7o), _mm_mul_pd(a33, s8o));
        a53 = *((a03 + 4));
        a63 = *((a03 + 5));
        s1s = _mm_sub_pd(_mm_mul_pd(a53, s9o), _mm_mul_pd(a63, s0p));
        s2s = _mm_add_pd(_mm_mul_pd(a63, s9o), _mm_mul_pd(a53, s0p));
        a73 = *((a03 + 6));
        a83 = *((a03 + 7));
        s3s = _mm_sub_pd(_mm_mul_pd(a73, s1p), _mm_mul_pd(a83, s2p));
        s4s = _mm_add_pd(_mm_mul_pd(a83, s1p), _mm_mul_pd(a73, s2p));
        a93 = *((a03 + 8));
        a04 = *((a03 + 9));
        s5s = _mm_sub_pd(_mm_mul_pd(a93, s3p), _mm_mul_pd(a04, s4p));
        s6s = _mm_add_pd(_mm_mul_pd(a04, s3p), _mm_mul_pd(a93, s4p));
        a14 = *((a03 + 10));
        a24 = *((a03 + 11));
        s7s = _mm_sub_pd(_mm_mul_pd(a14, s5p), _mm_mul_pd(a24, s6p));
        s8s = _mm_add_pd(_mm_mul_pd(a24, s5p), _mm_mul_pd(a14, s6p));
        a34 = *((a03 + 12));
        a44 = *((a03 + 13));
        s9s = _mm_sub_pd(_mm_mul_pd(a34, s7p), _mm_mul_pd(a44, s8p));
        s0t = _mm_add_pd(_mm_mul_pd(a44, s7p), _mm_mul_pd(a34, s8p));
        a54 = *((a03 + 14));
        a64 = *((a03 + 15));
        s1t = _mm_sub_pd(_mm_mul_pd(a54, s9p), _mm_mul_pd(a64, s0q));
        s2t = _mm_add_pd(_mm_mul_pd(a64, s9p), _mm_mul_pd(a54, s0q));
        a74 = *((a03 + 16));
        a84 = *((a03 + 17));
        s3t = _mm_sub_pd(_mm_mul_pd(a74, s1q), _mm_mul_pd(a84, s2q));
        s4t = _mm_add_pd(_mm_mul_pd(a84, s1q), _mm_mul_pd(a74, s2q));
        a94 = *((a03 + 18));
        a05 = *((a03 + 19));
        s5t = _mm_sub_pd(_mm_mul_pd(a94, s3q), _mm_mul_pd(a05, s4q));
        s6t = _mm_add_pd(_mm_mul_pd(a05, s3q), _mm_mul_pd(a94, s4q));
        a15 = *((a03 + 20));
        a25 = *((a03 + 21));
        s7t = _mm_sub_pd(_mm_mul_pd(a15, s5q), _mm_mul_pd(a25, s6q));
        s8t = _mm_add_pd(_mm_mul_pd(a25, s5q), _mm_mul_pd(a15, s6q));
        a35 = *((a03 + 22));
        a45 = *((a03 + 23));
        s9t = _mm_sub_pd(_mm_mul_pd(a35, s7q), _mm_mul_pd(a45, s8q));
        s0u = _mm_add_pd(_mm_mul_pd(a45, s7q), _mm_mul_pd(a35, s8q));
        a55 = *((a03 + 24));
        a65 = *((a03 + 25));
        s1u = _mm_sub_pd(_mm_mul_pd(a55, s9q), _mm_mul_pd(a65, s0r));
        s2u = _mm_add_pd(_mm_mul_pd(a65, s9q), _mm_mul_pd(a55, s0r));
        a75 = *((a03 + 26));
        a85 = *((a03 + 27));
        s3u = _mm_sub_pd(_mm_mul_pd(a75, s1r), _mm_mul_pd(a85, s2r));
        s4u = _mm_add_pd(_mm_mul_pd(a85, s1r), _mm_mul_pd(a75, s2r));
        a95 = *((a03 + 28));
        a06 = *((a03 + 29));
        s5u = _mm_sub_pd(_mm_mul_pd(a95, s3r), _mm_mul_pd(a06, s4r));
        s6u = _mm_add_pd(_mm_mul_pd(a06, s3r), _mm_mul_pd(a95, s4r));
        a16 = *((a03 + 30));
        a26 = *((a03 + 31));
        s7u = _mm_sub_pd(_mm_mul_pd(a16, s5r), _mm_mul_pd(a26, s6r));
        s8u = _mm_add_pd(_mm_mul_pd(a26, s5r), _mm_mul_pd(a16, s6r));
        t2k = _mm_add_pd(s7r, s3t);
        t3k = _mm_add_pd(s8r, s4t);
        t4k = _mm_sub_pd(s7r, s3t);
        t5k = _mm_sub_pd(s8r, s4t);
        t6k = _mm_add_pd(s9r, s5t);
        t7k = _mm_add_pd(s0s, s6t);
        t8k = _mm_sub_pd(s9r, s5t);
        t9k = _mm_sub_pd(s0s, s6t);
        s9u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9k));
        s0v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9k));
        t0l = _mm_add_pd(s1s, s7t);
        t1l = _mm_add_pd(s2s, s8t);
        a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1s, s7t));
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2s, s8t));
        s1v = _mm_sub_pd(a36, a46);
        s2v = _mm_add_pd(a36, a46);
        t2l = _mm_add_pd(s3s, s9t);
        t3l = _mm_add_pd(s4s, s0u);
        t4l = _mm_sub_pd(s3s, s9t);
        t5l = _mm_sub_pd(s4s, s0u);
        s3v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4l), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5l));
        s4v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4l), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5l));
        t6l = _mm_add_pd(s5s, s1u);
        t7l = _mm_add_pd(s6s, s2u);
        t8l = _mm_sub_pd(s5s, s1u);
        t9l = _mm_sub_pd(s6s, s2u);
        t0m = _mm_add_pd(s7s, s3u);
        t1m = _mm_add_pd(s8s, s4u);
        t2m = _mm_sub_pd(s7s, s3u);
        t3m = _mm_sub_pd(s8s, s4u);
        s5v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3m));
        s6v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2m), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3m));
        t4m = _mm_add_pd(s9s, s5u);
        t5m = _mm_add_pd(s0t, s6u);
        a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9s, s5u));
        a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0t, s6u));
        s7v = _mm_sub_pd(a56, a66);
        s8v = _mm_add_pd(a56, a66);
        t6m = _mm_add_pd(s1t, s7u);
        t7m = _mm_add_pd(s2t, s8u);
        t8m = _mm_sub_pd(s1t, s7u);
        t9m = _mm_sub_pd(s2t, s8u);
        s9v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8m), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9m));
        s0w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9m));
        t0n = _mm_add_pd(t2k, t6l);
        t1n = _mm_add_pd(t3k, t7l);
        t2n = _mm_sub_pd(t2k, t6l);
        t3n = _mm_sub_pd(t3k, t7l);
        t4n = _mm_add_pd(t0l, t4m);
        t5n = _mm_add_pd(t1l, t5m);
        t6n = _mm_sub_pd(t0l, t4m);
        t7n = _mm_sub_pd(t1l, t5m);
        t8n = _mm_add_pd(t0n, t4n);
        t9n = _mm_add_pd(t1n, t5n);
        t0o = _mm_sub_pd(t0n, t4n);
        t1o = _mm_sub_pd(t1n, t5n);
        t2o = _mm_add_pd(t2n, t7n);
        t3o = _mm_sub_pd(t3n, t6n);
        t4o = _mm_sub_pd(t2n, t7n);
        t5o = _mm_add_pd(t3n, t6n);
        t6o = _mm_add_pd(t6k, t0m);
        t7o = _mm_add_pd(t7k, t1m);
        t8o = _mm_sub_pd(t6k, t0m);
        t9o = _mm_sub_pd(t7k, t1m);
        t0p = _mm_add_pd(t2l, t6m);
        t1p = _mm_add_pd(t3l, t7m);
        t2p = _mm_sub_pd(t2l, t6m);
        t3p = _mm_sub_pd(t3l, t7m);
        t4p = _mm_add_pd(t6o, t0p);
        t5p = _mm_add_pd(t7o, t1p);
        t6p = _mm_sub_pd(t6o, t0p);
        t7p = _mm_sub_pd(t7o, t1p);
        a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8o, t3p));
        a86 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9o, t2p));
        s1w = _mm_sub_pd(a76, a86);
        s2w = _mm_add_pd(a76, a86);
        a96 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t8o, t3p));
        a07 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t9o, t2p));
        s3w = _mm_sub_pd(a96, a07);
        s4w = _mm_add_pd(a96, a07);
        t8p = _mm_add_pd(t8n, t4p);
        t9p = _mm_add_pd(t9n, t5p);
        t0q = _mm_sub_pd(t8n, t4p);
        t1q = _mm_sub_pd(t9n, t5p);
        t2q = _mm_add_pd(t2o, s1w);
        t3q = _mm_sub_pd(t3o, s2w);
        t4q = _mm_sub_pd(t2o, s1w);
        t5q = _mm_add_pd(t3o, s2w);
        t6q = _mm_add_pd(t0o, t7p);
        t7q = _mm_sub_pd(t1o, t6p);
        t8q = _mm_sub_pd(t0o, t7p);
        t9q = _mm_add_pd(t1o, t6p);
        t0r = _mm_add_pd(t4o, s3w);
        t1r = _mm_add_pd(t5o, s4w);
        t2r = _mm_sub_pd(t4o, s3w);
        t3r = _mm_sub_pd(t5o, s4w);
        t4r = _mm_add_pd(t4k, t9l);
        t5r = _mm_sub_pd(t5k, t8l);
        t6r = _mm_sub_pd(t4k, t9l);
        t7r = _mm_add_pd(t5k, t8l);
        t8r = _mm_add_pd(s1v, s7v);
        t9r = _mm_sub_pd(s8v, s2v);
        t0s = _mm_sub_pd(s1v, s7v);
        t1s = _mm_add_pd(s2v, s8v);
        t2s = _mm_add_pd(t4r, t8r);
        t3s = _mm_add_pd(t5r, t9r);
        t4s = _mm_sub_pd(t4r, t8r);
        t5s = _mm_sub_pd(t5r, t9r);
        t6s = _mm_sub_pd(t6r, t1s);
        t7s = _mm_sub_pd(t7r, t0s);
        t8s = _mm_add_pd(t6r, t1s);
        t9s = _mm_add_pd(t7r, t0s);
        t0t = _mm_add_pd(s9u, s5v);
        t1t = _mm_add_pd(s0v, s6v);
        t2t = _mm_sub_pd(s9u, s5v);
        t3t = _mm_sub_pd(s0v, s6v);
        t4t = _mm_add_pd(s3v, s9v);
        t5t = _mm_add_pd(s4v, s0w);
        t6t = _mm_sub_pd(s3v, s9v);
        t7t = _mm_sub_pd(s4v, s0w);
        t8t = _mm_add_pd(t0t, t4t);
        t9t = _mm_add_pd(t1t, t5t);
        t0u = _mm_sub_pd(t0t, t4t);
        t1u = _mm_sub_pd(t1t, t5t);
        a17 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2t, t7t));
        a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3t, t6t));
        s5w = _mm_sub_pd(a17, a27);
        s6w = _mm_add_pd(a17, a27);
        a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t2t, t7t));
        a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3t, t6t));
        s7w = _mm_sub_pd(a37, a47);
        s8w = _mm_add_pd(a37, a47);
        t2u = _mm_add_pd(t2s, t8t);
        t3u = _mm_add_pd(t3s, t9t);
        t4u = _mm_sub_pd(t2s, t8t);
        t5u = _mm_sub_pd(t3s, t9t);
        t6u = _mm_add_pd(t6s, s5w);
        t7u = _mm_sub_pd(t7s, s6w);
        t8u = _mm_sub_pd(t6s, s5w);
        t9u = _mm_add_pd(t7s, s6w);
        t0v = _mm_add_pd(t4s, t1u);
        t1v = _mm_sub_pd(t5s, t0u);
        t2v = _mm_sub_pd(t4s, t1u);
        t3v = _mm_add_pd(t5s, t0u);
        t4v = _mm_add_pd(t8s, s7w);
        t5v = _mm_add_pd(t9s, s8w);
        t6v = _mm_sub_pd(t8s, s7w);
        t7v = _mm_sub_pd(t9s, s8w);
        a57 = (D43 + a92);
        a67 = *(a57);
        a77 = *((a57 + 1));
        s9w = _mm_sub_pd(_mm_mul_pd(a67, t8p), _mm_mul_pd(a77, t9p));
        s0x = _mm_add_pd(_mm_mul_pd(a77, t8p), _mm_mul_pd(a67, t9p));
        s1x = v_lo2(s9w, s0x);
        s2x = v_hi2(s9w, s0x);
        a87 = ((__m128d  *) dst);
        b2 = (a87 + i2);
        s3x = _mm_add_pd(s1x, s2x);
        *((b2 + 1)) = s3x;
        b3 = (a87 - i2);
        s4x = v_neg23(_mm_sub_pd(s1x, s2x));
        *((b3 + 511)) = s4x;
        a97 = *((a57 + 2));
        a08 = *((a57 + 3));
        s5x = _mm_sub_pd(_mm_mul_pd(a97, t2u), _mm_mul_pd(a08, t3u));
        s6x = _mm_add_pd(_mm_mul_pd(a08, t2u), _mm_mul_pd(a97, t3u));
        s7x = v_lo2(s5x, s6x);
        s8x = v_hi2(s5x, s6x);
        s9x = _mm_add_pd(s7x, s8x);
        *((b2 + 33)) = s9x;
        s0y = v_neg23(_mm_sub_pd(s7x, s8x));
        *((b3 + 479)) = s0y;
        a18 = *((a57 + 4));
        a28 = *((a57 + 5));
        s1y = _mm_sub_pd(_mm_mul_pd(a18, t2q), _mm_mul_pd(a28, t3q));
        s2y = _mm_add_pd(_mm_mul_pd(a28, t2q), _mm_mul_pd(a18, t3q));
        s3y = v_lo2(s1y, s2y);
        s4y = v_hi2(s1y, s2y);
        s5y = _mm_add_pd(s3y, s4y);
        *((b2 + 65)) = s5y;
        s6y = v_neg23(_mm_sub_pd(s3y, s4y));
        *((b3 + 447)) = s6y;
        a38 = *((a57 + 6));
        a48 = *((a57 + 7));
        s7y = _mm_sub_pd(_mm_mul_pd(a38, t6u), _mm_mul_pd(a48, t7u));
        s8y = _mm_add_pd(_mm_mul_pd(a48, t6u), _mm_mul_pd(a38, t7u));
        s9y = v_lo2(s7y, s8y);
        s0z = v_hi2(s7y, s8y);
        s1z = _mm_add_pd(s9y, s0z);
        *((b2 + 97)) = s1z;
        s2z = v_neg23(_mm_sub_pd(s9y, s0z));
        *((b3 + 415)) = s2z;
        a58 = *((a57 + 8));
        a68 = *((a57 + 9));
        s3z = _mm_sub_pd(_mm_mul_pd(a58, t6q), _mm_mul_pd(a68, t7q));
        s4z = _mm_add_pd(_mm_mul_pd(a68, t6q), _mm_mul_pd(a58, t7q));
        s5z = v_lo2(s3z, s4z);
        s6z = v_hi2(s3z, s4z);
        s7z = _mm_add_pd(s5z, s6z);
        *((b2 + 129)) = s7z;
        s8z = v_neg23(_mm_sub_pd(s5z, s6z));
        *((b3 + 383)) = s8z;
        a78 = *((a57 + 10));
        a88 = *((a57 + 11));
        s9z = _mm_sub_pd(_mm_mul_pd(a78, t0v), _mm_mul_pd(a88, t1v));
        s0A = _mm_add_pd(_mm_mul_pd(a88, t0v), _mm_mul_pd(a78, t1v));
        s1A = v_lo2(s9z, s0A);
        s2A = v_hi2(s9z, s0A);
        s3A = _mm_add_pd(s1A, s2A);
        *((b2 + 161)) = s3A;
        s4A = v_neg23(_mm_sub_pd(s1A, s2A));
        *((b3 + 351)) = s4A;
        a98 = *((a57 + 12));
        a09 = *((a57 + 13));
        s5A = _mm_sub_pd(_mm_mul_pd(a98, t0r), _mm_mul_pd(a09, t1r));
        s6A = _mm_add_pd(_mm_mul_pd(a09, t0r), _mm_mul_pd(a98, t1r));
        s7A = v_lo2(s5A, s6A);
        s8A = v_hi2(s5A, s6A);
        s9A = _mm_add_pd(s7A, s8A);
        *((b2 + 193)) = s9A;
        s0B = v_neg23(_mm_sub_pd(s7A, s8A));
        *((b3 + 319)) = s0B;
        a19 = *((a57 + 14));
        a29 = *((a57 + 15));
        s1B = _mm_sub_pd(_mm_mul_pd(a19, t4v), _mm_mul_pd(a29, t5v));
        s2B = _mm_add_pd(_mm_mul_pd(a29, t4v), _mm_mul_pd(a19, t5v));
        s3B = v_lo2(s1B, s2B);
        s4B = v_hi2(s1B, s2B);
        s5B = _mm_add_pd(s3B, s4B);
        *((b2 + 225)) = s5B;
        s6B = v_neg23(_mm_sub_pd(s3B, s4B));
        *((b3 + 287)) = s6B;
        a39 = *((a57 + 16));
        a49 = *((a57 + 17));
        s7B = _mm_sub_pd(_mm_mul_pd(a39, t0q), _mm_mul_pd(a49, t1q));
        s8B = _mm_add_pd(_mm_mul_pd(a49, t0q), _mm_mul_pd(a39, t1q));
        s9B = v_lo2(s7B, s8B);
        s0C = v_hi2(s7B, s8B);
        s1C = _mm_add_pd(s9B, s0C);
        *((b2 + 257)) = s1C;
        s2C = v_neg23(_mm_sub_pd(s9B, s0C));
        *((b3 + 255)) = s2C;
        a59 = *((a57 + 18));
        a69 = *((a57 + 19));
        s3C = _mm_sub_pd(_mm_mul_pd(a59, t4u), _mm_mul_pd(a69, t5u));
        s4C = _mm_add_pd(_mm_mul_pd(a69, t4u), _mm_mul_pd(a59, t5u));
        s5C = v_lo2(s3C, s4C);
        s6C = v_hi2(s3C, s4C);
        s7C = _mm_add_pd(s5C, s6C);
        *((b2 + 289)) = s7C;
        s8C = v_neg23(_mm_sub_pd(s5C, s6C));
        *((b3 + 223)) = s8C;
        a79 = *((a57 + 20));
        a89 = *((a57 + 21));
        s9C = _mm_sub_pd(_mm_mul_pd(a79, t4q), _mm_mul_pd(a89, t5q));
        s0D = _mm_add_pd(_mm_mul_pd(a89, t4q), _mm_mul_pd(a79, t5q));
        s1D = v_lo2(s9C, s0D);
        s2D = v_hi2(s9C, s0D);
        s3D = _mm_add_pd(s1D, s2D);
        *((b2 + 321)) = s3D;
        s4D = v_neg23(_mm_sub_pd(s1D, s2D));
        *((b3 + 191)) = s4D;
        a99 = *((a57 + 22));
        a0a = *((a57 + 23));
        s5D = _mm_sub_pd(_mm_mul_pd(a99, t8u), _mm_mul_pd(a0a, t9u));
        s6D = _mm_add_pd(_mm_mul_pd(a0a, t8u), _mm_mul_pd(a99, t9u));
        s7D = v_lo2(s5D, s6D);
        s8D = v_hi2(s5D, s6D);
        s9D = _mm_add_pd(s7D, s8D);
        *((b2 + 353)) = s9D;
        s0E = v_neg23(_mm_sub_pd(s7D, s8D));
        *((b3 + 159)) = s0E;
        a1a = *((a57 + 24));
        a2a = *((a57 + 25));
        s1E = _mm_sub_pd(_mm_mul_pd(a1a, t8q), _mm_mul_pd(a2a, t9q));
        s2E = _mm_add_pd(_mm_mul_pd(a2a, t8q), _mm_mul_pd(a1a, t9q));
        s3E = v_lo2(s1E, s2E);
        s4E = v_hi2(s1E, s2E);
        s5E = _mm_add_pd(s3E, s4E);
        *((b2 + 385)) = s5E;
        s6E = v_neg23(_mm_sub_pd(s3E, s4E));
        *((b3 + 127)) = s6E;
        a3a = *((a57 + 26));
        a4a = *((a57 + 27));
        s7E = _mm_sub_pd(_mm_mul_pd(a3a, t2v), _mm_mul_pd(a4a, t3v));
        s8E = _mm_add_pd(_mm_mul_pd(a4a, t2v), _mm_mul_pd(a3a, t3v));
        s9E = v_lo2(s7E, s8E);
        s0F = v_hi2(s7E, s8E);
        s1F = _mm_add_pd(s9E, s0F);
        *((b2 + 417)) = s1F;
        s2F = v_neg23(_mm_sub_pd(s9E, s0F));
        *((b3 + 95)) = s2F;
        a5a = *((a57 + 28));
        a6a = *((a57 + 29));
        s3F = _mm_sub_pd(_mm_mul_pd(a5a, t2r), _mm_mul_pd(a6a, t3r));
        s4F = _mm_add_pd(_mm_mul_pd(a6a, t2r), _mm_mul_pd(a5a, t3r));
        s5F = v_lo2(s3F, s4F);
        s6F = v_hi2(s3F, s4F);
        s7F = _mm_add_pd(s5F, s6F);
        *((b2 + 449)) = s7F;
        s8F = v_neg23(_mm_sub_pd(s5F, s6F));
        *((b3 + 63)) = s8F;
        a7a = *((a57 + 30));
        a8a = *((a57 + 31));
        s9F = _mm_sub_pd(_mm_mul_pd(a7a, t6v), _mm_mul_pd(a8a, t7v));
        s0G = _mm_add_pd(_mm_mul_pd(a8a, t6v), _mm_mul_pd(a7a, t7v));
        s1G = v_lo2(s9F, s0G);
        s2G = v_hi2(s9F, s0G);
        s3G = _mm_add_pd(s1G, s2G);
        *((b2 + 481)) = s3G;
        s4G = v_neg23(_mm_sub_pd(s1G, s2G));
        *((b3 + 31)) = s4G;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_2048_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[2048]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a09, a0a, a0b, a11, a12, a13, a14, a15, a16, a17, a18, a19, a1a, a1b
            , a2, a21, a22, a23, a24, a25, a26, a27, a29, a2a, a2b, a3, a31, a33, a34, a35, a36, a37, a38, a39, a3a, a3b
            , a4, a41, a42, a43, a44, a45, a46, a47, a48, a49, a4a, a4b, a5, a51, a52, a53, a54, a55, a56, a57, a59, a5a
            , a5b, a6, a61, a62, a64, a65, a66, a67, a68, a69, a6a, a7, a71, a72, a74, a75, a76, a77, a78, a79, a7a, a8
            , a82, a83, a84, a85, a86, a87, a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0P, s0Q, s0R, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r
            , s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E
            , s1F, s1G, s1H, s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1P, s1Q, s1R, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i
            , s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24
            , s25, s26, s27, s28, s29, s2A, s2B, s2C, s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2P, s2Q
            , s2R, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u
            , s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G
            , s3H, s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3P, s3Q, s3R, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k
            , s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46
            , s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4L, s4M, s4N, s4O, s4P, s4Q, s4R, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w
            , s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I
            , s5J, s5K, s5L, s5M, s5N, s5O, s5P, s5Q, s5R, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m
            , s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6O, s6P, s6Q, s6R, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7K
            , s7L, s7M, s7N, s7O, s7P, s7Q, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p
            , s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B
            , s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8O, s8P, s8Q, s8a, s8b, s8c, s8d, s8e, s8f, s8g
            , s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92
            , s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9O
            , s9P, s9Q, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t
            , s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F
            , t0G, t0H, t0I, t0J, t0K, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q
            , t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1A, t1B, t1C, t1D
            , t1E, t1F, t1G, t1H, t1I, t1J, t1K, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o
            , t1p, t1q, t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2A
            , t2B, t2C, t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l
            , t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36, t37
            , t38, t39, t3A, t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i
            , t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t42, t43, t44
            , t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4a, t4b, t4c, t4d, t4e, t4f
            , t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t4y, t4z, t5, t51
            , t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5F, t5G, t5H, t5I, t5J, t5K, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y
            , t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K
            , t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v
            , t6w, t6x, t6y, t6z, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7F, t7G, t7H
            , t7I, t7J, t7K, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s
            , t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E
            , t8F, t8G, t8H, t8I, t8J, t8K, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p
            , t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9A, t9B
            , t9C, t9D, t9E, t9F, t9G, t9H, t9I, t9J, t9K, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m
            , t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a28, *a32, *a73, *a81, *b2;
    double  *b3, *b4;
    const double  *b;
    int a, a58, a63;
    {long i; for(i = 0; i <= 15; i++) {
        a = (2 * i);
        s = _mm_loadu_pd(((const double  *) (a + src)));
        b = (src + a);
        s2 = _mm_loadu_pd(((const double  *) (b + 1024)));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = _mm_loadu_pd(((const double  *) (b + 512)));
        s4 = _mm_loadu_pd(((const double  *) (b + 1536)));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = _mm_loadu_pd(((const double  *) (b + 128)));
        s6 = _mm_loadu_pd(((const double  *) (b + 1152)));
        t5 = _mm_add_pd(s5, s6);
        t6 = _mm_sub_pd(s5, s6);
        s7 = _mm_loadu_pd(((const double  *) (b + 640)));
        s8 = _mm_loadu_pd(((const double  *) (b + 1664)));
        t7 = _mm_add_pd(s7, s8);
        t8 = _mm_sub_pd(s7, s8);
        s9 = _mm_loadu_pd(((const double  *) (b + 256)));
        s01 = _mm_loadu_pd(((const double  *) (b + 1280)));
        t9 = _mm_add_pd(s9, s01);
        s11 = _mm_loadu_pd(((const double  *) (b + 768)));
        s21 = _mm_loadu_pd(((const double  *) (b + 1792)));
        t01 = _mm_add_pd(s11, s21);
        s31 = _mm_loadu_pd(((const double  *) (b + 384)));
        s41 = _mm_loadu_pd(((const double  *) (b + 1408)));
        t11 = _mm_add_pd(s31, s41);
        t21 = _mm_sub_pd(s31, s41);
        s51 = _mm_loadu_pd(((const double  *) (b + 896)));
        s61 = _mm_loadu_pd(((const double  *) (b + 1920)));
        t31 = _mm_add_pd(s51, s61);
        t41 = _mm_sub_pd(s51, s61);
        t51 = _mm_add_pd(t, t3);
        t61 = _mm_sub_pd(t, t3);
        t71 = _mm_add_pd(t9, t01);
        t81 = _mm_sub_pd(t9, t01);
        t91 = _mm_add_pd(t5, t7);
        t02 = _mm_add_pd(t11, t31);
        t12 = _mm_add_pd(t51, t71);
        t22 = _mm_sub_pd(t51, t71);
        t32 = _mm_add_pd(t91, t02);
        t42 = _mm_sub_pd(t91, t02);
        a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
        a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
        s71 = _mm_add_pd(a2, a3);
        s81 = _mm_sub_pd(a3, a2);
        t52 = _mm_add_pd(t61, s71);
        t62 = _mm_sub_pd(s81, t81);
        t72 = _mm_sub_pd(t61, s71);
        t82 = _mm_add_pd(t81, s81);
        s91 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
        s02 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
        a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
        a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
        s12 = _mm_add_pd(a4, a5);
        s22 = _mm_sub_pd(a5, a4);
        s32 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
        s42 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
        t92 = _mm_add_pd(t2, s12);
        t03 = _mm_sub_pd(s22, t4);
        t13 = _mm_sub_pd(t2, s12);
        t23 = _mm_add_pd(t4, s22);
        t33 = _mm_add_pd(s91, s32);
        t43 = _mm_add_pd(s02, s42);
        t53 = _mm_sub_pd(s91, s32);
        t63 = _mm_sub_pd(s02, s42);
        t73 = _mm_add_pd(t92, t33);
        t83 = _mm_add_pd(t03, t43);
        t93 = _mm_sub_pd(t92, t33);
        t04 = _mm_sub_pd(t03, t43);
        t14 = _mm_add_pd(t13, t63);
        t24 = _mm_add_pd(t23, t53);
        t34 = _mm_sub_pd(t13, t63);
        t44 = _mm_sub_pd(t53, t23);
        s52 = _mm_loadu_pd(((const double  *) (b + 32)));
        s62 = _mm_loadu_pd(((const double  *) (b + 1056)));
        t54 = _mm_add_pd(s52, s62);
        t64 = _mm_sub_pd(s52, s62);
        s72 = _mm_loadu_pd(((const double  *) (b + 544)));
        s82 = _mm_loadu_pd(((const double  *) (b + 1568)));
        t74 = _mm_add_pd(s72, s82);
        t84 = _mm_sub_pd(s72, s82);
        s92 = _mm_loadu_pd(((const double  *) (b + 160)));
        s03 = _mm_loadu_pd(((const double  *) (b + 1184)));
        t94 = _mm_add_pd(s92, s03);
        t05 = _mm_sub_pd(s92, s03);
        s13 = _mm_loadu_pd(((const double  *) (b + 672)));
        s23 = _mm_loadu_pd(((const double  *) (b + 1696)));
        t15 = _mm_add_pd(s13, s23);
        t25 = _mm_sub_pd(s13, s23);
        s33 = _mm_loadu_pd(((const double  *) (b + 288)));
        s43 = _mm_loadu_pd(((const double  *) (b + 1312)));
        t35 = _mm_add_pd(s33, s43);
        s53 = _mm_loadu_pd(((const double  *) (b + 800)));
        s63 = _mm_loadu_pd(((const double  *) (b + 1824)));
        t45 = _mm_add_pd(s53, s63);
        s73 = _mm_loadu_pd(((const double  *) (b + 416)));
        s83 = _mm_loadu_pd(((const double  *) (b + 1440)));
        t55 = _mm_add_pd(s73, s83);
        t65 = _mm_sub_pd(s73, s83);
        s93 = _mm_loadu_pd(((const double  *) (b + 928)));
        s04 = _mm_loadu_pd(((const double  *) (b + 1952)));
        t75 = _mm_add_pd(s93, s04);
        t85 = _mm_sub_pd(s93, s04);
        t95 = _mm_add_pd(t54, t74);
        t06 = _mm_sub_pd(t54, t74);
        t16 = _mm_add_pd(t35, t45);
        t26 = _mm_sub_pd(t35, t45);
        t36 = _mm_add_pd(t94, t15);
        t46 = _mm_add_pd(t55, t75);
        t56 = _mm_add_pd(t95, t16);
        t66 = _mm_sub_pd(t95, t16);
        t76 = _mm_add_pd(t36, t46);
        t86 = _mm_sub_pd(t36, t46);
        a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
        a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t55, t75));
        s14 = _mm_add_pd(a6, a7);
        s24 = _mm_sub_pd(a7, a6);
        t96 = _mm_add_pd(t06, s14);
        t07 = _mm_sub_pd(s24, t26);
        t17 = _mm_sub_pd(t06, s14);
        t27 = _mm_add_pd(t26, s24);
        s34 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
        s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
        s54 = _mm_add_pd(a8, a9);
        s64 = _mm_sub_pd(a9, a8);
        s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t85));
        s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
        t37 = _mm_add_pd(t64, s54);
        t47 = _mm_sub_pd(s64, t84);
        t57 = _mm_sub_pd(t64, s54);
        t67 = _mm_add_pd(t84, s64);
        t77 = _mm_add_pd(s34, s74);
        t87 = _mm_add_pd(s44, s84);
        t97 = _mm_sub_pd(s34, s74);
        t08 = _mm_sub_pd(s44, s84);
        t18 = _mm_add_pd(t37, t77);
        t28 = _mm_add_pd(t47, t87);
        t38 = _mm_sub_pd(t37, t77);
        t48 = _mm_sub_pd(t47, t87);
        t58 = _mm_add_pd(t57, t08);
        t68 = _mm_add_pd(t67, t97);
        t78 = _mm_sub_pd(t57, t08);
        t88 = _mm_sub_pd(t97, t67);
        s94 = _mm_loadu_pd(((const double  *) (b + 64)));
        s05 = _mm_loadu_pd(((const double  *) (b + 1088)));
        t98 = _mm_add_pd(s94, s05);
        t09 = _mm_sub_pd(s94, s05);
        s15 = _mm_loadu_pd(((const double  *) (b + 576)));
        s25 = _mm_loadu_pd(((const double  *) (b + 1600)));
        t19 = _mm_add_pd(s15, s25);
        t29 = _mm_sub_pd(s15, s25);
        s35 = _mm_loadu_pd(((const double  *) (b + 192)));
        s45 = _mm_loadu_pd(((const double  *) (b + 1216)));
        t39 = _mm_add_pd(s35, s45);
        t49 = _mm_sub_pd(s35, s45);
        s55 = _mm_loadu_pd(((const double  *) (b + 704)));
        s65 = _mm_loadu_pd(((const double  *) (b + 1728)));
        t59 = _mm_add_pd(s55, s65);
        t69 = _mm_sub_pd(s55, s65);
        s75 = _mm_loadu_pd(((const double  *) (b + 320)));
        s85 = _mm_loadu_pd(((const double  *) (b + 1344)));
        t79 = _mm_add_pd(s75, s85);
        s95 = _mm_loadu_pd(((const double  *) (b + 832)));
        s06 = _mm_loadu_pd(((const double  *) (b + 1856)));
        t89 = _mm_add_pd(s95, s06);
        s16 = _mm_loadu_pd(((const double  *) (b + 448)));
        s26 = _mm_loadu_pd(((const double  *) (b + 1472)));
        t99 = _mm_add_pd(s16, s26);
        t0a = _mm_sub_pd(s16, s26);
        s36 = _mm_loadu_pd(((const double  *) (b + 960)));
        s46 = _mm_loadu_pd(((const double  *) (b + 1984)));
        t1a = _mm_add_pd(s36, s46);
        t2a = _mm_sub_pd(s36, s46);
        t3a = _mm_add_pd(t98, t19);
        t4a = _mm_sub_pd(t98, t19);
        t5a = _mm_add_pd(t79, t89);
        t6a = _mm_sub_pd(t79, t89);
        t7a = _mm_add_pd(t39, t59);
        t8a = _mm_add_pd(t99, t1a);
        t9a = _mm_add_pd(t3a, t5a);
        t0b = _mm_add_pd(t7a, t8a);
        a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t39, t59));
        a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t99, t1a));
        s56 = _mm_add_pd(a01, a11);
        s66 = _mm_sub_pd(a11, a01);
        t1b = _mm_add_pd(t4a, s56);
        t2b = _mm_sub_pd(s66, t6a);
        t3b = _mm_sub_pd(t4a, s56);
        t4b = _mm_add_pd(t6a, s66);
        s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t49), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t69));
        s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t49), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t69));
        a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s75, s85));
        a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s95, s06));
        s96 = _mm_add_pd(a21, a31);
        s07 = _mm_sub_pd(a31, a21);
        s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0a), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2a));
        s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2a));
        t5b = _mm_add_pd(t09, s96);
        t6b = _mm_sub_pd(s07, t29);
        t7b = _mm_sub_pd(t09, s96);
        t8b = _mm_add_pd(t29, s07);
        t9b = _mm_add_pd(s76, s17);
        t0c = _mm_add_pd(s86, s27);
        t1c = _mm_sub_pd(s76, s17);
        t2c = _mm_sub_pd(s86, s27);
        t3c = _mm_add_pd(t5b, t9b);
        t4c = _mm_add_pd(t6b, t0c);
        t5c = _mm_sub_pd(t5b, t9b);
        t6c = _mm_sub_pd(t6b, t0c);
        t7c = _mm_add_pd(t7b, t2c);
        t8c = _mm_add_pd(t8b, t1c);
        t9c = _mm_sub_pd(t7b, t2c);
        t0d = _mm_sub_pd(t1c, t8b);
        s37 = _mm_loadu_pd(((const double  *) (b + 96)));
        s47 = _mm_loadu_pd(((const double  *) (b + 1120)));
        t1d = _mm_add_pd(s37, s47);
        t2d = _mm_sub_pd(s37, s47);
        s57 = _mm_loadu_pd(((const double  *) (b + 608)));
        s67 = _mm_loadu_pd(((const double  *) (b + 1632)));
        t3d = _mm_add_pd(s57, s67);
        t4d = _mm_sub_pd(s57, s67);
        s77 = _mm_loadu_pd(((const double  *) (b + 224)));
        s87 = _mm_loadu_pd(((const double  *) (b + 1248)));
        t5d = _mm_add_pd(s77, s87);
        t6d = _mm_sub_pd(s77, s87);
        s97 = _mm_loadu_pd(((const double  *) (b + 736)));
        s08 = _mm_loadu_pd(((const double  *) (b + 1760)));
        t7d = _mm_add_pd(s97, s08);
        t8d = _mm_sub_pd(s97, s08);
        s18 = _mm_loadu_pd(((const double  *) (b + 352)));
        s28 = _mm_loadu_pd(((const double  *) (b + 1376)));
        t9d = _mm_add_pd(s18, s28);
        s38 = _mm_loadu_pd(((const double  *) (b + 864)));
        s48 = _mm_loadu_pd(((const double  *) (b + 1888)));
        t0e = _mm_add_pd(s38, s48);
        s58 = _mm_loadu_pd(((const double  *) (b + 480)));
        s68 = _mm_loadu_pd(((const double  *) (b + 1504)));
        t1e = _mm_add_pd(s58, s68);
        t2e = _mm_sub_pd(s58, s68);
        s78 = _mm_loadu_pd(((const double  *) (b + 992)));
        s88 = _mm_loadu_pd(((const double  *) (b + 2016)));
        t3e = _mm_add_pd(s78, s88);
        t4e = _mm_sub_pd(s78, s88);
        t5e = _mm_add_pd(t1d, t3d);
        t6e = _mm_sub_pd(t1d, t3d);
        t7e = _mm_add_pd(t9d, t0e);
        t8e = _mm_sub_pd(t9d, t0e);
        t9e = _mm_add_pd(t5d, t7d);
        t0f = _mm_add_pd(t1e, t3e);
        t1f = _mm_add_pd(t5e, t7e);
        t2f = _mm_sub_pd(t5e, t7e);
        t3f = _mm_add_pd(t9e, t0f);
        t4f = _mm_sub_pd(t9e, t0f);
        a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t7d));
        a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1e, t3e));
        s98 = _mm_add_pd(a41, a51);
        s09 = _mm_sub_pd(a51, a41);
        t5f = _mm_add_pd(t6e, s98);
        t6f = _mm_sub_pd(s09, t8e);
        t7f = _mm_sub_pd(t6e, s98);
        t8f = _mm_add_pd(t8e, s09);
        s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8d));
        s29 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8d));
        a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s18, s28));
        a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s38, s48));
        s39 = _mm_add_pd(a61, a71);
        s49 = _mm_sub_pd(a71, a61);
        s59 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e));
        s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4e));
        t9f = _mm_add_pd(t2d, s39);
        t0g = _mm_sub_pd(s49, t4d);
        t1g = _mm_sub_pd(t2d, s39);
        t2g = _mm_add_pd(t4d, s49);
        t3g = _mm_add_pd(s19, s59);
        t4g = _mm_add_pd(s29, s69);
        t5g = _mm_sub_pd(s19, s59);
        t6g = _mm_sub_pd(s29, s69);
        t7g = _mm_add_pd(t9f, t3g);
        t8g = _mm_add_pd(t0g, t4g);
        t9g = _mm_sub_pd(t9f, t3g);
        t0h = _mm_sub_pd(t0g, t4g);
        t1h = _mm_add_pd(t1g, t6g);
        t2h = _mm_add_pd(t2g, t5g);
        t3h = _mm_sub_pd(t1g, t6g);
        t4h = _mm_sub_pd(t5g, t2g);
        t5h = _mm_add_pd(t12, t32);
        t6h = _mm_sub_pd(t12, t32);
        t7h = _mm_add_pd(t9a, t0b);
        t8h = _mm_sub_pd(t9a, t0b);
        t9h = _mm_add_pd(t56, t76);
        t0i = _mm_add_pd(t1f, t3f);
        a81 = (((__m128d  *) T) + i);
        s79 = _mm_add_pd(t5h, t7h);
        *(a81) = s79;
        s89 = _mm_sub_pd(t5h, t7h);
        *((a81 + 512)) = s89;
        s99 = _mm_add_pd(t9h, t0i);
        *((a81 + 16)) = s99;
        s0a = _mm_sub_pd(t0i, t9h);
        *((a81 + 528)) = s0a;
        a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t76));
        a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1f, t3f));
        s1a = _mm_add_pd(a91, a02);
        s2a = _mm_sub_pd(a02, a91);
        s3a = _mm_add_pd(t6h, s1a);
        *((a81 + 256)) = s3a;
        s4a = _mm_sub_pd(s2a, t8h);
        *((a81 + 272)) = s4a;
        s5a = _mm_sub_pd(t6h, s1a);
        *((a81 + 768)) = s5a;
        s6a = _mm_add_pd(t8h, s2a);
        *((a81 + 784)) = s6a;
        s7a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t18), _mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t28));
        s8a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t18), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t28));
        s9a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3c), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4c));
        s0b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4c));
        s1b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7g), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t8g));
        s2b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t7g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8g));
        t1i = _mm_add_pd(t73, s9a);
        t2i = _mm_add_pd(t83, s0b);
        t3i = _mm_sub_pd(t73, s9a);
        t4i = _mm_sub_pd(t83, s0b);
        t5i = _mm_add_pd(s7a, s1b);
        t6i = _mm_add_pd(s8a, s2b);
        t7i = _mm_sub_pd(s7a, s1b);
        t8i = _mm_sub_pd(s8a, s2b);
        s3b = _mm_add_pd(t1i, t5i);
        *((a81 + 32)) = s3b;
        s4b = _mm_add_pd(t2i, t6i);
        *((a81 + 48)) = s4b;
        s5b = _mm_sub_pd(t1i, t5i);
        *((a81 + 992)) = s5b;
        s6b = _mm_sub_pd(t6i, t2i);
        *((a81 + 1008)) = s6b;
        s7b = _mm_add_pd(t3i, t8i);
        *((a81 + 544)) = s7b;
        s8b = _mm_sub_pd(t4i, t7i);
        *((a81 + 560)) = s8b;
        s9b = _mm_sub_pd(t3i, t8i);
        *((a81 + 480)) = s9b;
        s0c = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4i, t7i));
        *((a81 + 496)) = s0c;
        s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t96), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t07));
        s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t96), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t07));
        s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2b));
        s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2b));
        s5c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5f), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6f));
        s6c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5f), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6f));
        t9i = _mm_add_pd(t52, s3c);
        t0j = _mm_add_pd(t62, s4c);
        t1j = _mm_sub_pd(t52, s3c);
        t2j = _mm_sub_pd(t62, s4c);
        t3j = _mm_add_pd(s1c, s5c);
        t4j = _mm_add_pd(s2c, s6c);
        t5j = _mm_sub_pd(s1c, s5c);
        t6j = _mm_sub_pd(s2c, s6c);
        s7c = _mm_add_pd(t9i, t3j);
        *((a81 + 64)) = s7c;
        s8c = _mm_add_pd(t0j, t4j);
        *((a81 + 80)) = s8c;
        s9c = _mm_sub_pd(t9i, t3j);
        *((a81 + 960)) = s9c;
        s0d = _mm_sub_pd(t4j, t0j);
        *((a81 + 976)) = s0d;
        s1d = _mm_add_pd(t1j, t6j);
        *((a81 + 576)) = s1d;
        s2d = _mm_sub_pd(t2j, t5j);
        *((a81 + 592)) = s2d;
        s3d = _mm_sub_pd(t1j, t6j);
        *((a81 + 448)) = s3d;
        s4d = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2j, t5j));
        *((a81 + 464)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t78), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t88));
        s6d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t78), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t88));
        s7d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9c), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t0d));
        s8d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t9c), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0d));
        s9d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3h), _mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t4h));
        s0e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t3h), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4h));
        t7j = _mm_add_pd(t34, s7d);
        t8j = _mm_sub_pd(s8d, t44);
        t9j = _mm_sub_pd(t34, s7d);
        t0k = _mm_add_pd(t44, s8d);
        t1k = _mm_add_pd(s5d, s9d);
        t2k = _mm_add_pd(s6d, s0e);
        t3k = _mm_sub_pd(s5d, s9d);
        t4k = _mm_sub_pd(s6d, s0e);
        s1e = _mm_add_pd(t7j, t1k);
        *((a81 + 96)) = s1e;
        s2e = _mm_add_pd(t8j, t2k);
        *((a81 + 112)) = s2e;
        s3e = _mm_sub_pd(t7j, t1k);
        *((a81 + 928)) = s3e;
        s4e = _mm_sub_pd(t2k, t8j);
        *((a81 + 944)) = s4e;
        s5e = _mm_add_pd(t9j, t4k);
        *((a81 + 608)) = s5e;
        s6e = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0k, t3k));
        *((a81 + 624)) = s6e;
        s7e = _mm_sub_pd(t9j, t4k);
        *((a81 + 416)) = s7e;
        s8e = _mm_sub_pd(t0k, t3k);
        *((a81 + 432)) = s8e;
        s9e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t86));
        s0f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t86));
        a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3a, t5a));
        a22 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7a, t8a));
        s1f = _mm_add_pd(a12, a22);
        s2f = _mm_sub_pd(a22, a12);
        s3f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4f));
        s4f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
        t5k = _mm_add_pd(t22, s1f);
        t6k = _mm_sub_pd(s2f, t42);
        t7k = _mm_sub_pd(t22, s1f);
        t8k = _mm_add_pd(t42, s2f);
        t9k = _mm_add_pd(s9e, s3f);
        t0l = _mm_add_pd(s0f, s4f);
        t1l = _mm_sub_pd(s9e, s3f);
        t2l = _mm_sub_pd(s0f, s4f);
        s5f = _mm_add_pd(t5k, t9k);
        *((a81 + 128)) = s5f;
        s6f = _mm_add_pd(t6k, t0l);
        *((a81 + 144)) = s6f;
        s7f = _mm_sub_pd(t5k, t9k);
        *((a81 + 896)) = s7f;
        s8f = _mm_sub_pd(t0l, t6k);
        *((a81 + 912)) = s8f;
        s9f = _mm_add_pd(t7k, t2l);
        *((a81 + 640)) = s9f;
        s0g = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8k, t1l));
        *((a81 + 656)) = s0g;
        s1g = _mm_sub_pd(t7k, t2l);
        *((a81 + 384)) = s1g;
        s2g = _mm_sub_pd(t8k, t1l);
        *((a81 + 400)) = s2g;
        s3g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t58), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t68));
        s4g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t58), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t68));
        s5g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7c), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t8c));
        s6g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t7c), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8c));
        s7g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1h), _mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t2h));
        s8g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t1h), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2h));
        t3l = _mm_add_pd(t14, s5g);
        t4l = _mm_sub_pd(s6g, t24);
        t5l = _mm_sub_pd(t14, s5g);
        t6l = _mm_add_pd(t24, s6g);
        t7l = _mm_add_pd(s3g, s7g);
        t8l = _mm_add_pd(s4g, s8g);
        t9l = _mm_sub_pd(s3g, s7g);
        t0m = _mm_sub_pd(s4g, s8g);
        s9g = _mm_add_pd(t3l, t7l);
        *((a81 + 160)) = s9g;
        s0h = _mm_add_pd(t4l, t8l);
        *((a81 + 176)) = s0h;
        s1h = _mm_sub_pd(t3l, t7l);
        *((a81 + 864)) = s1h;
        s2h = _mm_sub_pd(t8l, t4l);
        *((a81 + 880)) = s2h;
        s3h = _mm_add_pd(t5l, t0m);
        *((a81 + 672)) = s3h;
        s4h = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6l, t9l));
        *((a81 + 688)) = s4h;
        s5h = _mm_sub_pd(t5l, t0m);
        *((a81 + 352)) = s5h;
        s6h = _mm_sub_pd(t6l, t9l);
        *((a81 + 368)) = s6h;
        s7h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t17), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t27));
        s8h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t17), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t27));
        s9h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3b), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4b));
        s0i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4b));
        s1i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7f), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8f));
        s2i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7f), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8f));
        t1m = _mm_add_pd(t72, s9h);
        t2m = _mm_add_pd(t82, s0i);
        t3m = _mm_sub_pd(t72, s9h);
        t4m = _mm_sub_pd(t82, s0i);
        t5m = _mm_add_pd(s7h, s1i);
        t6m = _mm_add_pd(s8h, s2i);
        t7m = _mm_sub_pd(s7h, s1i);
        t8m = _mm_sub_pd(s8h, s2i);
        s3i = _mm_add_pd(t1m, t5m);
        *((a81 + 192)) = s3i;
        s4i = _mm_add_pd(t2m, t6m);
        *((a81 + 208)) = s4i;
        s5i = _mm_sub_pd(t1m, t5m);
        *((a81 + 832)) = s5i;
        s6i = _mm_sub_pd(t6m, t2m);
        *((a81 + 848)) = s6i;
        s7i = _mm_add_pd(t3m, t8m);
        *((a81 + 704)) = s7i;
        s8i = _mm_sub_pd(t4m, t7m);
        *((a81 + 720)) = s8i;
        s9i = _mm_sub_pd(t3m, t8m);
        *((a81 + 320)) = s9i;
        s0j = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4m, t7m));
        *((a81 + 336)) = s0j;
        s1j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t38), _mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t48));
        s2j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t38), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t48));
        s3j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5c), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t6c));
        s4j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t5c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6c));
        s5j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9g), _mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t0h));
        s6j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t9g), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0h));
        t9m = _mm_add_pd(t93, s3j);
        t0n = _mm_sub_pd(s4j, t04);
        t1n = _mm_sub_pd(t93, s3j);
        t2n = _mm_add_pd(t04, s4j);
        t3n = _mm_add_pd(s1j, s5j);
        t4n = _mm_add_pd(s2j, s6j);
        t5n = _mm_sub_pd(s1j, s5j);
        t6n = _mm_sub_pd(s2j, s6j);
        s7j = _mm_add_pd(t9m, t3n);
        *((a81 + 224)) = s7j;
        s8j = _mm_add_pd(t0n, t4n);
        *((a81 + 240)) = s8j;
        s9j = _mm_sub_pd(t9m, t3n);
        *((a81 + 800)) = s9j;
        s0k = _mm_sub_pd(t4n, t0n);
        *((a81 + 816)) = s0k;
        s1k = _mm_add_pd(t1n, t6n);
        *((a81 + 736)) = s1k;
        s2k = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2n, t5n));
        *((a81 + 752)) = s2k;
        s3k = _mm_sub_pd(t1n, t6n);
        *((a81 + 288)) = s3k;
        s4k = _mm_sub_pd(t2n, t5n);
        *((a81 + 304)) = s4k;
    }}
    a32 = ((__m128d  *) T);
    s5k = *(a32);
    s6k = *((a32 + 16));
    t7n = _mm_add_pd(s5k, s6k);
    t8n = _mm_sub_pd(s5k, s6k);
    s7k = *((a32 + 8));
    s8k = *((a32 + 24));
    t9n = _mm_add_pd(s7k, s8k);
    t0o = _mm_sub_pd(s7k, s8k);
    s9k = *((a32 + 4));
    s0l = *((a32 + 20));
    t1o = _mm_add_pd(s9k, s0l);
    s1l = *((a32 + 12));
    s2l = *((a32 + 28));
    t2o = _mm_add_pd(s1l, s2l);
    t3o = _mm_add_pd(t7n, t9n);
    t4o = _mm_sub_pd(t7n, t9n);
    t5o = _mm_add_pd(t1o, t2o);
    t6o = _mm_sub_pd(t1o, t2o);
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9k, s0l));
    a52 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1l, s2l));
    s3l = _mm_add_pd(a42, a52);
    s4l = _mm_sub_pd(a52, a42);
    t7o = _mm_add_pd(t8n, s3l);
    t8o = _mm_sub_pd(s4l, t0o);
    t9o = _mm_sub_pd(t8n, s3l);
    t0p = _mm_add_pd(t0o, s4l);
    s5l = *((a32 + 1));
    s6l = *((a32 + 17));
    t1p = _mm_add_pd(s5l, s6l);
    t2p = _mm_sub_pd(s5l, s6l);
    s7l = *((a32 + 9));
    s8l = *((a32 + 25));
    t3p = _mm_add_pd(s7l, s8l);
    t4p = _mm_sub_pd(s7l, s8l);
    s9l = *((a32 + 5));
    s0m = *((a32 + 21));
    t5p = _mm_add_pd(s9l, s0m);
    s1m = *((a32 + 13));
    s2m = *((a32 + 29));
    t6p = _mm_add_pd(s1m, s2m);
    t7p = _mm_add_pd(t1p, t3p);
    t8p = _mm_sub_pd(t1p, t3p);
    t9p = _mm_add_pd(t5p, t6p);
    t0q = _mm_sub_pd(t5p, t6p);
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9l, s0m));
    a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1m, s2m));
    s3m = _mm_add_pd(a62, a72);
    s4m = _mm_sub_pd(a72, a62);
    t1q = _mm_add_pd(t2p, s3m);
    t2q = _mm_sub_pd(s4m, t4p);
    t3q = _mm_sub_pd(t2p, s3m);
    t4q = _mm_add_pd(t4p, s4m);
    s5m = *((a32 + 2));
    s6m = *((a32 + 18));
    t5q = _mm_add_pd(s5m, s6m);
    t6q = _mm_sub_pd(s5m, s6m);
    s7m = *((a32 + 10));
    s8m = *((a32 + 26));
    t7q = _mm_add_pd(s7m, s8m);
    t8q = _mm_sub_pd(s7m, s8m);
    s9m = *((a32 + 6));
    s0n = *((a32 + 22));
    t9q = _mm_add_pd(s9m, s0n);
    s1n = *((a32 + 14));
    s2n = *((a32 + 30));
    t0r = _mm_add_pd(s1n, s2n);
    t1r = _mm_add_pd(t5q, t7q);
    t2r = _mm_add_pd(t9q, t0r);
    a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9m, s0n));
    a92 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1n, s2n));
    s3n = _mm_add_pd(a82, a92);
    s4n = _mm_sub_pd(a92, a82);
    t3r = _mm_add_pd(t6q, s3n);
    t4r = _mm_sub_pd(s4n, t8q);
    t5r = _mm_sub_pd(t6q, s3n);
    t6r = _mm_add_pd(t8q, s4n);
    s5n = *((a32 + 3));
    s6n = *((a32 + 19));
    t7r = _mm_add_pd(s5n, s6n);
    t8r = _mm_sub_pd(s5n, s6n);
    s7n = *((a32 + 11));
    s8n = *((a32 + 27));
    t9r = _mm_add_pd(s7n, s8n);
    t0s = _mm_sub_pd(s7n, s8n);
    s9n = *((a32 + 7));
    s0o = *((a32 + 23));
    t1s = _mm_add_pd(s9n, s0o);
    s1o = *((a32 + 15));
    s2o = *((a32 + 31));
    t2s = _mm_add_pd(s1o, s2o);
    t3s = _mm_add_pd(t7r, t9r);
    t4s = _mm_sub_pd(t7r, t9r);
    t5s = _mm_add_pd(t1s, t2s);
    t6s = _mm_sub_pd(t1s, t2s);
    a03 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9n, s0o));
    a13 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1o, s2o));
    s3o = _mm_add_pd(a03, a13);
    s4o = _mm_sub_pd(a13, a03);
    t7s = _mm_add_pd(t8r, s3o);
    t8s = _mm_sub_pd(s4o, t0s);
    t9s = _mm_sub_pd(t8r, s3o);
    t0t = _mm_add_pd(t0s, s4o);
    t1t = _mm_add_pd(t3o, t5o);
    t2t = _mm_sub_pd(t3o, t5o);
    t3t = _mm_add_pd(t1r, t2r);
    t4t = _mm_sub_pd(t1r, t2r);
    t5t = _mm_add_pd(t7p, t9p);
    t6t = _mm_add_pd(t3s, t5s);
    t7t = _mm_add_pd(t1t, t3t);
    t8t = _mm_sub_pd(t1t, t3t);
    t9t = _mm_add_pd(t5t, t6t);
    t0u = _mm_sub_pd(t5t, t6t);
    a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7p, t9p));
    a33 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3s, t5s));
    s5o = _mm_add_pd(a23, a33);
    s6o = _mm_sub_pd(a33, a23);
    t1u = _mm_add_pd(t2t, s5o);
    t2u = _mm_sub_pd(s6o, t4t);
    t3u = _mm_sub_pd(t2t, s5o);
    t4u = _mm_add_pd(t4t, s6o);
    s7o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1q), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2q));
    s8o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1q), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2q));
    s9o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3r), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4r));
    s0p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4r));
    s1p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t7s), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t8s));
    s2p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t7s), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t8s));
    t5u = _mm_add_pd(t7o, s9o);
    t6u = _mm_add_pd(t8o, s0p);
    t7u = _mm_sub_pd(t7o, s9o);
    t8u = _mm_sub_pd(t8o, s0p);
    t9u = _mm_add_pd(s7o, s1p);
    t0v = _mm_add_pd(s8o, s2p);
    t1v = _mm_sub_pd(s7o, s1p);
    t2v = _mm_sub_pd(s8o, s2p);
    t3v = _mm_add_pd(t5u, t9u);
    t4v = _mm_add_pd(t6u, t0v);
    t5v = _mm_sub_pd(t5u, t9u);
    t6v = _mm_sub_pd(t6u, t0v);
    t7v = _mm_add_pd(t7u, t2v);
    t8v = _mm_sub_pd(t8u, t1v);
    t9v = _mm_sub_pd(t7u, t2v);
    t0w = _mm_add_pd(t8u, t1v);
    s3p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8p), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0q));
    s4p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0q));
    a43 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5q, t7q));
    a53 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9q, t0r));
    s5p = _mm_add_pd(a43, a53);
    s6p = _mm_sub_pd(a53, a43);
    s7p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4s), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6s));
    s8p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6s));
    t1w = _mm_add_pd(t4o, s5p);
    t2w = _mm_sub_pd(s6p, t6o);
    t3w = _mm_sub_pd(t4o, s5p);
    t4w = _mm_add_pd(t6o, s6p);
    t5w = _mm_add_pd(s3p, s7p);
    t6w = _mm_add_pd(s4p, s8p);
    t7w = _mm_sub_pd(s3p, s7p);
    t8w = _mm_sub_pd(s4p, s8p);
    t9w = _mm_add_pd(t1w, t5w);
    t0x = _mm_add_pd(t2w, t6w);
    t1x = _mm_sub_pd(t1w, t5w);
    t2x = _mm_sub_pd(t2w, t6w);
    t3x = _mm_add_pd(t3w, t8w);
    t4x = _mm_add_pd(t4w, t7w);
    t5x = _mm_sub_pd(t3w, t8w);
    t6x = _mm_sub_pd(t7w, t4w);
    s9p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3q), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t4q));
    s0q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t3q), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4q));
    s1q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5r), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6r));
    s2q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6r));
    s3q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9s), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t0t));
    s4q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t9s), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0t));
    t7x = _mm_add_pd(t9o, s1q);
    t8x = _mm_add_pd(t0p, s2q);
    t9x = _mm_sub_pd(t9o, s1q);
    t0y = _mm_sub_pd(t0p, s2q);
    t1y = _mm_add_pd(s9p, s3q);
    t2y = _mm_add_pd(s0q, s4q);
    t3y = _mm_sub_pd(s9p, s3q);
    t4y = _mm_sub_pd(s0q, s4q);
    t5y = _mm_add_pd(t7x, t1y);
    t6y = _mm_add_pd(t8x, t2y);
    t7y = _mm_sub_pd(t7x, t1y);
    t8y = _mm_sub_pd(t8x, t2y);
    t9y = _mm_add_pd(t9x, t4y);
    t0z = _mm_sub_pd(t0y, t3y);
    t1z = _mm_sub_pd(t9x, t4y);
    t2z = _mm_add_pd(t0y, t3y);
    t3z = _mm_add_pd(t7t, t9t);
    s5q = _mm_add_pd(v_neg03(v_hi2(t3z, t3z)), v_lo2(t3z, t3z));
    _mm_storeu_pd(((double  *) dst), s5q);
    s6q = v_neg23(_mm_sub_pd(t7t, t9t));
    _mm_storeu_pd(((double  *) (dst + 1024)), s6q);
    s7q = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t3v), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t4v));
    s8q = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t3v), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t4v));
    s9q = v_lo2(s7q, s8q);
    s0r = v_hi2(s7q, s8q);
    s1r = _mm_add_pd(s9q, s0r);
    _mm_storeu_pd(((double  *) (dst + 64)), s1r);
    s2r = v_neg23(_mm_sub_pd(s9q, s0r));
    _mm_storeu_pd(((double  *) (dst + 1984)), s2r);
    s3r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t9w), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t0x));
    s4r = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t9w), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t0x));
    s5r = v_lo2(s3r, s4r);
    s6r = v_hi2(s3r, s4r);
    s7r = _mm_add_pd(s5r, s6r);
    _mm_storeu_pd(((double  *) (dst + 128)), s7r);
    s8r = v_neg23(_mm_sub_pd(s5r, s6r));
    _mm_storeu_pd(((double  *) (dst + 1920)), s8r);
    s9r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t5y), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t6y));
    s0s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t5y), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t6y));
    s1s = v_lo2(s9r, s0s);
    s2s = v_hi2(s9r, s0s);
    s3s = _mm_add_pd(s1s, s2s);
    _mm_storeu_pd(((double  *) (dst + 192)), s3s);
    s4s = v_neg23(_mm_sub_pd(s1s, s2s));
    _mm_storeu_pd(((double  *) (dst + 1856)), s4s);
    s5s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t1u), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t2u));
    s6s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t1u), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t2u));
    s7s = v_lo2(s5s, s6s);
    s8s = v_hi2(s5s, s6s);
    s9s = _mm_add_pd(s7s, s8s);
    _mm_storeu_pd(((double  *) (dst + 256)), s9s);
    s0t = v_neg23(_mm_sub_pd(s7s, s8s));
    _mm_storeu_pd(((double  *) (dst + 1792)), s0t);
    s1t = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t1z), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t2z));
    s2t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t1z), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t2z));
    s3t = v_lo2(s1t, s2t);
    s4t = v_hi2(s1t, s2t);
    s5t = _mm_add_pd(s3t, s4t);
    _mm_storeu_pd(((double  *) (dst + 320)), s5t);
    s6t = v_neg23(_mm_sub_pd(s3t, s4t));
    _mm_storeu_pd(((double  *) (dst + 1728)), s6t);
    s7t = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t5x), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6x));
    s8t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t5x), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6x));
    s9t = v_lo2(s7t, s8t);
    s0u = v_hi2(s7t, s8t);
    s1u = _mm_add_pd(s9t, s0u);
    _mm_storeu_pd(((double  *) (dst + 384)), s1u);
    s2u = v_neg23(_mm_sub_pd(s9t, s0u));
    _mm_storeu_pd(((double  *) (dst + 1664)), s2u);
    s3u = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t9v), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t0w));
    s4u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t9v), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t0w));
    s5u = v_lo2(s3u, s4u);
    s6u = v_hi2(s3u, s4u);
    s7u = _mm_add_pd(s5u, s6u);
    _mm_storeu_pd(((double  *) (dst + 448)), s7u);
    s8u = v_neg23(_mm_sub_pd(s5u, s6u));
    _mm_storeu_pd(((double  *) (dst + 1600)), s8u);
    s9u = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8t), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t0u));
    s0v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8t), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t0u));
    s1v = v_lo2(s9u, s0v);
    s2v = v_hi2(s9u, s0v);
    s3v = _mm_add_pd(s1v, s2v);
    _mm_storeu_pd(((double  *) (dst + 512)), s3v);
    s4v = v_neg23(_mm_sub_pd(s1v, s2v));
    _mm_storeu_pd(((double  *) (dst + 1536)), s4v);
    s5v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t7v), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t8v));
    s6v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t7v), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t8v));
    s7v = v_lo2(s5v, s6v);
    s8v = v_hi2(s5v, s6v);
    s9v = _mm_add_pd(s7v, s8v);
    _mm_storeu_pd(((double  *) (dst + 576)), s9v);
    s0w = v_neg23(_mm_sub_pd(s7v, s8v));
    _mm_storeu_pd(((double  *) (dst + 1472)), s0w);
    s1w = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t3x), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4x));
    s2w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t3x), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t4x));
    s3w = v_lo2(s1w, s2w);
    s4w = v_hi2(s1w, s2w);
    s5w = _mm_add_pd(s3w, s4w);
    _mm_storeu_pd(((double  *) (dst + 640)), s5w);
    s6w = v_neg23(_mm_sub_pd(s3w, s4w));
    _mm_storeu_pd(((double  *) (dst + 1408)), s6w);
    s7w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t9y), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t0z));
    s8w = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t9y), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t0z));
    s9w = v_lo2(s7w, s8w);
    s0x = v_hi2(s7w, s8w);
    s1x = _mm_add_pd(s9w, s0x);
    _mm_storeu_pd(((double  *) (dst + 704)), s1x);
    s2x = v_neg23(_mm_sub_pd(s9w, s0x));
    _mm_storeu_pd(((double  *) (dst + 1344)), s2x);
    s3x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t3u), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t4u));
    s4x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t3u), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t4u));
    s5x = v_lo2(s3x, s4x);
    s6x = v_hi2(s3x, s4x);
    s7x = _mm_add_pd(s5x, s6x);
    _mm_storeu_pd(((double  *) (dst + 768)), s7x);
    s8x = v_neg23(_mm_sub_pd(s5x, s6x));
    _mm_storeu_pd(((double  *) (dst + 1280)), s8x);
    s9x = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t7y), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t8y));
    s0y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t7y), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t8y));
    s1y = v_lo2(s9x, s0y);
    s2y = v_hi2(s9x, s0y);
    s3y = _mm_add_pd(s1y, s2y);
    _mm_storeu_pd(((double  *) (dst + 832)), s3y);
    s4y = v_neg23(_mm_sub_pd(s1y, s2y));
    _mm_storeu_pd(((double  *) (dst + 1216)), s4y);
    s5y = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t1x), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t2x));
    s6y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1x), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t2x));
    s7y = v_lo2(s5y, s6y);
    s8y = v_hi2(s5y, s6y);
    s9y = _mm_add_pd(s7y, s8y);
    _mm_storeu_pd(((double  *) (dst + 896)), s9y);
    s0z = v_neg23(_mm_sub_pd(s7y, s8y));
    _mm_storeu_pd(((double  *) (dst + 1152)), s0z);
    s1z = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t5v), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t6v));
    s2z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t5v), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t6v));
    s3z = v_lo2(s1z, s2z);
    s4z = v_hi2(s1z, s2z);
    s5z = _mm_add_pd(s3z, s4z);
    _mm_storeu_pd(((double  *) (dst + 960)), s5z);
    s6z = v_neg23(_mm_sub_pd(s3z, s4z));
    _mm_storeu_pd(((double  *) (dst + 1088)), s6z);
    {long i2; for(i2 = 0; i2 <= 30; i2++) {
        a63 = (32 * i2);
        b2 = (((__m128d  *) T) + a63);
        s7z = *((b2 + 32));
        s8z = *((b2 + 48));
        s9z = *((b2 + 33));
        s0A = *((b2 + 49));
        s1A = *((b2 + 34));
        s2A = *((b2 + 50));
        s3A = *((b2 + 35));
        s4A = *((b2 + 51));
        s5A = *((b2 + 36));
        s6A = *((b2 + 52));
        s7A = *((b2 + 37));
        s8A = *((b2 + 53));
        s9A = *((b2 + 38));
        s0B = *((b2 + 54));
        s1B = *((b2 + 39));
        s2B = *((b2 + 55));
        s3B = *((b2 + 40));
        s4B = *((b2 + 56));
        s5B = *((b2 + 41));
        s6B = *((b2 + 57));
        s7B = *((b2 + 42));
        s8B = *((b2 + 58));
        s9B = *((b2 + 43));
        s0C = *((b2 + 59));
        s1C = *((b2 + 44));
        s2C = *((b2 + 60));
        s3C = *((b2 + 45));
        s4C = *((b2 + 61));
        s5C = *((b2 + 46));
        s6C = *((b2 + 62));
        s7C = *((b2 + 47));
        s8C = *((b2 + 63));
        a73 = (D47 + a63);
        a83 = *(a73);
        a93 = *((a73 + 1));
        s9C = _mm_sub_pd(_mm_mul_pd(a83, s7z), _mm_mul_pd(a93, s8z));
        s0D = _mm_add_pd(_mm_mul_pd(a93, s7z), _mm_mul_pd(a83, s8z));
        a04 = *((a73 + 2));
        a14 = *((a73 + 3));
        s1D = _mm_sub_pd(_mm_mul_pd(a04, s9z), _mm_mul_pd(a14, s0A));
        s2D = _mm_add_pd(_mm_mul_pd(a14, s9z), _mm_mul_pd(a04, s0A));
        a24 = *((a73 + 4));
        a34 = *((a73 + 5));
        s3D = _mm_sub_pd(_mm_mul_pd(a24, s1A), _mm_mul_pd(a34, s2A));
        s4D = _mm_add_pd(_mm_mul_pd(a34, s1A), _mm_mul_pd(a24, s2A));
        a44 = *((a73 + 6));
        a54 = *((a73 + 7));
        s5D = _mm_sub_pd(_mm_mul_pd(a44, s3A), _mm_mul_pd(a54, s4A));
        s6D = _mm_add_pd(_mm_mul_pd(a54, s3A), _mm_mul_pd(a44, s4A));
        a64 = *((a73 + 8));
        a74 = *((a73 + 9));
        s7D = _mm_sub_pd(_mm_mul_pd(a64, s5A), _mm_mul_pd(a74, s6A));
        s8D = _mm_add_pd(_mm_mul_pd(a74, s5A), _mm_mul_pd(a64, s6A));
        a84 = *((a73 + 10));
        a94 = *((a73 + 11));
        s9D = _mm_sub_pd(_mm_mul_pd(a84, s7A), _mm_mul_pd(a94, s8A));
        s0E = _mm_add_pd(_mm_mul_pd(a94, s7A), _mm_mul_pd(a84, s8A));
        a05 = *((a73 + 12));
        a15 = *((a73 + 13));
        s1E = _mm_sub_pd(_mm_mul_pd(a05, s9A), _mm_mul_pd(a15, s0B));
        s2E = _mm_add_pd(_mm_mul_pd(a15, s9A), _mm_mul_pd(a05, s0B));
        a25 = *((a73 + 14));
        a35 = *((a73 + 15));
        s3E = _mm_sub_pd(_mm_mul_pd(a25, s1B), _mm_mul_pd(a35, s2B));
        s4E = _mm_add_pd(_mm_mul_pd(a35, s1B), _mm_mul_pd(a25, s2B));
        a45 = *((a73 + 16));
        a55 = *((a73 + 17));
        s5E = _mm_sub_pd(_mm_mul_pd(a45, s3B), _mm_mul_pd(a55, s4B));
        s6E = _mm_add_pd(_mm_mul_pd(a55, s3B), _mm_mul_pd(a45, s4B));
        a65 = *((a73 + 18));
        a75 = *((a73 + 19));
        s7E = _mm_sub_pd(_mm_mul_pd(a65, s5B), _mm_mul_pd(a75, s6B));
        s8E = _mm_add_pd(_mm_mul_pd(a75, s5B), _mm_mul_pd(a65, s6B));
        a85 = *((a73 + 20));
        a95 = *((a73 + 21));
        s9E = _mm_sub_pd(_mm_mul_pd(a85, s7B), _mm_mul_pd(a95, s8B));
        s0F = _mm_add_pd(_mm_mul_pd(a95, s7B), _mm_mul_pd(a85, s8B));
        a06 = *((a73 + 22));
        a16 = *((a73 + 23));
        s1F = _mm_sub_pd(_mm_mul_pd(a06, s9B), _mm_mul_pd(a16, s0C));
        s2F = _mm_add_pd(_mm_mul_pd(a16, s9B), _mm_mul_pd(a06, s0C));
        a26 = *((a73 + 24));
        a36 = *((a73 + 25));
        s3F = _mm_sub_pd(_mm_mul_pd(a26, s1C), _mm_mul_pd(a36, s2C));
        s4F = _mm_add_pd(_mm_mul_pd(a36, s1C), _mm_mul_pd(a26, s2C));
        a46 = *((a73 + 26));
        a56 = *((a73 + 27));
        s5F = _mm_sub_pd(_mm_mul_pd(a46, s3C), _mm_mul_pd(a56, s4C));
        s6F = _mm_add_pd(_mm_mul_pd(a56, s3C), _mm_mul_pd(a46, s4C));
        a66 = *((a73 + 28));
        a76 = *((a73 + 29));
        s7F = _mm_sub_pd(_mm_mul_pd(a66, s5C), _mm_mul_pd(a76, s6C));
        s8F = _mm_add_pd(_mm_mul_pd(a76, s5C), _mm_mul_pd(a66, s6C));
        a86 = *((a73 + 30));
        a96 = *((a73 + 31));
        s9F = _mm_sub_pd(_mm_mul_pd(a86, s7C), _mm_mul_pd(a96, s8C));
        s0G = _mm_add_pd(_mm_mul_pd(a96, s7C), _mm_mul_pd(a86, s8C));
        t4z = _mm_add_pd(s9C, s5E);
        t5z = _mm_add_pd(s0D, s6E);
        t6z = _mm_sub_pd(s9C, s5E);
        t7z = _mm_sub_pd(s0D, s6E);
        t8z = _mm_add_pd(s1D, s7E);
        t9z = _mm_add_pd(s2D, s8E);
        t0A = _mm_sub_pd(s1D, s7E);
        t1A = _mm_sub_pd(s2D, s8E);
        s1G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0A), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1A));
        s2G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1A));
        t2A = _mm_add_pd(s3D, s9E);
        t3A = _mm_add_pd(s4D, s0F);
        a07 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3D, s9E));
        a17 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s4D, s0F));
        s3G = _mm_sub_pd(a07, a17);
        s4G = _mm_add_pd(a07, a17);
        t4A = _mm_add_pd(s5D, s1F);
        t5A = _mm_add_pd(s6D, s2F);
        t6A = _mm_sub_pd(s5D, s1F);
        t7A = _mm_sub_pd(s6D, s2F);
        s5G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6A), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7A));
        s6G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7A));
        t8A = _mm_add_pd(s7D, s3F);
        t9A = _mm_add_pd(s8D, s4F);
        t0B = _mm_sub_pd(s7D, s3F);
        t1B = _mm_sub_pd(s8D, s4F);
        t2B = _mm_add_pd(s9D, s5F);
        t3B = _mm_add_pd(s0E, s6F);
        t4B = _mm_sub_pd(s9D, s5F);
        t5B = _mm_sub_pd(s0E, s6F);
        s7G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4B), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5B));
        s8G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4B), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5B));
        t6B = _mm_add_pd(s1E, s7F);
        t7B = _mm_add_pd(s2E, s8F);
        a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1E, s7F));
        a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2E, s8F));
        s9G = _mm_sub_pd(a27, a37);
        s0H = _mm_add_pd(a27, a37);
        t8B = _mm_add_pd(s3E, s9F);
        t9B = _mm_add_pd(s4E, s0G);
        t0C = _mm_sub_pd(s3E, s9F);
        t1C = _mm_sub_pd(s4E, s0G);
        s1H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0C), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1C));
        s2H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0C), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1C));
        t2C = _mm_add_pd(t4z, t8A);
        t3C = _mm_add_pd(t5z, t9A);
        t4C = _mm_sub_pd(t4z, t8A);
        t5C = _mm_sub_pd(t5z, t9A);
        t6C = _mm_add_pd(t2A, t6B);
        t7C = _mm_add_pd(t3A, t7B);
        t8C = _mm_sub_pd(t2A, t6B);
        t9C = _mm_sub_pd(t3A, t7B);
        t0D = _mm_add_pd(t2C, t6C);
        t1D = _mm_add_pd(t3C, t7C);
        t2D = _mm_sub_pd(t2C, t6C);
        t3D = _mm_sub_pd(t3C, t7C);
        t4D = _mm_add_pd(t4C, t9C);
        t5D = _mm_sub_pd(t5C, t8C);
        t6D = _mm_sub_pd(t4C, t9C);
        t7D = _mm_add_pd(t5C, t8C);
        t8D = _mm_add_pd(t8z, t2B);
        t9D = _mm_add_pd(t9z, t3B);
        t0E = _mm_sub_pd(t8z, t2B);
        t1E = _mm_sub_pd(t9z, t3B);
        t2E = _mm_add_pd(t4A, t8B);
        t3E = _mm_add_pd(t5A, t9B);
        t4E = _mm_sub_pd(t4A, t8B);
        t5E = _mm_sub_pd(t5A, t9B);
        t6E = _mm_add_pd(t8D, t2E);
        t7E = _mm_add_pd(t9D, t3E);
        t8E = _mm_sub_pd(t8D, t2E);
        t9E = _mm_sub_pd(t9D, t3E);
        a47 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0E, t5E));
        a57 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1E, t4E));
        s3H = _mm_sub_pd(a47, a57);
        s4H = _mm_add_pd(a47, a57);
        a67 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0E, t5E));
        a77 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1E, t4E));
        s5H = _mm_sub_pd(a67, a77);
        s6H = _mm_add_pd(a67, a77);
        t0F = _mm_add_pd(t0D, t6E);
        t1F = _mm_add_pd(t1D, t7E);
        t2F = _mm_sub_pd(t0D, t6E);
        t3F = _mm_sub_pd(t1D, t7E);
        t4F = _mm_add_pd(t4D, s3H);
        t5F = _mm_sub_pd(t5D, s4H);
        t6F = _mm_sub_pd(t4D, s3H);
        t7F = _mm_add_pd(t5D, s4H);
        t8F = _mm_add_pd(t2D, t9E);
        t9F = _mm_sub_pd(t3D, t8E);
        t0G = _mm_sub_pd(t2D, t9E);
        t1G = _mm_add_pd(t3D, t8E);
        t2G = _mm_add_pd(t6D, s5H);
        t3G = _mm_add_pd(t7D, s6H);
        t4G = _mm_sub_pd(t6D, s5H);
        t5G = _mm_sub_pd(t7D, s6H);
        t6G = _mm_add_pd(t6z, t1B);
        t7G = _mm_sub_pd(t7z, t0B);
        t8G = _mm_sub_pd(t6z, t1B);
        t9G = _mm_add_pd(t7z, t0B);
        t0H = _mm_add_pd(s3G, s9G);
        t1H = _mm_sub_pd(s0H, s4G);
        t2H = _mm_sub_pd(s3G, s9G);
        t3H = _mm_add_pd(s4G, s0H);
        t4H = _mm_add_pd(t6G, t0H);
        t5H = _mm_add_pd(t7G, t1H);
        t6H = _mm_sub_pd(t6G, t0H);
        t7H = _mm_sub_pd(t7G, t1H);
        t8H = _mm_sub_pd(t8G, t3H);
        t9H = _mm_sub_pd(t9G, t2H);
        t0I = _mm_add_pd(t8G, t3H);
        t1I = _mm_add_pd(t9G, t2H);
        t2I = _mm_add_pd(s1G, s7G);
        t3I = _mm_add_pd(s2G, s8G);
        t4I = _mm_sub_pd(s1G, s7G);
        t5I = _mm_sub_pd(s2G, s8G);
        t6I = _mm_add_pd(s5G, s1H);
        t7I = _mm_add_pd(s6G, s2H);
        t8I = _mm_sub_pd(s5G, s1H);
        t9I = _mm_sub_pd(s6G, s2H);
        t0J = _mm_add_pd(t2I, t6I);
        t1J = _mm_add_pd(t3I, t7I);
        t2J = _mm_sub_pd(t2I, t6I);
        t3J = _mm_sub_pd(t3I, t7I);
        a87 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4I, t9I));
        a97 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5I, t8I));
        s7H = _mm_sub_pd(a87, a97);
        s8H = _mm_add_pd(a87, a97);
        a08 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4I, t9I));
        a18 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5I, t8I));
        s9H = _mm_sub_pd(a08, a18);
        s0I = _mm_add_pd(a08, a18);
        t4J = _mm_add_pd(t4H, t0J);
        t5J = _mm_add_pd(t5H, t1J);
        t6J = _mm_sub_pd(t4H, t0J);
        t7J = _mm_sub_pd(t5H, t1J);
        t8J = _mm_add_pd(t8H, s7H);
        t9J = _mm_sub_pd(t9H, s8H);
        t0K = _mm_sub_pd(t8H, s7H);
        t1K = _mm_add_pd(t9H, s8H);
        t2K = _mm_add_pd(t6H, t3J);
        t3K = _mm_sub_pd(t7H, t2J);
        t4K = _mm_sub_pd(t6H, t3J);
        t5K = _mm_add_pd(t7H, t2J);
        t6K = _mm_add_pd(t0I, s9H);
        t7K = _mm_add_pd(t1I, s0I);
        t8K = _mm_sub_pd(t0I, s9H);
        t9K = _mm_sub_pd(t1I, s0I);
        a28 = (D46 + a63);
        a38 = *(a28);
        a48 = *((a28 + 1));
        s1I = _mm_sub_pd(_mm_mul_pd(a38, t0F), _mm_mul_pd(a48, t1F));
        s2I = _mm_add_pd(_mm_mul_pd(a48, t0F), _mm_mul_pd(a38, t1F));
        s3I = v_lo2(s1I, s2I);
        s4I = v_hi2(s1I, s2I);
        a58 = (2 * i2);
        b3 = (dst + a58);
        s5I = _mm_add_pd(s3I, s4I);
        _mm_storeu_pd(((double  *) (b3 + 2)), s5I);
        b4 = (dst - a58);
        s6I = v_neg23(_mm_sub_pd(s3I, s4I));
        _mm_storeu_pd(((double  *) (b4 + 2046)), s6I);
        a68 = *((a28 + 2));
        a78 = *((a28 + 3));
        s7I = _mm_sub_pd(_mm_mul_pd(a68, t4J), _mm_mul_pd(a78, t5J));
        s8I = _mm_add_pd(_mm_mul_pd(a78, t4J), _mm_mul_pd(a68, t5J));
        s9I = v_lo2(s7I, s8I);
        s0J = v_hi2(s7I, s8I);
        s1J = _mm_add_pd(s9I, s0J);
        _mm_storeu_pd(((double  *) (b3 + 130)), s1J);
        s2J = v_neg23(_mm_sub_pd(s9I, s0J));
        _mm_storeu_pd(((double  *) (b4 + 1918)), s2J);
        a88 = *((a28 + 4));
        a98 = *((a28 + 5));
        s3J = _mm_sub_pd(_mm_mul_pd(a88, t4F), _mm_mul_pd(a98, t5F));
        s4J = _mm_add_pd(_mm_mul_pd(a98, t4F), _mm_mul_pd(a88, t5F));
        s5J = v_lo2(s3J, s4J);
        s6J = v_hi2(s3J, s4J);
        s7J = _mm_add_pd(s5J, s6J);
        _mm_storeu_pd(((double  *) (b3 + 258)), s7J);
        s8J = v_neg23(_mm_sub_pd(s5J, s6J));
        _mm_storeu_pd(((double  *) (b4 + 1790)), s8J);
        a09 = *((a28 + 6));
        a19 = *((a28 + 7));
        s9J = _mm_sub_pd(_mm_mul_pd(a09, t8J), _mm_mul_pd(a19, t9J));
        s0K = _mm_add_pd(_mm_mul_pd(a19, t8J), _mm_mul_pd(a09, t9J));
        s1K = v_lo2(s9J, s0K);
        s2K = v_hi2(s9J, s0K);
        s3K = _mm_add_pd(s1K, s2K);
        _mm_storeu_pd(((double  *) (b3 + 386)), s3K);
        s4K = v_neg23(_mm_sub_pd(s1K, s2K));
        _mm_storeu_pd(((double  *) (b4 + 1662)), s4K);
        a29 = *((a28 + 8));
        a39 = *((a28 + 9));
        s5K = _mm_sub_pd(_mm_mul_pd(a29, t8F), _mm_mul_pd(a39, t9F));
        s6K = _mm_add_pd(_mm_mul_pd(a39, t8F), _mm_mul_pd(a29, t9F));
        s7K = v_lo2(s5K, s6K);
        s8K = v_hi2(s5K, s6K);
        s9K = _mm_add_pd(s7K, s8K);
        _mm_storeu_pd(((double  *) (b3 + 514)), s9K);
        s0L = v_neg23(_mm_sub_pd(s7K, s8K));
        _mm_storeu_pd(((double  *) (b4 + 1534)), s0L);
        a49 = *((a28 + 10));
        a59 = *((a28 + 11));
        s1L = _mm_sub_pd(_mm_mul_pd(a49, t2K), _mm_mul_pd(a59, t3K));
        s2L = _mm_add_pd(_mm_mul_pd(a59, t2K), _mm_mul_pd(a49, t3K));
        s3L = v_lo2(s1L, s2L);
        s4L = v_hi2(s1L, s2L);
        s5L = _mm_add_pd(s3L, s4L);
        _mm_storeu_pd(((double  *) (b3 + 642)), s5L);
        s6L = v_neg23(_mm_sub_pd(s3L, s4L));
        _mm_storeu_pd(((double  *) (b4 + 1406)), s6L);
        a69 = *((a28 + 12));
        a79 = *((a28 + 13));
        s7L = _mm_sub_pd(_mm_mul_pd(a69, t2G), _mm_mul_pd(a79, t3G));
        s8L = _mm_add_pd(_mm_mul_pd(a79, t2G), _mm_mul_pd(a69, t3G));
        s9L = v_lo2(s7L, s8L);
        s0M = v_hi2(s7L, s8L);
        s1M = _mm_add_pd(s9L, s0M);
        _mm_storeu_pd(((double  *) (b3 + 770)), s1M);
        s2M = v_neg23(_mm_sub_pd(s9L, s0M));
        _mm_storeu_pd(((double  *) (b4 + 1278)), s2M);
        a89 = *((a28 + 14));
        a99 = *((a28 + 15));
        s3M = _mm_sub_pd(_mm_mul_pd(a89, t6K), _mm_mul_pd(a99, t7K));
        s4M = _mm_add_pd(_mm_mul_pd(a99, t6K), _mm_mul_pd(a89, t7K));
        s5M = v_lo2(s3M, s4M);
        s6M = v_hi2(s3M, s4M);
        s7M = _mm_add_pd(s5M, s6M);
        _mm_storeu_pd(((double  *) (b3 + 898)), s7M);
        s8M = v_neg23(_mm_sub_pd(s5M, s6M));
        _mm_storeu_pd(((double  *) (b4 + 1150)), s8M);
        a0a = *((a28 + 16));
        a1a = *((a28 + 17));
        s9M = _mm_sub_pd(_mm_mul_pd(a0a, t2F), _mm_mul_pd(a1a, t3F));
        s0N = _mm_add_pd(_mm_mul_pd(a1a, t2F), _mm_mul_pd(a0a, t3F));
        s1N = v_lo2(s9M, s0N);
        s2N = v_hi2(s9M, s0N);
        s3N = _mm_add_pd(s1N, s2N);
        _mm_storeu_pd(((double  *) (b3 + 1026)), s3N);
        s4N = v_neg23(_mm_sub_pd(s1N, s2N));
        _mm_storeu_pd(((double  *) (b4 + 1022)), s4N);
        a2a = *((a28 + 18));
        a3a = *((a28 + 19));
        s5N = _mm_sub_pd(_mm_mul_pd(a2a, t6J), _mm_mul_pd(a3a, t7J));
        s6N = _mm_add_pd(_mm_mul_pd(a3a, t6J), _mm_mul_pd(a2a, t7J));
        s7N = v_lo2(s5N, s6N);
        s8N = v_hi2(s5N, s6N);
        s9N = _mm_add_pd(s7N, s8N);
        _mm_storeu_pd(((double  *) (b3 + 1154)), s9N);
        s0O = v_neg23(_mm_sub_pd(s7N, s8N));
        _mm_storeu_pd(((double  *) (b4 + 894)), s0O);
        a4a = *((a28 + 20));
        a5a = *((a28 + 21));
        s1O = _mm_sub_pd(_mm_mul_pd(a4a, t6F), _mm_mul_pd(a5a, t7F));
        s2O = _mm_add_pd(_mm_mul_pd(a5a, t6F), _mm_mul_pd(a4a, t7F));
        s3O = v_lo2(s1O, s2O);
        s4O = v_hi2(s1O, s2O);
        s5O = _mm_add_pd(s3O, s4O);
        _mm_storeu_pd(((double  *) (b3 + 1282)), s5O);
        s6O = v_neg23(_mm_sub_pd(s3O, s4O));
        _mm_storeu_pd(((double  *) (b4 + 766)), s6O);
        a6a = *((a28 + 22));
        a7a = *((a28 + 23));
        s7O = _mm_sub_pd(_mm_mul_pd(a6a, t0K), _mm_mul_pd(a7a, t1K));
        s8O = _mm_add_pd(_mm_mul_pd(a7a, t0K), _mm_mul_pd(a6a, t1K));
        s9O = v_lo2(s7O, s8O);
        s0P = v_hi2(s7O, s8O);
        s1P = _mm_add_pd(s9O, s0P);
        _mm_storeu_pd(((double  *) (b3 + 1410)), s1P);
        s2P = v_neg23(_mm_sub_pd(s9O, s0P));
        _mm_storeu_pd(((double  *) (b4 + 638)), s2P);
        a8a = *((a28 + 24));
        a9a = *((a28 + 25));
        s3P = _mm_sub_pd(_mm_mul_pd(a8a, t0G), _mm_mul_pd(a9a, t1G));
        s4P = _mm_add_pd(_mm_mul_pd(a9a, t0G), _mm_mul_pd(a8a, t1G));
        s5P = v_lo2(s3P, s4P);
        s6P = v_hi2(s3P, s4P);
        s7P = _mm_add_pd(s5P, s6P);
        _mm_storeu_pd(((double  *) (b3 + 1538)), s7P);
        s8P = v_neg23(_mm_sub_pd(s5P, s6P));
        _mm_storeu_pd(((double  *) (b4 + 510)), s8P);
        a0b = *((a28 + 26));
        a1b = *((a28 + 27));
        s9P = _mm_sub_pd(_mm_mul_pd(a0b, t4K), _mm_mul_pd(a1b, t5K));
        s0Q = _mm_add_pd(_mm_mul_pd(a1b, t4K), _mm_mul_pd(a0b, t5K));
        s1Q = v_lo2(s9P, s0Q);
        s2Q = v_hi2(s9P, s0Q);
        s3Q = _mm_add_pd(s1Q, s2Q);
        _mm_storeu_pd(((double  *) (b3 + 1666)), s3Q);
        s4Q = v_neg23(_mm_sub_pd(s1Q, s2Q));
        _mm_storeu_pd(((double  *) (b4 + 382)), s4Q);
        a2b = *((a28 + 28));
        a3b = *((a28 + 29));
        s5Q = _mm_sub_pd(_mm_mul_pd(a2b, t4G), _mm_mul_pd(a3b, t5G));
        s6Q = _mm_add_pd(_mm_mul_pd(a3b, t4G), _mm_mul_pd(a2b, t5G));
        s7Q = v_lo2(s5Q, s6Q);
        s8Q = v_hi2(s5Q, s6Q);
        s9Q = _mm_add_pd(s7Q, s8Q);
        _mm_storeu_pd(((double  *) (b3 + 1794)), s9Q);
        s0R = v_neg23(_mm_sub_pd(s7Q, s8Q));
        _mm_storeu_pd(((double  *) (b4 + 254)), s0R);
        a4b = *((a28 + 30));
        a5b = *((a28 + 31));
        s1R = _mm_sub_pd(_mm_mul_pd(a4b, t8K), _mm_mul_pd(a5b, t9K));
        s2R = _mm_add_pd(_mm_mul_pd(a5b, t8K), _mm_mul_pd(a4b, t9K));
        s3R = v_lo2(s1R, s2R);
        s4R = v_hi2(s1R, s2R);
        s5R = _mm_add_pd(s3R, s4R);
        _mm_storeu_pd(((double  *) (b3 + 1922)), s5R);
        s6R = v_neg23(_mm_sub_pd(s3R, s4R));
        _mm_storeu_pd(((double  *) (b4 + 126)), s6R);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_2048)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_2048_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[2048]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a09, a0a, a0b, a11, a12, a13, a14, a15, a16, a17, a18, a19, a1a, a1b
            , a2, a21, a22, a23, a24, a25, a26, a27, a28, a29, a2a, a2b, a3, a31, a33, a34, a35, a36, a37, a39, a3a, a3b
            , a4, a41, a42, a43, a44, a45, a46, a47, a48, a49, a4a, a4b, a5, a51, a52, a53, a54, a55, a56, a57, a58, a59
            , a5a, a5b, a6, a61, a62, a64, a65, a66, a67, a69, a6a, a6b, a7, a71, a72, a74, a75, a76, a77, a78, a79, a7a
            , a8, a82, a84, a85, a86, a87, a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0P, s0Q, s0R, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r
            , s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E
            , s1F, s1G, s1H, s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1P, s1Q, s1R, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i
            , s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24
            , s25, s26, s27, s28, s29, s2A, s2B, s2C, s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2P, s2Q
            , s2R, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u
            , s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G
            , s3H, s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3P, s3Q, s3R, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k
            , s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46
            , s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4L, s4M, s4N, s4O, s4P, s4Q, s4R, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w
            , s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I
            , s5J, s5K, s5L, s5M, s5N, s5O, s5P, s5Q, s5R, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m
            , s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6O, s6P, s6Q, s6R, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7K
            , s7L, s7M, s7N, s7O, s7P, s7Q, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p
            , s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B
            , s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8O, s8P, s8Q, s8a, s8b, s8c, s8d, s8e, s8f, s8g
            , s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92
            , s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9O
            , s9P, s9Q, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t
            , s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F
            , t0G, t0H, t0I, t0J, t0K, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q
            , t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1A, t1B, t1C, t1D
            , t1E, t1F, t1G, t1H, t1I, t1J, t1K, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o
            , t1p, t1q, t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2A
            , t2B, t2C, t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l
            , t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36, t37
            , t38, t39, t3A, t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i
            , t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t42, t43, t44
            , t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4a, t4b, t4c, t4d, t4e, t4f
            , t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t4y, t4z, t5, t51
            , t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5F, t5G, t5H, t5I, t5J, t5K, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y
            , t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K
            , t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v
            , t6w, t6x, t6y, t6z, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7F, t7G, t7H
            , t7I, t7J, t7K, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s
            , t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E
            , t8F, t8G, t8H, t8I, t8J, t8K, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p
            , t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9A, t9B
            , t9C, t9D, t9E, t9F, t9G, t9H, t9I, t9J, t9K, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m
            , t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a, *a32, *a38, *a63, *a68, *a81, *a83, *b, *b2, *b3;
    int a73;
    {long i; for(i = 0; i <= 15; i++) {
        a = (((__m128d  *) src) + i);
        s = *(a);
        s2 = *((a + 512));
        t = _mm_add_pd(s, s2);
        t2 = _mm_sub_pd(s, s2);
        s3 = *((a + 256));
        s4 = *((a + 768));
        t3 = _mm_add_pd(s3, s4);
        t4 = _mm_sub_pd(s3, s4);
        s5 = *((a + 64));
        s6 = *((a + 576));
        t5 = _mm_add_pd(s5, s6);
        t6 = _mm_sub_pd(s5, s6);
        s7 = *((a + 320));
        s8 = *((a + 832));
        t7 = _mm_add_pd(s7, s8);
        t8 = _mm_sub_pd(s7, s8);
        s9 = *((a + 128));
        s01 = *((a + 640));
        t9 = _mm_add_pd(s9, s01);
        s11 = *((a + 384));
        s21 = *((a + 896));
        t01 = _mm_add_pd(s11, s21);
        s31 = *((a + 192));
        s41 = *((a + 704));
        t11 = _mm_add_pd(s31, s41);
        t21 = _mm_sub_pd(s31, s41);
        s51 = *((a + 448));
        s61 = *((a + 960));
        t31 = _mm_add_pd(s51, s61);
        t41 = _mm_sub_pd(s51, s61);
        t51 = _mm_add_pd(t, t3);
        t61 = _mm_sub_pd(t, t3);
        t71 = _mm_add_pd(t9, t01);
        t81 = _mm_sub_pd(t9, t01);
        t91 = _mm_add_pd(t5, t7);
        t02 = _mm_add_pd(t11, t31);
        t12 = _mm_add_pd(t51, t71);
        t22 = _mm_sub_pd(t51, t71);
        t32 = _mm_add_pd(t91, t02);
        t42 = _mm_sub_pd(t91, t02);
        a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
        a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
        s71 = _mm_add_pd(a2, a3);
        s81 = _mm_sub_pd(a3, a2);
        t52 = _mm_add_pd(t61, s71);
        t62 = _mm_sub_pd(s81, t81);
        t72 = _mm_sub_pd(t61, s71);
        t82 = _mm_add_pd(t81, s81);
        s91 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
        s02 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
        a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
        a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
        s12 = _mm_add_pd(a4, a5);
        s22 = _mm_sub_pd(a5, a4);
        s32 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
        s42 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
        t92 = _mm_add_pd(t2, s12);
        t03 = _mm_sub_pd(s22, t4);
        t13 = _mm_sub_pd(t2, s12);
        t23 = _mm_add_pd(t4, s22);
        t33 = _mm_add_pd(s91, s32);
        t43 = _mm_add_pd(s02, s42);
        t53 = _mm_sub_pd(s91, s32);
        t63 = _mm_sub_pd(s02, s42);
        t73 = _mm_add_pd(t92, t33);
        t83 = _mm_add_pd(t03, t43);
        t93 = _mm_sub_pd(t92, t33);
        t04 = _mm_sub_pd(t03, t43);
        t14 = _mm_add_pd(t13, t63);
        t24 = _mm_add_pd(t23, t53);
        t34 = _mm_sub_pd(t13, t63);
        t44 = _mm_sub_pd(t53, t23);
        s52 = *((a + 16));
        s62 = *((a + 528));
        t54 = _mm_add_pd(s52, s62);
        t64 = _mm_sub_pd(s52, s62);
        s72 = *((a + 272));
        s82 = *((a + 784));
        t74 = _mm_add_pd(s72, s82);
        t84 = _mm_sub_pd(s72, s82);
        s92 = *((a + 80));
        s03 = *((a + 592));
        t94 = _mm_add_pd(s92, s03);
        t05 = _mm_sub_pd(s92, s03);
        s13 = *((a + 336));
        s23 = *((a + 848));
        t15 = _mm_add_pd(s13, s23);
        t25 = _mm_sub_pd(s13, s23);
        s33 = *((a + 144));
        s43 = *((a + 656));
        t35 = _mm_add_pd(s33, s43);
        s53 = *((a + 400));
        s63 = *((a + 912));
        t45 = _mm_add_pd(s53, s63);
        s73 = *((a + 208));
        s83 = *((a + 720));
        t55 = _mm_add_pd(s73, s83);
        t65 = _mm_sub_pd(s73, s83);
        s93 = *((a + 464));
        s04 = *((a + 976));
        t75 = _mm_add_pd(s93, s04);
        t85 = _mm_sub_pd(s93, s04);
        t95 = _mm_add_pd(t54, t74);
        t06 = _mm_sub_pd(t54, t74);
        t16 = _mm_add_pd(t35, t45);
        t26 = _mm_sub_pd(t35, t45);
        t36 = _mm_add_pd(t94, t15);
        t46 = _mm_add_pd(t55, t75);
        t56 = _mm_add_pd(t95, t16);
        t66 = _mm_sub_pd(t95, t16);
        t76 = _mm_add_pd(t36, t46);
        t86 = _mm_sub_pd(t36, t46);
        a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
        a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t55, t75));
        s14 = _mm_add_pd(a6, a7);
        s24 = _mm_sub_pd(a7, a6);
        t96 = _mm_add_pd(t06, s14);
        t07 = _mm_sub_pd(s24, t26);
        t17 = _mm_sub_pd(t06, s14);
        t27 = _mm_add_pd(t26, s24);
        s34 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
        s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s33, s43));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s53, s63));
        s54 = _mm_add_pd(a8, a9);
        s64 = _mm_sub_pd(a9, a8);
        s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t65), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t85));
        s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t65), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
        t37 = _mm_add_pd(t64, s54);
        t47 = _mm_sub_pd(s64, t84);
        t57 = _mm_sub_pd(t64, s54);
        t67 = _mm_add_pd(t84, s64);
        t77 = _mm_add_pd(s34, s74);
        t87 = _mm_add_pd(s44, s84);
        t97 = _mm_sub_pd(s34, s74);
        t08 = _mm_sub_pd(s44, s84);
        t18 = _mm_add_pd(t37, t77);
        t28 = _mm_add_pd(t47, t87);
        t38 = _mm_sub_pd(t37, t77);
        t48 = _mm_sub_pd(t47, t87);
        t58 = _mm_add_pd(t57, t08);
        t68 = _mm_add_pd(t67, t97);
        t78 = _mm_sub_pd(t57, t08);
        t88 = _mm_sub_pd(t97, t67);
        s94 = *((a + 32));
        s05 = *((a + 544));
        t98 = _mm_add_pd(s94, s05);
        t09 = _mm_sub_pd(s94, s05);
        s15 = *((a + 288));
        s25 = *((a + 800));
        t19 = _mm_add_pd(s15, s25);
        t29 = _mm_sub_pd(s15, s25);
        s35 = *((a + 96));
        s45 = *((a + 608));
        t39 = _mm_add_pd(s35, s45);
        t49 = _mm_sub_pd(s35, s45);
        s55 = *((a + 352));
        s65 = *((a + 864));
        t59 = _mm_add_pd(s55, s65);
        t69 = _mm_sub_pd(s55, s65);
        s75 = *((a + 160));
        s85 = *((a + 672));
        t79 = _mm_add_pd(s75, s85);
        s95 = *((a + 416));
        s06 = *((a + 928));
        t89 = _mm_add_pd(s95, s06);
        s16 = *((a + 224));
        s26 = *((a + 736));
        t99 = _mm_add_pd(s16, s26);
        t0a = _mm_sub_pd(s16, s26);
        s36 = *((a + 480));
        s46 = *((a + 992));
        t1a = _mm_add_pd(s36, s46);
        t2a = _mm_sub_pd(s36, s46);
        t3a = _mm_add_pd(t98, t19);
        t4a = _mm_sub_pd(t98, t19);
        t5a = _mm_add_pd(t79, t89);
        t6a = _mm_sub_pd(t79, t89);
        t7a = _mm_add_pd(t39, t59);
        t8a = _mm_add_pd(t99, t1a);
        t9a = _mm_add_pd(t3a, t5a);
        t0b = _mm_add_pd(t7a, t8a);
        a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t39, t59));
        a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t99, t1a));
        s56 = _mm_add_pd(a01, a11);
        s66 = _mm_sub_pd(a11, a01);
        t1b = _mm_add_pd(t4a, s56);
        t2b = _mm_sub_pd(s66, t6a);
        t3b = _mm_sub_pd(t4a, s56);
        t4b = _mm_add_pd(t6a, s66);
        s76 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t49), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t69));
        s86 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t49), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t69));
        a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s75, s85));
        a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s95, s06));
        s96 = _mm_add_pd(a21, a31);
        s07 = _mm_sub_pd(a31, a21);
        s17 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0a), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2a));
        s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2a));
        t5b = _mm_add_pd(t09, s96);
        t6b = _mm_sub_pd(s07, t29);
        t7b = _mm_sub_pd(t09, s96);
        t8b = _mm_add_pd(t29, s07);
        t9b = _mm_add_pd(s76, s17);
        t0c = _mm_add_pd(s86, s27);
        t1c = _mm_sub_pd(s76, s17);
        t2c = _mm_sub_pd(s86, s27);
        t3c = _mm_add_pd(t5b, t9b);
        t4c = _mm_add_pd(t6b, t0c);
        t5c = _mm_sub_pd(t5b, t9b);
        t6c = _mm_sub_pd(t6b, t0c);
        t7c = _mm_add_pd(t7b, t2c);
        t8c = _mm_add_pd(t8b, t1c);
        t9c = _mm_sub_pd(t7b, t2c);
        t0d = _mm_sub_pd(t1c, t8b);
        s37 = *((a + 48));
        s47 = *((a + 560));
        t1d = _mm_add_pd(s37, s47);
        t2d = _mm_sub_pd(s37, s47);
        s57 = *((a + 304));
        s67 = *((a + 816));
        t3d = _mm_add_pd(s57, s67);
        t4d = _mm_sub_pd(s57, s67);
        s77 = *((a + 112));
        s87 = *((a + 624));
        t5d = _mm_add_pd(s77, s87);
        t6d = _mm_sub_pd(s77, s87);
        s97 = *((a + 368));
        s08 = *((a + 880));
        t7d = _mm_add_pd(s97, s08);
        t8d = _mm_sub_pd(s97, s08);
        s18 = *((a + 176));
        s28 = *((a + 688));
        t9d = _mm_add_pd(s18, s28);
        s38 = *((a + 432));
        s48 = *((a + 944));
        t0e = _mm_add_pd(s38, s48);
        s58 = *((a + 240));
        s68 = *((a + 752));
        t1e = _mm_add_pd(s58, s68);
        t2e = _mm_sub_pd(s58, s68);
        s78 = *((a + 496));
        s88 = *((a + 1008));
        t3e = _mm_add_pd(s78, s88);
        t4e = _mm_sub_pd(s78, s88);
        t5e = _mm_add_pd(t1d, t3d);
        t6e = _mm_sub_pd(t1d, t3d);
        t7e = _mm_add_pd(t9d, t0e);
        t8e = _mm_sub_pd(t9d, t0e);
        t9e = _mm_add_pd(t5d, t7d);
        t0f = _mm_add_pd(t1e, t3e);
        t1f = _mm_add_pd(t5e, t7e);
        t2f = _mm_sub_pd(t5e, t7e);
        t3f = _mm_add_pd(t9e, t0f);
        t4f = _mm_sub_pd(t9e, t0f);
        a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t7d));
        a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1e, t3e));
        s98 = _mm_add_pd(a41, a51);
        s09 = _mm_sub_pd(a51, a41);
        t5f = _mm_add_pd(t6e, s98);
        t6f = _mm_sub_pd(s09, t8e);
        t7f = _mm_sub_pd(t6e, s98);
        t8f = _mm_add_pd(t8e, s09);
        s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8d));
        s29 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8d));
        a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s18, s28));
        a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s38, s48));
        s39 = _mm_add_pd(a61, a71);
        s49 = _mm_sub_pd(a71, a61);
        s59 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2e), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4e));
        s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4e));
        t9f = _mm_add_pd(t2d, s39);
        t0g = _mm_sub_pd(s49, t4d);
        t1g = _mm_sub_pd(t2d, s39);
        t2g = _mm_add_pd(t4d, s49);
        t3g = _mm_add_pd(s19, s59);
        t4g = _mm_add_pd(s29, s69);
        t5g = _mm_sub_pd(s19, s59);
        t6g = _mm_sub_pd(s29, s69);
        t7g = _mm_add_pd(t9f, t3g);
        t8g = _mm_add_pd(t0g, t4g);
        t9g = _mm_sub_pd(t9f, t3g);
        t0h = _mm_sub_pd(t0g, t4g);
        t1h = _mm_add_pd(t1g, t6g);
        t2h = _mm_add_pd(t2g, t5g);
        t3h = _mm_sub_pd(t1g, t6g);
        t4h = _mm_sub_pd(t5g, t2g);
        t5h = _mm_add_pd(t12, t32);
        t6h = _mm_sub_pd(t12, t32);
        t7h = _mm_add_pd(t9a, t0b);
        t8h = _mm_sub_pd(t9a, t0b);
        t9h = _mm_add_pd(t56, t76);
        t0i = _mm_add_pd(t1f, t3f);
        a81 = (((__m128d  *) T) + i);
        s79 = _mm_add_pd(t5h, t7h);
        *(a81) = s79;
        s89 = _mm_sub_pd(t5h, t7h);
        *((a81 + 512)) = s89;
        s99 = _mm_add_pd(t9h, t0i);
        *((a81 + 16)) = s99;
        s0a = _mm_sub_pd(t0i, t9h);
        *((a81 + 528)) = s0a;
        a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t76));
        a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1f, t3f));
        s1a = _mm_add_pd(a91, a02);
        s2a = _mm_sub_pd(a02, a91);
        s3a = _mm_add_pd(t6h, s1a);
        *((a81 + 256)) = s3a;
        s4a = _mm_sub_pd(s2a, t8h);
        *((a81 + 272)) = s4a;
        s5a = _mm_sub_pd(t6h, s1a);
        *((a81 + 768)) = s5a;
        s6a = _mm_add_pd(t8h, s2a);
        *((a81 + 784)) = s6a;
        s7a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t18), _mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t28));
        s8a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.098017140329560604)), t18), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t28));
        s9a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3c), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4c));
        s0b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4c));
        s1b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7g), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t8g));
        s2b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t7g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8g));
        t1i = _mm_add_pd(t73, s9a);
        t2i = _mm_add_pd(t83, s0b);
        t3i = _mm_sub_pd(t73, s9a);
        t4i = _mm_sub_pd(t83, s0b);
        t5i = _mm_add_pd(s7a, s1b);
        t6i = _mm_add_pd(s8a, s2b);
        t7i = _mm_sub_pd(s7a, s1b);
        t8i = _mm_sub_pd(s8a, s2b);
        s3b = _mm_add_pd(t1i, t5i);
        *((a81 + 32)) = s3b;
        s4b = _mm_add_pd(t2i, t6i);
        *((a81 + 48)) = s4b;
        s5b = _mm_sub_pd(t1i, t5i);
        *((a81 + 992)) = s5b;
        s6b = _mm_sub_pd(t6i, t2i);
        *((a81 + 1008)) = s6b;
        s7b = _mm_add_pd(t3i, t8i);
        *((a81 + 544)) = s7b;
        s8b = _mm_sub_pd(t4i, t7i);
        *((a81 + 560)) = s8b;
        s9b = _mm_sub_pd(t3i, t8i);
        *((a81 + 480)) = s9b;
        s0c = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4i, t7i));
        *((a81 + 496)) = s0c;
        s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t96), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t07));
        s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t96), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t07));
        s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2b));
        s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2b));
        s5c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5f), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6f));
        s6c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5f), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6f));
        t9i = _mm_add_pd(t52, s3c);
        t0j = _mm_add_pd(t62, s4c);
        t1j = _mm_sub_pd(t52, s3c);
        t2j = _mm_sub_pd(t62, s4c);
        t3j = _mm_add_pd(s1c, s5c);
        t4j = _mm_add_pd(s2c, s6c);
        t5j = _mm_sub_pd(s1c, s5c);
        t6j = _mm_sub_pd(s2c, s6c);
        s7c = _mm_add_pd(t9i, t3j);
        *((a81 + 64)) = s7c;
        s8c = _mm_add_pd(t0j, t4j);
        *((a81 + 80)) = s8c;
        s9c = _mm_sub_pd(t9i, t3j);
        *((a81 + 960)) = s9c;
        s0d = _mm_sub_pd(t4j, t0j);
        *((a81 + 976)) = s0d;
        s1d = _mm_add_pd(t1j, t6j);
        *((a81 + 576)) = s1d;
        s2d = _mm_sub_pd(t2j, t5j);
        *((a81 + 592)) = s2d;
        s3d = _mm_sub_pd(t1j, t6j);
        *((a81 + 448)) = s3d;
        s4d = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2j, t5j));
        *((a81 + 464)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t78), _mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t88));
        s6d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.29028467725446239)), t78), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t88));
        s7d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9c), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t0d));
        s8d = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t9c), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0d));
        s9d = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3h), _mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t4h));
        s0e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.77301045336273699)), t3h), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4h));
        t7j = _mm_add_pd(t34, s7d);
        t8j = _mm_sub_pd(s8d, t44);
        t9j = _mm_sub_pd(t34, s7d);
        t0k = _mm_add_pd(t44, s8d);
        t1k = _mm_add_pd(s5d, s9d);
        t2k = _mm_add_pd(s6d, s0e);
        t3k = _mm_sub_pd(s5d, s9d);
        t4k = _mm_sub_pd(s6d, s0e);
        s1e = _mm_add_pd(t7j, t1k);
        *((a81 + 96)) = s1e;
        s2e = _mm_add_pd(t8j, t2k);
        *((a81 + 112)) = s2e;
        s3e = _mm_sub_pd(t7j, t1k);
        *((a81 + 928)) = s3e;
        s4e = _mm_sub_pd(t2k, t8j);
        *((a81 + 944)) = s4e;
        s5e = _mm_add_pd(t9j, t4k);
        *((a81 + 608)) = s5e;
        s6e = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0k, t3k));
        *((a81 + 624)) = s6e;
        s7e = _mm_sub_pd(t9j, t4k);
        *((a81 + 416)) = s7e;
        s8e = _mm_sub_pd(t0k, t3k);
        *((a81 + 432)) = s8e;
        s9e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t86));
        s0f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t86));
        a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3a, t5a));
        a22 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7a, t8a));
        s1f = _mm_add_pd(a12, a22);
        s2f = _mm_sub_pd(a22, a12);
        s3f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4f));
        s4f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
        t5k = _mm_add_pd(t22, s1f);
        t6k = _mm_sub_pd(s2f, t42);
        t7k = _mm_sub_pd(t22, s1f);
        t8k = _mm_add_pd(t42, s2f);
        t9k = _mm_add_pd(s9e, s3f);
        t0l = _mm_add_pd(s0f, s4f);
        t1l = _mm_sub_pd(s9e, s3f);
        t2l = _mm_sub_pd(s0f, s4f);
        s5f = _mm_add_pd(t5k, t9k);
        *((a81 + 128)) = s5f;
        s6f = _mm_add_pd(t6k, t0l);
        *((a81 + 144)) = s6f;
        s7f = _mm_sub_pd(t5k, t9k);
        *((a81 + 896)) = s7f;
        s8f = _mm_sub_pd(t0l, t6k);
        *((a81 + 912)) = s8f;
        s9f = _mm_add_pd(t7k, t2l);
        *((a81 + 640)) = s9f;
        s0g = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8k, t1l));
        *((a81 + 656)) = s0g;
        s1g = _mm_sub_pd(t7k, t2l);
        *((a81 + 384)) = s1g;
        s2g = _mm_sub_pd(t8k, t1l);
        *((a81 + 400)) = s2g;
        s3g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t58), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t68));
        s4g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t58), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t68));
        s5g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7c), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t8c));
        s6g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t7c), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8c));
        s7g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1h), _mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t2h));
        s8g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.99518472667219693)), t1h), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2h));
        t3l = _mm_add_pd(t14, s5g);
        t4l = _mm_sub_pd(s6g, t24);
        t5l = _mm_sub_pd(t14, s5g);
        t6l = _mm_add_pd(t24, s6g);
        t7l = _mm_add_pd(s3g, s7g);
        t8l = _mm_add_pd(s4g, s8g);
        t9l = _mm_sub_pd(s3g, s7g);
        t0m = _mm_sub_pd(s4g, s8g);
        s9g = _mm_add_pd(t3l, t7l);
        *((a81 + 160)) = s9g;
        s0h = _mm_add_pd(t4l, t8l);
        *((a81 + 176)) = s0h;
        s1h = _mm_sub_pd(t3l, t7l);
        *((a81 + 864)) = s1h;
        s2h = _mm_sub_pd(t8l, t4l);
        *((a81 + 880)) = s2h;
        s3h = _mm_add_pd(t5l, t0m);
        *((a81 + 672)) = s3h;
        s4h = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6l, t9l));
        *((a81 + 688)) = s4h;
        s5h = _mm_sub_pd(t5l, t0m);
        *((a81 + 352)) = s5h;
        s6h = _mm_sub_pd(t6l, t9l);
        *((a81 + 368)) = s6h;
        s7h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t17), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t27));
        s8h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t17), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t27));
        s9h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3b), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4b));
        s0i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4b));
        s1i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7f), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8f));
        s2i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7f), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8f));
        t1m = _mm_add_pd(t72, s9h);
        t2m = _mm_add_pd(t82, s0i);
        t3m = _mm_sub_pd(t72, s9h);
        t4m = _mm_sub_pd(t82, s0i);
        t5m = _mm_add_pd(s7h, s1i);
        t6m = _mm_add_pd(s8h, s2i);
        t7m = _mm_sub_pd(s7h, s1i);
        t8m = _mm_sub_pd(s8h, s2i);
        s3i = _mm_add_pd(t1m, t5m);
        *((a81 + 192)) = s3i;
        s4i = _mm_add_pd(t2m, t6m);
        *((a81 + 208)) = s4i;
        s5i = _mm_sub_pd(t1m, t5m);
        *((a81 + 832)) = s5i;
        s6i = _mm_sub_pd(t6m, t2m);
        *((a81 + 848)) = s6i;
        s7i = _mm_add_pd(t3m, t8m);
        *((a81 + 704)) = s7i;
        s8i = _mm_sub_pd(t4m, t7m);
        *((a81 + 720)) = s8i;
        s9i = _mm_sub_pd(t3m, t8m);
        *((a81 + 320)) = s9i;
        s0j = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4m, t7m));
        *((a81 + 336)) = s0j;
        s1j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t38), _mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t48));
        s2j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.63439328416364549)), t38), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t48));
        s3j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5c), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t6c));
        s4j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t5c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6c));
        s5j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9g), _mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t0h));
        s6j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.88192126434835505)), t9g), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0h));
        t9m = _mm_add_pd(t93, s3j);
        t0n = _mm_sub_pd(s4j, t04);
        t1n = _mm_sub_pd(t93, s3j);
        t2n = _mm_add_pd(t04, s4j);
        t3n = _mm_add_pd(s1j, s5j);
        t4n = _mm_add_pd(s2j, s6j);
        t5n = _mm_sub_pd(s1j, s5j);
        t6n = _mm_sub_pd(s2j, s6j);
        s7j = _mm_add_pd(t9m, t3n);
        *((a81 + 224)) = s7j;
        s8j = _mm_add_pd(t0n, t4n);
        *((a81 + 240)) = s8j;
        s9j = _mm_sub_pd(t9m, t3n);
        *((a81 + 800)) = s9j;
        s0k = _mm_sub_pd(t4n, t0n);
        *((a81 + 816)) = s0k;
        s1k = _mm_add_pd(t1n, t6n);
        *((a81 + 736)) = s1k;
        s2k = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2n, t5n));
        *((a81 + 752)) = s2k;
        s3k = _mm_sub_pd(t1n, t6n);
        *((a81 + 288)) = s3k;
        s4k = _mm_sub_pd(t2n, t5n);
        *((a81 + 304)) = s4k;
    }}
    a32 = ((__m128d  *) T);
    s5k = *(a32);
    s6k = *((a32 + 16));
    t7n = _mm_add_pd(s5k, s6k);
    t8n = _mm_sub_pd(s5k, s6k);
    s7k = *((a32 + 8));
    s8k = *((a32 + 24));
    t9n = _mm_add_pd(s7k, s8k);
    t0o = _mm_sub_pd(s7k, s8k);
    s9k = *((a32 + 4));
    s0l = *((a32 + 20));
    t1o = _mm_add_pd(s9k, s0l);
    s1l = *((a32 + 12));
    s2l = *((a32 + 28));
    t2o = _mm_add_pd(s1l, s2l);
    t3o = _mm_add_pd(t7n, t9n);
    t4o = _mm_sub_pd(t7n, t9n);
    t5o = _mm_add_pd(t1o, t2o);
    t6o = _mm_sub_pd(t1o, t2o);
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9k, s0l));
    a52 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1l, s2l));
    s3l = _mm_add_pd(a42, a52);
    s4l = _mm_sub_pd(a52, a42);
    t7o = _mm_add_pd(t8n, s3l);
    t8o = _mm_sub_pd(s4l, t0o);
    t9o = _mm_sub_pd(t8n, s3l);
    t0p = _mm_add_pd(t0o, s4l);
    s5l = *((a32 + 1));
    s6l = *((a32 + 17));
    t1p = _mm_add_pd(s5l, s6l);
    t2p = _mm_sub_pd(s5l, s6l);
    s7l = *((a32 + 9));
    s8l = *((a32 + 25));
    t3p = _mm_add_pd(s7l, s8l);
    t4p = _mm_sub_pd(s7l, s8l);
    s9l = *((a32 + 5));
    s0m = *((a32 + 21));
    t5p = _mm_add_pd(s9l, s0m);
    s1m = *((a32 + 13));
    s2m = *((a32 + 29));
    t6p = _mm_add_pd(s1m, s2m);
    t7p = _mm_add_pd(t1p, t3p);
    t8p = _mm_sub_pd(t1p, t3p);
    t9p = _mm_add_pd(t5p, t6p);
    t0q = _mm_sub_pd(t5p, t6p);
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9l, s0m));
    a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1m, s2m));
    s3m = _mm_add_pd(a62, a72);
    s4m = _mm_sub_pd(a72, a62);
    t1q = _mm_add_pd(t2p, s3m);
    t2q = _mm_sub_pd(s4m, t4p);
    t3q = _mm_sub_pd(t2p, s3m);
    t4q = _mm_add_pd(t4p, s4m);
    s5m = *((a32 + 2));
    s6m = *((a32 + 18));
    t5q = _mm_add_pd(s5m, s6m);
    t6q = _mm_sub_pd(s5m, s6m);
    s7m = *((a32 + 10));
    s8m = *((a32 + 26));
    t7q = _mm_add_pd(s7m, s8m);
    t8q = _mm_sub_pd(s7m, s8m);
    s9m = *((a32 + 6));
    s0n = *((a32 + 22));
    t9q = _mm_add_pd(s9m, s0n);
    s1n = *((a32 + 14));
    s2n = *((a32 + 30));
    t0r = _mm_add_pd(s1n, s2n);
    t1r = _mm_add_pd(t5q, t7q);
    t2r = _mm_add_pd(t9q, t0r);
    a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9m, s0n));
    a92 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1n, s2n));
    s3n = _mm_add_pd(a82, a92);
    s4n = _mm_sub_pd(a92, a82);
    t3r = _mm_add_pd(t6q, s3n);
    t4r = _mm_sub_pd(s4n, t8q);
    t5r = _mm_sub_pd(t6q, s3n);
    t6r = _mm_add_pd(t8q, s4n);
    s5n = *((a32 + 3));
    s6n = *((a32 + 19));
    t7r = _mm_add_pd(s5n, s6n);
    t8r = _mm_sub_pd(s5n, s6n);
    s7n = *((a32 + 11));
    s8n = *((a32 + 27));
    t9r = _mm_add_pd(s7n, s8n);
    t0s = _mm_sub_pd(s7n, s8n);
    s9n = *((a32 + 7));
    s0o = *((a32 + 23));
    t1s = _mm_add_pd(s9n, s0o);
    s1o = *((a32 + 15));
    s2o = *((a32 + 31));
    t2s = _mm_add_pd(s1o, s2o);
    t3s = _mm_add_pd(t7r, t9r);
    t4s = _mm_sub_pd(t7r, t9r);
    t5s = _mm_add_pd(t1s, t2s);
    t6s = _mm_sub_pd(t1s, t2s);
    a03 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9n, s0o));
    a13 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1o, s2o));
    s3o = _mm_add_pd(a03, a13);
    s4o = _mm_sub_pd(a13, a03);
    t7s = _mm_add_pd(t8r, s3o);
    t8s = _mm_sub_pd(s4o, t0s);
    t9s = _mm_sub_pd(t8r, s3o);
    t0t = _mm_add_pd(t0s, s4o);
    t1t = _mm_add_pd(t3o, t5o);
    t2t = _mm_sub_pd(t3o, t5o);
    t3t = _mm_add_pd(t1r, t2r);
    t4t = _mm_sub_pd(t1r, t2r);
    t5t = _mm_add_pd(t7p, t9p);
    t6t = _mm_add_pd(t3s, t5s);
    t7t = _mm_add_pd(t1t, t3t);
    t8t = _mm_sub_pd(t1t, t3t);
    t9t = _mm_add_pd(t5t, t6t);
    t0u = _mm_sub_pd(t5t, t6t);
    a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7p, t9p));
    a33 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3s, t5s));
    s5o = _mm_add_pd(a23, a33);
    s6o = _mm_sub_pd(a33, a23);
    t1u = _mm_add_pd(t2t, s5o);
    t2u = _mm_sub_pd(s6o, t4t);
    t3u = _mm_sub_pd(t2t, s5o);
    t4u = _mm_add_pd(t4t, s6o);
    s7o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1q), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2q));
    s8o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1q), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2q));
    s9o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3r), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4r));
    s0p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4r));
    s1p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t7s), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t8s));
    s2p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t7s), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t8s));
    t5u = _mm_add_pd(t7o, s9o);
    t6u = _mm_add_pd(t8o, s0p);
    t7u = _mm_sub_pd(t7o, s9o);
    t8u = _mm_sub_pd(t8o, s0p);
    t9u = _mm_add_pd(s7o, s1p);
    t0v = _mm_add_pd(s8o, s2p);
    t1v = _mm_sub_pd(s7o, s1p);
    t2v = _mm_sub_pd(s8o, s2p);
    t3v = _mm_add_pd(t5u, t9u);
    t4v = _mm_add_pd(t6u, t0v);
    t5v = _mm_sub_pd(t5u, t9u);
    t6v = _mm_sub_pd(t6u, t0v);
    t7v = _mm_add_pd(t7u, t2v);
    t8v = _mm_sub_pd(t8u, t1v);
    t9v = _mm_sub_pd(t7u, t2v);
    t0w = _mm_add_pd(t8u, t1v);
    s3p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8p), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0q));
    s4p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0q));
    a43 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5q, t7q));
    a53 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9q, t0r));
    s5p = _mm_add_pd(a43, a53);
    s6p = _mm_sub_pd(a53, a43);
    s7p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4s), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6s));
    s8p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6s));
    t1w = _mm_add_pd(t4o, s5p);
    t2w = _mm_sub_pd(s6p, t6o);
    t3w = _mm_sub_pd(t4o, s5p);
    t4w = _mm_add_pd(t6o, s6p);
    t5w = _mm_add_pd(s3p, s7p);
    t6w = _mm_add_pd(s4p, s8p);
    t7w = _mm_sub_pd(s3p, s7p);
    t8w = _mm_sub_pd(s4p, s8p);
    t9w = _mm_add_pd(t1w, t5w);
    t0x = _mm_add_pd(t2w, t6w);
    t1x = _mm_sub_pd(t1w, t5w);
    t2x = _mm_sub_pd(t2w, t6w);
    t3x = _mm_add_pd(t3w, t8w);
    t4x = _mm_add_pd(t4w, t7w);
    t5x = _mm_sub_pd(t3w, t8w);
    t6x = _mm_sub_pd(t7w, t4w);
    s9p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3q), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t4q));
    s0q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t3q), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4q));
    s1q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5r), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6r));
    s2q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6r));
    s3q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9s), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t0t));
    s4q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t9s), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0t));
    t7x = _mm_add_pd(t9o, s1q);
    t8x = _mm_add_pd(t0p, s2q);
    t9x = _mm_sub_pd(t9o, s1q);
    t0y = _mm_sub_pd(t0p, s2q);
    t1y = _mm_add_pd(s9p, s3q);
    t2y = _mm_add_pd(s0q, s4q);
    t3y = _mm_sub_pd(s9p, s3q);
    t4y = _mm_sub_pd(s0q, s4q);
    t5y = _mm_add_pd(t7x, t1y);
    t6y = _mm_add_pd(t8x, t2y);
    t7y = _mm_sub_pd(t7x, t1y);
    t8y = _mm_sub_pd(t8x, t2y);
    t9y = _mm_add_pd(t9x, t4y);
    t0z = _mm_sub_pd(t0y, t3y);
    t1z = _mm_sub_pd(t9x, t4y);
    t2z = _mm_add_pd(t0y, t3y);
    t3z = _mm_add_pd(t7t, t9t);
    a63 = ((__m128d  *) dst);
    s5q = _mm_add_pd(v_neg03(v_hi2(t3z, t3z)), v_lo2(t3z, t3z));
    *(a63) = s5q;
    s6q = v_neg23(_mm_sub_pd(t7t, t9t));
    *((a63 + 512)) = s6q;
    s7q = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t3v), _mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t4v));
    s8q = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.098017140329560604), 0.0), t3v), _mm_mul_pd(_mm_set_pd(0.99518472667219693, 1.0), t4v));
    s9q = v_lo2(s7q, s8q);
    s0r = v_hi2(s7q, s8q);
    s1r = _mm_add_pd(s9q, s0r);
    *((a63 + 32)) = s1r;
    s2r = v_neg23(_mm_sub_pd(s9q, s0r));
    *((a63 + 992)) = s2r;
    s3r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t9w), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t0x));
    s4r = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t9w), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t0x));
    s5r = v_lo2(s3r, s4r);
    s6r = v_hi2(s3r, s4r);
    s7r = _mm_add_pd(s5r, s6r);
    *((a63 + 64)) = s7r;
    s8r = v_neg23(_mm_sub_pd(s5r, s6r));
    *((a63 + 960)) = s8r;
    s9r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t5y), _mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t6y));
    s0s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.29028467725446239), 0.0), t5y), _mm_mul_pd(_mm_set_pd(0.95694033573220882, 1.0), t6y));
    s1s = v_lo2(s9r, s0s);
    s2s = v_hi2(s9r, s0s);
    s3s = _mm_add_pd(s1s, s2s);
    *((a63 + 96)) = s3s;
    s4s = v_neg23(_mm_sub_pd(s1s, s2s));
    *((a63 + 928)) = s4s;
    s5s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t1u), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t2u));
    s6s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t1u), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t2u));
    s7s = v_lo2(s5s, s6s);
    s8s = v_hi2(s5s, s6s);
    s9s = _mm_add_pd(s7s, s8s);
    *((a63 + 128)) = s9s;
    s0t = v_neg23(_mm_sub_pd(s7s, s8s));
    *((a63 + 896)) = s0t;
    s1t = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t1z), _mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t2z));
    s2t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.47139673682599764), 0.0), t1z), _mm_mul_pd(_mm_set_pd(0.88192126434835505, 1.0), t2z));
    s3t = v_lo2(s1t, s2t);
    s4t = v_hi2(s1t, s2t);
    s5t = _mm_add_pd(s3t, s4t);
    *((a63 + 160)) = s5t;
    s6t = v_neg23(_mm_sub_pd(s3t, s4t));
    *((a63 + 864)) = s6t;
    s7t = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t5x), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6x));
    s8t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t5x), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6x));
    s9t = v_lo2(s7t, s8t);
    s0u = v_hi2(s7t, s8t);
    s1u = _mm_add_pd(s9t, s0u);
    *((a63 + 192)) = s1u;
    s2u = v_neg23(_mm_sub_pd(s9t, s0u));
    *((a63 + 832)) = s2u;
    s3u = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t9v), _mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t0w));
    s4u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.63439328416364549), 0.0), t9v), _mm_mul_pd(_mm_set_pd(0.77301045336273699, 1.0), t0w));
    s5u = v_lo2(s3u, s4u);
    s6u = v_hi2(s3u, s4u);
    s7u = _mm_add_pd(s5u, s6u);
    *((a63 + 224)) = s7u;
    s8u = v_neg23(_mm_sub_pd(s5u, s6u));
    *((a63 + 800)) = s8u;
    s9u = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t8t), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t0u));
    s0v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t8t), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t0u));
    s1v = v_lo2(s9u, s0v);
    s2v = v_hi2(s9u, s0v);
    s3v = _mm_add_pd(s1v, s2v);
    *((a63 + 256)) = s3v;
    s4v = v_neg23(_mm_sub_pd(s1v, s2v));
    *((a63 + 768)) = s4v;
    s5v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t7v), _mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t8v));
    s6v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.77301045336273699), 0.0), t7v), _mm_mul_pd(_mm_set_pd(0.63439328416364549, 1.0), t8v));
    s7v = v_lo2(s5v, s6v);
    s8v = v_hi2(s5v, s6v);
    s9v = _mm_add_pd(s7v, s8v);
    *((a63 + 288)) = s9v;
    s0w = v_neg23(_mm_sub_pd(s7v, s8v));
    *((a63 + 736)) = s0w;
    s1w = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t3x), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4x));
    s2w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t3x), _mm_mul_pd(_mm_set_pd(0.55557023301960218, 1.0), t4x));
    s3w = v_lo2(s1w, s2w);
    s4w = v_hi2(s1w, s2w);
    s5w = _mm_add_pd(s3w, s4w);
    *((a63 + 320)) = s5w;
    s6w = v_neg23(_mm_sub_pd(s3w, s4w));
    *((a63 + 704)) = s6w;
    s7w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t9y), _mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t0z));
    s8w = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.88192126434835505), 0.0), t9y), _mm_mul_pd(_mm_set_pd(0.47139673682599764, 1.0), t0z));
    s9w = v_lo2(s7w, s8w);
    s0x = v_hi2(s7w, s8w);
    s1x = _mm_add_pd(s9w, s0x);
    *((a63 + 352)) = s1x;
    s2x = v_neg23(_mm_sub_pd(s9w, s0x));
    *((a63 + 672)) = s2x;
    s3x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t3u), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t4u));
    s4x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t3u), _mm_mul_pd(_mm_set_pd(0.38268343236508978, 1.0), t4u));
    s5x = v_lo2(s3x, s4x);
    s6x = v_hi2(s3x, s4x);
    s7x = _mm_add_pd(s5x, s6x);
    *((a63 + 384)) = s7x;
    s8x = v_neg23(_mm_sub_pd(s5x, s6x));
    *((a63 + 640)) = s8x;
    s9x = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t7y), _mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t8y));
    s0y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.95694033573220882), 0.0), t7y), _mm_mul_pd(_mm_set_pd(0.29028467725446239, 1.0), t8y));
    s1y = v_lo2(s9x, s0y);
    s2y = v_hi2(s9x, s0y);
    s3y = _mm_add_pd(s1y, s2y);
    *((a63 + 416)) = s3y;
    s4y = v_neg23(_mm_sub_pd(s1y, s2y));
    *((a63 + 608)) = s4y;
    s5y = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t1x), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t2x));
    s6y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1x), _mm_mul_pd(_mm_set_pd(0.19509032201612828, 1.0), t2x));
    s7y = v_lo2(s5y, s6y);
    s8y = v_hi2(s5y, s6y);
    s9y = _mm_add_pd(s7y, s8y);
    *((a63 + 448)) = s9y;
    s0z = v_neg23(_mm_sub_pd(s7y, s8y));
    *((a63 + 576)) = s0z;
    s1z = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t5v), _mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t6v));
    s2z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.99518472667219693), 0.0), t5v), _mm_mul_pd(_mm_set_pd(0.098017140329560604, 1.0), t6v));
    s3z = v_lo2(s1z, s2z);
    s4z = v_hi2(s1z, s2z);
    s5z = _mm_add_pd(s3z, s4z);
    *((a63 + 480)) = s5z;
    s6z = v_neg23(_mm_sub_pd(s3z, s4z));
    *((a63 + 544)) = s6z;
    {long i2; for(i2 = 0; i2 <= 30; i2++) {
        a73 = (32 * i2);
        b = (((__m128d  *) T) + a73);
        s7z = *((b + 32));
        s8z = *((b + 48));
        s9z = *((b + 33));
        s0A = *((b + 49));
        s1A = *((b + 34));
        s2A = *((b + 50));
        s3A = *((b + 35));
        s4A = *((b + 51));
        s5A = *((b + 36));
        s6A = *((b + 52));
        s7A = *((b + 37));
        s8A = *((b + 53));
        s9A = *((b + 38));
        s0B = *((b + 54));
        s1B = *((b + 39));
        s2B = *((b + 55));
        s3B = *((b + 40));
        s4B = *((b + 56));
        s5B = *((b + 41));
        s6B = *((b + 57));
        s7B = *((b + 42));
        s8B = *((b + 58));
        s9B = *((b + 43));
        s0C = *((b + 59));
        s1C = *((b + 44));
        s2C = *((b + 60));
        s3C = *((b + 45));
        s4C = *((b + 61));
        s5C = *((b + 46));
        s6C = *((b + 62));
        s7C = *((b + 47));
        s8C = *((b + 63));
        a83 = (D48 + a73);
        a93 = *(a83);
        a04 = *((a83 + 1));
        s9C = _mm_sub_pd(_mm_mul_pd(a93, s7z), _mm_mul_pd(a04, s8z));
        s0D = _mm_add_pd(_mm_mul_pd(a04, s7z), _mm_mul_pd(a93, s8z));
        a14 = *((a83 + 2));
        a24 = *((a83 + 3));
        s1D = _mm_sub_pd(_mm_mul_pd(a14, s9z), _mm_mul_pd(a24, s0A));
        s2D = _mm_add_pd(_mm_mul_pd(a24, s9z), _mm_mul_pd(a14, s0A));
        a34 = *((a83 + 4));
        a44 = *((a83 + 5));
        s3D = _mm_sub_pd(_mm_mul_pd(a34, s1A), _mm_mul_pd(a44, s2A));
        s4D = _mm_add_pd(_mm_mul_pd(a44, s1A), _mm_mul_pd(a34, s2A));
        a54 = *((a83 + 6));
        a64 = *((a83 + 7));
        s5D = _mm_sub_pd(_mm_mul_pd(a54, s3A), _mm_mul_pd(a64, s4A));
        s6D = _mm_add_pd(_mm_mul_pd(a64, s3A), _mm_mul_pd(a54, s4A));
        a74 = *((a83 + 8));
        a84 = *((a83 + 9));
        s7D = _mm_sub_pd(_mm_mul_pd(a74, s5A), _mm_mul_pd(a84, s6A));
        s8D = _mm_add_pd(_mm_mul_pd(a84, s5A), _mm_mul_pd(a74, s6A));
        a94 = *((a83 + 10));
        a05 = *((a83 + 11));
        s9D = _mm_sub_pd(_mm_mul_pd(a94, s7A), _mm_mul_pd(a05, s8A));
        s0E = _mm_add_pd(_mm_mul_pd(a05, s7A), _mm_mul_pd(a94, s8A));
        a15 = *((a83 + 12));
        a25 = *((a83 + 13));
        s1E = _mm_sub_pd(_mm_mul_pd(a15, s9A), _mm_mul_pd(a25, s0B));
        s2E = _mm_add_pd(_mm_mul_pd(a25, s9A), _mm_mul_pd(a15, s0B));
        a35 = *((a83 + 14));
        a45 = *((a83 + 15));
        s3E = _mm_sub_pd(_mm_mul_pd(a35, s1B), _mm_mul_pd(a45, s2B));
        s4E = _mm_add_pd(_mm_mul_pd(a45, s1B), _mm_mul_pd(a35, s2B));
        a55 = *((a83 + 16));
        a65 = *((a83 + 17));
        s5E = _mm_sub_pd(_mm_mul_pd(a55, s3B), _mm_mul_pd(a65, s4B));
        s6E = _mm_add_pd(_mm_mul_pd(a65, s3B), _mm_mul_pd(a55, s4B));
        a75 = *((a83 + 18));
        a85 = *((a83 + 19));
        s7E = _mm_sub_pd(_mm_mul_pd(a75, s5B), _mm_mul_pd(a85, s6B));
        s8E = _mm_add_pd(_mm_mul_pd(a85, s5B), _mm_mul_pd(a75, s6B));
        a95 = *((a83 + 20));
        a06 = *((a83 + 21));
        s9E = _mm_sub_pd(_mm_mul_pd(a95, s7B), _mm_mul_pd(a06, s8B));
        s0F = _mm_add_pd(_mm_mul_pd(a06, s7B), _mm_mul_pd(a95, s8B));
        a16 = *((a83 + 22));
        a26 = *((a83 + 23));
        s1F = _mm_sub_pd(_mm_mul_pd(a16, s9B), _mm_mul_pd(a26, s0C));
        s2F = _mm_add_pd(_mm_mul_pd(a26, s9B), _mm_mul_pd(a16, s0C));
        a36 = *((a83 + 24));
        a46 = *((a83 + 25));
        s3F = _mm_sub_pd(_mm_mul_pd(a36, s1C), _mm_mul_pd(a46, s2C));
        s4F = _mm_add_pd(_mm_mul_pd(a46, s1C), _mm_mul_pd(a36, s2C));
        a56 = *((a83 + 26));
        a66 = *((a83 + 27));
        s5F = _mm_sub_pd(_mm_mul_pd(a56, s3C), _mm_mul_pd(a66, s4C));
        s6F = _mm_add_pd(_mm_mul_pd(a66, s3C), _mm_mul_pd(a56, s4C));
        a76 = *((a83 + 28));
        a86 = *((a83 + 29));
        s7F = _mm_sub_pd(_mm_mul_pd(a76, s5C), _mm_mul_pd(a86, s6C));
        s8F = _mm_add_pd(_mm_mul_pd(a86, s5C), _mm_mul_pd(a76, s6C));
        a96 = *((a83 + 30));
        a07 = *((a83 + 31));
        s9F = _mm_sub_pd(_mm_mul_pd(a96, s7C), _mm_mul_pd(a07, s8C));
        s0G = _mm_add_pd(_mm_mul_pd(a07, s7C), _mm_mul_pd(a96, s8C));
        t4z = _mm_add_pd(s9C, s5E);
        t5z = _mm_add_pd(s0D, s6E);
        t6z = _mm_sub_pd(s9C, s5E);
        t7z = _mm_sub_pd(s0D, s6E);
        t8z = _mm_add_pd(s1D, s7E);
        t9z = _mm_add_pd(s2D, s8E);
        t0A = _mm_sub_pd(s1D, s7E);
        t1A = _mm_sub_pd(s2D, s8E);
        s1G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0A), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1A));
        s2G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1A));
        t2A = _mm_add_pd(s3D, s9E);
        t3A = _mm_add_pd(s4D, s0F);
        a17 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3D, s9E));
        a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s4D, s0F));
        s3G = _mm_sub_pd(a17, a27);
        s4G = _mm_add_pd(a17, a27);
        t4A = _mm_add_pd(s5D, s1F);
        t5A = _mm_add_pd(s6D, s2F);
        t6A = _mm_sub_pd(s5D, s1F);
        t7A = _mm_sub_pd(s6D, s2F);
        s5G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6A), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7A));
        s6G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7A));
        t8A = _mm_add_pd(s7D, s3F);
        t9A = _mm_add_pd(s8D, s4F);
        t0B = _mm_sub_pd(s7D, s3F);
        t1B = _mm_sub_pd(s8D, s4F);
        t2B = _mm_add_pd(s9D, s5F);
        t3B = _mm_add_pd(s0E, s6F);
        t4B = _mm_sub_pd(s9D, s5F);
        t5B = _mm_sub_pd(s0E, s6F);
        s7G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4B), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5B));
        s8G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4B), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5B));
        t6B = _mm_add_pd(s1E, s7F);
        t7B = _mm_add_pd(s2E, s8F);
        a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s1E, s7F));
        a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2E, s8F));
        s9G = _mm_sub_pd(a37, a47);
        s0H = _mm_add_pd(a37, a47);
        t8B = _mm_add_pd(s3E, s9F);
        t9B = _mm_add_pd(s4E, s0G);
        t0C = _mm_sub_pd(s3E, s9F);
        t1C = _mm_sub_pd(s4E, s0G);
        s1H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0C), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1C));
        s2H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0C), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1C));
        t2C = _mm_add_pd(t4z, t8A);
        t3C = _mm_add_pd(t5z, t9A);
        t4C = _mm_sub_pd(t4z, t8A);
        t5C = _mm_sub_pd(t5z, t9A);
        t6C = _mm_add_pd(t2A, t6B);
        t7C = _mm_add_pd(t3A, t7B);
        t8C = _mm_sub_pd(t2A, t6B);
        t9C = _mm_sub_pd(t3A, t7B);
        t0D = _mm_add_pd(t2C, t6C);
        t1D = _mm_add_pd(t3C, t7C);
        t2D = _mm_sub_pd(t2C, t6C);
        t3D = _mm_sub_pd(t3C, t7C);
        t4D = _mm_add_pd(t4C, t9C);
        t5D = _mm_sub_pd(t5C, t8C);
        t6D = _mm_sub_pd(t4C, t9C);
        t7D = _mm_add_pd(t5C, t8C);
        t8D = _mm_add_pd(t8z, t2B);
        t9D = _mm_add_pd(t9z, t3B);
        t0E = _mm_sub_pd(t8z, t2B);
        t1E = _mm_sub_pd(t9z, t3B);
        t2E = _mm_add_pd(t4A, t8B);
        t3E = _mm_add_pd(t5A, t9B);
        t4E = _mm_sub_pd(t4A, t8B);
        t5E = _mm_sub_pd(t5A, t9B);
        t6E = _mm_add_pd(t8D, t2E);
        t7E = _mm_add_pd(t9D, t3E);
        t8E = _mm_sub_pd(t8D, t2E);
        t9E = _mm_sub_pd(t9D, t3E);
        a57 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0E, t5E));
        a67 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1E, t4E));
        s3H = _mm_sub_pd(a57, a67);
        s4H = _mm_add_pd(a57, a67);
        a77 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0E, t5E));
        a87 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1E, t4E));
        s5H = _mm_sub_pd(a77, a87);
        s6H = _mm_add_pd(a77, a87);
        t0F = _mm_add_pd(t0D, t6E);
        t1F = _mm_add_pd(t1D, t7E);
        t2F = _mm_sub_pd(t0D, t6E);
        t3F = _mm_sub_pd(t1D, t7E);
        t4F = _mm_add_pd(t4D, s3H);
        t5F = _mm_sub_pd(t5D, s4H);
        t6F = _mm_sub_pd(t4D, s3H);
        t7F = _mm_add_pd(t5D, s4H);
        t8F = _mm_add_pd(t2D, t9E);
        t9F = _mm_sub_pd(t3D, t8E);
        t0G = _mm_sub_pd(t2D, t9E);
        t1G = _mm_add_pd(t3D, t8E);
        t2G = _mm_add_pd(t6D, s5H);
        t3G = _mm_add_pd(t7D, s6H);
        t4G = _mm_sub_pd(t6D, s5H);
        t5G = _mm_sub_pd(t7D, s6H);
        t6G = _mm_add_pd(t6z, t1B);
        t7G = _mm_sub_pd(t7z, t0B);
        t8G = _mm_sub_pd(t6z, t1B);
        t9G = _mm_add_pd(t7z, t0B);
        t0H = _mm_add_pd(s3G, s9G);
        t1H = _mm_sub_pd(s0H, s4G);
        t2H = _mm_sub_pd(s3G, s9G);
        t3H = _mm_add_pd(s4G, s0H);
        t4H = _mm_add_pd(t6G, t0H);
        t5H = _mm_add_pd(t7G, t1H);
        t6H = _mm_sub_pd(t6G, t0H);
        t7H = _mm_sub_pd(t7G, t1H);
        t8H = _mm_sub_pd(t8G, t3H);
        t9H = _mm_sub_pd(t9G, t2H);
        t0I = _mm_add_pd(t8G, t3H);
        t1I = _mm_add_pd(t9G, t2H);
        t2I = _mm_add_pd(s1G, s7G);
        t3I = _mm_add_pd(s2G, s8G);
        t4I = _mm_sub_pd(s1G, s7G);
        t5I = _mm_sub_pd(s2G, s8G);
        t6I = _mm_add_pd(s5G, s1H);
        t7I = _mm_add_pd(s6G, s2H);
        t8I = _mm_sub_pd(s5G, s1H);
        t9I = _mm_sub_pd(s6G, s2H);
        t0J = _mm_add_pd(t2I, t6I);
        t1J = _mm_add_pd(t3I, t7I);
        t2J = _mm_sub_pd(t2I, t6I);
        t3J = _mm_sub_pd(t3I, t7I);
        a97 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4I, t9I));
        a08 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5I, t8I));
        s7H = _mm_sub_pd(a97, a08);
        s8H = _mm_add_pd(a97, a08);
        a18 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4I, t9I));
        a28 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5I, t8I));
        s9H = _mm_sub_pd(a18, a28);
        s0I = _mm_add_pd(a18, a28);
        t4J = _mm_add_pd(t4H, t0J);
        t5J = _mm_add_pd(t5H, t1J);
        t6J = _mm_sub_pd(t4H, t0J);
        t7J = _mm_sub_pd(t5H, t1J);
        t8J = _mm_add_pd(t8H, s7H);
        t9J = _mm_sub_pd(t9H, s8H);
        t0K = _mm_sub_pd(t8H, s7H);
        t1K = _mm_add_pd(t9H, s8H);
        t2K = _mm_add_pd(t6H, t3J);
        t3K = _mm_sub_pd(t7H, t2J);
        t4K = _mm_sub_pd(t6H, t3J);
        t5K = _mm_add_pd(t7H, t2J);
        t6K = _mm_add_pd(t0I, s9H);
        t7K = _mm_add_pd(t1I, s0I);
        t8K = _mm_sub_pd(t0I, s9H);
        t9K = _mm_sub_pd(t1I, s0I);
        a38 = (D46 + a73);
        a48 = *(a38);
        a58 = *((a38 + 1));
        s1I = _mm_sub_pd(_mm_mul_pd(a48, t0F), _mm_mul_pd(a58, t1F));
        s2I = _mm_add_pd(_mm_mul_pd(a58, t0F), _mm_mul_pd(a48, t1F));
        s3I = v_lo2(s1I, s2I);
        s4I = v_hi2(s1I, s2I);
        a68 = ((__m128d  *) dst);
        b2 = (a68 + i2);
        s5I = _mm_add_pd(s3I, s4I);
        *((b2 + 1)) = s5I;
        b3 = (a68 - i2);
        s6I = v_neg23(_mm_sub_pd(s3I, s4I));
        *((b3 + 1023)) = s6I;
        a78 = *((a38 + 2));
        a88 = *((a38 + 3));
        s7I = _mm_sub_pd(_mm_mul_pd(a78, t4J), _mm_mul_pd(a88, t5J));
        s8I = _mm_add_pd(_mm_mul_pd(a88, t4J), _mm_mul_pd(a78, t5J));
        s9I = v_lo2(s7I, s8I);
        s0J = v_hi2(s7I, s8I);
        s1J = _mm_add_pd(s9I, s0J);
        *((b2 + 65)) = s1J;
        s2J = v_neg23(_mm_sub_pd(s9I, s0J));
        *((b3 + 959)) = s2J;
        a98 = *((a38 + 4));
        a09 = *((a38 + 5));
        s3J = _mm_sub_pd(_mm_mul_pd(a98, t4F), _mm_mul_pd(a09, t5F));
        s4J = _mm_add_pd(_mm_mul_pd(a09, t4F), _mm_mul_pd(a98, t5F));
        s5J = v_lo2(s3J, s4J);
        s6J = v_hi2(s3J, s4J);
        s7J = _mm_add_pd(s5J, s6J);
        *((b2 + 129)) = s7J;
        s8J = v_neg23(_mm_sub_pd(s5J, s6J));
        *((b3 + 895)) = s8J;
        a19 = *((a38 + 6));
        a29 = *((a38 + 7));
        s9J = _mm_sub_pd(_mm_mul_pd(a19, t8J), _mm_mul_pd(a29, t9J));
        s0K = _mm_add_pd(_mm_mul_pd(a29, t8J), _mm_mul_pd(a19, t9J));
        s1K = v_lo2(s9J, s0K);
        s2K = v_hi2(s9J, s0K);
        s3K = _mm_add_pd(s1K, s2K);
        *((b2 + 193)) = s3K;
        s4K = v_neg23(_mm_sub_pd(s1K, s2K));
        *((b3 + 831)) = s4K;
        a39 = *((a38 + 8));
        a49 = *((a38 + 9));
        s5K = _mm_sub_pd(_mm_mul_pd(a39, t8F), _mm_mul_pd(a49, t9F));
        s6K = _mm_add_pd(_mm_mul_pd(a49, t8F), _mm_mul_pd(a39, t9F));
        s7K = v_lo2(s5K, s6K);
        s8K = v_hi2(s5K, s6K);
        s9K = _mm_add_pd(s7K, s8K);
        *((b2 + 257)) = s9K;
        s0L = v_neg23(_mm_sub_pd(s7K, s8K));
        *((b3 + 767)) = s0L;
        a59 = *((a38 + 10));
        a69 = *((a38 + 11));
        s1L = _mm_sub_pd(_mm_mul_pd(a59, t2K), _mm_mul_pd(a69, t3K));
        s2L = _mm_add_pd(_mm_mul_pd(a69, t2K), _mm_mul_pd(a59, t3K));
        s3L = v_lo2(s1L, s2L);
        s4L = v_hi2(s1L, s2L);
        s5L = _mm_add_pd(s3L, s4L);
        *((b2 + 321)) = s5L;
        s6L = v_neg23(_mm_sub_pd(s3L, s4L));
        *((b3 + 703)) = s6L;
        a79 = *((a38 + 12));
        a89 = *((a38 + 13));
        s7L = _mm_sub_pd(_mm_mul_pd(a79, t2G), _mm_mul_pd(a89, t3G));
        s8L = _mm_add_pd(_mm_mul_pd(a89, t2G), _mm_mul_pd(a79, t3G));
        s9L = v_lo2(s7L, s8L);
        s0M = v_hi2(s7L, s8L);
        s1M = _mm_add_pd(s9L, s0M);
        *((b2 + 385)) = s1M;
        s2M = v_neg23(_mm_sub_pd(s9L, s0M));
        *((b3 + 639)) = s2M;
        a99 = *((a38 + 14));
        a0a = *((a38 + 15));
        s3M = _mm_sub_pd(_mm_mul_pd(a99, t6K), _mm_mul_pd(a0a, t7K));
        s4M = _mm_add_pd(_mm_mul_pd(a0a, t6K), _mm_mul_pd(a99, t7K));
        s5M = v_lo2(s3M, s4M);
        s6M = v_hi2(s3M, s4M);
        s7M = _mm_add_pd(s5M, s6M);
        *((b2 + 449)) = s7M;
        s8M = v_neg23(_mm_sub_pd(s5M, s6M));
        *((b3 + 575)) = s8M;
        a1a = *((a38 + 16));
        a2a = *((a38 + 17));
        s9M = _mm_sub_pd(_mm_mul_pd(a1a, t2F), _mm_mul_pd(a2a, t3F));
        s0N = _mm_add_pd(_mm_mul_pd(a2a, t2F), _mm_mul_pd(a1a, t3F));
        s1N = v_lo2(s9M, s0N);
        s2N = v_hi2(s9M, s0N);
        s3N = _mm_add_pd(s1N, s2N);
        *((b2 + 513)) = s3N;
        s4N = v_neg23(_mm_sub_pd(s1N, s2N));
        *((b3 + 511)) = s4N;
        a3a = *((a38 + 18));
        a4a = *((a38 + 19));
        s5N = _mm_sub_pd(_mm_mul_pd(a3a, t6J), _mm_mul_pd(a4a, t7J));
        s6N = _mm_add_pd(_mm_mul_pd(a4a, t6J), _mm_mul_pd(a3a, t7J));
        s7N = v_lo2(s5N, s6N);
        s8N = v_hi2(s5N, s6N);
        s9N = _mm_add_pd(s7N, s8N);
        *((b2 + 577)) = s9N;
        s0O = v_neg23(_mm_sub_pd(s7N, s8N));
        *((b3 + 447)) = s0O;
        a5a = *((a38 + 20));
        a6a = *((a38 + 21));
        s1O = _mm_sub_pd(_mm_mul_pd(a5a, t6F), _mm_mul_pd(a6a, t7F));
        s2O = _mm_add_pd(_mm_mul_pd(a6a, t6F), _mm_mul_pd(a5a, t7F));
        s3O = v_lo2(s1O, s2O);
        s4O = v_hi2(s1O, s2O);
        s5O = _mm_add_pd(s3O, s4O);
        *((b2 + 641)) = s5O;
        s6O = v_neg23(_mm_sub_pd(s3O, s4O));
        *((b3 + 383)) = s6O;
        a7a = *((a38 + 22));
        a8a = *((a38 + 23));
        s7O = _mm_sub_pd(_mm_mul_pd(a7a, t0K), _mm_mul_pd(a8a, t1K));
        s8O = _mm_add_pd(_mm_mul_pd(a8a, t0K), _mm_mul_pd(a7a, t1K));
        s9O = v_lo2(s7O, s8O);
        s0P = v_hi2(s7O, s8O);
        s1P = _mm_add_pd(s9O, s0P);
        *((b2 + 705)) = s1P;
        s2P = v_neg23(_mm_sub_pd(s9O, s0P));
        *((b3 + 319)) = s2P;
        a9a = *((a38 + 24));
        a0b = *((a38 + 25));
        s3P = _mm_sub_pd(_mm_mul_pd(a9a, t0G), _mm_mul_pd(a0b, t1G));
        s4P = _mm_add_pd(_mm_mul_pd(a0b, t0G), _mm_mul_pd(a9a, t1G));
        s5P = v_lo2(s3P, s4P);
        s6P = v_hi2(s3P, s4P);
        s7P = _mm_add_pd(s5P, s6P);
        *((b2 + 769)) = s7P;
        s8P = v_neg23(_mm_sub_pd(s5P, s6P));
        *((b3 + 255)) = s8P;
        a1b = *((a38 + 26));
        a2b = *((a38 + 27));
        s9P = _mm_sub_pd(_mm_mul_pd(a1b, t4K), _mm_mul_pd(a2b, t5K));
        s0Q = _mm_add_pd(_mm_mul_pd(a2b, t4K), _mm_mul_pd(a1b, t5K));
        s1Q = v_lo2(s9P, s0Q);
        s2Q = v_hi2(s9P, s0Q);
        s3Q = _mm_add_pd(s1Q, s2Q);
        *((b2 + 833)) = s3Q;
        s4Q = v_neg23(_mm_sub_pd(s1Q, s2Q));
        *((b3 + 191)) = s4Q;
        a3b = *((a38 + 28));
        a4b = *((a38 + 29));
        s5Q = _mm_sub_pd(_mm_mul_pd(a3b, t4G), _mm_mul_pd(a4b, t5G));
        s6Q = _mm_add_pd(_mm_mul_pd(a4b, t4G), _mm_mul_pd(a3b, t5G));
        s7Q = v_lo2(s5Q, s6Q);
        s8Q = v_hi2(s5Q, s6Q);
        s9Q = _mm_add_pd(s7Q, s8Q);
        *((b2 + 897)) = s9Q;
        s0R = v_neg23(_mm_sub_pd(s7Q, s8Q));
        *((b3 + 127)) = s0R;
        a5b = *((a38 + 30));
        a6b = *((a38 + 31));
        s1R = _mm_sub_pd(_mm_mul_pd(a5b, t8K), _mm_mul_pd(a6b, t9K));
        s2R = _mm_add_pd(_mm_mul_pd(a6b, t8K), _mm_mul_pd(a5b, t9K));
        s3R = v_lo2(s1R, s2R);
        s4R = v_hi2(s1R, s2R);
        s5R = _mm_add_pd(s3R, s4R);
        *((b2 + 961)) = s5R;
        s6R = v_neg23(_mm_sub_pd(s3R, s4R));
        *((b3 + 63)) = s6R;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_4096_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[4096]);
     SPIRAL_ALIGNED(double T2[512]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a0a, a0b, a11, a13, a14, a15, a16, a17, a19, a1a, a1b, a21, a23, a24
            , a25, a26, a27, a28, a29, a2a, a2b, a3, a31, a32, a33, a34, a35, a37, a38, a3a, a3b, a4, a41, a42, a43, a44
            , a45, a46, a47, a48, a49, a4a, a4b, a5, a51, a52, a53, a54, a55, a56, a58, a59, a5a, a5b, a6, a62, a63, a64
            , a65, a66, a68, a69, a6a, a71, a72, a73, a74, a75, a76, a77, a78, a79, a7a, a8, a81, a82, a83, a84, a85, a87
            , a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01, s02, s03, s04, s05, s06, s07
            , s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n
            , s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A
            , s1B, s1C, s1D, s1E, s1F, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s
            , s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E
            , s3F, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u
            , s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w
            , s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5a, s5b, s5c, s5d
            , s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z
            , s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6a, s6b, s6c, s6d, s6e, s6f, s6g
            , s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y, s6z, s7, s71, s72
            , s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85
            , s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p
            , s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b
            , t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t11, t12, t13, t14, t15
            , t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r
            , t1s, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k
            , t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d
            , t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t4, t41, t42, t43, t44, t45, t46
            , t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s
            , t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l
            , t5m, t5n, t5o, t5p, t5q, t5r, t5s, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e
            , t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t7, t71, t72, t73, t74, t75, t76, t77
            , t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t8
            , t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m
            , t8n, t8o, t8p, t8q, t8r, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g
            , t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r;
    __m128d  *a09, *a18, *a2, *a22, *a61, *a67, *a7, *a86, *b, *b2, *b3, *b4, *b5;
    double  *b6, *b7;
    const double  *a;
    int a12, a36, a39, a57;
    {long i; for(i = 0; i <= 7; i++) {
        {long i2; for(i2 = 0; i2 <= 15; i2++) {
            a = (src + ((2 * i) + (16 * i2)));
            s = _mm_loadu_pd(((const double  *) a));
            s2 = _mm_loadu_pd(((const double  *) (a + 2048)));
            t = _mm_add_pd(s, s2);
            t2 = _mm_sub_pd(s, s2);
            s3 = _mm_loadu_pd(((const double  *) (a + 1024)));
            s4 = _mm_loadu_pd(((const double  *) (a + 3072)));
            t3 = _mm_add_pd(s3, s4);
            t4 = _mm_sub_pd(s3, s4);
            s5 = _mm_loadu_pd(((const double  *) (a + 256)));
            s6 = _mm_loadu_pd(((const double  *) (a + 2304)));
            t5 = _mm_add_pd(s5, s6);
            t6 = _mm_sub_pd(s5, s6);
            s7 = _mm_loadu_pd(((const double  *) (a + 1280)));
            s8 = _mm_loadu_pd(((const double  *) (a + 3328)));
            t7 = _mm_add_pd(s7, s8);
            t8 = _mm_sub_pd(s7, s8);
            s9 = _mm_loadu_pd(((const double  *) (a + 512)));
            s01 = _mm_loadu_pd(((const double  *) (a + 2560)));
            t9 = _mm_add_pd(s9, s01);
            s11 = _mm_loadu_pd(((const double  *) (a + 1536)));
            s21 = _mm_loadu_pd(((const double  *) (a + 3584)));
            t01 = _mm_add_pd(s11, s21);
            s31 = _mm_loadu_pd(((const double  *) (a + 768)));
            s41 = _mm_loadu_pd(((const double  *) (a + 2816)));
            t11 = _mm_add_pd(s31, s41);
            t21 = _mm_sub_pd(s31, s41);
            s51 = _mm_loadu_pd(((const double  *) (a + 1792)));
            s61 = _mm_loadu_pd(((const double  *) (a + 3840)));
            t31 = _mm_add_pd(s51, s61);
            t41 = _mm_sub_pd(s51, s61);
            t51 = _mm_add_pd(t, t3);
            t61 = _mm_sub_pd(t, t3);
            t71 = _mm_add_pd(t9, t01);
            t81 = _mm_sub_pd(t9, t01);
            t91 = _mm_add_pd(t5, t7);
            t02 = _mm_add_pd(t11, t31);
            a2 = (((__m128d  *) T2) + i2);
            s71 = _mm_add_pd(t51, t71);
            *(a2) = s71;
            s81 = _mm_sub_pd(t51, t71);
            *((a2 + 128)) = s81;
            s91 = _mm_add_pd(t91, t02);
            *((a2 + 16)) = s91;
            s02 = _mm_sub_pd(t02, t91);
            *((a2 + 144)) = s02;
            a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
            a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
            s12 = _mm_add_pd(a3, a4);
            s22 = _mm_sub_pd(a4, a3);
            s32 = _mm_add_pd(t61, s12);
            *((a2 + 64)) = s32;
            s42 = _mm_sub_pd(s22, t81);
            *((a2 + 80)) = s42;
            s52 = _mm_sub_pd(t61, s12);
            *((a2 + 192)) = s52;
            s62 = _mm_add_pd(t81, s22);
            *((a2 + 208)) = s62;
            s72 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
            s82 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
            a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
            a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
            s92 = _mm_add_pd(a5, a6);
            s03 = _mm_sub_pd(a6, a5);
            s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
            s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
            t12 = _mm_add_pd(t2, s92);
            t22 = _mm_sub_pd(s03, t4);
            t32 = _mm_sub_pd(t2, s92);
            t42 = _mm_add_pd(t4, s03);
            t52 = _mm_add_pd(s72, s13);
            t62 = _mm_add_pd(s82, s23);
            t72 = _mm_sub_pd(s72, s13);
            t82 = _mm_sub_pd(s82, s23);
            s33 = _mm_add_pd(t12, t52);
            *((a2 + 32)) = s33;
            s43 = _mm_add_pd(t22, t62);
            *((a2 + 48)) = s43;
            s53 = _mm_sub_pd(t12, t52);
            *((a2 + 224)) = s53;
            s63 = _mm_sub_pd(t62, t22);
            *((a2 + 240)) = s63;
            s73 = _mm_add_pd(t32, t82);
            *((a2 + 160)) = s73;
            s83 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t42, t72));
            *((a2 + 176)) = s83;
            s93 = _mm_sub_pd(t32, t82);
            *((a2 + 96)) = s93;
            s04 = _mm_sub_pd(t42, t72);
            *((a2 + 112)) = s04;
        }}
        a7 = ((__m128d  *) T2);
        s14 = *(a7);
        s24 = *((a7 + 16));
        t92 = _mm_add_pd(s14, s24);
        t03 = _mm_sub_pd(s14, s24);
        s34 = *((a7 + 8));
        s44 = *((a7 + 24));
        t13 = _mm_add_pd(s34, s44);
        t23 = _mm_sub_pd(s34, s44);
        s54 = *((a7 + 4));
        s64 = *((a7 + 20));
        t33 = _mm_add_pd(s54, s64);
        s74 = *((a7 + 12));
        s84 = *((a7 + 28));
        t43 = _mm_add_pd(s74, s84);
        t53 = _mm_add_pd(t92, t13);
        t63 = _mm_sub_pd(t92, t13);
        t73 = _mm_add_pd(t33, t43);
        t83 = _mm_sub_pd(t33, t43);
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s54, s64));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s74, s84));
        s94 = _mm_add_pd(a8, a9);
        s05 = _mm_sub_pd(a9, a8);
        t93 = _mm_add_pd(t03, s94);
        t04 = _mm_sub_pd(s05, t23);
        t14 = _mm_sub_pd(t03, s94);
        t24 = _mm_add_pd(t23, s05);
        s15 = *((a7 + 1));
        s25 = *((a7 + 17));
        t34 = _mm_add_pd(s15, s25);
        t44 = _mm_sub_pd(s15, s25);
        s35 = *((a7 + 9));
        s45 = *((a7 + 25));
        t54 = _mm_add_pd(s35, s45);
        t64 = _mm_sub_pd(s35, s45);
        s55 = *((a7 + 5));
        s65 = *((a7 + 21));
        t74 = _mm_add_pd(s55, s65);
        s75 = *((a7 + 13));
        s85 = *((a7 + 29));
        t84 = _mm_add_pd(s75, s85);
        t94 = _mm_add_pd(t34, t54);
        t05 = _mm_sub_pd(t34, t54);
        t15 = _mm_add_pd(t74, t84);
        t25 = _mm_sub_pd(t74, t84);
        a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s55, s65));
        a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s75, s85));
        s95 = _mm_add_pd(a01, a11);
        s06 = _mm_sub_pd(a11, a01);
        t35 = _mm_add_pd(t44, s95);
        t45 = _mm_sub_pd(s06, t64);
        t55 = _mm_sub_pd(t44, s95);
        t65 = _mm_add_pd(t64, s06);
        s16 = *((a7 + 2));
        s26 = *((a7 + 18));
        t75 = _mm_add_pd(s16, s26);
        t85 = _mm_sub_pd(s16, s26);
        s36 = *((a7 + 10));
        s46 = *((a7 + 26));
        t95 = _mm_add_pd(s36, s46);
        t06 = _mm_sub_pd(s36, s46);
        s56 = *((a7 + 6));
        s66 = *((a7 + 22));
        t16 = _mm_add_pd(s56, s66);
        s76 = *((a7 + 14));
        s86 = *((a7 + 30));
        t26 = _mm_add_pd(s76, s86);
        t36 = _mm_add_pd(t75, t95);
        t46 = _mm_add_pd(t16, t26);
        a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s56, s66));
        a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s76, s86));
        s96 = _mm_add_pd(a21, a31);
        s07 = _mm_sub_pd(a31, a21);
        t56 = _mm_add_pd(t85, s96);
        t66 = _mm_sub_pd(s07, t06);
        t76 = _mm_sub_pd(t85, s96);
        t86 = _mm_add_pd(t06, s07);
        s17 = *((a7 + 3));
        s27 = *((a7 + 19));
        t96 = _mm_add_pd(s17, s27);
        t07 = _mm_sub_pd(s17, s27);
        s37 = *((a7 + 11));
        s47 = *((a7 + 27));
        t17 = _mm_add_pd(s37, s47);
        t27 = _mm_sub_pd(s37, s47);
        s57 = *((a7 + 7));
        s67 = *((a7 + 23));
        t37 = _mm_add_pd(s57, s67);
        s77 = *((a7 + 15));
        s87 = *((a7 + 31));
        t47 = _mm_add_pd(s77, s87);
        t57 = _mm_add_pd(t96, t17);
        t67 = _mm_sub_pd(t96, t17);
        t77 = _mm_add_pd(t37, t47);
        t87 = _mm_sub_pd(t37, t47);
        a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s57, s67));
        a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s77, s87));
        s97 = _mm_add_pd(a41, a51);
        s08 = _mm_sub_pd(a51, a41);
        t97 = _mm_add_pd(t07, s97);
        t08 = _mm_sub_pd(s08, t27);
        t18 = _mm_sub_pd(t07, s97);
        t28 = _mm_add_pd(t27, s08);
        t38 = _mm_add_pd(t53, t73);
        t48 = _mm_sub_pd(t53, t73);
        t58 = _mm_add_pd(t36, t46);
        t68 = _mm_sub_pd(t36, t46);
        t78 = _mm_add_pd(t94, t15);
        t88 = _mm_add_pd(t57, t77);
        a61 = (((__m128d  *) T) + i);
        s18 = _mm_add_pd(t38, t58);
        *(a61) = s18;
        s28 = _mm_sub_pd(t38, t58);
        *((a61 + 1024)) = s28;
        s38 = _mm_add_pd(t78, t88);
        *((a61 + 8)) = s38;
        s48 = _mm_sub_pd(t88, t78);
        *((a61 + 1032)) = s48;
        a71 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
        a81 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t57, t77));
        s58 = _mm_add_pd(a71, a81);
        s68 = _mm_sub_pd(a81, a71);
        s78 = _mm_add_pd(t48, s58);
        *((a61 + 512)) = s78;
        s88 = _mm_sub_pd(s68, t68);
        *((a61 + 520)) = s88;
        s98 = _mm_sub_pd(t48, s58);
        *((a61 + 1536)) = s98;
        s09 = _mm_add_pd(t68, s68);
        *((a61 + 1544)) = s09;
        s19 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
        s29 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t45));
        s39 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t56), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66));
        s49 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t56), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66));
        s59 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t97), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t08));
        s69 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t97), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t08));
        t98 = _mm_add_pd(t93, s39);
        t09 = _mm_add_pd(t04, s49);
        t19 = _mm_sub_pd(t93, s39);
        t29 = _mm_sub_pd(t04, s49);
        t39 = _mm_add_pd(s19, s59);
        t49 = _mm_add_pd(s29, s69);
        t59 = _mm_sub_pd(s19, s59);
        t69 = _mm_sub_pd(s29, s69);
        s79 = _mm_add_pd(t98, t39);
        *((a61 + 128)) = s79;
        s89 = _mm_add_pd(t09, t49);
        *((a61 + 136)) = s89;
        s99 = _mm_sub_pd(t98, t39);
        *((a61 + 1920)) = s99;
        s0a = _mm_sub_pd(t49, t09);
        *((a61 + 1928)) = s0a;
        s1a = _mm_add_pd(t19, t69);
        *((a61 + 1152)) = s1a;
        s2a = _mm_sub_pd(t29, t59);
        *((a61 + 1160)) = s2a;
        s3a = _mm_sub_pd(t19, t69);
        *((a61 + 896)) = s3a;
        s4a = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t29, t59));
        *((a61 + 904)) = s4a;
        s5a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
        s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
        a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t75, t95));
        a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t16, t26));
        s7a = _mm_add_pd(a91, a02);
        s8a = _mm_sub_pd(a02, a91);
        s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t87));
        s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t67), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
        t79 = _mm_add_pd(t63, s7a);
        t89 = _mm_sub_pd(s8a, t83);
        t99 = _mm_sub_pd(t63, s7a);
        t0a = _mm_add_pd(t83, s8a);
        t1a = _mm_add_pd(s5a, s9a);
        t2a = _mm_add_pd(s6a, s0b);
        t3a = _mm_sub_pd(s5a, s9a);
        t4a = _mm_sub_pd(s6a, s0b);
        s1b = _mm_add_pd(t79, t1a);
        *((a61 + 256)) = s1b;
        s2b = _mm_add_pd(t89, t2a);
        *((a61 + 264)) = s2b;
        s3b = _mm_sub_pd(t79, t1a);
        *((a61 + 1792)) = s3b;
        s4b = _mm_sub_pd(t2a, t89);
        *((a61 + 1800)) = s4b;
        s5b = _mm_add_pd(t99, t4a);
        *((a61 + 1280)) = s5b;
        s6b = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0a, t3a));
        *((a61 + 1288)) = s6b;
        s7b = _mm_sub_pd(t99, t4a);
        *((a61 + 768)) = s7b;
        s8b = _mm_sub_pd(t0a, t3a);
        *((a61 + 776)) = s8b;
        s9b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t55), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t65));
        s0c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t55), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t65));
        s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t76), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t86));
        s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t76), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t86));
        s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t18), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t28));
        s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t18), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t28));
        t5a = _mm_add_pd(t14, s1c);
        t6a = _mm_add_pd(t24, s2c);
        t7a = _mm_sub_pd(t14, s1c);
        t8a = _mm_sub_pd(t24, s2c);
        t9a = _mm_add_pd(s9b, s3c);
        t0b = _mm_add_pd(s0c, s4c);
        t1b = _mm_sub_pd(s9b, s3c);
        t2b = _mm_sub_pd(s0c, s4c);
        s5c = _mm_add_pd(t5a, t9a);
        *((a61 + 384)) = s5c;
        s6c = _mm_add_pd(t6a, t0b);
        *((a61 + 392)) = s6c;
        s7c = _mm_sub_pd(t5a, t9a);
        *((a61 + 1664)) = s7c;
        s8c = _mm_sub_pd(t0b, t6a);
        *((a61 + 1672)) = s8c;
        s9c = _mm_add_pd(t7a, t2b);
        *((a61 + 1408)) = s9c;
        s0d = _mm_sub_pd(t8a, t1b);
        *((a61 + 1416)) = s0d;
        s1d = _mm_sub_pd(t7a, t2b);
        *((a61 + 640)) = s1d;
        s2d = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8a, t1b));
        *((a61 + 648)) = s2d;
        {long i3; for(i3 = 0; i3 <= 6; i3++) {
            a12 = (32 * i3);
            b = (((__m128d  *) T2) + a12);
            s3d = *((b + 32));
            s4d = *((b + 48));
            s5d = *((b + 33));
            s6d = *((b + 49));
            s7d = *((b + 34));
            s8d = *((b + 50));
            s9d = *((b + 35));
            s0e = *((b + 51));
            s1e = *((b + 36));
            s2e = *((b + 52));
            s3e = *((b + 37));
            s4e = *((b + 53));
            s5e = *((b + 38));
            s6e = *((b + 54));
            s7e = *((b + 39));
            s8e = *((b + 55));
            s9e = *((b + 40));
            s0f = *((b + 56));
            s1f = *((b + 41));
            s2f = *((b + 57));
            s3f = *((b + 42));
            s4f = *((b + 58));
            s5f = *((b + 43));
            s6f = *((b + 59));
            s7f = *((b + 44));
            s8f = *((b + 60));
            s9f = *((b + 45));
            s0g = *((b + 61));
            s1g = *((b + 46));
            s2g = *((b + 62));
            s3g = *((b + 47));
            s4g = *((b + 63));
            a22 = (D52 + a12);
            a32 = *(a22);
            a42 = *((a22 + 1));
            s5g = _mm_sub_pd(_mm_mul_pd(a32, s3d), _mm_mul_pd(a42, s4d));
            s6g = _mm_add_pd(_mm_mul_pd(a42, s3d), _mm_mul_pd(a32, s4d));
            a52 = *((a22 + 2));
            a62 = *((a22 + 3));
            s7g = _mm_sub_pd(_mm_mul_pd(a52, s5d), _mm_mul_pd(a62, s6d));
            s8g = _mm_add_pd(_mm_mul_pd(a62, s5d), _mm_mul_pd(a52, s6d));
            a72 = *((a22 + 4));
            a82 = *((a22 + 5));
            s9g = _mm_sub_pd(_mm_mul_pd(a72, s7d), _mm_mul_pd(a82, s8d));
            s0h = _mm_add_pd(_mm_mul_pd(a82, s7d), _mm_mul_pd(a72, s8d));
            a92 = *((a22 + 6));
            a03 = *((a22 + 7));
            s1h = _mm_sub_pd(_mm_mul_pd(a92, s9d), _mm_mul_pd(a03, s0e));
            s2h = _mm_add_pd(_mm_mul_pd(a03, s9d), _mm_mul_pd(a92, s0e));
            a13 = *((a22 + 8));
            a23 = *((a22 + 9));
            s3h = _mm_sub_pd(_mm_mul_pd(a13, s1e), _mm_mul_pd(a23, s2e));
            s4h = _mm_add_pd(_mm_mul_pd(a23, s1e), _mm_mul_pd(a13, s2e));
            a33 = *((a22 + 10));
            a43 = *((a22 + 11));
            s5h = _mm_sub_pd(_mm_mul_pd(a33, s3e), _mm_mul_pd(a43, s4e));
            s6h = _mm_add_pd(_mm_mul_pd(a43, s3e), _mm_mul_pd(a33, s4e));
            a53 = *((a22 + 12));
            a63 = *((a22 + 13));
            s7h = _mm_sub_pd(_mm_mul_pd(a53, s5e), _mm_mul_pd(a63, s6e));
            s8h = _mm_add_pd(_mm_mul_pd(a63, s5e), _mm_mul_pd(a53, s6e));
            a73 = *((a22 + 14));
            a83 = *((a22 + 15));
            s9h = _mm_sub_pd(_mm_mul_pd(a73, s7e), _mm_mul_pd(a83, s8e));
            s0i = _mm_add_pd(_mm_mul_pd(a83, s7e), _mm_mul_pd(a73, s8e));
            a93 = *((a22 + 16));
            a04 = *((a22 + 17));
            s1i = _mm_sub_pd(_mm_mul_pd(a93, s9e), _mm_mul_pd(a04, s0f));
            s2i = _mm_add_pd(_mm_mul_pd(a04, s9e), _mm_mul_pd(a93, s0f));
            a14 = *((a22 + 18));
            a24 = *((a22 + 19));
            s3i = _mm_sub_pd(_mm_mul_pd(a14, s1f), _mm_mul_pd(a24, s2f));
            s4i = _mm_add_pd(_mm_mul_pd(a24, s1f), _mm_mul_pd(a14, s2f));
            a34 = *((a22 + 20));
            a44 = *((a22 + 21));
            s5i = _mm_sub_pd(_mm_mul_pd(a34, s3f), _mm_mul_pd(a44, s4f));
            s6i = _mm_add_pd(_mm_mul_pd(a44, s3f), _mm_mul_pd(a34, s4f));
            a54 = *((a22 + 22));
            a64 = *((a22 + 23));
            s7i = _mm_sub_pd(_mm_mul_pd(a54, s5f), _mm_mul_pd(a64, s6f));
            s8i = _mm_add_pd(_mm_mul_pd(a64, s5f), _mm_mul_pd(a54, s6f));
            a74 = *((a22 + 24));
            a84 = *((a22 + 25));
            s9i = _mm_sub_pd(_mm_mul_pd(a74, s7f), _mm_mul_pd(a84, s8f));
            s0j = _mm_add_pd(_mm_mul_pd(a84, s7f), _mm_mul_pd(a74, s8f));
            a94 = *((a22 + 26));
            a05 = *((a22 + 27));
            s1j = _mm_sub_pd(_mm_mul_pd(a94, s9f), _mm_mul_pd(a05, s0g));
            s2j = _mm_add_pd(_mm_mul_pd(a05, s9f), _mm_mul_pd(a94, s0g));
            a15 = *((a22 + 28));
            a25 = *((a22 + 29));
            s3j = _mm_sub_pd(_mm_mul_pd(a15, s1g), _mm_mul_pd(a25, s2g));
            s4j = _mm_add_pd(_mm_mul_pd(a25, s1g), _mm_mul_pd(a15, s2g));
            a35 = *((a22 + 30));
            a45 = *((a22 + 31));
            s5j = _mm_sub_pd(_mm_mul_pd(a35, s3g), _mm_mul_pd(a45, s4g));
            s6j = _mm_add_pd(_mm_mul_pd(a45, s3g), _mm_mul_pd(a35, s4g));
            t3b = _mm_add_pd(s5g, s1i);
            t4b = _mm_add_pd(s6g, s2i);
            t5b = _mm_sub_pd(s5g, s1i);
            t6b = _mm_sub_pd(s6g, s2i);
            t7b = _mm_add_pd(s7g, s3i);
            t8b = _mm_add_pd(s8g, s4i);
            t9b = _mm_sub_pd(s7g, s3i);
            t0c = _mm_sub_pd(s8g, s4i);
            s7j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0c));
            s8j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0c));
            t1c = _mm_add_pd(s9g, s5i);
            t2c = _mm_add_pd(s0h, s6i);
            a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9g, s5i));
            a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0h, s6i));
            s9j = _mm_sub_pd(a55, a65);
            s0k = _mm_add_pd(a55, a65);
            t3c = _mm_add_pd(s1h, s7i);
            t4c = _mm_add_pd(s2h, s8i);
            t5c = _mm_sub_pd(s1h, s7i);
            t6c = _mm_sub_pd(s2h, s8i);
            s1k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6c));
            s2k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6c));
            t7c = _mm_add_pd(s3h, s9i);
            t8c = _mm_add_pd(s4h, s0j);
            t9c = _mm_sub_pd(s3h, s9i);
            t0d = _mm_sub_pd(s4h, s0j);
            t1d = _mm_add_pd(s5h, s1j);
            t2d = _mm_add_pd(s6h, s2j);
            t3d = _mm_sub_pd(s5h, s1j);
            t4d = _mm_sub_pd(s6h, s2j);
            s3k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
            s4k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4d));
            t5d = _mm_add_pd(s7h, s3j);
            t6d = _mm_add_pd(s8h, s4j);
            a75 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7h, s3j));
            a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8h, s4j));
            s5k = _mm_sub_pd(a75, a85);
            s6k = _mm_add_pd(a75, a85);
            t7d = _mm_add_pd(s9h, s5j);
            t8d = _mm_add_pd(s0i, s6j);
            t9d = _mm_sub_pd(s9h, s5j);
            t0e = _mm_sub_pd(s0i, s6j);
            s7k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0e));
            s8k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0e));
            t1e = _mm_add_pd(t3b, t7c);
            t2e = _mm_add_pd(t4b, t8c);
            t3e = _mm_sub_pd(t3b, t7c);
            t4e = _mm_sub_pd(t4b, t8c);
            t5e = _mm_add_pd(t1c, t5d);
            t6e = _mm_add_pd(t2c, t6d);
            t7e = _mm_sub_pd(t1c, t5d);
            t8e = _mm_sub_pd(t2c, t6d);
            t9e = _mm_add_pd(t1e, t5e);
            t0f = _mm_add_pd(t2e, t6e);
            t1f = _mm_sub_pd(t1e, t5e);
            t2f = _mm_sub_pd(t2e, t6e);
            t3f = _mm_add_pd(t3e, t8e);
            t4f = _mm_sub_pd(t4e, t7e);
            t5f = _mm_sub_pd(t3e, t8e);
            t6f = _mm_add_pd(t4e, t7e);
            t7f = _mm_add_pd(t7b, t1d);
            t8f = _mm_add_pd(t8b, t2d);
            t9f = _mm_sub_pd(t7b, t1d);
            t0g = _mm_sub_pd(t8b, t2d);
            t1g = _mm_add_pd(t3c, t7d);
            t2g = _mm_add_pd(t4c, t8d);
            t3g = _mm_sub_pd(t3c, t7d);
            t4g = _mm_sub_pd(t4c, t8d);
            t5g = _mm_add_pd(t7f, t1g);
            t6g = _mm_add_pd(t8f, t2g);
            t7g = _mm_sub_pd(t7f, t1g);
            t8g = _mm_sub_pd(t8f, t2g);
            a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t9f, t4g));
            a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0g, t3g));
            s9k = _mm_sub_pd(a95, a06);
            s0l = _mm_add_pd(a95, a06);
            a16 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9f, t4g));
            a26 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t0g, t3g));
            s1l = _mm_sub_pd(a16, a26);
            s2l = _mm_add_pd(a16, a26);
            a36 = (16 * i3);
            b2 = (((__m128d  *) T) + i);
            b3 = (b2 + a36);
            s3l = _mm_add_pd(t9e, t5g);
            *((b3 + 16)) = s3l;
            s4l = _mm_add_pd(t0f, t6g);
            *((b3 + 24)) = s4l;
            b4 = (b2 - a36);
            s5l = _mm_sub_pd(t9e, t5g);
            *((b4 + 2032)) = s5l;
            s6l = _mm_sub_pd(t6g, t0f);
            *((b4 + 2040)) = s6l;
            s7l = _mm_add_pd(t3f, s9k);
            *((b3 + 528)) = s7l;
            s8l = _mm_sub_pd(t4f, s0l);
            *((b3 + 536)) = s8l;
            s9l = _mm_sub_pd(t3f, s9k);
            *((b4 + 1520)) = s9l;
            s0m = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4f, s0l));
            *((b4 + 1528)) = s0m;
            s1m = _mm_add_pd(t1f, t8g);
            *((b3 + 1040)) = s1m;
            s2m = _mm_sub_pd(t2f, t7g);
            *((b3 + 1048)) = s2m;
            s3m = _mm_sub_pd(t1f, t8g);
            *((b4 + 1008)) = s3m;
            s4m = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2f, t7g));
            *((b4 + 1016)) = s4m;
            s5m = _mm_add_pd(t5f, s1l);
            *((b3 + 1552)) = s5m;
            s6m = _mm_add_pd(t6f, s2l);
            *((b3 + 1560)) = s6m;
            s7m = _mm_sub_pd(t5f, s1l);
            *((b4 + 496)) = s7m;
            s8m = _mm_sub_pd(s2l, t6f);
            *((b4 + 504)) = s8m;
            t9g = _mm_add_pd(t5b, t0d);
            t0h = _mm_sub_pd(t6b, t9c);
            t1h = _mm_sub_pd(t5b, t0d);
            t2h = _mm_add_pd(t6b, t9c);
            t3h = _mm_add_pd(s9j, s5k);
            t4h = _mm_sub_pd(s6k, s0k);
            t5h = _mm_sub_pd(s9j, s5k);
            t6h = _mm_add_pd(s0k, s6k);
            t7h = _mm_add_pd(t9g, t3h);
            t8h = _mm_add_pd(t0h, t4h);
            t9h = _mm_sub_pd(t9g, t3h);
            t0i = _mm_sub_pd(t0h, t4h);
            t1i = _mm_sub_pd(t1h, t6h);
            t2i = _mm_sub_pd(t2h, t5h);
            t3i = _mm_add_pd(t1h, t6h);
            t4i = _mm_add_pd(t2h, t5h);
            t5i = _mm_add_pd(s7j, s3k);
            t6i = _mm_add_pd(s8j, s4k);
            t7i = _mm_sub_pd(s7j, s3k);
            t8i = _mm_sub_pd(s8j, s4k);
            t9i = _mm_add_pd(s1k, s7k);
            t0j = _mm_add_pd(s2k, s8k);
            t1j = _mm_sub_pd(s1k, s7k);
            t2j = _mm_sub_pd(s2k, s8k);
            t3j = _mm_add_pd(t5i, t9i);
            t4j = _mm_add_pd(t6i, t0j);
            t5j = _mm_sub_pd(t5i, t9i);
            t6j = _mm_sub_pd(t6i, t0j);
            a46 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t7i, t2j));
            a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t8i, t1j));
            s9m = _mm_sub_pd(a46, a56);
            s0n = _mm_add_pd(a46, a56);
            a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7i, t2j));
            a76 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t8i, t1j));
            s1n = _mm_sub_pd(a66, a76);
            s2n = _mm_add_pd(a66, a76);
            s3n = _mm_add_pd(t7h, t3j);
            *((b3 + 272)) = s3n;
            s4n = _mm_add_pd(t8h, t4j);
            *((b3 + 280)) = s4n;
            s5n = _mm_sub_pd(t7h, t3j);
            *((b4 + 1776)) = s5n;
            s6n = _mm_sub_pd(t4j, t8h);
            *((b4 + 1784)) = s6n;
            s7n = _mm_add_pd(t1i, s9m);
            *((b3 + 784)) = s7n;
            s8n = _mm_sub_pd(t2i, s0n);
            *((b3 + 792)) = s8n;
            s9n = _mm_sub_pd(t1i, s9m);
            *((b4 + 1264)) = s9n;
            s0o = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2i, s0n));
            *((b4 + 1272)) = s0o;
            s1o = _mm_add_pd(t9h, t6j);
            *((b3 + 1296)) = s1o;
            s2o = _mm_sub_pd(t0i, t5j);
            *((b3 + 1304)) = s2o;
            s3o = _mm_sub_pd(t9h, t6j);
            *((b4 + 752)) = s3o;
            s4o = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0i, t5j));
            *((b4 + 760)) = s4o;
            s5o = _mm_add_pd(t3i, s1n);
            *((b3 + 1808)) = s5o;
            s6o = _mm_add_pd(t4i, s2n);
            *((b3 + 1816)) = s6o;
            s7o = _mm_sub_pd(t3i, s1n);
            *((b4 + 240)) = s7o;
            s8o = _mm_sub_pd(s2n, t4i);
            *((b4 + 248)) = s8o;
        }}
    }}
    a86 = ((__m128d  *) T);
    s9o = *(a86);
    s0p = *((a86 + 8));
    t7j = _mm_add_pd(s9o, s0p);
    t8j = _mm_sub_pd(s9o, s0p);
    s1p = *((a86 + 4));
    s2p = *((a86 + 12));
    t9j = _mm_add_pd(s1p, s2p);
    t0k = _mm_sub_pd(s1p, s2p);
    s3p = *((a86 + 2));
    s4p = *((a86 + 10));
    t1k = _mm_add_pd(s3p, s4p);
    s5p = *((a86 + 6));
    s6p = *((a86 + 14));
    t2k = _mm_add_pd(s5p, s6p);
    t3k = _mm_add_pd(t7j, t9j);
    t4k = _mm_sub_pd(t7j, t9j);
    t5k = _mm_add_pd(t1k, t2k);
    t6k = _mm_sub_pd(t1k, t2k);
    a96 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3p, s4p));
    a07 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5p, s6p));
    s7p = _mm_add_pd(a96, a07);
    s8p = _mm_sub_pd(a07, a96);
    t7k = _mm_add_pd(t8j, s7p);
    t8k = _mm_sub_pd(s8p, t0k);
    t9k = _mm_sub_pd(t8j, s7p);
    t0l = _mm_add_pd(t0k, s8p);
    s9p = *((a86 + 1));
    s0q = *((a86 + 9));
    t1l = _mm_add_pd(s9p, s0q);
    t2l = _mm_sub_pd(s9p, s0q);
    s1q = *((a86 + 5));
    s2q = *((a86 + 13));
    t3l = _mm_add_pd(s1q, s2q);
    t4l = _mm_sub_pd(s1q, s2q);
    s3q = *((a86 + 3));
    s4q = *((a86 + 11));
    t5l = _mm_add_pd(s3q, s4q);
    s5q = *((a86 + 7));
    s6q = *((a86 + 15));
    t6l = _mm_add_pd(s5q, s6q);
    t7l = _mm_add_pd(t1l, t3l);
    t8l = _mm_add_pd(t5l, t6l);
    a17 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3q, s4q));
    a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5q, s6q));
    s7q = _mm_add_pd(a17, a27);
    s8q = _mm_sub_pd(a27, a17);
    t9l = _mm_add_pd(t2l, s7q);
    t0m = _mm_sub_pd(s8q, t4l);
    t1m = _mm_sub_pd(t2l, s7q);
    t2m = _mm_add_pd(t4l, s8q);
    t3m = _mm_add_pd(t3k, t5k);
    t4m = _mm_sub_pd(t3k, t5k);
    t5m = _mm_add_pd(t7l, t8l);
    t6m = _mm_sub_pd(t7l, t8l);
    t7m = _mm_add_pd(t3m, t5m);
    s9q = _mm_add_pd(v_neg03(v_hi2(t7m, t7m)), v_lo2(t7m, t7m));
    _mm_storeu_pd(((double  *) dst), s9q);
    s0r = v_neg23(_mm_sub_pd(t3m, t5m));
    _mm_storeu_pd(((double  *) (dst + 2048)), s0r);
    s1r = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t4m), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t6m));
    s2r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t4m), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t6m));
    s3r = v_lo2(s1r, s2r);
    s4r = v_hi2(s1r, s2r);
    s5r = _mm_add_pd(s3r, s4r);
    _mm_storeu_pd(((double  *) (dst + 1024)), s5r);
    s6r = v_neg23(_mm_sub_pd(s3r, s4r));
    _mm_storeu_pd(((double  *) (dst + 3072)), s6r);
    s7r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9l), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0m));
    s8r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9l), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0m));
    t8m = _mm_add_pd(t7k, s7r);
    t9m = _mm_add_pd(t8k, s8r);
    t0n = _mm_sub_pd(t7k, s7r);
    t1n = _mm_sub_pd(t8k, s8r);
    s9r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t8m), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t9m));
    s0s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t8m), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t9m));
    s1s = v_lo2(s9r, s0s);
    s2s = v_hi2(s9r, s0s);
    s3s = _mm_add_pd(s1s, s2s);
    _mm_storeu_pd(((double  *) (dst + 256)), s3s);
    s4s = v_neg23(_mm_sub_pd(s1s, s2s));
    _mm_storeu_pd(((double  *) (dst + 3840)), s4s);
    s5s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t0n), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1n));
    s6s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t0n), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t1n));
    s7s = v_lo2(s5s, s6s);
    s8s = v_hi2(s5s, s6s);
    s9s = _mm_add_pd(s7s, s8s);
    _mm_storeu_pd(((double  *) (dst + 2304)), s9s);
    s0t = v_neg23(_mm_sub_pd(s7s, s8s));
    _mm_storeu_pd(((double  *) (dst + 1792)), s0t);
    a37 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1l, t3l));
    a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t6l));
    s1t = _mm_add_pd(a37, a47);
    s2t = _mm_sub_pd(a47, a37);
    t2n = _mm_add_pd(t4k, s1t);
    t3n = _mm_sub_pd(s2t, t6k);
    t4n = _mm_sub_pd(t4k, s1t);
    t5n = _mm_add_pd(t6k, s2t);
    s3t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t2n), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t3n));
    s4t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t2n), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t3n));
    s5t = v_lo2(s3t, s4t);
    s6t = v_hi2(s3t, s4t);
    s7t = _mm_add_pd(s5t, s6t);
    _mm_storeu_pd(((double  *) (dst + 512)), s7t);
    s8t = v_neg23(_mm_sub_pd(s5t, s6t));
    _mm_storeu_pd(((double  *) (dst + 3584)), s8t);
    s9t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t4n), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t5n));
    s0u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t4n), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t5n));
    s1u = v_lo2(s9t, s0u);
    s2u = v_hi2(s9t, s0u);
    s3u = _mm_add_pd(s1u, s2u);
    _mm_storeu_pd(((double  *) (dst + 2560)), s3u);
    s4u = v_neg23(_mm_sub_pd(s1u, s2u));
    _mm_storeu_pd(((double  *) (dst + 1536)), s4u);
    s5u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2m));
    s6u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1m), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2m));
    t6n = _mm_add_pd(t9k, s5u);
    t7n = _mm_add_pd(t0l, s6u);
    t8n = _mm_sub_pd(t9k, s5u);
    t9n = _mm_sub_pd(t0l, s6u);
    s7u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6n), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t7n));
    s8u = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6n), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t7n));
    s9u = v_lo2(s7u, s8u);
    s0v = v_hi2(s7u, s8u);
    s1v = _mm_add_pd(s9u, s0v);
    _mm_storeu_pd(((double  *) (dst + 768)), s1v);
    s2v = v_neg23(_mm_sub_pd(s9u, s0v));
    _mm_storeu_pd(((double  *) (dst + 3328)), s2v);
    s3v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t8n), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t9n));
    s4v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t8n), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t9n));
    s5v = v_lo2(s3v, s4v);
    s6v = v_hi2(s3v, s4v);
    s7v = _mm_add_pd(s5v, s6v);
    _mm_storeu_pd(((double  *) (dst + 2816)), s7v);
    s8v = v_neg23(_mm_sub_pd(s5v, s6v));
    _mm_storeu_pd(((double  *) (dst + 1280)), s8v);
    {long i4; for(i4 = 0; i4 <= 126; i4++) {
        a57 = (16 * i4);
        b5 = (((__m128d  *) T) + a57);
        s9v = *((b5 + 16));
        s0w = *((b5 + 24));
        s1w = *((b5 + 20));
        s2w = *((b5 + 28));
        a67 = (D51 + (4 * i4));
        a77 = *(a67);
        a87 = *((a67 + 1));
        s3w = _mm_sub_pd(_mm_mul_pd(a77, s9v), _mm_mul_pd(a87, s0w));
        s4w = _mm_add_pd(_mm_mul_pd(a87, s9v), _mm_mul_pd(a77, s0w));
        a97 = *((a67 + 2));
        a08 = *((a67 + 3));
        s5w = _mm_sub_pd(_mm_mul_pd(a97, s1w), _mm_mul_pd(a08, s2w));
        s6w = _mm_add_pd(_mm_mul_pd(a08, s1w), _mm_mul_pd(a97, s2w));
        t0o = _mm_add_pd(s3w, s5w);
        t1o = _mm_add_pd(s4w, s6w);
        t2o = _mm_sub_pd(s3w, s5w);
        t3o = _mm_sub_pd(s4w, s6w);
        s7w = *((b5 + 17));
        s8w = *((b5 + 25));
        s9w = *((b5 + 21));
        s0x = *((b5 + 29));
        s1x = _mm_sub_pd(_mm_mul_pd(a77, s7w), _mm_mul_pd(a87, s8w));
        s2x = _mm_add_pd(_mm_mul_pd(a87, s7w), _mm_mul_pd(a77, s8w));
        s3x = _mm_sub_pd(_mm_mul_pd(a97, s9w), _mm_mul_pd(a08, s0x));
        s4x = _mm_add_pd(_mm_mul_pd(a08, s9w), _mm_mul_pd(a97, s0x));
        t4o = _mm_add_pd(s1x, s3x);
        t5o = _mm_add_pd(s2x, s4x);
        t6o = _mm_sub_pd(s1x, s3x);
        t7o = _mm_sub_pd(s2x, s4x);
        s5x = *((b5 + 18));
        s6x = *((b5 + 26));
        s7x = *((b5 + 22));
        s8x = *((b5 + 30));
        s9x = _mm_sub_pd(_mm_mul_pd(a77, s5x), _mm_mul_pd(a87, s6x));
        s0y = _mm_add_pd(_mm_mul_pd(a87, s5x), _mm_mul_pd(a77, s6x));
        s1y = _mm_sub_pd(_mm_mul_pd(a97, s7x), _mm_mul_pd(a08, s8x));
        s2y = _mm_add_pd(_mm_mul_pd(a08, s7x), _mm_mul_pd(a97, s8x));
        t8o = _mm_add_pd(s9x, s1y);
        t9o = _mm_add_pd(s0y, s2y);
        t0p = _mm_sub_pd(s9x, s1y);
        t1p = _mm_sub_pd(s0y, s2y);
        s3y = *((b5 + 19));
        s4y = *((b5 + 27));
        s5y = *((b5 + 23));
        s6y = *((b5 + 31));
        s7y = _mm_sub_pd(_mm_mul_pd(a77, s3y), _mm_mul_pd(a87, s4y));
        s8y = _mm_add_pd(_mm_mul_pd(a87, s3y), _mm_mul_pd(a77, s4y));
        s9y = _mm_sub_pd(_mm_mul_pd(a97, s5y), _mm_mul_pd(a08, s6y));
        s0z = _mm_add_pd(_mm_mul_pd(a08, s5y), _mm_mul_pd(a97, s6y));
        t2p = _mm_add_pd(s7y, s9y);
        t3p = _mm_add_pd(s8y, s0z);
        t4p = _mm_sub_pd(s7y, s9y);
        t5p = _mm_sub_pd(s8y, s0z);
        a18 = (D50 + a57);
        a28 = *(a18);
        a38 = *((a18 + 1));
        s1z = _mm_sub_pd(_mm_mul_pd(a28, t0o), _mm_mul_pd(a38, t1o));
        s2z = _mm_add_pd(_mm_mul_pd(a38, t0o), _mm_mul_pd(a28, t1o));
        a48 = *((a18 + 2));
        a58 = *((a18 + 3));
        s3z = _mm_sub_pd(_mm_mul_pd(a48, t4o), _mm_mul_pd(a58, t5o));
        s4z = _mm_add_pd(_mm_mul_pd(a58, t4o), _mm_mul_pd(a48, t5o));
        a68 = *((a18 + 4));
        a78 = *((a18 + 5));
        s5z = _mm_sub_pd(_mm_mul_pd(a68, t8o), _mm_mul_pd(a78, t9o));
        s6z = _mm_add_pd(_mm_mul_pd(a78, t8o), _mm_mul_pd(a68, t9o));
        a88 = *((a18 + 6));
        a98 = *((a18 + 7));
        s7z = _mm_sub_pd(_mm_mul_pd(a88, t2p), _mm_mul_pd(a98, t3p));
        s8z = _mm_add_pd(_mm_mul_pd(a98, t2p), _mm_mul_pd(a88, t3p));
        t6p = _mm_add_pd(s1z, s5z);
        t7p = _mm_add_pd(s2z, s6z);
        t8p = _mm_sub_pd(s1z, s5z);
        t9p = _mm_sub_pd(s2z, s6z);
        t0q = _mm_add_pd(s3z, s7z);
        t1q = _mm_add_pd(s4z, s8z);
        t2q = _mm_sub_pd(s3z, s7z);
        t3q = _mm_sub_pd(s4z, s8z);
        t4q = _mm_add_pd(t6p, t0q);
        t5q = _mm_add_pd(t7p, t1q);
        t6q = _mm_sub_pd(t6p, t0q);
        t7q = _mm_sub_pd(t7p, t1q);
        t8q = _mm_add_pd(t8p, t3q);
        t9q = _mm_sub_pd(t9p, t2q);
        t0r = _mm_sub_pd(t8p, t3q);
        t1r = _mm_add_pd(t9p, t2q);
        a09 = (D49 + a57);
        a19 = *(a09);
        a29 = *((a09 + 1));
        s9z = _mm_sub_pd(_mm_mul_pd(a19, t4q), _mm_mul_pd(a29, t5q));
        s0A = _mm_add_pd(_mm_mul_pd(a29, t4q), _mm_mul_pd(a19, t5q));
        s1A = v_lo2(s9z, s0A);
        s2A = v_hi2(s9z, s0A);
        a39 = (2 * i4);
        b6 = (dst + a39);
        s3A = _mm_add_pd(s1A, s2A);
        _mm_storeu_pd(((double  *) (b6 + 2)), s3A);
        b7 = (dst - a39);
        s4A = v_neg23(_mm_sub_pd(s1A, s2A));
        _mm_storeu_pd(((double  *) (b7 + 4094)), s4A);
        a49 = *((a09 + 2));
        a59 = *((a09 + 3));
        s5A = _mm_sub_pd(_mm_mul_pd(a49, t8q), _mm_mul_pd(a59, t9q));
        s6A = _mm_add_pd(_mm_mul_pd(a59, t8q), _mm_mul_pd(a49, t9q));
        s7A = v_lo2(s5A, s6A);
        s8A = v_hi2(s5A, s6A);
        s9A = _mm_add_pd(s7A, s8A);
        _mm_storeu_pd(((double  *) (b6 + 1026)), s9A);
        s0B = v_neg23(_mm_sub_pd(s7A, s8A));
        _mm_storeu_pd(((double  *) (b7 + 3070)), s0B);
        a69 = *((a09 + 4));
        a79 = *((a09 + 5));
        s1B = _mm_sub_pd(_mm_mul_pd(a69, t6q), _mm_mul_pd(a79, t7q));
        s2B = _mm_add_pd(_mm_mul_pd(a79, t6q), _mm_mul_pd(a69, t7q));
        s3B = v_lo2(s1B, s2B);
        s4B = v_hi2(s1B, s2B);
        s5B = _mm_add_pd(s3B, s4B);
        _mm_storeu_pd(((double  *) (b6 + 2050)), s5B);
        s6B = v_neg23(_mm_sub_pd(s3B, s4B));
        _mm_storeu_pd(((double  *) (b7 + 2046)), s6B);
        a89 = *((a09 + 6));
        a99 = *((a09 + 7));
        s7B = _mm_sub_pd(_mm_mul_pd(a89, t0r), _mm_mul_pd(a99, t1r));
        s8B = _mm_add_pd(_mm_mul_pd(a99, t0r), _mm_mul_pd(a89, t1r));
        s9B = v_lo2(s7B, s8B);
        s0C = v_hi2(s7B, s8B);
        s1C = _mm_add_pd(s9B, s0C);
        _mm_storeu_pd(((double  *) (b6 + 3074)), s1C);
        s2C = v_neg23(_mm_sub_pd(s9B, s0C));
        _mm_storeu_pd(((double  *) (b7 + 1022)), s2C);
        a0a = *((a18 + 8));
        a1a = *((a18 + 9));
        s3C = _mm_sub_pd(_mm_mul_pd(a0a, t2o), _mm_mul_pd(a1a, t3o));
        s4C = _mm_add_pd(_mm_mul_pd(a1a, t2o), _mm_mul_pd(a0a, t3o));
        a2a = *((a18 + 10));
        a3a = *((a18 + 11));
        s5C = _mm_sub_pd(_mm_mul_pd(a2a, t6o), _mm_mul_pd(a3a, t7o));
        s6C = _mm_add_pd(_mm_mul_pd(a3a, t6o), _mm_mul_pd(a2a, t7o));
        a4a = *((a18 + 12));
        a5a = *((a18 + 13));
        s7C = _mm_sub_pd(_mm_mul_pd(a4a, t0p), _mm_mul_pd(a5a, t1p));
        s8C = _mm_add_pd(_mm_mul_pd(a5a, t0p), _mm_mul_pd(a4a, t1p));
        a6a = *((a18 + 14));
        a7a = *((a18 + 15));
        s9C = _mm_sub_pd(_mm_mul_pd(a6a, t4p), _mm_mul_pd(a7a, t5p));
        s0D = _mm_add_pd(_mm_mul_pd(a7a, t4p), _mm_mul_pd(a6a, t5p));
        t2r = _mm_add_pd(s3C, s7C);
        t3r = _mm_add_pd(s4C, s8C);
        t4r = _mm_sub_pd(s3C, s7C);
        t5r = _mm_sub_pd(s4C, s8C);
        t6r = _mm_add_pd(s5C, s9C);
        t7r = _mm_add_pd(s6C, s0D);
        t8r = _mm_sub_pd(s5C, s9C);
        t9r = _mm_sub_pd(s6C, s0D);
        t0s = _mm_add_pd(t2r, t6r);
        t1s = _mm_add_pd(t3r, t7r);
        t2s = _mm_sub_pd(t2r, t6r);
        t3s = _mm_sub_pd(t3r, t7r);
        t4s = _mm_add_pd(t4r, t9r);
        t5s = _mm_sub_pd(t5r, t8r);
        t6s = _mm_sub_pd(t4r, t9r);
        t7s = _mm_add_pd(t5r, t8r);
        a8a = *((a09 + 8));
        a9a = *((a09 + 9));
        s1D = _mm_sub_pd(_mm_mul_pd(a8a, t0s), _mm_mul_pd(a9a, t1s));
        s2D = _mm_add_pd(_mm_mul_pd(a9a, t0s), _mm_mul_pd(a8a, t1s));
        s3D = v_lo2(s1D, s2D);
        s4D = v_hi2(s1D, s2D);
        s5D = _mm_add_pd(s3D, s4D);
        _mm_storeu_pd(((double  *) (b6 + 514)), s5D);
        s6D = v_neg23(_mm_sub_pd(s3D, s4D));
        _mm_storeu_pd(((double  *) (b7 + 3582)), s6D);
        a0b = *((a09 + 10));
        a1b = *((a09 + 11));
        s7D = _mm_sub_pd(_mm_mul_pd(a0b, t4s), _mm_mul_pd(a1b, t5s));
        s8D = _mm_add_pd(_mm_mul_pd(a1b, t4s), _mm_mul_pd(a0b, t5s));
        s9D = v_lo2(s7D, s8D);
        s0E = v_hi2(s7D, s8D);
        s1E = _mm_add_pd(s9D, s0E);
        _mm_storeu_pd(((double  *) (b6 + 1538)), s1E);
        s2E = v_neg23(_mm_sub_pd(s9D, s0E));
        _mm_storeu_pd(((double  *) (b7 + 2558)), s2E);
        a2b = *((a09 + 12));
        a3b = *((a09 + 13));
        s3E = _mm_sub_pd(_mm_mul_pd(a2b, t2s), _mm_mul_pd(a3b, t3s));
        s4E = _mm_add_pd(_mm_mul_pd(a3b, t2s), _mm_mul_pd(a2b, t3s));
        s5E = v_lo2(s3E, s4E);
        s6E = v_hi2(s3E, s4E);
        s7E = _mm_add_pd(s5E, s6E);
        _mm_storeu_pd(((double  *) (b6 + 2562)), s7E);
        s8E = v_neg23(_mm_sub_pd(s5E, s6E));
        _mm_storeu_pd(((double  *) (b7 + 1534)), s8E);
        a4b = *((a09 + 14));
        a5b = *((a09 + 15));
        s9E = _mm_sub_pd(_mm_mul_pd(a4b, t6s), _mm_mul_pd(a5b, t7s));
        s0F = _mm_add_pd(_mm_mul_pd(a5b, t6s), _mm_mul_pd(a4b, t7s));
        s1F = v_lo2(s9E, s0F);
        s2F = v_hi2(s9E, s0F);
        s3F = _mm_add_pd(s1F, s2F);
        _mm_storeu_pd(((double  *) (b6 + 3586)), s3F);
        s4F = v_neg23(_mm_sub_pd(s1F, s2F));
        _mm_storeu_pd(((double  *) (b7 + 510)), s4F);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_4096)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_4096_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[4096]);
     SPIRAL_ALIGNED(double T2[512]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a09, a0a, a0b, a11, a13, a14, a15, a16, a17, a18, a1a, a1b, a21, a23
            , a24, a25, a26, a27, a29, a2a, a2b, a3, a31, a32, a33, a34, a35, a38, a39, a3a, a3b, a4, a41, a42, a43, a44
            , a45, a46, a47, a48, a4a, a4b, a5, a51, a52, a53, a54, a55, a56, a57, a58, a59, a5a, a5b, a6, a62, a63, a64
            , a65, a66, a68, a69, a6a, a6b, a71, a72, a73, a74, a75, a76, a78, a79, a7a, a8, a81, a82, a83, a84, a85, a87
            , a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01, s02, s03, s04, s05, s06, s07
            , s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n
            , s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A
            , s1B, s1C, s1D, s1E, s1F, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s
            , s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E
            , s3F, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u
            , s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w
            , s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5a, s5b, s5c, s5d
            , s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z
            , s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6a, s6b, s6c, s6d, s6e, s6f, s6g
            , s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y, s6z, s7, s71, s72
            , s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85
            , s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p
            , s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b
            , t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t11, t12, t13, t14, t15
            , t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r
            , t1s, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k
            , t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d
            , t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t4, t41, t42, t43, t44, t45, t46
            , t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s
            , t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l
            , t5m, t5n, t5o, t5p, t5q, t5r, t5s, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e
            , t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t7, t71, t72, t73, t74, t75, t76, t77
            , t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t8
            , t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m
            , t8n, t8o, t8p, t8q, t8r, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g
            , t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r;
    __m128d  *a, *a19, *a2, *a22, *a28, *a37, *a49, *a61, *a7, *a77, *a86, *b, *b2, *b3, *b4, *b5, *b6, *b7;
    int a12, a36, a67;
    {long i; for(i = 0; i <= 7; i++) {
        {long i2; for(i2 = 0; i2 <= 15; i2++) {
            a = (((__m128d  *) src) + (i + (8 * i2)));
            s = *(a);
            s2 = *((a + 1024));
            t = _mm_add_pd(s, s2);
            t2 = _mm_sub_pd(s, s2);
            s3 = *((a + 512));
            s4 = *((a + 1536));
            t3 = _mm_add_pd(s3, s4);
            t4 = _mm_sub_pd(s3, s4);
            s5 = *((a + 128));
            s6 = *((a + 1152));
            t5 = _mm_add_pd(s5, s6);
            t6 = _mm_sub_pd(s5, s6);
            s7 = *((a + 640));
            s8 = *((a + 1664));
            t7 = _mm_add_pd(s7, s8);
            t8 = _mm_sub_pd(s7, s8);
            s9 = *((a + 256));
            s01 = *((a + 1280));
            t9 = _mm_add_pd(s9, s01);
            s11 = *((a + 768));
            s21 = *((a + 1792));
            t01 = _mm_add_pd(s11, s21);
            s31 = *((a + 384));
            s41 = *((a + 1408));
            t11 = _mm_add_pd(s31, s41);
            t21 = _mm_sub_pd(s31, s41);
            s51 = *((a + 896));
            s61 = *((a + 1920));
            t31 = _mm_add_pd(s51, s61);
            t41 = _mm_sub_pd(s51, s61);
            t51 = _mm_add_pd(t, t3);
            t61 = _mm_sub_pd(t, t3);
            t71 = _mm_add_pd(t9, t01);
            t81 = _mm_sub_pd(t9, t01);
            t91 = _mm_add_pd(t5, t7);
            t02 = _mm_add_pd(t11, t31);
            a2 = (((__m128d  *) T2) + i2);
            s71 = _mm_add_pd(t51, t71);
            *(a2) = s71;
            s81 = _mm_sub_pd(t51, t71);
            *((a2 + 128)) = s81;
            s91 = _mm_add_pd(t91, t02);
            *((a2 + 16)) = s91;
            s02 = _mm_sub_pd(t02, t91);
            *((a2 + 144)) = s02;
            a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5, t7));
            a4 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t11, t31));
            s12 = _mm_add_pd(a3, a4);
            s22 = _mm_sub_pd(a4, a3);
            s32 = _mm_add_pd(t61, s12);
            *((a2 + 64)) = s32;
            s42 = _mm_sub_pd(s22, t81);
            *((a2 + 80)) = s42;
            s52 = _mm_sub_pd(t61, s12);
            *((a2 + 192)) = s52;
            s62 = _mm_add_pd(t81, s22);
            *((a2 + 208)) = s62;
            s72 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8));
            s82 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8));
            a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9, s01));
            a6 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s11, s21));
            s92 = _mm_add_pd(a5, a6);
            s03 = _mm_sub_pd(a6, a5);
            s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t41));
            s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t21), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t41));
            t12 = _mm_add_pd(t2, s92);
            t22 = _mm_sub_pd(s03, t4);
            t32 = _mm_sub_pd(t2, s92);
            t42 = _mm_add_pd(t4, s03);
            t52 = _mm_add_pd(s72, s13);
            t62 = _mm_add_pd(s82, s23);
            t72 = _mm_sub_pd(s72, s13);
            t82 = _mm_sub_pd(s82, s23);
            s33 = _mm_add_pd(t12, t52);
            *((a2 + 32)) = s33;
            s43 = _mm_add_pd(t22, t62);
            *((a2 + 48)) = s43;
            s53 = _mm_sub_pd(t12, t52);
            *((a2 + 224)) = s53;
            s63 = _mm_sub_pd(t62, t22);
            *((a2 + 240)) = s63;
            s73 = _mm_add_pd(t32, t82);
            *((a2 + 160)) = s73;
            s83 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t42, t72));
            *((a2 + 176)) = s83;
            s93 = _mm_sub_pd(t32, t82);
            *((a2 + 96)) = s93;
            s04 = _mm_sub_pd(t42, t72);
            *((a2 + 112)) = s04;
        }}
        a7 = ((__m128d  *) T2);
        s14 = *(a7);
        s24 = *((a7 + 16));
        t92 = _mm_add_pd(s14, s24);
        t03 = _mm_sub_pd(s14, s24);
        s34 = *((a7 + 8));
        s44 = *((a7 + 24));
        t13 = _mm_add_pd(s34, s44);
        t23 = _mm_sub_pd(s34, s44);
        s54 = *((a7 + 4));
        s64 = *((a7 + 20));
        t33 = _mm_add_pd(s54, s64);
        s74 = *((a7 + 12));
        s84 = *((a7 + 28));
        t43 = _mm_add_pd(s74, s84);
        t53 = _mm_add_pd(t92, t13);
        t63 = _mm_sub_pd(t92, t13);
        t73 = _mm_add_pd(t33, t43);
        t83 = _mm_sub_pd(t33, t43);
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s54, s64));
        a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s74, s84));
        s94 = _mm_add_pd(a8, a9);
        s05 = _mm_sub_pd(a9, a8);
        t93 = _mm_add_pd(t03, s94);
        t04 = _mm_sub_pd(s05, t23);
        t14 = _mm_sub_pd(t03, s94);
        t24 = _mm_add_pd(t23, s05);
        s15 = *((a7 + 1));
        s25 = *((a7 + 17));
        t34 = _mm_add_pd(s15, s25);
        t44 = _mm_sub_pd(s15, s25);
        s35 = *((a7 + 9));
        s45 = *((a7 + 25));
        t54 = _mm_add_pd(s35, s45);
        t64 = _mm_sub_pd(s35, s45);
        s55 = *((a7 + 5));
        s65 = *((a7 + 21));
        t74 = _mm_add_pd(s55, s65);
        s75 = *((a7 + 13));
        s85 = *((a7 + 29));
        t84 = _mm_add_pd(s75, s85);
        t94 = _mm_add_pd(t34, t54);
        t05 = _mm_sub_pd(t34, t54);
        t15 = _mm_add_pd(t74, t84);
        t25 = _mm_sub_pd(t74, t84);
        a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s55, s65));
        a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s75, s85));
        s95 = _mm_add_pd(a01, a11);
        s06 = _mm_sub_pd(a11, a01);
        t35 = _mm_add_pd(t44, s95);
        t45 = _mm_sub_pd(s06, t64);
        t55 = _mm_sub_pd(t44, s95);
        t65 = _mm_add_pd(t64, s06);
        s16 = *((a7 + 2));
        s26 = *((a7 + 18));
        t75 = _mm_add_pd(s16, s26);
        t85 = _mm_sub_pd(s16, s26);
        s36 = *((a7 + 10));
        s46 = *((a7 + 26));
        t95 = _mm_add_pd(s36, s46);
        t06 = _mm_sub_pd(s36, s46);
        s56 = *((a7 + 6));
        s66 = *((a7 + 22));
        t16 = _mm_add_pd(s56, s66);
        s76 = *((a7 + 14));
        s86 = *((a7 + 30));
        t26 = _mm_add_pd(s76, s86);
        t36 = _mm_add_pd(t75, t95);
        t46 = _mm_add_pd(t16, t26);
        a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s56, s66));
        a31 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s76, s86));
        s96 = _mm_add_pd(a21, a31);
        s07 = _mm_sub_pd(a31, a21);
        t56 = _mm_add_pd(t85, s96);
        t66 = _mm_sub_pd(s07, t06);
        t76 = _mm_sub_pd(t85, s96);
        t86 = _mm_add_pd(t06, s07);
        s17 = *((a7 + 3));
        s27 = *((a7 + 19));
        t96 = _mm_add_pd(s17, s27);
        t07 = _mm_sub_pd(s17, s27);
        s37 = *((a7 + 11));
        s47 = *((a7 + 27));
        t17 = _mm_add_pd(s37, s47);
        t27 = _mm_sub_pd(s37, s47);
        s57 = *((a7 + 7));
        s67 = *((a7 + 23));
        t37 = _mm_add_pd(s57, s67);
        s77 = *((a7 + 15));
        s87 = *((a7 + 31));
        t47 = _mm_add_pd(s77, s87);
        t57 = _mm_add_pd(t96, t17);
        t67 = _mm_sub_pd(t96, t17);
        t77 = _mm_add_pd(t37, t47);
        t87 = _mm_sub_pd(t37, t47);
        a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s57, s67));
        a51 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s77, s87));
        s97 = _mm_add_pd(a41, a51);
        s08 = _mm_sub_pd(a51, a41);
        t97 = _mm_add_pd(t07, s97);
        t08 = _mm_sub_pd(s08, t27);
        t18 = _mm_sub_pd(t07, s97);
        t28 = _mm_add_pd(t27, s08);
        t38 = _mm_add_pd(t53, t73);
        t48 = _mm_sub_pd(t53, t73);
        t58 = _mm_add_pd(t36, t46);
        t68 = _mm_sub_pd(t36, t46);
        t78 = _mm_add_pd(t94, t15);
        t88 = _mm_add_pd(t57, t77);
        a61 = (((__m128d  *) T) + i);
        s18 = _mm_add_pd(t38, t58);
        *(a61) = s18;
        s28 = _mm_sub_pd(t38, t58);
        *((a61 + 1024)) = s28;
        s38 = _mm_add_pd(t78, t88);
        *((a61 + 8)) = s38;
        s48 = _mm_sub_pd(t88, t78);
        *((a61 + 1032)) = s48;
        a71 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t94, t15));
        a81 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t57, t77));
        s58 = _mm_add_pd(a71, a81);
        s68 = _mm_sub_pd(a81, a71);
        s78 = _mm_add_pd(t48, s58);
        *((a61 + 512)) = s78;
        s88 = _mm_sub_pd(s68, t68);
        *((a61 + 520)) = s88;
        s98 = _mm_sub_pd(t48, s58);
        *((a61 + 1536)) = s98;
        s09 = _mm_add_pd(t68, s68);
        *((a61 + 1544)) = s09;
        s19 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
        s29 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t45));
        s39 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t56), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t66));
        s49 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t56), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t66));
        s59 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t97), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t08));
        s69 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t97), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t08));
        t98 = _mm_add_pd(t93, s39);
        t09 = _mm_add_pd(t04, s49);
        t19 = _mm_sub_pd(t93, s39);
        t29 = _mm_sub_pd(t04, s49);
        t39 = _mm_add_pd(s19, s59);
        t49 = _mm_add_pd(s29, s69);
        t59 = _mm_sub_pd(s19, s59);
        t69 = _mm_sub_pd(s29, s69);
        s79 = _mm_add_pd(t98, t39);
        *((a61 + 128)) = s79;
        s89 = _mm_add_pd(t09, t49);
        *((a61 + 136)) = s89;
        s99 = _mm_sub_pd(t98, t39);
        *((a61 + 1920)) = s99;
        s0a = _mm_sub_pd(t49, t09);
        *((a61 + 1928)) = s0a;
        s1a = _mm_add_pd(t19, t69);
        *((a61 + 1152)) = s1a;
        s2a = _mm_sub_pd(t29, t59);
        *((a61 + 1160)) = s2a;
        s3a = _mm_sub_pd(t19, t69);
        *((a61 + 896)) = s3a;
        s4a = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t29, t59));
        *((a61 + 904)) = s4a;
        s5a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t05), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t25));
        s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t05), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t25));
        a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t75, t95));
        a02 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t16, t26));
        s7a = _mm_add_pd(a91, a02);
        s8a = _mm_sub_pd(a02, a91);
        s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t87));
        s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t67), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
        t79 = _mm_add_pd(t63, s7a);
        t89 = _mm_sub_pd(s8a, t83);
        t99 = _mm_sub_pd(t63, s7a);
        t0a = _mm_add_pd(t83, s8a);
        t1a = _mm_add_pd(s5a, s9a);
        t2a = _mm_add_pd(s6a, s0b);
        t3a = _mm_sub_pd(s5a, s9a);
        t4a = _mm_sub_pd(s6a, s0b);
        s1b = _mm_add_pd(t79, t1a);
        *((a61 + 256)) = s1b;
        s2b = _mm_add_pd(t89, t2a);
        *((a61 + 264)) = s2b;
        s3b = _mm_sub_pd(t79, t1a);
        *((a61 + 1792)) = s3b;
        s4b = _mm_sub_pd(t2a, t89);
        *((a61 + 1800)) = s4b;
        s5b = _mm_add_pd(t99, t4a);
        *((a61 + 1280)) = s5b;
        s6b = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0a, t3a));
        *((a61 + 1288)) = s6b;
        s7b = _mm_sub_pd(t99, t4a);
        *((a61 + 768)) = s7b;
        s8b = _mm_sub_pd(t0a, t3a);
        *((a61 + 776)) = s8b;
        s9b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t55), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t65));
        s0c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t55), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t65));
        s1c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t76), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t86));
        s2c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t76), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t86));
        s3c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t18), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t28));
        s4c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t18), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t28));
        t5a = _mm_add_pd(t14, s1c);
        t6a = _mm_add_pd(t24, s2c);
        t7a = _mm_sub_pd(t14, s1c);
        t8a = _mm_sub_pd(t24, s2c);
        t9a = _mm_add_pd(s9b, s3c);
        t0b = _mm_add_pd(s0c, s4c);
        t1b = _mm_sub_pd(s9b, s3c);
        t2b = _mm_sub_pd(s0c, s4c);
        s5c = _mm_add_pd(t5a, t9a);
        *((a61 + 384)) = s5c;
        s6c = _mm_add_pd(t6a, t0b);
        *((a61 + 392)) = s6c;
        s7c = _mm_sub_pd(t5a, t9a);
        *((a61 + 1664)) = s7c;
        s8c = _mm_sub_pd(t0b, t6a);
        *((a61 + 1672)) = s8c;
        s9c = _mm_add_pd(t7a, t2b);
        *((a61 + 1408)) = s9c;
        s0d = _mm_sub_pd(t8a, t1b);
        *((a61 + 1416)) = s0d;
        s1d = _mm_sub_pd(t7a, t2b);
        *((a61 + 640)) = s1d;
        s2d = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8a, t1b));
        *((a61 + 648)) = s2d;
        {long i3; for(i3 = 0; i3 <= 6; i3++) {
            a12 = (32 * i3);
            b = (((__m128d  *) T2) + a12);
            s3d = *((b + 32));
            s4d = *((b + 48));
            s5d = *((b + 33));
            s6d = *((b + 49));
            s7d = *((b + 34));
            s8d = *((b + 50));
            s9d = *((b + 35));
            s0e = *((b + 51));
            s1e = *((b + 36));
            s2e = *((b + 52));
            s3e = *((b + 37));
            s4e = *((b + 53));
            s5e = *((b + 38));
            s6e = *((b + 54));
            s7e = *((b + 39));
            s8e = *((b + 55));
            s9e = *((b + 40));
            s0f = *((b + 56));
            s1f = *((b + 41));
            s2f = *((b + 57));
            s3f = *((b + 42));
            s4f = *((b + 58));
            s5f = *((b + 43));
            s6f = *((b + 59));
            s7f = *((b + 44));
            s8f = *((b + 60));
            s9f = *((b + 45));
            s0g = *((b + 61));
            s1g = *((b + 46));
            s2g = *((b + 62));
            s3g = *((b + 47));
            s4g = *((b + 63));
            a22 = (D55 + a12);
            a32 = *(a22);
            a42 = *((a22 + 1));
            s5g = _mm_sub_pd(_mm_mul_pd(a32, s3d), _mm_mul_pd(a42, s4d));
            s6g = _mm_add_pd(_mm_mul_pd(a42, s3d), _mm_mul_pd(a32, s4d));
            a52 = *((a22 + 2));
            a62 = *((a22 + 3));
            s7g = _mm_sub_pd(_mm_mul_pd(a52, s5d), _mm_mul_pd(a62, s6d));
            s8g = _mm_add_pd(_mm_mul_pd(a62, s5d), _mm_mul_pd(a52, s6d));
            a72 = *((a22 + 4));
            a82 = *((a22 + 5));
            s9g = _mm_sub_pd(_mm_mul_pd(a72, s7d), _mm_mul_pd(a82, s8d));
            s0h = _mm_add_pd(_mm_mul_pd(a82, s7d), _mm_mul_pd(a72, s8d));
            a92 = *((a22 + 6));
            a03 = *((a22 + 7));
            s1h = _mm_sub_pd(_mm_mul_pd(a92, s9d), _mm_mul_pd(a03, s0e));
            s2h = _mm_add_pd(_mm_mul_pd(a03, s9d), _mm_mul_pd(a92, s0e));
            a13 = *((a22 + 8));
            a23 = *((a22 + 9));
            s3h = _mm_sub_pd(_mm_mul_pd(a13, s1e), _mm_mul_pd(a23, s2e));
            s4h = _mm_add_pd(_mm_mul_pd(a23, s1e), _mm_mul_pd(a13, s2e));
            a33 = *((a22 + 10));
            a43 = *((a22 + 11));
            s5h = _mm_sub_pd(_mm_mul_pd(a33, s3e), _mm_mul_pd(a43, s4e));
            s6h = _mm_add_pd(_mm_mul_pd(a43, s3e), _mm_mul_pd(a33, s4e));
            a53 = *((a22 + 12));
            a63 = *((a22 + 13));
            s7h = _mm_sub_pd(_mm_mul_pd(a53, s5e), _mm_mul_pd(a63, s6e));
            s8h = _mm_add_pd(_mm_mul_pd(a63, s5e), _mm_mul_pd(a53, s6e));
            a73 = *((a22 + 14));
            a83 = *((a22 + 15));
            s9h = _mm_sub_pd(_mm_mul_pd(a73, s7e), _mm_mul_pd(a83, s8e));
            s0i = _mm_add_pd(_mm_mul_pd(a83, s7e), _mm_mul_pd(a73, s8e));
            a93 = *((a22 + 16));
            a04 = *((a22 + 17));
            s1i = _mm_sub_pd(_mm_mul_pd(a93, s9e), _mm_mul_pd(a04, s0f));
            s2i = _mm_add_pd(_mm_mul_pd(a04, s9e), _mm_mul_pd(a93, s0f));
            a14 = *((a22 + 18));
            a24 = *((a22 + 19));
            s3i = _mm_sub_pd(_mm_mul_pd(a14, s1f), _mm_mul_pd(a24, s2f));
            s4i = _mm_add_pd(_mm_mul_pd(a24, s1f), _mm_mul_pd(a14, s2f));
            a34 = *((a22 + 20));
            a44 = *((a22 + 21));
            s5i = _mm_sub_pd(_mm_mul_pd(a34, s3f), _mm_mul_pd(a44, s4f));
            s6i = _mm_add_pd(_mm_mul_pd(a44, s3f), _mm_mul_pd(a34, s4f));
            a54 = *((a22 + 22));
            a64 = *((a22 + 23));
            s7i = _mm_sub_pd(_mm_mul_pd(a54, s5f), _mm_mul_pd(a64, s6f));
            s8i = _mm_add_pd(_mm_mul_pd(a64, s5f), _mm_mul_pd(a54, s6f));
            a74 = *((a22 + 24));
            a84 = *((a22 + 25));
            s9i = _mm_sub_pd(_mm_mul_pd(a74, s7f), _mm_mul_pd(a84, s8f));
            s0j = _mm_add_pd(_mm_mul_pd(a84, s7f), _mm_mul_pd(a74, s8f));
            a94 = *((a22 + 26));
            a05 = *((a22 + 27));
            s1j = _mm_sub_pd(_mm_mul_pd(a94, s9f), _mm_mul_pd(a05, s0g));
            s2j = _mm_add_pd(_mm_mul_pd(a05, s9f), _mm_mul_pd(a94, s0g));
            a15 = *((a22 + 28));
            a25 = *((a22 + 29));
            s3j = _mm_sub_pd(_mm_mul_pd(a15, s1g), _mm_mul_pd(a25, s2g));
            s4j = _mm_add_pd(_mm_mul_pd(a25, s1g), _mm_mul_pd(a15, s2g));
            a35 = *((a22 + 30));
            a45 = *((a22 + 31));
            s5j = _mm_sub_pd(_mm_mul_pd(a35, s3g), _mm_mul_pd(a45, s4g));
            s6j = _mm_add_pd(_mm_mul_pd(a45, s3g), _mm_mul_pd(a35, s4g));
            t3b = _mm_add_pd(s5g, s1i);
            t4b = _mm_add_pd(s6g, s2i);
            t5b = _mm_sub_pd(s5g, s1i);
            t6b = _mm_sub_pd(s6g, s2i);
            t7b = _mm_add_pd(s7g, s3i);
            t8b = _mm_add_pd(s8g, s4i);
            t9b = _mm_sub_pd(s7g, s3i);
            t0c = _mm_sub_pd(s8g, s4i);
            s7j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9b), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0c));
            s8j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0c));
            t1c = _mm_add_pd(s9g, s5i);
            t2c = _mm_add_pd(s0h, s6i);
            a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s9g, s5i));
            a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0h, s6i));
            s9j = _mm_sub_pd(a55, a65);
            s0k = _mm_add_pd(a55, a65);
            t3c = _mm_add_pd(s1h, s7i);
            t4c = _mm_add_pd(s2h, s8i);
            t5c = _mm_sub_pd(s1h, s7i);
            t6c = _mm_sub_pd(s2h, s8i);
            s1k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6c));
            s2k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6c));
            t7c = _mm_add_pd(s3h, s9i);
            t8c = _mm_add_pd(s4h, s0j);
            t9c = _mm_sub_pd(s3h, s9i);
            t0d = _mm_sub_pd(s4h, s0j);
            t1d = _mm_add_pd(s5h, s1j);
            t2d = _mm_add_pd(s6h, s2j);
            t3d = _mm_sub_pd(s5h, s1j);
            t4d = _mm_sub_pd(s6h, s2j);
            s3k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t3d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
            s4k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t4d));
            t5d = _mm_add_pd(s7h, s3j);
            t6d = _mm_add_pd(s8h, s4j);
            a75 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7h, s3j));
            a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s8h, s4j));
            s5k = _mm_sub_pd(a75, a85);
            s6k = _mm_add_pd(a75, a85);
            t7d = _mm_add_pd(s9h, s5j);
            t8d = _mm_add_pd(s0i, s6j);
            t9d = _mm_sub_pd(s9h, s5j);
            t0e = _mm_sub_pd(s0i, s6j);
            s7k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9d), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0e));
            s8k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0e));
            t1e = _mm_add_pd(t3b, t7c);
            t2e = _mm_add_pd(t4b, t8c);
            t3e = _mm_sub_pd(t3b, t7c);
            t4e = _mm_sub_pd(t4b, t8c);
            t5e = _mm_add_pd(t1c, t5d);
            t6e = _mm_add_pd(t2c, t6d);
            t7e = _mm_sub_pd(t1c, t5d);
            t8e = _mm_sub_pd(t2c, t6d);
            t9e = _mm_add_pd(t1e, t5e);
            t0f = _mm_add_pd(t2e, t6e);
            t1f = _mm_sub_pd(t1e, t5e);
            t2f = _mm_sub_pd(t2e, t6e);
            t3f = _mm_add_pd(t3e, t8e);
            t4f = _mm_sub_pd(t4e, t7e);
            t5f = _mm_sub_pd(t3e, t8e);
            t6f = _mm_add_pd(t4e, t7e);
            t7f = _mm_add_pd(t7b, t1d);
            t8f = _mm_add_pd(t8b, t2d);
            t9f = _mm_sub_pd(t7b, t1d);
            t0g = _mm_sub_pd(t8b, t2d);
            t1g = _mm_add_pd(t3c, t7d);
            t2g = _mm_add_pd(t4c, t8d);
            t3g = _mm_sub_pd(t3c, t7d);
            t4g = _mm_sub_pd(t4c, t8d);
            t5g = _mm_add_pd(t7f, t1g);
            t6g = _mm_add_pd(t8f, t2g);
            t7g = _mm_sub_pd(t7f, t1g);
            t8g = _mm_sub_pd(t8f, t2g);
            a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t9f, t4g));
            a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t0g, t3g));
            s9k = _mm_sub_pd(a95, a06);
            s0l = _mm_add_pd(a95, a06);
            a16 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t9f, t4g));
            a26 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t0g, t3g));
            s1l = _mm_sub_pd(a16, a26);
            s2l = _mm_add_pd(a16, a26);
            a36 = (16 * i3);
            b2 = (((__m128d  *) T) + i);
            b3 = (b2 + a36);
            s3l = _mm_add_pd(t9e, t5g);
            *((b3 + 16)) = s3l;
            s4l = _mm_add_pd(t0f, t6g);
            *((b3 + 24)) = s4l;
            b4 = (b2 - a36);
            s5l = _mm_sub_pd(t9e, t5g);
            *((b4 + 2032)) = s5l;
            s6l = _mm_sub_pd(t6g, t0f);
            *((b4 + 2040)) = s6l;
            s7l = _mm_add_pd(t3f, s9k);
            *((b3 + 528)) = s7l;
            s8l = _mm_sub_pd(t4f, s0l);
            *((b3 + 536)) = s8l;
            s9l = _mm_sub_pd(t3f, s9k);
            *((b4 + 1520)) = s9l;
            s0m = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4f, s0l));
            *((b4 + 1528)) = s0m;
            s1m = _mm_add_pd(t1f, t8g);
            *((b3 + 1040)) = s1m;
            s2m = _mm_sub_pd(t2f, t7g);
            *((b3 + 1048)) = s2m;
            s3m = _mm_sub_pd(t1f, t8g);
            *((b4 + 1008)) = s3m;
            s4m = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2f, t7g));
            *((b4 + 1016)) = s4m;
            s5m = _mm_add_pd(t5f, s1l);
            *((b3 + 1552)) = s5m;
            s6m = _mm_add_pd(t6f, s2l);
            *((b3 + 1560)) = s6m;
            s7m = _mm_sub_pd(t5f, s1l);
            *((b4 + 496)) = s7m;
            s8m = _mm_sub_pd(s2l, t6f);
            *((b4 + 504)) = s8m;
            t9g = _mm_add_pd(t5b, t0d);
            t0h = _mm_sub_pd(t6b, t9c);
            t1h = _mm_sub_pd(t5b, t0d);
            t2h = _mm_add_pd(t6b, t9c);
            t3h = _mm_add_pd(s9j, s5k);
            t4h = _mm_sub_pd(s6k, s0k);
            t5h = _mm_sub_pd(s9j, s5k);
            t6h = _mm_add_pd(s0k, s6k);
            t7h = _mm_add_pd(t9g, t3h);
            t8h = _mm_add_pd(t0h, t4h);
            t9h = _mm_sub_pd(t9g, t3h);
            t0i = _mm_sub_pd(t0h, t4h);
            t1i = _mm_sub_pd(t1h, t6h);
            t2i = _mm_sub_pd(t2h, t5h);
            t3i = _mm_add_pd(t1h, t6h);
            t4i = _mm_add_pd(t2h, t5h);
            t5i = _mm_add_pd(s7j, s3k);
            t6i = _mm_add_pd(s8j, s4k);
            t7i = _mm_sub_pd(s7j, s3k);
            t8i = _mm_sub_pd(s8j, s4k);
            t9i = _mm_add_pd(s1k, s7k);
            t0j = _mm_add_pd(s2k, s8k);
            t1j = _mm_sub_pd(s1k, s7k);
            t2j = _mm_sub_pd(s2k, s8k);
            t3j = _mm_add_pd(t5i, t9i);
            t4j = _mm_add_pd(t6i, t0j);
            t5j = _mm_sub_pd(t5i, t9i);
            t6j = _mm_sub_pd(t6i, t0j);
            a46 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t7i, t2j));
            a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t8i, t1j));
            s9m = _mm_sub_pd(a46, a56);
            s0n = _mm_add_pd(a46, a56);
            a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7i, t2j));
            a76 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t8i, t1j));
            s1n = _mm_sub_pd(a66, a76);
            s2n = _mm_add_pd(a66, a76);
            s3n = _mm_add_pd(t7h, t3j);
            *((b3 + 272)) = s3n;
            s4n = _mm_add_pd(t8h, t4j);
            *((b3 + 280)) = s4n;
            s5n = _mm_sub_pd(t7h, t3j);
            *((b4 + 1776)) = s5n;
            s6n = _mm_sub_pd(t4j, t8h);
            *((b4 + 1784)) = s6n;
            s7n = _mm_add_pd(t1i, s9m);
            *((b3 + 784)) = s7n;
            s8n = _mm_sub_pd(t2i, s0n);
            *((b3 + 792)) = s8n;
            s9n = _mm_sub_pd(t1i, s9m);
            *((b4 + 1264)) = s9n;
            s0o = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t2i, s0n));
            *((b4 + 1272)) = s0o;
            s1o = _mm_add_pd(t9h, t6j);
            *((b3 + 1296)) = s1o;
            s2o = _mm_sub_pd(t0i, t5j);
            *((b3 + 1304)) = s2o;
            s3o = _mm_sub_pd(t9h, t6j);
            *((b4 + 752)) = s3o;
            s4o = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0i, t5j));
            *((b4 + 760)) = s4o;
            s5o = _mm_add_pd(t3i, s1n);
            *((b3 + 1808)) = s5o;
            s6o = _mm_add_pd(t4i, s2n);
            *((b3 + 1816)) = s6o;
            s7o = _mm_sub_pd(t3i, s1n);
            *((b4 + 240)) = s7o;
            s8o = _mm_sub_pd(s2n, t4i);
            *((b4 + 248)) = s8o;
        }}
    }}
    a86 = ((__m128d  *) T);
    s9o = *(a86);
    s0p = *((a86 + 8));
    t7j = _mm_add_pd(s9o, s0p);
    t8j = _mm_sub_pd(s9o, s0p);
    s1p = *((a86 + 4));
    s2p = *((a86 + 12));
    t9j = _mm_add_pd(s1p, s2p);
    t0k = _mm_sub_pd(s1p, s2p);
    s3p = *((a86 + 2));
    s4p = *((a86 + 10));
    t1k = _mm_add_pd(s3p, s4p);
    s5p = *((a86 + 6));
    s6p = *((a86 + 14));
    t2k = _mm_add_pd(s5p, s6p);
    t3k = _mm_add_pd(t7j, t9j);
    t4k = _mm_sub_pd(t7j, t9j);
    t5k = _mm_add_pd(t1k, t2k);
    t6k = _mm_sub_pd(t1k, t2k);
    a96 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3p, s4p));
    a07 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5p, s6p));
    s7p = _mm_add_pd(a96, a07);
    s8p = _mm_sub_pd(a07, a96);
    t7k = _mm_add_pd(t8j, s7p);
    t8k = _mm_sub_pd(s8p, t0k);
    t9k = _mm_sub_pd(t8j, s7p);
    t0l = _mm_add_pd(t0k, s8p);
    s9p = *((a86 + 1));
    s0q = *((a86 + 9));
    t1l = _mm_add_pd(s9p, s0q);
    t2l = _mm_sub_pd(s9p, s0q);
    s1q = *((a86 + 5));
    s2q = *((a86 + 13));
    t3l = _mm_add_pd(s1q, s2q);
    t4l = _mm_sub_pd(s1q, s2q);
    s3q = *((a86 + 3));
    s4q = *((a86 + 11));
    t5l = _mm_add_pd(s3q, s4q);
    s5q = *((a86 + 7));
    s6q = *((a86 + 15));
    t6l = _mm_add_pd(s5q, s6q);
    t7l = _mm_add_pd(t1l, t3l);
    t8l = _mm_add_pd(t5l, t6l);
    a17 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s3q, s4q));
    a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s5q, s6q));
    s7q = _mm_add_pd(a17, a27);
    s8q = _mm_sub_pd(a27, a17);
    t9l = _mm_add_pd(t2l, s7q);
    t0m = _mm_sub_pd(s8q, t4l);
    t1m = _mm_sub_pd(t2l, s7q);
    t2m = _mm_add_pd(t4l, s8q);
    t3m = _mm_add_pd(t3k, t5k);
    t4m = _mm_sub_pd(t3k, t5k);
    t5m = _mm_add_pd(t7l, t8l);
    t6m = _mm_sub_pd(t7l, t8l);
    t7m = _mm_add_pd(t3m, t5m);
    a37 = ((__m128d  *) dst);
    s9q = _mm_add_pd(v_neg03(v_hi2(t7m, t7m)), v_lo2(t7m, t7m));
    *(a37) = s9q;
    s0r = v_neg23(_mm_sub_pd(t3m, t5m));
    *((a37 + 1024)) = s0r;
    s1r = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t4m), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t6m));
    s2r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t4m), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t6m));
    s3r = v_lo2(s1r, s2r);
    s4r = v_hi2(s1r, s2r);
    s5r = _mm_add_pd(s3r, s4r);
    *((a37 + 512)) = s5r;
    s6r = v_neg23(_mm_sub_pd(s3r, s4r));
    *((a37 + 1536)) = s6r;
    s7r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9l), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0m));
    s8r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9l), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0m));
    t8m = _mm_add_pd(t7k, s7r);
    t9m = _mm_add_pd(t8k, s8r);
    t0n = _mm_sub_pd(t7k, s7r);
    t1n = _mm_sub_pd(t8k, s8r);
    s9r = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t8m), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t9m));
    s0s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t8m), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t9m));
    s1s = v_lo2(s9r, s0s);
    s2s = v_hi2(s9r, s0s);
    s3s = _mm_add_pd(s1s, s2s);
    *((a37 + 128)) = s3s;
    s4s = v_neg23(_mm_sub_pd(s1s, s2s));
    *((a37 + 1920)) = s4s;
    s5s = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t0n), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t1n));
    s6s = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t0n), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t1n));
    s7s = v_lo2(s5s, s6s);
    s8s = v_hi2(s5s, s6s);
    s9s = _mm_add_pd(s7s, s8s);
    *((a37 + 1152)) = s9s;
    s0t = v_neg23(_mm_sub_pd(s7s, s8s));
    *((a37 + 896)) = s0t;
    a47 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1l, t3l));
    a57 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t6l));
    s1t = _mm_add_pd(a47, a57);
    s2t = _mm_sub_pd(a57, a47);
    t2n = _mm_add_pd(t4k, s1t);
    t3n = _mm_sub_pd(s2t, t6k);
    t4n = _mm_sub_pd(t4k, s1t);
    t5n = _mm_add_pd(t6k, s2t);
    s3t = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t2n), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t3n));
    s4t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t2n), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t3n));
    s5t = v_lo2(s3t, s4t);
    s6t = v_hi2(s3t, s4t);
    s7t = _mm_add_pd(s5t, s6t);
    *((a37 + 256)) = s7t;
    s8t = v_neg23(_mm_sub_pd(s5t, s6t));
    *((a37 + 1792)) = s8t;
    s9t = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t4n), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t5n));
    s0u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t4n), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t5n));
    s1u = v_lo2(s9t, s0u);
    s2u = v_hi2(s9t, s0u);
    s3u = _mm_add_pd(s1u, s2u);
    *((a37 + 1280)) = s3u;
    s4u = v_neg23(_mm_sub_pd(s1u, s2u));
    *((a37 + 768)) = s4u;
    s5u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1m), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2m));
    s6u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1m), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2m));
    t6n = _mm_add_pd(t9k, s5u);
    t7n = _mm_add_pd(t0l, s6u);
    t8n = _mm_sub_pd(t9k, s5u);
    t9n = _mm_sub_pd(t0l, s6u);
    s7u = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t6n), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t7n));
    s8u = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t6n), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t7n));
    s9u = v_lo2(s7u, s8u);
    s0v = v_hi2(s7u, s8u);
    s1v = _mm_add_pd(s9u, s0v);
    *((a37 + 384)) = s1v;
    s2v = v_neg23(_mm_sub_pd(s9u, s0v));
    *((a37 + 1664)) = s2v;
    s3v = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t8n), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t9n));
    s4v = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t8n), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t9n));
    s5v = v_lo2(s3v, s4v);
    s6v = v_hi2(s3v, s4v);
    s7v = _mm_add_pd(s5v, s6v);
    *((a37 + 1408)) = s7v;
    s8v = v_neg23(_mm_sub_pd(s5v, s6v));
    *((a37 + 640)) = s8v;
    {long i4; for(i4 = 0; i4 <= 126; i4++) {
        a67 = (16 * i4);
        b5 = (((__m128d  *) T) + a67);
        s9v = *((b5 + 16));
        s0w = *((b5 + 24));
        s1w = *((b5 + 20));
        s2w = *((b5 + 28));
        a77 = (D54 + (4 * i4));
        a87 = *(a77);
        a97 = *((a77 + 1));
        s3w = _mm_sub_pd(_mm_mul_pd(a87, s9v), _mm_mul_pd(a97, s0w));
        s4w = _mm_add_pd(_mm_mul_pd(a97, s9v), _mm_mul_pd(a87, s0w));
        a08 = *((a77 + 2));
        a18 = *((a77 + 3));
        s5w = _mm_sub_pd(_mm_mul_pd(a08, s1w), _mm_mul_pd(a18, s2w));
        s6w = _mm_add_pd(_mm_mul_pd(a18, s1w), _mm_mul_pd(a08, s2w));
        t0o = _mm_add_pd(s3w, s5w);
        t1o = _mm_add_pd(s4w, s6w);
        t2o = _mm_sub_pd(s3w, s5w);
        t3o = _mm_sub_pd(s4w, s6w);
        s7w = *((b5 + 17));
        s8w = *((b5 + 25));
        s9w = *((b5 + 21));
        s0x = *((b5 + 29));
        s1x = _mm_sub_pd(_mm_mul_pd(a87, s7w), _mm_mul_pd(a97, s8w));
        s2x = _mm_add_pd(_mm_mul_pd(a97, s7w), _mm_mul_pd(a87, s8w));
        s3x = _mm_sub_pd(_mm_mul_pd(a08, s9w), _mm_mul_pd(a18, s0x));
        s4x = _mm_add_pd(_mm_mul_pd(a18, s9w), _mm_mul_pd(a08, s0x));
        t4o = _mm_add_pd(s1x, s3x);
        t5o = _mm_add_pd(s2x, s4x);
        t6o = _mm_sub_pd(s1x, s3x);
        t7o = _mm_sub_pd(s2x, s4x);
        s5x = *((b5 + 18));
        s6x = *((b5 + 26));
        s7x = *((b5 + 22));
        s8x = *((b5 + 30));
        s9x = _mm_sub_pd(_mm_mul_pd(a87, s5x), _mm_mul_pd(a97, s6x));
        s0y = _mm_add_pd(_mm_mul_pd(a97, s5x), _mm_mul_pd(a87, s6x));
        s1y = _mm_sub_pd(_mm_mul_pd(a08, s7x), _mm_mul_pd(a18, s8x));
        s2y = _mm_add_pd(_mm_mul_pd(a18, s7x), _mm_mul_pd(a08, s8x));
        t8o = _mm_add_pd(s9x, s1y);
        t9o = _mm_add_pd(s0y, s2y);
        t0p = _mm_sub_pd(s9x, s1y);
        t1p = _mm_sub_pd(s0y, s2y);
        s3y = *((b5 + 19));
        s4y = *((b5 + 27));
        s5y = *((b5 + 23));
        s6y = *((b5 + 31));
        s7y = _mm_sub_pd(_mm_mul_pd(a87, s3y), _mm_mul_pd(a97, s4y));
        s8y = _mm_add_pd(_mm_mul_pd(a97, s3y), _mm_mul_pd(a87, s4y));
        s9y = _mm_sub_pd(_mm_mul_pd(a08, s5y), _mm_mul_pd(a18, s6y));
        s0z = _mm_add_pd(_mm_mul_pd(a18, s5y), _mm_mul_pd(a08, s6y));
        t2p = _mm_add_pd(s7y, s9y);
        t3p = _mm_add_pd(s8y, s0z);
        t4p = _mm_sub_pd(s7y, s9y);
        t5p = _mm_sub_pd(s8y, s0z);
        a28 = (D53 + a67);
        a38 = *(a28);
        a48 = *((a28 + 1));
        s1z = _mm_sub_pd(_mm_mul_pd(a38, t0o), _mm_mul_pd(a48, t1o));
        s2z = _mm_add_pd(_mm_mul_pd(a48, t0o), _mm_mul_pd(a38, t1o));
        a58 = *((a28 + 2));
        a68 = *((a28 + 3));
        s3z = _mm_sub_pd(_mm_mul_pd(a58, t4o), _mm_mul_pd(a68, t5o));
        s4z = _mm_add_pd(_mm_mul_pd(a68, t4o), _mm_mul_pd(a58, t5o));
        a78 = *((a28 + 4));
        a88 = *((a28 + 5));
        s5z = _mm_sub_pd(_mm_mul_pd(a78, t8o), _mm_mul_pd(a88, t9o));
        s6z = _mm_add_pd(_mm_mul_pd(a88, t8o), _mm_mul_pd(a78, t9o));
        a98 = *((a28 + 6));
        a09 = *((a28 + 7));
        s7z = _mm_sub_pd(_mm_mul_pd(a98, t2p), _mm_mul_pd(a09, t3p));
        s8z = _mm_add_pd(_mm_mul_pd(a09, t2p), _mm_mul_pd(a98, t3p));
        t6p = _mm_add_pd(s1z, s5z);
        t7p = _mm_add_pd(s2z, s6z);
        t8p = _mm_sub_pd(s1z, s5z);
        t9p = _mm_sub_pd(s2z, s6z);
        t0q = _mm_add_pd(s3z, s7z);
        t1q = _mm_add_pd(s4z, s8z);
        t2q = _mm_sub_pd(s3z, s7z);
        t3q = _mm_sub_pd(s4z, s8z);
        t4q = _mm_add_pd(t6p, t0q);
        t5q = _mm_add_pd(t7p, t1q);
        t6q = _mm_sub_pd(t6p, t0q);
        t7q = _mm_sub_pd(t7p, t1q);
        t8q = _mm_add_pd(t8p, t3q);
        t9q = _mm_sub_pd(t9p, t2q);
        t0r = _mm_sub_pd(t8p, t3q);
        t1r = _mm_add_pd(t9p, t2q);
        a19 = (D49 + a67);
        a29 = *(a19);
        a39 = *((a19 + 1));
        s9z = _mm_sub_pd(_mm_mul_pd(a29, t4q), _mm_mul_pd(a39, t5q));
        s0A = _mm_add_pd(_mm_mul_pd(a39, t4q), _mm_mul_pd(a29, t5q));
        s1A = v_lo2(s9z, s0A);
        s2A = v_hi2(s9z, s0A);
        a49 = ((__m128d  *) dst);
        b6 = (a49 + i4);
        s3A = _mm_add_pd(s1A, s2A);
        *((b6 + 1)) = s3A;
        b7 = (a49 - i4);
        s4A = v_neg23(_mm_sub_pd(s1A, s2A));
        *((b7 + 2047)) = s4A;
        a59 = *((a19 + 2));
        a69 = *((a19 + 3));
        s5A = _mm_sub_pd(_mm_mul_pd(a59, t8q), _mm_mul_pd(a69, t9q));
        s6A = _mm_add_pd(_mm_mul_pd(a69, t8q), _mm_mul_pd(a59, t9q));
        s7A = v_lo2(s5A, s6A);
        s8A = v_hi2(s5A, s6A);
        s9A = _mm_add_pd(s7A, s8A);
        *((b6 + 513)) = s9A;
        s0B = v_neg23(_mm_sub_pd(s7A, s8A));
        *((b7 + 1535)) = s0B;
        a79 = *((a19 + 4));
        a89 = *((a19 + 5));
        s1B = _mm_sub_pd(_mm_mul_pd(a79, t6q), _mm_mul_pd(a89, t7q));
        s2B = _mm_add_pd(_mm_mul_pd(a89, t6q), _mm_mul_pd(a79, t7q));
        s3B = v_lo2(s1B, s2B);
        s4B = v_hi2(s1B, s2B);
        s5B = _mm_add_pd(s3B, s4B);
        *((b6 + 1025)) = s5B;
        s6B = v_neg23(_mm_sub_pd(s3B, s4B));
        *((b7 + 1023)) = s6B;
        a99 = *((a19 + 6));
        a0a = *((a19 + 7));
        s7B = _mm_sub_pd(_mm_mul_pd(a99, t0r), _mm_mul_pd(a0a, t1r));
        s8B = _mm_add_pd(_mm_mul_pd(a0a, t0r), _mm_mul_pd(a99, t1r));
        s9B = v_lo2(s7B, s8B);
        s0C = v_hi2(s7B, s8B);
        s1C = _mm_add_pd(s9B, s0C);
        *((b6 + 1537)) = s1C;
        s2C = v_neg23(_mm_sub_pd(s9B, s0C));
        *((b7 + 511)) = s2C;
        a1a = *((a28 + 8));
        a2a = *((a28 + 9));
        s3C = _mm_sub_pd(_mm_mul_pd(a1a, t2o), _mm_mul_pd(a2a, t3o));
        s4C = _mm_add_pd(_mm_mul_pd(a2a, t2o), _mm_mul_pd(a1a, t3o));
        a3a = *((a28 + 10));
        a4a = *((a28 + 11));
        s5C = _mm_sub_pd(_mm_mul_pd(a3a, t6o), _mm_mul_pd(a4a, t7o));
        s6C = _mm_add_pd(_mm_mul_pd(a4a, t6o), _mm_mul_pd(a3a, t7o));
        a5a = *((a28 + 12));
        a6a = *((a28 + 13));
        s7C = _mm_sub_pd(_mm_mul_pd(a5a, t0p), _mm_mul_pd(a6a, t1p));
        s8C = _mm_add_pd(_mm_mul_pd(a6a, t0p), _mm_mul_pd(a5a, t1p));
        a7a = *((a28 + 14));
        a8a = *((a28 + 15));
        s9C = _mm_sub_pd(_mm_mul_pd(a7a, t4p), _mm_mul_pd(a8a, t5p));
        s0D = _mm_add_pd(_mm_mul_pd(a8a, t4p), _mm_mul_pd(a7a, t5p));
        t2r = _mm_add_pd(s3C, s7C);
        t3r = _mm_add_pd(s4C, s8C);
        t4r = _mm_sub_pd(s3C, s7C);
        t5r = _mm_sub_pd(s4C, s8C);
        t6r = _mm_add_pd(s5C, s9C);
        t7r = _mm_add_pd(s6C, s0D);
        t8r = _mm_sub_pd(s5C, s9C);
        t9r = _mm_sub_pd(s6C, s0D);
        t0s = _mm_add_pd(t2r, t6r);
        t1s = _mm_add_pd(t3r, t7r);
        t2s = _mm_sub_pd(t2r, t6r);
        t3s = _mm_sub_pd(t3r, t7r);
        t4s = _mm_add_pd(t4r, t9r);
        t5s = _mm_sub_pd(t5r, t8r);
        t6s = _mm_sub_pd(t4r, t9r);
        t7s = _mm_add_pd(t5r, t8r);
        a9a = *((a19 + 8));
        a0b = *((a19 + 9));
        s1D = _mm_sub_pd(_mm_mul_pd(a9a, t0s), _mm_mul_pd(a0b, t1s));
        s2D = _mm_add_pd(_mm_mul_pd(a0b, t0s), _mm_mul_pd(a9a, t1s));
        s3D = v_lo2(s1D, s2D);
        s4D = v_hi2(s1D, s2D);
        s5D = _mm_add_pd(s3D, s4D);
        *((b6 + 257)) = s5D;
        s6D = v_neg23(_mm_sub_pd(s3D, s4D));
        *((b7 + 1791)) = s6D;
        a1b = *((a19 + 10));
        a2b = *((a19 + 11));
        s7D = _mm_sub_pd(_mm_mul_pd(a1b, t4s), _mm_mul_pd(a2b, t5s));
        s8D = _mm_add_pd(_mm_mul_pd(a2b, t4s), _mm_mul_pd(a1b, t5s));
        s9D = v_lo2(s7D, s8D);
        s0E = v_hi2(s7D, s8D);
        s1E = _mm_add_pd(s9D, s0E);
        *((b6 + 769)) = s1E;
        s2E = v_neg23(_mm_sub_pd(s9D, s0E));
        *((b7 + 1279)) = s2E;
        a3b = *((a19 + 12));
        a4b = *((a19 + 13));
        s3E = _mm_sub_pd(_mm_mul_pd(a3b, t2s), _mm_mul_pd(a4b, t3s));
        s4E = _mm_add_pd(_mm_mul_pd(a4b, t2s), _mm_mul_pd(a3b, t3s));
        s5E = v_lo2(s3E, s4E);
        s6E = v_hi2(s3E, s4E);
        s7E = _mm_add_pd(s5E, s6E);
        *((b6 + 1281)) = s7E;
        s8E = v_neg23(_mm_sub_pd(s5E, s6E));
        *((b7 + 767)) = s8E;
        a5b = *((a19 + 14));
        a6b = *((a19 + 15));
        s9E = _mm_sub_pd(_mm_mul_pd(a5b, t6s), _mm_mul_pd(a6b, t7s));
        s0F = _mm_add_pd(_mm_mul_pd(a6b, t6s), _mm_mul_pd(a5b, t7s));
        s1F = v_lo2(s9E, s0F);
        s2F = v_hi2(s9E, s0F);
        s3F = _mm_add_pd(s1F, s2F);
        *((b6 + 1793)) = s3F;
        s4F = v_neg23(_mm_sub_pd(s1F, s2F));
        *((b7 + 255)) = s4F;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftfwd_double_8192_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[8192]);
     SPIRAL_ALIGNED(double T2[1024]);
    __m128d a02, a04, a05, a06, a07, a08, a09, a0a, a0b, a0c, a11, a12, a13, a14, a15, a16, a18, a19, a1b, a1c, a2, a21
            , a22, a23, a24, a25, a26, a27, a28, a29, a2a, a2b, a2c, a3, a31, a32, a33, a34, a35, a36, a37, a39, a3a, a3b
            , a3c, a4, a41, a43, a44, a45, a46, a47, a49, a4a, a4b, a5, a52, a53, a54, a55, a56, a57, a58, a59, a5a, a5b
            , a6, a61, a62, a63, a64, a65, a66, a68, a69, a6a, a6b, a7, a71, a72, a73, a74, a75, a76, a77, a78, a79, a7a
            , a7b, a8, a81, a82, a83, a84, a85, a86, a87, a88, a8a, a8b, a9, a91, a93, a94, a95, a96, a97, a99, a9a, a9b
            , s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0a
            , s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w
            , s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H, s1I, s1J
            , s1K, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u
            , s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C, s2D, s2E, s2F, s2G
            , s2H, s2I, s2J, s2K, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r
            , s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D
            , s3E, s3F, s3G, s3H, s3I, s3J, s3K, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o
            , s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A
            , s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l
            , s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57
            , s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i
            , s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6a, s6b, s6c, s6d, s6e, s6f
            , s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y, s6z, s7, s71
            , s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z
            , s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8a, s8b
            , s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x
            , s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J
            , s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v
            , s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h
            , t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t11, t12, t13, t14, t15
            , t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r
            , t1s, t1t, t1u, t1v, t1w, t1x, t1y, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e
            , t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t3, t31
            , t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n
            , t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a
            , t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w
            , t4x, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t6, t61, t62, t63, t64, t65, t66, t67, t68
            , t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u
            , t6v, t6w, t6x, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i
            , t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t8, t81, t82, t83, t84, t85, t86
            , t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s
            , t8t, t8u, t8v, t8w, t8x, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g
            , t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x;
    __m128d  *a01, *a03, *a42, *a48, *a51, *a67, *a89, *a98, *b, *b2, *b3, *b4, *b5;
    double  *b6, *b7;
    const double  *a;
    int a17, a1a, a38, a92;
    {long i; for(i = 0; i <= 7; i++) {
        {long i2; for(i2 = 0; i2 <= 15; i2++) {
            a = (src + ((2 * i) + (16 * i2)));
            s = _mm_loadu_pd(((const double  *) a));
            s2 = _mm_loadu_pd(((const double  *) (a + 4096)));
            t = _mm_add_pd(s, s2);
            t2 = _mm_sub_pd(s, s2);
            s3 = _mm_loadu_pd(((const double  *) (a + 2048)));
            s4 = _mm_loadu_pd(((const double  *) (a + 6144)));
            t3 = _mm_add_pd(s3, s4);
            t4 = _mm_sub_pd(s3, s4);
            s5 = _mm_loadu_pd(((const double  *) (a + 1024)));
            s6 = _mm_loadu_pd(((const double  *) (a + 5120)));
            t5 = _mm_add_pd(s5, s6);
            s7 = _mm_loadu_pd(((const double  *) (a + 3072)));
            s8 = _mm_loadu_pd(((const double  *) (a + 7168)));
            t6 = _mm_add_pd(s7, s8);
            t7 = _mm_add_pd(t, t3);
            t8 = _mm_sub_pd(t, t3);
            t9 = _mm_add_pd(t5, t6);
            t01 = _mm_sub_pd(t5, t6);
            a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
            a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
            s9 = _mm_add_pd(a2, a3);
            s01 = _mm_sub_pd(a3, a2);
            t11 = _mm_add_pd(t2, s9);
            t21 = _mm_sub_pd(s01, t4);
            t31 = _mm_sub_pd(t2, s9);
            t41 = _mm_add_pd(t4, s01);
            s11 = _mm_loadu_pd(((const double  *) (a + 256)));
            s21 = _mm_loadu_pd(((const double  *) (a + 4352)));
            t51 = _mm_add_pd(s11, s21);
            t61 = _mm_sub_pd(s11, s21);
            s31 = _mm_loadu_pd(((const double  *) (a + 2304)));
            s41 = _mm_loadu_pd(((const double  *) (a + 6400)));
            t71 = _mm_add_pd(s31, s41);
            t81 = _mm_sub_pd(s31, s41);
            s51 = _mm_loadu_pd(((const double  *) (a + 1280)));
            s61 = _mm_loadu_pd(((const double  *) (a + 5376)));
            t91 = _mm_add_pd(s51, s61);
            s71 = _mm_loadu_pd(((const double  *) (a + 3328)));
            s81 = _mm_loadu_pd(((const double  *) (a + 7424)));
            t02 = _mm_add_pd(s71, s81);
            t12 = _mm_add_pd(t51, t71);
            t22 = _mm_sub_pd(t51, t71);
            t32 = _mm_add_pd(t91, t02);
            t42 = _mm_sub_pd(t91, t02);
            a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
            a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
            s91 = _mm_add_pd(a4, a5);
            s02 = _mm_sub_pd(a5, a4);
            t52 = _mm_add_pd(t61, s91);
            t62 = _mm_sub_pd(s02, t81);
            t72 = _mm_sub_pd(t61, s91);
            t82 = _mm_add_pd(t81, s02);
            s12 = _mm_loadu_pd(((const double  *) (a + 512)));
            s22 = _mm_loadu_pd(((const double  *) (a + 4608)));
            t92 = _mm_add_pd(s12, s22);
            t03 = _mm_sub_pd(s12, s22);
            s32 = _mm_loadu_pd(((const double  *) (a + 2560)));
            s42 = _mm_loadu_pd(((const double  *) (a + 6656)));
            t13 = _mm_add_pd(s32, s42);
            t23 = _mm_sub_pd(s32, s42);
            s52 = _mm_loadu_pd(((const double  *) (a + 1536)));
            s62 = _mm_loadu_pd(((const double  *) (a + 5632)));
            t33 = _mm_add_pd(s52, s62);
            s72 = _mm_loadu_pd(((const double  *) (a + 3584)));
            s82 = _mm_loadu_pd(((const double  *) (a + 7680)));
            t43 = _mm_add_pd(s72, s82);
            t53 = _mm_add_pd(t92, t13);
            t63 = _mm_add_pd(t33, t43);
            a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
            a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
            s92 = _mm_add_pd(a6, a7);
            s03 = _mm_sub_pd(a7, a6);
            t73 = _mm_add_pd(t03, s92);
            t83 = _mm_sub_pd(s03, t23);
            t93 = _mm_sub_pd(t03, s92);
            t04 = _mm_add_pd(t23, s03);
            s13 = _mm_loadu_pd(((const double  *) (a + 768)));
            s23 = _mm_loadu_pd(((const double  *) (a + 4864)));
            t14 = _mm_add_pd(s13, s23);
            t24 = _mm_sub_pd(s13, s23);
            s33 = _mm_loadu_pd(((const double  *) (a + 2816)));
            s43 = _mm_loadu_pd(((const double  *) (a + 6912)));
            t34 = _mm_add_pd(s33, s43);
            t44 = _mm_sub_pd(s33, s43);
            s53 = _mm_loadu_pd(((const double  *) (a + 1792)));
            s63 = _mm_loadu_pd(((const double  *) (a + 5888)));
            t54 = _mm_add_pd(s53, s63);
            s73 = _mm_loadu_pd(((const double  *) (a + 3840)));
            s83 = _mm_loadu_pd(((const double  *) (a + 7936)));
            t64 = _mm_add_pd(s73, s83);
            t74 = _mm_add_pd(t14, t34);
            t84 = _mm_sub_pd(t14, t34);
            t94 = _mm_add_pd(t54, t64);
            t05 = _mm_sub_pd(t54, t64);
            a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
            a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
            s93 = _mm_add_pd(a8, a9);
            s04 = _mm_sub_pd(a9, a8);
            t15 = _mm_add_pd(t24, s93);
            t25 = _mm_sub_pd(s04, t44);
            t35 = _mm_sub_pd(t24, s93);
            t45 = _mm_add_pd(t44, s04);
            t55 = _mm_add_pd(t7, t9);
            t65 = _mm_sub_pd(t7, t9);
            t75 = _mm_add_pd(t53, t63);
            t85 = _mm_sub_pd(t53, t63);
            t95 = _mm_add_pd(t12, t32);
            t06 = _mm_add_pd(t74, t94);
            a01 = (((__m128d  *) T2) + i2);
            s14 = _mm_add_pd(t55, t75);
            *(a01) = s14;
            s24 = _mm_sub_pd(t55, t75);
            *((a01 + 256)) = s24;
            s34 = _mm_add_pd(t95, t06);
            *((a01 + 16)) = s34;
            s44 = _mm_sub_pd(t06, t95);
            *((a01 + 272)) = s44;
            a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
            a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
            s54 = _mm_add_pd(a11, a21);
            s64 = _mm_sub_pd(a21, a11);
            s74 = _mm_add_pd(t65, s54);
            *((a01 + 128)) = s74;
            s84 = _mm_sub_pd(s64, t85);
            *((a01 + 144)) = s84;
            s94 = _mm_sub_pd(t65, s54);
            *((a01 + 384)) = s94;
            s05 = _mm_add_pd(t85, s64);
            *((a01 + 400)) = s05;
            s15 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
            s25 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
            s35 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
            s45 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
            s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
            s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
            t16 = _mm_add_pd(t11, s35);
            t26 = _mm_add_pd(t21, s45);
            t36 = _mm_sub_pd(t11, s35);
            t46 = _mm_sub_pd(t21, s45);
            t56 = _mm_add_pd(s15, s55);
            t66 = _mm_add_pd(s25, s65);
            t76 = _mm_sub_pd(s15, s55);
            t86 = _mm_sub_pd(s25, s65);
            s75 = _mm_add_pd(t16, t56);
            *((a01 + 32)) = s75;
            s85 = _mm_add_pd(t26, t66);
            *((a01 + 48)) = s85;
            s95 = _mm_sub_pd(t16, t56);
            *((a01 + 480)) = s95;
            s06 = _mm_sub_pd(t66, t26);
            *((a01 + 496)) = s06;
            s16 = _mm_add_pd(t36, t86);
            *((a01 + 288)) = s16;
            s26 = _mm_sub_pd(t46, t76);
            *((a01 + 304)) = s26;
            s36 = _mm_sub_pd(t36, t86);
            *((a01 + 224)) = s36;
            s46 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t46, t76));
            *((a01 + 240)) = s46;
            s56 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
            s66 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
            a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
            a41 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
            s76 = _mm_add_pd(a31, a41);
            s86 = _mm_sub_pd(a41, a31);
            s96 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
            s07 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
            t96 = _mm_add_pd(t8, s76);
            t07 = _mm_sub_pd(s86, t01);
            t17 = _mm_sub_pd(t8, s76);
            t27 = _mm_add_pd(t01, s86);
            t37 = _mm_add_pd(s56, s96);
            t47 = _mm_add_pd(s66, s07);
            t57 = _mm_sub_pd(s56, s96);
            t67 = _mm_sub_pd(s66, s07);
            s17 = _mm_add_pd(t96, t37);
            *((a01 + 64)) = s17;
            s27 = _mm_add_pd(t07, t47);
            *((a01 + 80)) = s27;
            s37 = _mm_sub_pd(t96, t37);
            *((a01 + 448)) = s37;
            s47 = _mm_sub_pd(t47, t07);
            *((a01 + 464)) = s47;
            s57 = _mm_add_pd(t17, t67);
            *((a01 + 320)) = s57;
            s67 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t27, t57));
            *((a01 + 336)) = s67;
            s77 = _mm_sub_pd(t17, t67);
            *((a01 + 192)) = s77;
            s87 = _mm_sub_pd(t27, t57);
            *((a01 + 208)) = s87;
            s97 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
            s08 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
            s18 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
            s28 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
            s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
            s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
            t77 = _mm_add_pd(t31, s18);
            t87 = _mm_add_pd(t41, s28);
            t97 = _mm_sub_pd(t31, s18);
            t08 = _mm_sub_pd(t41, s28);
            t18 = _mm_add_pd(s97, s38);
            t28 = _mm_add_pd(s08, s48);
            t38 = _mm_sub_pd(s97, s38);
            t48 = _mm_sub_pd(s08, s48);
            s58 = _mm_add_pd(t77, t18);
            *((a01 + 96)) = s58;
            s68 = _mm_add_pd(t87, t28);
            *((a01 + 112)) = s68;
            s78 = _mm_sub_pd(t77, t18);
            *((a01 + 416)) = s78;
            s88 = _mm_sub_pd(t28, t87);
            *((a01 + 432)) = s88;
            s98 = _mm_add_pd(t97, t48);
            *((a01 + 352)) = s98;
            s09 = _mm_sub_pd(t08, t38);
            *((a01 + 368)) = s09;
            s19 = _mm_sub_pd(t97, t48);
            *((a01 + 160)) = s19;
            s29 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t08, t38));
            *((a01 + 176)) = s29;
        }}
        a51 = ((__m128d  *) T2);
        s39 = *(a51);
        s49 = *((a51 + 16));
        t58 = _mm_add_pd(s39, s49);
        t68 = _mm_sub_pd(s39, s49);
        s59 = *((a51 + 8));
        s69 = *((a51 + 24));
        t78 = _mm_add_pd(s59, s69);
        t88 = _mm_sub_pd(s59, s69);
        s79 = *((a51 + 4));
        s89 = *((a51 + 20));
        t98 = _mm_add_pd(s79, s89);
        s99 = *((a51 + 12));
        s0a = *((a51 + 28));
        t09 = _mm_add_pd(s99, s0a);
        t19 = _mm_add_pd(t58, t78);
        t29 = _mm_sub_pd(t58, t78);
        t39 = _mm_add_pd(t98, t09);
        t49 = _mm_sub_pd(t98, t09);
        a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s79, s89));
        a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s99, s0a));
        s1a = _mm_add_pd(a61, a71);
        s2a = _mm_sub_pd(a71, a61);
        t59 = _mm_add_pd(t68, s1a);
        t69 = _mm_sub_pd(s2a, t88);
        t79 = _mm_sub_pd(t68, s1a);
        t89 = _mm_add_pd(t88, s2a);
        s3a = *((a51 + 1));
        s4a = *((a51 + 17));
        t99 = _mm_add_pd(s3a, s4a);
        t0a = _mm_sub_pd(s3a, s4a);
        s5a = *((a51 + 9));
        s6a = *((a51 + 25));
        t1a = _mm_add_pd(s5a, s6a);
        t2a = _mm_sub_pd(s5a, s6a);
        s7a = *((a51 + 5));
        s8a = *((a51 + 21));
        t3a = _mm_add_pd(s7a, s8a);
        s9a = *((a51 + 13));
        s0b = *((a51 + 29));
        t4a = _mm_add_pd(s9a, s0b);
        t5a = _mm_add_pd(t99, t1a);
        t6a = _mm_sub_pd(t99, t1a);
        t7a = _mm_add_pd(t3a, t4a);
        t8a = _mm_sub_pd(t3a, t4a);
        a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7a, s8a));
        a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9a, s0b));
        s1b = _mm_add_pd(a81, a91);
        s2b = _mm_sub_pd(a91, a81);
        t9a = _mm_add_pd(t0a, s1b);
        t0b = _mm_sub_pd(s2b, t2a);
        t1b = _mm_sub_pd(t0a, s1b);
        t2b = _mm_add_pd(t2a, s2b);
        s3b = *((a51 + 2));
        s4b = *((a51 + 18));
        t3b = _mm_add_pd(s3b, s4b);
        t4b = _mm_sub_pd(s3b, s4b);
        s5b = *((a51 + 10));
        s6b = *((a51 + 26));
        t5b = _mm_add_pd(s5b, s6b);
        t6b = _mm_sub_pd(s5b, s6b);
        s7b = *((a51 + 6));
        s8b = *((a51 + 22));
        t7b = _mm_add_pd(s7b, s8b);
        s9b = *((a51 + 14));
        s0c = *((a51 + 30));
        t8b = _mm_add_pd(s9b, s0c);
        t9b = _mm_add_pd(t3b, t5b);
        t0c = _mm_add_pd(t7b, t8b);
        a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7b, s8b));
        a12 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9b, s0c));
        s1c = _mm_add_pd(a02, a12);
        s2c = _mm_sub_pd(a12, a02);
        t1c = _mm_add_pd(t4b, s1c);
        t2c = _mm_sub_pd(s2c, t6b);
        t3c = _mm_sub_pd(t4b, s1c);
        t4c = _mm_add_pd(t6b, s2c);
        s3c = *((a51 + 3));
        s4c = *((a51 + 19));
        t5c = _mm_add_pd(s3c, s4c);
        t6c = _mm_sub_pd(s3c, s4c);
        s5c = *((a51 + 11));
        s6c = *((a51 + 27));
        t7c = _mm_add_pd(s5c, s6c);
        t8c = _mm_sub_pd(s5c, s6c);
        s7c = *((a51 + 7));
        s8c = *((a51 + 23));
        t9c = _mm_add_pd(s7c, s8c);
        s9c = *((a51 + 15));
        s0d = *((a51 + 31));
        t0d = _mm_add_pd(s9c, s0d);
        t1d = _mm_add_pd(t5c, t7c);
        t2d = _mm_sub_pd(t5c, t7c);
        t3d = _mm_add_pd(t9c, t0d);
        t4d = _mm_sub_pd(t9c, t0d);
        a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7c, s8c));
        a32 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9c, s0d));
        s1d = _mm_add_pd(a22, a32);
        s2d = _mm_sub_pd(a32, a22);
        t5d = _mm_add_pd(t6c, s1d);
        t6d = _mm_sub_pd(s2d, t8c);
        t7d = _mm_sub_pd(t6c, s1d);
        t8d = _mm_add_pd(t8c, s2d);
        t9d = _mm_add_pd(t19, t39);
        t0e = _mm_sub_pd(t19, t39);
        t1e = _mm_add_pd(t9b, t0c);
        t2e = _mm_sub_pd(t9b, t0c);
        t3e = _mm_add_pd(t5a, t7a);
        t4e = _mm_add_pd(t1d, t3d);
        a42 = (((__m128d  *) T) + i);
        s3d = _mm_add_pd(t9d, t1e);
        *(a42) = s3d;
        s4d = _mm_sub_pd(t9d, t1e);
        *((a42 + 2048)) = s4d;
        s5d = _mm_add_pd(t3e, t4e);
        *((a42 + 8)) = s5d;
        s6d = _mm_sub_pd(t4e, t3e);
        *((a42 + 2056)) = s6d;
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t7a));
        a62 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1d, t3d));
        s7d = _mm_add_pd(a52, a62);
        s8d = _mm_sub_pd(a62, a52);
        s9d = _mm_add_pd(t0e, s7d);
        *((a42 + 1024)) = s9d;
        s0e = _mm_sub_pd(s8d, t2e);
        *((a42 + 1032)) = s0e;
        s1e = _mm_sub_pd(t0e, s7d);
        *((a42 + 3072)) = s1e;
        s2e = _mm_add_pd(t2e, s8d);
        *((a42 + 3080)) = s2e;
        s3e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
        s4e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
        s5e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1c), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2c));
        s6e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2c));
        s7e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5d), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6d));
        s8e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6d));
        t5e = _mm_add_pd(t59, s5e);
        t6e = _mm_add_pd(t69, s6e);
        t7e = _mm_sub_pd(t59, s5e);
        t8e = _mm_sub_pd(t69, s6e);
        t9e = _mm_add_pd(s3e, s7e);
        t0f = _mm_add_pd(s4e, s8e);
        t1f = _mm_sub_pd(s3e, s7e);
        t2f = _mm_sub_pd(s4e, s8e);
        s9e = _mm_add_pd(t5e, t9e);
        *((a42 + 256)) = s9e;
        s0f = _mm_add_pd(t6e, t0f);
        *((a42 + 264)) = s0f;
        s1f = _mm_sub_pd(t5e, t9e);
        *((a42 + 3840)) = s1f;
        s2f = _mm_sub_pd(t0f, t6e);
        *((a42 + 3848)) = s2f;
        s3f = _mm_add_pd(t7e, t2f);
        *((a42 + 2304)) = s3f;
        s4f = _mm_sub_pd(t8e, t1f);
        *((a42 + 2312)) = s4f;
        s5f = _mm_sub_pd(t7e, t2f);
        *((a42 + 1792)) = s5f;
        s6f = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8e, t1f));
        *((a42 + 1800)) = s6f;
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8a));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3b, t5b));
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7b, t8b));
        s9f = _mm_add_pd(a72, a82);
        s0g = _mm_sub_pd(a82, a72);
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
        s2g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4d));
        t3f = _mm_add_pd(t29, s9f);
        t4f = _mm_sub_pd(s0g, t49);
        t5f = _mm_sub_pd(t29, s9f);
        t6f = _mm_add_pd(t49, s0g);
        t7f = _mm_add_pd(s7f, s1g);
        t8f = _mm_add_pd(s8f, s2g);
        t9f = _mm_sub_pd(s7f, s1g);
        t0g = _mm_sub_pd(s8f, s2g);
        s3g = _mm_add_pd(t3f, t7f);
        *((a42 + 512)) = s3g;
        s4g = _mm_add_pd(t4f, t8f);
        *((a42 + 520)) = s4g;
        s5g = _mm_sub_pd(t3f, t7f);
        *((a42 + 3584)) = s5g;
        s6g = _mm_sub_pd(t8f, t4f);
        *((a42 + 3592)) = s6g;
        s7g = _mm_add_pd(t5f, t0g);
        *((a42 + 2560)) = s7g;
        s8g = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6f, t9f));
        *((a42 + 2568)) = s8g;
        s9g = _mm_sub_pd(t5f, t0g);
        *((a42 + 1536)) = s9g;
        s0h = _mm_sub_pd(t6f, t9f);
        *((a42 + 1544)) = s0h;
        s1h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1b), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t2b));
        s2h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t1b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2b));
        s3h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4c));
        s4h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4c));
        s5h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7d), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8d));
        s6h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7d), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8d));
        t1g = _mm_add_pd(t79, s3h);
        t2g = _mm_add_pd(t89, s4h);
        t3g = _mm_sub_pd(t79, s3h);
        t4g = _mm_sub_pd(t89, s4h);
        t5g = _mm_add_pd(s1h, s5h);
        t6g = _mm_add_pd(s2h, s6h);
        t7g = _mm_sub_pd(s1h, s5h);
        t8g = _mm_sub_pd(s2h, s6h);
        s7h = _mm_add_pd(t1g, t5g);
        *((a42 + 768)) = s7h;
        s8h = _mm_add_pd(t2g, t6g);
        *((a42 + 776)) = s8h;
        s9h = _mm_sub_pd(t1g, t5g);
        *((a42 + 3328)) = s9h;
        s0i = _mm_sub_pd(t6g, t2g);
        *((a42 + 3336)) = s0i;
        s1i = _mm_add_pd(t3g, t8g);
        *((a42 + 2816)) = s1i;
        s2i = _mm_sub_pd(t4g, t7g);
        *((a42 + 2824)) = s2i;
        s3i = _mm_sub_pd(t3g, t8g);
        *((a42 + 1280)) = s3i;
        s4i = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4g, t7g));
        *((a42 + 1288)) = s4i;
        {long i3; for(i3 = 0; i3 <= 14; i3++) {
            a92 = (32 * i3);
            b = (((__m128d  *) T2) + a92);
            s5i = *((b + 32));
            s6i = *((b + 48));
            s7i = *((b + 33));
            s8i = *((b + 49));
            s9i = *((b + 34));
            s0j = *((b + 50));
            s1j = *((b + 35));
            s2j = *((b + 51));
            s3j = *((b + 36));
            s4j = *((b + 52));
            s5j = *((b + 37));
            s6j = *((b + 53));
            s7j = *((b + 38));
            s8j = *((b + 54));
            s9j = *((b + 39));
            s0k = *((b + 55));
            s1k = *((b + 40));
            s2k = *((b + 56));
            s3k = *((b + 41));
            s4k = *((b + 57));
            s5k = *((b + 42));
            s6k = *((b + 58));
            s7k = *((b + 43));
            s8k = *((b + 59));
            s9k = *((b + 44));
            s0l = *((b + 60));
            s1l = *((b + 45));
            s2l = *((b + 61));
            s3l = *((b + 46));
            s4l = *((b + 62));
            s5l = *((b + 47));
            s6l = *((b + 63));
            a03 = (D59 + a92);
            a13 = *(a03);
            a23 = *((a03 + 1));
            s7l = _mm_sub_pd(_mm_mul_pd(a13, s5i), _mm_mul_pd(a23, s6i));
            s8l = _mm_add_pd(_mm_mul_pd(a23, s5i), _mm_mul_pd(a13, s6i));
            a33 = *((a03 + 2));
            a43 = *((a03 + 3));
            s9l = _mm_sub_pd(_mm_mul_pd(a33, s7i), _mm_mul_pd(a43, s8i));
            s0m = _mm_add_pd(_mm_mul_pd(a43, s7i), _mm_mul_pd(a33, s8i));
            a53 = *((a03 + 4));
            a63 = *((a03 + 5));
            s1m = _mm_sub_pd(_mm_mul_pd(a53, s9i), _mm_mul_pd(a63, s0j));
            s2m = _mm_add_pd(_mm_mul_pd(a63, s9i), _mm_mul_pd(a53, s0j));
            a73 = *((a03 + 6));
            a83 = *((a03 + 7));
            s3m = _mm_sub_pd(_mm_mul_pd(a73, s1j), _mm_mul_pd(a83, s2j));
            s4m = _mm_add_pd(_mm_mul_pd(a83, s1j), _mm_mul_pd(a73, s2j));
            a93 = *((a03 + 8));
            a04 = *((a03 + 9));
            s5m = _mm_sub_pd(_mm_mul_pd(a93, s3j), _mm_mul_pd(a04, s4j));
            s6m = _mm_add_pd(_mm_mul_pd(a04, s3j), _mm_mul_pd(a93, s4j));
            a14 = *((a03 + 10));
            a24 = *((a03 + 11));
            s7m = _mm_sub_pd(_mm_mul_pd(a14, s5j), _mm_mul_pd(a24, s6j));
            s8m = _mm_add_pd(_mm_mul_pd(a24, s5j), _mm_mul_pd(a14, s6j));
            a34 = *((a03 + 12));
            a44 = *((a03 + 13));
            s9m = _mm_sub_pd(_mm_mul_pd(a34, s7j), _mm_mul_pd(a44, s8j));
            s0n = _mm_add_pd(_mm_mul_pd(a44, s7j), _mm_mul_pd(a34, s8j));
            a54 = *((a03 + 14));
            a64 = *((a03 + 15));
            s1n = _mm_sub_pd(_mm_mul_pd(a54, s9j), _mm_mul_pd(a64, s0k));
            s2n = _mm_add_pd(_mm_mul_pd(a64, s9j), _mm_mul_pd(a54, s0k));
            a74 = *((a03 + 16));
            a84 = *((a03 + 17));
            s3n = _mm_sub_pd(_mm_mul_pd(a74, s1k), _mm_mul_pd(a84, s2k));
            s4n = _mm_add_pd(_mm_mul_pd(a84, s1k), _mm_mul_pd(a74, s2k));
            a94 = *((a03 + 18));
            a05 = *((a03 + 19));
            s5n = _mm_sub_pd(_mm_mul_pd(a94, s3k), _mm_mul_pd(a05, s4k));
            s6n = _mm_add_pd(_mm_mul_pd(a05, s3k), _mm_mul_pd(a94, s4k));
            a15 = *((a03 + 20));
            a25 = *((a03 + 21));
            s7n = _mm_sub_pd(_mm_mul_pd(a15, s5k), _mm_mul_pd(a25, s6k));
            s8n = _mm_add_pd(_mm_mul_pd(a25, s5k), _mm_mul_pd(a15, s6k));
            a35 = *((a03 + 22));
            a45 = *((a03 + 23));
            s9n = _mm_sub_pd(_mm_mul_pd(a35, s7k), _mm_mul_pd(a45, s8k));
            s0o = _mm_add_pd(_mm_mul_pd(a45, s7k), _mm_mul_pd(a35, s8k));
            a55 = *((a03 + 24));
            a65 = *((a03 + 25));
            s1o = _mm_sub_pd(_mm_mul_pd(a55, s9k), _mm_mul_pd(a65, s0l));
            s2o = _mm_add_pd(_mm_mul_pd(a65, s9k), _mm_mul_pd(a55, s0l));
            a75 = *((a03 + 26));
            a85 = *((a03 + 27));
            s3o = _mm_sub_pd(_mm_mul_pd(a75, s1l), _mm_mul_pd(a85, s2l));
            s4o = _mm_add_pd(_mm_mul_pd(a85, s1l), _mm_mul_pd(a75, s2l));
            a95 = *((a03 + 28));
            a06 = *((a03 + 29));
            s5o = _mm_sub_pd(_mm_mul_pd(a95, s3l), _mm_mul_pd(a06, s4l));
            s6o = _mm_add_pd(_mm_mul_pd(a06, s3l), _mm_mul_pd(a95, s4l));
            a16 = *((a03 + 30));
            a26 = *((a03 + 31));
            s7o = _mm_sub_pd(_mm_mul_pd(a16, s5l), _mm_mul_pd(a26, s6l));
            s8o = _mm_add_pd(_mm_mul_pd(a26, s5l), _mm_mul_pd(a16, s6l));
            t9g = _mm_add_pd(s7l, s3n);
            t0h = _mm_add_pd(s8l, s4n);
            t1h = _mm_sub_pd(s7l, s3n);
            t2h = _mm_sub_pd(s8l, s4n);
            t3h = _mm_add_pd(s9l, s5n);
            t4h = _mm_add_pd(s0m, s6n);
            t5h = _mm_sub_pd(s9l, s5n);
            t6h = _mm_sub_pd(s0m, s6n);
            s9o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5h), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6h));
            s0p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6h));
            t7h = _mm_add_pd(s1m, s7n);
            t8h = _mm_add_pd(s2m, s8n);
            a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1m, s7n));
            a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2m, s8n));
            s1p = _mm_sub_pd(a36, a46);
            s2p = _mm_add_pd(a36, a46);
            t9h = _mm_add_pd(s3m, s9n);
            t0i = _mm_add_pd(s4m, s0o);
            t1i = _mm_sub_pd(s3m, s9n);
            t2i = _mm_sub_pd(s4m, s0o);
            s3p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1i), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2i));
            s4p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1i), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2i));
            t3i = _mm_add_pd(s5m, s1o);
            t4i = _mm_add_pd(s6m, s2o);
            t5i = _mm_sub_pd(s5m, s1o);
            t6i = _mm_sub_pd(s6m, s2o);
            t7i = _mm_add_pd(s7m, s3o);
            t8i = _mm_add_pd(s8m, s4o);
            t9i = _mm_sub_pd(s7m, s3o);
            t0j = _mm_sub_pd(s8m, s4o);
            s5p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9i), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0j));
            s6p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9i), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0j));
            t1j = _mm_add_pd(s9m, s5o);
            t2j = _mm_add_pd(s0n, s6o);
            a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9m, s5o));
            a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0n, s6o));
            s7p = _mm_sub_pd(a56, a66);
            s8p = _mm_add_pd(a56, a66);
            t3j = _mm_add_pd(s1n, s7o);
            t4j = _mm_add_pd(s2n, s8o);
            t5j = _mm_sub_pd(s1n, s7o);
            t6j = _mm_sub_pd(s2n, s8o);
            s9p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5j), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6j));
            s0q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5j), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6j));
            t7j = _mm_add_pd(t9g, t3i);
            t8j = _mm_add_pd(t0h, t4i);
            t9j = _mm_sub_pd(t9g, t3i);
            t0k = _mm_sub_pd(t0h, t4i);
            t1k = _mm_add_pd(t7h, t1j);
            t2k = _mm_add_pd(t8h, t2j);
            t3k = _mm_sub_pd(t7h, t1j);
            t4k = _mm_sub_pd(t8h, t2j);
            t5k = _mm_add_pd(t7j, t1k);
            t6k = _mm_add_pd(t8j, t2k);
            t7k = _mm_sub_pd(t7j, t1k);
            t8k = _mm_sub_pd(t8j, t2k);
            t9k = _mm_add_pd(t9j, t4k);
            t0l = _mm_sub_pd(t0k, t3k);
            t1l = _mm_sub_pd(t9j, t4k);
            t2l = _mm_add_pd(t0k, t3k);
            t3l = _mm_add_pd(t3h, t7i);
            t4l = _mm_add_pd(t4h, t8i);
            t5l = _mm_sub_pd(t3h, t7i);
            t6l = _mm_sub_pd(t4h, t8i);
            t7l = _mm_add_pd(t9h, t3j);
            t8l = _mm_add_pd(t0i, t4j);
            t9l = _mm_sub_pd(t9h, t3j);
            t0m = _mm_sub_pd(t0i, t4j);
            t1m = _mm_add_pd(t3l, t7l);
            t2m = _mm_add_pd(t4l, t8l);
            t3m = _mm_sub_pd(t3l, t7l);
            t4m = _mm_sub_pd(t4l, t8l);
            a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t5l, t0m));
            a86 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t6l, t9l));
            s1q = _mm_sub_pd(a76, a86);
            s2q = _mm_add_pd(a76, a86);
            a96 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t0m));
            a07 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t6l, t9l));
            s3q = _mm_sub_pd(a96, a07);
            s4q = _mm_add_pd(a96, a07);
            a17 = (16 * i3);
            b2 = (((__m128d  *) T) + i);
            b3 = (b2 + a17);
            s5q = _mm_add_pd(t5k, t1m);
            *((b3 + 16)) = s5q;
            s6q = _mm_add_pd(t6k, t2m);
            *((b3 + 24)) = s6q;
            b4 = (b2 - a17);
            s7q = _mm_sub_pd(t5k, t1m);
            *((b4 + 4080)) = s7q;
            s8q = _mm_sub_pd(t2m, t6k);
            *((b4 + 4088)) = s8q;
            s9q = _mm_add_pd(t9k, s1q);
            *((b3 + 1040)) = s9q;
            s0r = _mm_sub_pd(t0l, s2q);
            *((b3 + 1048)) = s0r;
            s1r = _mm_sub_pd(t9k, s1q);
            *((b4 + 3056)) = s1r;
            s2r = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0l, s2q));
            *((b4 + 3064)) = s2r;
            s3r = _mm_add_pd(t7k, t4m);
            *((b3 + 2064)) = s3r;
            s4r = _mm_sub_pd(t8k, t3m);
            *((b3 + 2072)) = s4r;
            s5r = _mm_sub_pd(t7k, t4m);
            *((b4 + 2032)) = s5r;
            s6r = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8k, t3m));
            *((b4 + 2040)) = s6r;
            s7r = _mm_add_pd(t1l, s3q);
            *((b3 + 3088)) = s7r;
            s8r = _mm_add_pd(t2l, s4q);
            *((b3 + 3096)) = s8r;
            s9r = _mm_sub_pd(t1l, s3q);
            *((b4 + 1008)) = s9r;
            s0s = _mm_sub_pd(s4q, t2l);
            *((b4 + 1016)) = s0s;
            t5m = _mm_add_pd(t1h, t6i);
            t6m = _mm_sub_pd(t2h, t5i);
            t7m = _mm_sub_pd(t1h, t6i);
            t8m = _mm_add_pd(t2h, t5i);
            t9m = _mm_add_pd(s1p, s7p);
            t0n = _mm_sub_pd(s8p, s2p);
            t1n = _mm_sub_pd(s1p, s7p);
            t2n = _mm_add_pd(s2p, s8p);
            t3n = _mm_add_pd(t5m, t9m);
            t4n = _mm_add_pd(t6m, t0n);
            t5n = _mm_sub_pd(t5m, t9m);
            t6n = _mm_sub_pd(t6m, t0n);
            t7n = _mm_sub_pd(t7m, t2n);
            t8n = _mm_sub_pd(t8m, t1n);
            t9n = _mm_add_pd(t7m, t2n);
            t0o = _mm_add_pd(t8m, t1n);
            t1o = _mm_add_pd(s9o, s5p);
            t2o = _mm_add_pd(s0p, s6p);
            t3o = _mm_sub_pd(s9o, s5p);
            t4o = _mm_sub_pd(s0p, s6p);
            t5o = _mm_add_pd(s3p, s9p);
            t6o = _mm_add_pd(s4p, s0q);
            t7o = _mm_sub_pd(s3p, s9p);
            t8o = _mm_sub_pd(s4p, s0q);
            t9o = _mm_add_pd(t1o, t5o);
            t0p = _mm_add_pd(t2o, t6o);
            t1p = _mm_sub_pd(t1o, t5o);
            t2p = _mm_sub_pd(t2o, t6o);
            a27 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t3o, t8o));
            a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4o, t7o));
            s1s = _mm_sub_pd(a27, a37);
            s2s = _mm_add_pd(a27, a37);
            a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3o, t8o));
            a57 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t4o, t7o));
            s3s = _mm_sub_pd(a47, a57);
            s4s = _mm_add_pd(a47, a57);
            s5s = _mm_add_pd(t3n, t9o);
            *((b3 + 528)) = s5s;
            s6s = _mm_add_pd(t4n, t0p);
            *((b3 + 536)) = s6s;
            s7s = _mm_sub_pd(t3n, t9o);
            *((b4 + 3568)) = s7s;
            s8s = _mm_sub_pd(t0p, t4n);
            *((b4 + 3576)) = s8s;
            s9s = _mm_add_pd(t7n, s1s);
            *((b3 + 1552)) = s9s;
            s0t = _mm_sub_pd(t8n, s2s);
            *((b3 + 1560)) = s0t;
            s1t = _mm_sub_pd(t7n, s1s);
            *((b4 + 2544)) = s1t;
            s2t = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8n, s2s));
            *((b4 + 2552)) = s2t;
            s3t = _mm_add_pd(t5n, t2p);
            *((b3 + 2576)) = s3t;
            s4t = _mm_sub_pd(t6n, t1p);
            *((b3 + 2584)) = s4t;
            s5t = _mm_sub_pd(t5n, t2p);
            *((b4 + 1520)) = s5t;
            s6t = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6n, t1p));
            *((b4 + 1528)) = s6t;
            s7t = _mm_add_pd(t9n, s3s);
            *((b3 + 3600)) = s7t;
            s8t = _mm_add_pd(t0o, s4s);
            *((b3 + 3608)) = s8t;
            s9t = _mm_sub_pd(t9n, s3s);
            *((b4 + 496)) = s9t;
            s0u = _mm_sub_pd(s4s, t0o);
            *((b4 + 504)) = s0u;
        }}
    }}
    a67 = ((__m128d  *) T);
    s1u = *(a67);
    s2u = *((a67 + 8));
    t3p = _mm_add_pd(s1u, s2u);
    t4p = _mm_sub_pd(s1u, s2u);
    s3u = *((a67 + 4));
    s4u = *((a67 + 12));
    t5p = _mm_add_pd(s3u, s4u);
    t6p = _mm_sub_pd(s3u, s4u);
    s5u = *((a67 + 2));
    s6u = *((a67 + 10));
    t7p = _mm_add_pd(s5u, s6u);
    s7u = *((a67 + 6));
    s8u = *((a67 + 14));
    t8p = _mm_add_pd(s7u, s8u);
    t9p = _mm_add_pd(t3p, t5p);
    t0q = _mm_sub_pd(t3p, t5p);
    t1q = _mm_add_pd(t7p, t8p);
    t2q = _mm_sub_pd(t7p, t8p);
    a77 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5u, s6u));
    a87 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7u, s8u));
    s9u = _mm_add_pd(a77, a87);
    s0v = _mm_sub_pd(a87, a77);
    t3q = _mm_add_pd(t4p, s9u);
    t4q = _mm_sub_pd(s0v, t6p);
    t5q = _mm_sub_pd(t4p, s9u);
    t6q = _mm_add_pd(t6p, s0v);
    s1v = *((a67 + 1));
    s2v = *((a67 + 9));
    t7q = _mm_add_pd(s1v, s2v);
    t8q = _mm_sub_pd(s1v, s2v);
    s3v = *((a67 + 5));
    s4v = *((a67 + 13));
    t9q = _mm_add_pd(s3v, s4v);
    t0r = _mm_sub_pd(s3v, s4v);
    s5v = *((a67 + 3));
    s6v = *((a67 + 11));
    t1r = _mm_add_pd(s5v, s6v);
    s7v = *((a67 + 7));
    s8v = *((a67 + 15));
    t2r = _mm_add_pd(s7v, s8v);
    t3r = _mm_add_pd(t7q, t9q);
    t4r = _mm_add_pd(t1r, t2r);
    a97 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5v, s6v));
    a08 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7v, s8v));
    s9v = _mm_add_pd(a97, a08);
    s0w = _mm_sub_pd(a08, a97);
    t5r = _mm_add_pd(t8q, s9v);
    t6r = _mm_sub_pd(s0w, t0r);
    t7r = _mm_sub_pd(t8q, s9v);
    t8r = _mm_add_pd(t0r, s0w);
    t9r = _mm_add_pd(t9p, t1q);
    t0s = _mm_sub_pd(t9p, t1q);
    t1s = _mm_add_pd(t3r, t4r);
    t2s = _mm_sub_pd(t3r, t4r);
    t3s = _mm_add_pd(t9r, t1s);
    s1w = _mm_add_pd(v_neg03(v_hi2(t3s, t3s)), v_lo2(t3s, t3s));
    _mm_storeu_pd(((double  *) dst), s1w);
    s2w = v_neg23(_mm_sub_pd(t9r, t1s));
    _mm_storeu_pd(((double  *) (dst + 4096)), s2w);
    s3w = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t0s), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t2s));
    s4w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t0s), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t2s));
    s5w = v_lo2(s3w, s4w);
    s6w = v_hi2(s3w, s4w);
    s7w = _mm_add_pd(s5w, s6w);
    _mm_storeu_pd(((double  *) (dst + 2048)), s7w);
    s8w = v_neg23(_mm_sub_pd(s5w, s6w));
    _mm_storeu_pd(((double  *) (dst + 6144)), s8w);
    s9w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5r), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6r));
    s0x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6r));
    t4s = _mm_add_pd(t3q, s9w);
    t5s = _mm_add_pd(t4q, s0x);
    t6s = _mm_sub_pd(t3q, s9w);
    t7s = _mm_sub_pd(t4q, s0x);
    s1x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t4s), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t5s));
    s2x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t4s), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t5s));
    s3x = v_lo2(s1x, s2x);
    s4x = v_hi2(s1x, s2x);
    s5x = _mm_add_pd(s3x, s4x);
    _mm_storeu_pd(((double  *) (dst + 512)), s5x);
    s6x = v_neg23(_mm_sub_pd(s3x, s4x));
    _mm_storeu_pd(((double  *) (dst + 7680)), s6x);
    s7x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t6s), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t7s));
    s8x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t6s), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t7s));
    s9x = v_lo2(s7x, s8x);
    s0y = v_hi2(s7x, s8x);
    s1y = _mm_add_pd(s9x, s0y);
    _mm_storeu_pd(((double  *) (dst + 4608)), s1y);
    s2y = v_neg23(_mm_sub_pd(s9x, s0y));
    _mm_storeu_pd(((double  *) (dst + 3584)), s2y);
    a18 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7q, t9q));
    a28 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1r, t2r));
    s3y = _mm_add_pd(a18, a28);
    s4y = _mm_sub_pd(a28, a18);
    t8s = _mm_add_pd(t0q, s3y);
    t9s = _mm_sub_pd(s4y, t2q);
    t0t = _mm_sub_pd(t0q, s3y);
    t1t = _mm_add_pd(t2q, s4y);
    s5y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t8s), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t9s));
    s6y = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t8s), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t9s));
    s7y = v_lo2(s5y, s6y);
    s8y = v_hi2(s5y, s6y);
    s9y = _mm_add_pd(s7y, s8y);
    _mm_storeu_pd(((double  *) (dst + 1024)), s9y);
    s0z = v_neg23(_mm_sub_pd(s7y, s8y));
    _mm_storeu_pd(((double  *) (dst + 7168)), s0z);
    s1z = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t0t), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t1t));
    s2z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t0t), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t1t));
    s3z = v_lo2(s1z, s2z);
    s4z = v_hi2(s1z, s2z);
    s5z = _mm_add_pd(s3z, s4z);
    _mm_storeu_pd(((double  *) (dst + 5120)), s5z);
    s6z = v_neg23(_mm_sub_pd(s3z, s4z));
    _mm_storeu_pd(((double  *) (dst + 3072)), s6z);
    s7z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7r), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8r));
    s8z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8r));
    t2t = _mm_add_pd(t5q, s7z);
    t3t = _mm_add_pd(t6q, s8z);
    t4t = _mm_sub_pd(t5q, s7z);
    t5t = _mm_sub_pd(t6q, s8z);
    s9z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t2t), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3t));
    s0A = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t2t), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t3t));
    s1A = v_lo2(s9z, s0A);
    s2A = v_hi2(s9z, s0A);
    s3A = _mm_add_pd(s1A, s2A);
    _mm_storeu_pd(((double  *) (dst + 1536)), s3A);
    s4A = v_neg23(_mm_sub_pd(s1A, s2A));
    _mm_storeu_pd(((double  *) (dst + 6656)), s4A);
    s5A = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t4t), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t5t));
    s6A = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4t), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t5t));
    s7A = v_lo2(s5A, s6A);
    s8A = v_hi2(s5A, s6A);
    s9A = _mm_add_pd(s7A, s8A);
    _mm_storeu_pd(((double  *) (dst + 5632)), s9A);
    s0B = v_neg23(_mm_sub_pd(s7A, s8A));
    _mm_storeu_pd(((double  *) (dst + 2560)), s0B);
    {long i4; for(i4 = 0; i4 <= 254; i4++) {
        a38 = (16 * i4);
        b5 = (((__m128d  *) T) + a38);
        s1B = *((b5 + 16));
        s2B = *((b5 + 24));
        s3B = *((b5 + 20));
        s4B = *((b5 + 28));
        a48 = (D58 + (4 * i4));
        a58 = *(a48);
        a68 = *((a48 + 1));
        s5B = _mm_sub_pd(_mm_mul_pd(a58, s1B), _mm_mul_pd(a68, s2B));
        s6B = _mm_add_pd(_mm_mul_pd(a68, s1B), _mm_mul_pd(a58, s2B));
        a78 = *((a48 + 2));
        a88 = *((a48 + 3));
        s7B = _mm_sub_pd(_mm_mul_pd(a78, s3B), _mm_mul_pd(a88, s4B));
        s8B = _mm_add_pd(_mm_mul_pd(a88, s3B), _mm_mul_pd(a78, s4B));
        t6t = _mm_add_pd(s5B, s7B);
        t7t = _mm_add_pd(s6B, s8B);
        t8t = _mm_sub_pd(s5B, s7B);
        t9t = _mm_sub_pd(s6B, s8B);
        s9B = *((b5 + 17));
        s0C = *((b5 + 25));
        s1C = *((b5 + 21));
        s2C = *((b5 + 29));
        s3C = _mm_sub_pd(_mm_mul_pd(a58, s9B), _mm_mul_pd(a68, s0C));
        s4C = _mm_add_pd(_mm_mul_pd(a68, s9B), _mm_mul_pd(a58, s0C));
        s5C = _mm_sub_pd(_mm_mul_pd(a78, s1C), _mm_mul_pd(a88, s2C));
        s6C = _mm_add_pd(_mm_mul_pd(a88, s1C), _mm_mul_pd(a78, s2C));
        t0u = _mm_add_pd(s3C, s5C);
        t1u = _mm_add_pd(s4C, s6C);
        t2u = _mm_sub_pd(s3C, s5C);
        t3u = _mm_sub_pd(s4C, s6C);
        s7C = *((b5 + 18));
        s8C = *((b5 + 26));
        s9C = *((b5 + 22));
        s0D = *((b5 + 30));
        s1D = _mm_sub_pd(_mm_mul_pd(a58, s7C), _mm_mul_pd(a68, s8C));
        s2D = _mm_add_pd(_mm_mul_pd(a68, s7C), _mm_mul_pd(a58, s8C));
        s3D = _mm_sub_pd(_mm_mul_pd(a78, s9C), _mm_mul_pd(a88, s0D));
        s4D = _mm_add_pd(_mm_mul_pd(a88, s9C), _mm_mul_pd(a78, s0D));
        t4u = _mm_add_pd(s1D, s3D);
        t5u = _mm_add_pd(s2D, s4D);
        t6u = _mm_sub_pd(s1D, s3D);
        t7u = _mm_sub_pd(s2D, s4D);
        s5D = *((b5 + 19));
        s6D = *((b5 + 27));
        s7D = *((b5 + 23));
        s8D = *((b5 + 31));
        s9D = _mm_sub_pd(_mm_mul_pd(a58, s5D), _mm_mul_pd(a68, s6D));
        s0E = _mm_add_pd(_mm_mul_pd(a68, s5D), _mm_mul_pd(a58, s6D));
        s1E = _mm_sub_pd(_mm_mul_pd(a78, s7D), _mm_mul_pd(a88, s8D));
        s2E = _mm_add_pd(_mm_mul_pd(a88, s7D), _mm_mul_pd(a78, s8D));
        t8u = _mm_add_pd(s9D, s1E);
        t9u = _mm_add_pd(s0E, s2E);
        t0v = _mm_sub_pd(s9D, s1E);
        t1v = _mm_sub_pd(s0E, s2E);
        a98 = (D57 + a38);
        a09 = *(a98);
        a19 = *((a98 + 1));
        s3E = _mm_sub_pd(_mm_mul_pd(a09, t6t), _mm_mul_pd(a19, t7t));
        s4E = _mm_add_pd(_mm_mul_pd(a19, t6t), _mm_mul_pd(a09, t7t));
        a29 = *((a98 + 2));
        a39 = *((a98 + 3));
        s5E = _mm_sub_pd(_mm_mul_pd(a29, t0u), _mm_mul_pd(a39, t1u));
        s6E = _mm_add_pd(_mm_mul_pd(a39, t0u), _mm_mul_pd(a29, t1u));
        a49 = *((a98 + 4));
        a59 = *((a98 + 5));
        s7E = _mm_sub_pd(_mm_mul_pd(a49, t4u), _mm_mul_pd(a59, t5u));
        s8E = _mm_add_pd(_mm_mul_pd(a59, t4u), _mm_mul_pd(a49, t5u));
        a69 = *((a98 + 6));
        a79 = *((a98 + 7));
        s9E = _mm_sub_pd(_mm_mul_pd(a69, t8u), _mm_mul_pd(a79, t9u));
        s0F = _mm_add_pd(_mm_mul_pd(a79, t8u), _mm_mul_pd(a69, t9u));
        t2v = _mm_add_pd(s3E, s7E);
        t3v = _mm_add_pd(s4E, s8E);
        t4v = _mm_sub_pd(s3E, s7E);
        t5v = _mm_sub_pd(s4E, s8E);
        t6v = _mm_add_pd(s5E, s9E);
        t7v = _mm_add_pd(s6E, s0F);
        t8v = _mm_sub_pd(s5E, s9E);
        t9v = _mm_sub_pd(s6E, s0F);
        t0w = _mm_add_pd(t2v, t6v);
        t1w = _mm_add_pd(t3v, t7v);
        t2w = _mm_sub_pd(t2v, t6v);
        t3w = _mm_sub_pd(t3v, t7v);
        t4w = _mm_add_pd(t4v, t9v);
        t5w = _mm_sub_pd(t5v, t8v);
        t6w = _mm_sub_pd(t4v, t9v);
        t7w = _mm_add_pd(t5v, t8v);
        a89 = (D56 + a38);
        a99 = *(a89);
        a0a = *((a89 + 1));
        s1F = _mm_sub_pd(_mm_mul_pd(a99, t0w), _mm_mul_pd(a0a, t1w));
        s2F = _mm_add_pd(_mm_mul_pd(a0a, t0w), _mm_mul_pd(a99, t1w));
        s3F = v_lo2(s1F, s2F);
        s4F = v_hi2(s1F, s2F);
        a1a = (2 * i4);
        b6 = (dst + a1a);
        s5F = _mm_add_pd(s3F, s4F);
        _mm_storeu_pd(((double  *) (b6 + 2)), s5F);
        b7 = (dst - a1a);
        s6F = v_neg23(_mm_sub_pd(s3F, s4F));
        _mm_storeu_pd(((double  *) (b7 + 8190)), s6F);
        a2a = *((a89 + 2));
        a3a = *((a89 + 3));
        s7F = _mm_sub_pd(_mm_mul_pd(a2a, t4w), _mm_mul_pd(a3a, t5w));
        s8F = _mm_add_pd(_mm_mul_pd(a3a, t4w), _mm_mul_pd(a2a, t5w));
        s9F = v_lo2(s7F, s8F);
        s0G = v_hi2(s7F, s8F);
        s1G = _mm_add_pd(s9F, s0G);
        _mm_storeu_pd(((double  *) (b6 + 2050)), s1G);
        s2G = v_neg23(_mm_sub_pd(s9F, s0G));
        _mm_storeu_pd(((double  *) (b7 + 6142)), s2G);
        a4a = *((a89 + 4));
        a5a = *((a89 + 5));
        s3G = _mm_sub_pd(_mm_mul_pd(a4a, t2w), _mm_mul_pd(a5a, t3w));
        s4G = _mm_add_pd(_mm_mul_pd(a5a, t2w), _mm_mul_pd(a4a, t3w));
        s5G = v_lo2(s3G, s4G);
        s6G = v_hi2(s3G, s4G);
        s7G = _mm_add_pd(s5G, s6G);
        _mm_storeu_pd(((double  *) (b6 + 4098)), s7G);
        s8G = v_neg23(_mm_sub_pd(s5G, s6G));
        _mm_storeu_pd(((double  *) (b7 + 4094)), s8G);
        a6a = *((a89 + 6));
        a7a = *((a89 + 7));
        s9G = _mm_sub_pd(_mm_mul_pd(a6a, t6w), _mm_mul_pd(a7a, t7w));
        s0H = _mm_add_pd(_mm_mul_pd(a7a, t6w), _mm_mul_pd(a6a, t7w));
        s1H = v_lo2(s9G, s0H);
        s2H = v_hi2(s9G, s0H);
        s3H = _mm_add_pd(s1H, s2H);
        _mm_storeu_pd(((double  *) (b6 + 6146)), s3H);
        s4H = v_neg23(_mm_sub_pd(s1H, s2H));
        _mm_storeu_pd(((double  *) (b7 + 2046)), s4H);
        a8a = *((a98 + 8));
        a9a = *((a98 + 9));
        s5H = _mm_sub_pd(_mm_mul_pd(a8a, t8t), _mm_mul_pd(a9a, t9t));
        s6H = _mm_add_pd(_mm_mul_pd(a9a, t8t), _mm_mul_pd(a8a, t9t));
        a0b = *((a98 + 10));
        a1b = *((a98 + 11));
        s7H = _mm_sub_pd(_mm_mul_pd(a0b, t2u), _mm_mul_pd(a1b, t3u));
        s8H = _mm_add_pd(_mm_mul_pd(a1b, t2u), _mm_mul_pd(a0b, t3u));
        a2b = *((a98 + 12));
        a3b = *((a98 + 13));
        s9H = _mm_sub_pd(_mm_mul_pd(a2b, t6u), _mm_mul_pd(a3b, t7u));
        s0I = _mm_add_pd(_mm_mul_pd(a3b, t6u), _mm_mul_pd(a2b, t7u));
        a4b = *((a98 + 14));
        a5b = *((a98 + 15));
        s1I = _mm_sub_pd(_mm_mul_pd(a4b, t0v), _mm_mul_pd(a5b, t1v));
        s2I = _mm_add_pd(_mm_mul_pd(a5b, t0v), _mm_mul_pd(a4b, t1v));
        t8w = _mm_add_pd(s5H, s9H);
        t9w = _mm_add_pd(s6H, s0I);
        t0x = _mm_sub_pd(s5H, s9H);
        t1x = _mm_sub_pd(s6H, s0I);
        t2x = _mm_add_pd(s7H, s1I);
        t3x = _mm_add_pd(s8H, s2I);
        t4x = _mm_sub_pd(s7H, s1I);
        t5x = _mm_sub_pd(s8H, s2I);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_add_pd(t9w, t3x);
        t8x = _mm_sub_pd(t8w, t2x);
        t9x = _mm_sub_pd(t9w, t3x);
        t0y = _mm_add_pd(t0x, t5x);
        t1y = _mm_sub_pd(t1x, t4x);
        t2y = _mm_sub_pd(t0x, t5x);
        t3y = _mm_add_pd(t1x, t4x);
        a6b = *((a89 + 8));
        a7b = *((a89 + 9));
        s3I = _mm_sub_pd(_mm_mul_pd(a6b, t6x), _mm_mul_pd(a7b, t7x));
        s4I = _mm_add_pd(_mm_mul_pd(a7b, t6x), _mm_mul_pd(a6b, t7x));
        s5I = v_lo2(s3I, s4I);
        s6I = v_hi2(s3I, s4I);
        s7I = _mm_add_pd(s5I, s6I);
        _mm_storeu_pd(((double  *) (b6 + 1026)), s7I);
        s8I = v_neg23(_mm_sub_pd(s5I, s6I));
        _mm_storeu_pd(((double  *) (b7 + 7166)), s8I);
        a8b = *((a89 + 10));
        a9b = *((a89 + 11));
        s9I = _mm_sub_pd(_mm_mul_pd(a8b, t0y), _mm_mul_pd(a9b, t1y));
        s0J = _mm_add_pd(_mm_mul_pd(a9b, t0y), _mm_mul_pd(a8b, t1y));
        s1J = v_lo2(s9I, s0J);
        s2J = v_hi2(s9I, s0J);
        s3J = _mm_add_pd(s1J, s2J);
        _mm_storeu_pd(((double  *) (b6 + 3074)), s3J);
        s4J = v_neg23(_mm_sub_pd(s1J, s2J));
        _mm_storeu_pd(((double  *) (b7 + 5118)), s4J);
        a0c = *((a89 + 12));
        a1c = *((a89 + 13));
        s5J = _mm_sub_pd(_mm_mul_pd(a0c, t8x), _mm_mul_pd(a1c, t9x));
        s6J = _mm_add_pd(_mm_mul_pd(a1c, t8x), _mm_mul_pd(a0c, t9x));
        s7J = v_lo2(s5J, s6J);
        s8J = v_hi2(s5J, s6J);
        s9J = _mm_add_pd(s7J, s8J);
        _mm_storeu_pd(((double  *) (b6 + 5122)), s9J);
        s0K = v_neg23(_mm_sub_pd(s7J, s8J));
        _mm_storeu_pd(((double  *) (b7 + 3070)), s0K);
        a2c = *((a89 + 14));
        a3c = *((a89 + 15));
        s1K = _mm_sub_pd(_mm_mul_pd(a2c, t2y), _mm_mul_pd(a3c, t3y));
        s2K = _mm_add_pd(_mm_mul_pd(a3c, t2y), _mm_mul_pd(a2c, t3y));
        s3K = v_lo2(s1K, s2K);
        s4K = v_hi2(s1K, s2K);
        s5K = _mm_add_pd(s3K, s4K);
        _mm_storeu_pd(((double  *) (b6 + 7170)), s5K);
        s6K = v_neg23(_mm_sub_pd(s3K, s4K));
        _mm_storeu_pd(((double  *) (b7 + 1022)), s6K);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftfwd_double_8192)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftfwd_double_8192_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[8192]);
     SPIRAL_ALIGNED(double T2[1024]);
    __m128d a02, a04, a05, a06, a07, a08, a0a, a0b, a0c, a11, a12, a13, a14, a15, a16, a19, a1a, a1b, a1c, a2, a21, a22
            , a23, a24, a25, a26, a27, a28, a29, a2b, a2c, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a3a, a3b, a3c
            , a4, a41, a43, a44, a45, a46, a47, a49, a4a, a4b, a4c, a5, a52, a53, a54, a55, a56, a57, a59, a5a, a5b, a6
            , a61, a62, a63, a64, a65, a66, a68, a69, a6a, a6b, a7, a71, a72, a73, a74, a75, a76, a77, a78, a79, a7a, a7b
            , a8, a81, a82, a83, a84, a85, a86, a87, a88, a89, a8a, a8b, a9, a91, a93, a94, a95, a96, a97, a98, a9a, a9b
            , s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0a
            , s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w
            , s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H, s1I, s1J
            , s1K, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u
            , s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C, s2D, s2E, s2F, s2G
            , s2H, s2I, s2J, s2K, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r
            , s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D
            , s3E, s3F, s3G, s3H, s3I, s3J, s3K, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o
            , s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A
            , s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l
            , s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57
            , s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i
            , s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6a, s6b, s6c, s6d, s6e, s6f
            , s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y, s6z, s7, s71
            , s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7a, s7b, s7c, s7d
            , s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z
            , s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8a, s8b
            , s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x
            , s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J
            , s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v
            , s9w, s9x, s9y, s9z, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h
            , t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t11, t12, t13, t14, t15
            , t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r
            , t1s, t1t, t1u, t1v, t1w, t1x, t1y, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e
            , t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t3, t31
            , t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n
            , t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a
            , t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w
            , t4x, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k
            , t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t6, t61, t62, t63, t64, t65, t66, t67, t68
            , t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u
            , t6v, t6w, t6x, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i
            , t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t8, t81, t82, t83, t84, t85, t86
            , t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s
            , t8t, t8u, t8v, t8w, t8x, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g
            , t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x;
    __m128d  *a, *a01, *a03, *a09, *a18, *a2a, *a42, *a51, *a58, *a67, *a99, *b, *b2, *b3, *b4, *b5, *b6, *b7;
    int a17, a48, a92;
    {long i; for(i = 0; i <= 7; i++) {
        {long i2; for(i2 = 0; i2 <= 15; i2++) {
            a = (((__m128d  *) src) + (i + (8 * i2)));
            s = *(a);
            s2 = *((a + 2048));
            t = _mm_add_pd(s, s2);
            t2 = _mm_sub_pd(s, s2);
            s3 = *((a + 1024));
            s4 = *((a + 3072));
            t3 = _mm_add_pd(s3, s4);
            t4 = _mm_sub_pd(s3, s4);
            s5 = *((a + 512));
            s6 = *((a + 2560));
            t5 = _mm_add_pd(s5, s6);
            s7 = *((a + 1536));
            s8 = *((a + 3584));
            t6 = _mm_add_pd(s7, s8);
            t7 = _mm_add_pd(t, t3);
            t8 = _mm_sub_pd(t, t3);
            t9 = _mm_add_pd(t5, t6);
            t01 = _mm_sub_pd(t5, t6);
            a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5, s6));
            a3 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7, s8));
            s9 = _mm_add_pd(a2, a3);
            s01 = _mm_sub_pd(a3, a2);
            t11 = _mm_add_pd(t2, s9);
            t21 = _mm_sub_pd(s01, t4);
            t31 = _mm_sub_pd(t2, s9);
            t41 = _mm_add_pd(t4, s01);
            s11 = *((a + 128));
            s21 = *((a + 2176));
            t51 = _mm_add_pd(s11, s21);
            t61 = _mm_sub_pd(s11, s21);
            s31 = *((a + 1152));
            s41 = *((a + 3200));
            t71 = _mm_add_pd(s31, s41);
            t81 = _mm_sub_pd(s31, s41);
            s51 = *((a + 640));
            s61 = *((a + 2688));
            t91 = _mm_add_pd(s51, s61);
            s71 = *((a + 1664));
            s81 = *((a + 3712));
            t02 = _mm_add_pd(s71, s81);
            t12 = _mm_add_pd(t51, t71);
            t22 = _mm_sub_pd(t51, t71);
            t32 = _mm_add_pd(t91, t02);
            t42 = _mm_sub_pd(t91, t02);
            a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s51, s61));
            a5 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s71, s81));
            s91 = _mm_add_pd(a4, a5);
            s02 = _mm_sub_pd(a5, a4);
            t52 = _mm_add_pd(t61, s91);
            t62 = _mm_sub_pd(s02, t81);
            t72 = _mm_sub_pd(t61, s91);
            t82 = _mm_add_pd(t81, s02);
            s12 = *((a + 256));
            s22 = *((a + 2304));
            t92 = _mm_add_pd(s12, s22);
            t03 = _mm_sub_pd(s12, s22);
            s32 = *((a + 1280));
            s42 = *((a + 3328));
            t13 = _mm_add_pd(s32, s42);
            t23 = _mm_sub_pd(s32, s42);
            s52 = *((a + 768));
            s62 = *((a + 2816));
            t33 = _mm_add_pd(s52, s62);
            s72 = *((a + 1792));
            s82 = *((a + 3840));
            t43 = _mm_add_pd(s72, s82);
            t53 = _mm_add_pd(t92, t13);
            t63 = _mm_add_pd(t33, t43);
            a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s52, s62));
            a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s72, s82));
            s92 = _mm_add_pd(a6, a7);
            s03 = _mm_sub_pd(a7, a6);
            t73 = _mm_add_pd(t03, s92);
            t83 = _mm_sub_pd(s03, t23);
            t93 = _mm_sub_pd(t03, s92);
            t04 = _mm_add_pd(t23, s03);
            s13 = *((a + 384));
            s23 = *((a + 2432));
            t14 = _mm_add_pd(s13, s23);
            t24 = _mm_sub_pd(s13, s23);
            s33 = *((a + 1408));
            s43 = *((a + 3456));
            t34 = _mm_add_pd(s33, s43);
            t44 = _mm_sub_pd(s33, s43);
            s53 = *((a + 896));
            s63 = *((a + 2944));
            t54 = _mm_add_pd(s53, s63);
            s73 = *((a + 1920));
            s83 = *((a + 3968));
            t64 = _mm_add_pd(s73, s83);
            t74 = _mm_add_pd(t14, t34);
            t84 = _mm_sub_pd(t14, t34);
            t94 = _mm_add_pd(t54, t64);
            t05 = _mm_sub_pd(t54, t64);
            a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s53, s63));
            a9 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s73, s83));
            s93 = _mm_add_pd(a8, a9);
            s04 = _mm_sub_pd(a9, a8);
            t15 = _mm_add_pd(t24, s93);
            t25 = _mm_sub_pd(s04, t44);
            t35 = _mm_sub_pd(t24, s93);
            t45 = _mm_add_pd(t44, s04);
            t55 = _mm_add_pd(t7, t9);
            t65 = _mm_sub_pd(t7, t9);
            t75 = _mm_add_pd(t53, t63);
            t85 = _mm_sub_pd(t53, t63);
            t95 = _mm_add_pd(t12, t32);
            t06 = _mm_add_pd(t74, t94);
            a01 = (((__m128d  *) T2) + i2);
            s14 = _mm_add_pd(t55, t75);
            *(a01) = s14;
            s24 = _mm_sub_pd(t55, t75);
            *((a01 + 256)) = s24;
            s34 = _mm_add_pd(t95, t06);
            *((a01 + 16)) = s34;
            s44 = _mm_sub_pd(t06, t95);
            *((a01 + 272)) = s44;
            a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t12, t32));
            a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t74, t94));
            s54 = _mm_add_pd(a11, a21);
            s64 = _mm_sub_pd(a21, a11);
            s74 = _mm_add_pd(t65, s54);
            *((a01 + 128)) = s74;
            s84 = _mm_sub_pd(s64, t85);
            *((a01 + 144)) = s84;
            s94 = _mm_sub_pd(t65, s54);
            *((a01 + 384)) = s94;
            s05 = _mm_add_pd(t85, s64);
            *((a01 + 400)) = s05;
            s15 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t52), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t62));
            s25 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t52), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t62));
            s35 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t73), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t83));
            s45 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t73), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t83));
            s55 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t15), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t25));
            s65 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t15), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t25));
            t16 = _mm_add_pd(t11, s35);
            t26 = _mm_add_pd(t21, s45);
            t36 = _mm_sub_pd(t11, s35);
            t46 = _mm_sub_pd(t21, s45);
            t56 = _mm_add_pd(s15, s55);
            t66 = _mm_add_pd(s25, s65);
            t76 = _mm_sub_pd(s15, s55);
            t86 = _mm_sub_pd(s25, s65);
            s75 = _mm_add_pd(t16, t56);
            *((a01 + 32)) = s75;
            s85 = _mm_add_pd(t26, t66);
            *((a01 + 48)) = s85;
            s95 = _mm_sub_pd(t16, t56);
            *((a01 + 480)) = s95;
            s06 = _mm_sub_pd(t66, t26);
            *((a01 + 496)) = s06;
            s16 = _mm_add_pd(t36, t86);
            *((a01 + 288)) = s16;
            s26 = _mm_sub_pd(t46, t76);
            *((a01 + 304)) = s26;
            s36 = _mm_sub_pd(t36, t86);
            *((a01 + 224)) = s36;
            s46 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t46, t76));
            *((a01 + 240)) = s46;
            s56 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t22), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t42));
            s66 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t22), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t42));
            a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t92, t13));
            a41 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t33, t43));
            s76 = _mm_add_pd(a31, a41);
            s86 = _mm_sub_pd(a41, a31);
            s96 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t84), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t05));
            s07 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t84), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t05));
            t96 = _mm_add_pd(t8, s76);
            t07 = _mm_sub_pd(s86, t01);
            t17 = _mm_sub_pd(t8, s76);
            t27 = _mm_add_pd(t01, s86);
            t37 = _mm_add_pd(s56, s96);
            t47 = _mm_add_pd(s66, s07);
            t57 = _mm_sub_pd(s56, s96);
            t67 = _mm_sub_pd(s66, s07);
            s17 = _mm_add_pd(t96, t37);
            *((a01 + 64)) = s17;
            s27 = _mm_add_pd(t07, t47);
            *((a01 + 80)) = s27;
            s37 = _mm_sub_pd(t96, t37);
            *((a01 + 448)) = s37;
            s47 = _mm_sub_pd(t47, t07);
            *((a01 + 464)) = s47;
            s57 = _mm_add_pd(t17, t67);
            *((a01 + 320)) = s57;
            s67 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t27, t57));
            *((a01 + 336)) = s67;
            s77 = _mm_sub_pd(t17, t67);
            *((a01 + 192)) = s77;
            s87 = _mm_sub_pd(t27, t57);
            *((a01 + 208)) = s87;
            s97 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t72), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t82));
            s08 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t72), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t82));
            s18 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t93), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t04));
            s28 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t93), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t04));
            s38 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t35), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t45));
            s48 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t35), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t45));
            t77 = _mm_add_pd(t31, s18);
            t87 = _mm_add_pd(t41, s28);
            t97 = _mm_sub_pd(t31, s18);
            t08 = _mm_sub_pd(t41, s28);
            t18 = _mm_add_pd(s97, s38);
            t28 = _mm_add_pd(s08, s48);
            t38 = _mm_sub_pd(s97, s38);
            t48 = _mm_sub_pd(s08, s48);
            s58 = _mm_add_pd(t77, t18);
            *((a01 + 96)) = s58;
            s68 = _mm_add_pd(t87, t28);
            *((a01 + 112)) = s68;
            s78 = _mm_sub_pd(t77, t18);
            *((a01 + 416)) = s78;
            s88 = _mm_sub_pd(t28, t87);
            *((a01 + 432)) = s88;
            s98 = _mm_add_pd(t97, t48);
            *((a01 + 352)) = s98;
            s09 = _mm_sub_pd(t08, t38);
            *((a01 + 368)) = s09;
            s19 = _mm_sub_pd(t97, t48);
            *((a01 + 160)) = s19;
            s29 = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t08, t38));
            *((a01 + 176)) = s29;
        }}
        a51 = ((__m128d  *) T2);
        s39 = *(a51);
        s49 = *((a51 + 16));
        t58 = _mm_add_pd(s39, s49);
        t68 = _mm_sub_pd(s39, s49);
        s59 = *((a51 + 8));
        s69 = *((a51 + 24));
        t78 = _mm_add_pd(s59, s69);
        t88 = _mm_sub_pd(s59, s69);
        s79 = *((a51 + 4));
        s89 = *((a51 + 20));
        t98 = _mm_add_pd(s79, s89);
        s99 = *((a51 + 12));
        s0a = *((a51 + 28));
        t09 = _mm_add_pd(s99, s0a);
        t19 = _mm_add_pd(t58, t78);
        t29 = _mm_sub_pd(t58, t78);
        t39 = _mm_add_pd(t98, t09);
        t49 = _mm_sub_pd(t98, t09);
        a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s79, s89));
        a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s99, s0a));
        s1a = _mm_add_pd(a61, a71);
        s2a = _mm_sub_pd(a71, a61);
        t59 = _mm_add_pd(t68, s1a);
        t69 = _mm_sub_pd(s2a, t88);
        t79 = _mm_sub_pd(t68, s1a);
        t89 = _mm_add_pd(t88, s2a);
        s3a = *((a51 + 1));
        s4a = *((a51 + 17));
        t99 = _mm_add_pd(s3a, s4a);
        t0a = _mm_sub_pd(s3a, s4a);
        s5a = *((a51 + 9));
        s6a = *((a51 + 25));
        t1a = _mm_add_pd(s5a, s6a);
        t2a = _mm_sub_pd(s5a, s6a);
        s7a = *((a51 + 5));
        s8a = *((a51 + 21));
        t3a = _mm_add_pd(s7a, s8a);
        s9a = *((a51 + 13));
        s0b = *((a51 + 29));
        t4a = _mm_add_pd(s9a, s0b);
        t5a = _mm_add_pd(t99, t1a);
        t6a = _mm_sub_pd(t99, t1a);
        t7a = _mm_add_pd(t3a, t4a);
        t8a = _mm_sub_pd(t3a, t4a);
        a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7a, s8a));
        a91 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9a, s0b));
        s1b = _mm_add_pd(a81, a91);
        s2b = _mm_sub_pd(a91, a81);
        t9a = _mm_add_pd(t0a, s1b);
        t0b = _mm_sub_pd(s2b, t2a);
        t1b = _mm_sub_pd(t0a, s1b);
        t2b = _mm_add_pd(t2a, s2b);
        s3b = *((a51 + 2));
        s4b = *((a51 + 18));
        t3b = _mm_add_pd(s3b, s4b);
        t4b = _mm_sub_pd(s3b, s4b);
        s5b = *((a51 + 10));
        s6b = *((a51 + 26));
        t5b = _mm_add_pd(s5b, s6b);
        t6b = _mm_sub_pd(s5b, s6b);
        s7b = *((a51 + 6));
        s8b = *((a51 + 22));
        t7b = _mm_add_pd(s7b, s8b);
        s9b = *((a51 + 14));
        s0c = *((a51 + 30));
        t8b = _mm_add_pd(s9b, s0c);
        t9b = _mm_add_pd(t3b, t5b);
        t0c = _mm_add_pd(t7b, t8b);
        a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7b, s8b));
        a12 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9b, s0c));
        s1c = _mm_add_pd(a02, a12);
        s2c = _mm_sub_pd(a12, a02);
        t1c = _mm_add_pd(t4b, s1c);
        t2c = _mm_sub_pd(s2c, t6b);
        t3c = _mm_sub_pd(t4b, s1c);
        t4c = _mm_add_pd(t6b, s2c);
        s3c = *((a51 + 3));
        s4c = *((a51 + 19));
        t5c = _mm_add_pd(s3c, s4c);
        t6c = _mm_sub_pd(s3c, s4c);
        s5c = *((a51 + 11));
        s6c = *((a51 + 27));
        t7c = _mm_add_pd(s5c, s6c);
        t8c = _mm_sub_pd(s5c, s6c);
        s7c = *((a51 + 7));
        s8c = *((a51 + 23));
        t9c = _mm_add_pd(s7c, s8c);
        s9c = *((a51 + 15));
        s0d = *((a51 + 31));
        t0d = _mm_add_pd(s9c, s0d);
        t1d = _mm_add_pd(t5c, t7c);
        t2d = _mm_sub_pd(t5c, t7c);
        t3d = _mm_add_pd(t9c, t0d);
        t4d = _mm_sub_pd(t9c, t0d);
        a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s7c, s8c));
        a32 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9c, s0d));
        s1d = _mm_add_pd(a22, a32);
        s2d = _mm_sub_pd(a32, a22);
        t5d = _mm_add_pd(t6c, s1d);
        t6d = _mm_sub_pd(s2d, t8c);
        t7d = _mm_sub_pd(t6c, s1d);
        t8d = _mm_add_pd(t8c, s2d);
        t9d = _mm_add_pd(t19, t39);
        t0e = _mm_sub_pd(t19, t39);
        t1e = _mm_add_pd(t9b, t0c);
        t2e = _mm_sub_pd(t9b, t0c);
        t3e = _mm_add_pd(t5a, t7a);
        t4e = _mm_add_pd(t1d, t3d);
        a42 = (((__m128d  *) T) + i);
        s3d = _mm_add_pd(t9d, t1e);
        *(a42) = s3d;
        s4d = _mm_sub_pd(t9d, t1e);
        *((a42 + 2048)) = s4d;
        s5d = _mm_add_pd(t3e, t4e);
        *((a42 + 8)) = s5d;
        s6d = _mm_sub_pd(t4e, t3e);
        *((a42 + 2056)) = s6d;
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t7a));
        a62 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1d, t3d));
        s7d = _mm_add_pd(a52, a62);
        s8d = _mm_sub_pd(a62, a52);
        s9d = _mm_add_pd(t0e, s7d);
        *((a42 + 1024)) = s9d;
        s0e = _mm_sub_pd(s8d, t2e);
        *((a42 + 1032)) = s0e;
        s1e = _mm_sub_pd(t0e, s7d);
        *((a42 + 3072)) = s1e;
        s2e = _mm_add_pd(t2e, s8d);
        *((a42 + 3080)) = s2e;
        s3e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
        s4e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
        s5e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1c), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2c));
        s6e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2c));
        s7e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5d), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6d));
        s8e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6d));
        t5e = _mm_add_pd(t59, s5e);
        t6e = _mm_add_pd(t69, s6e);
        t7e = _mm_sub_pd(t59, s5e);
        t8e = _mm_sub_pd(t69, s6e);
        t9e = _mm_add_pd(s3e, s7e);
        t0f = _mm_add_pd(s4e, s8e);
        t1f = _mm_sub_pd(s3e, s7e);
        t2f = _mm_sub_pd(s4e, s8e);
        s9e = _mm_add_pd(t5e, t9e);
        *((a42 + 256)) = s9e;
        s0f = _mm_add_pd(t6e, t0f);
        *((a42 + 264)) = s0f;
        s1f = _mm_sub_pd(t5e, t9e);
        *((a42 + 3840)) = s1f;
        s2f = _mm_sub_pd(t0f, t6e);
        *((a42 + 3848)) = s2f;
        s3f = _mm_add_pd(t7e, t2f);
        *((a42 + 2304)) = s3f;
        s4f = _mm_sub_pd(t8e, t1f);
        *((a42 + 2312)) = s4f;
        s5f = _mm_sub_pd(t7e, t2f);
        *((a42 + 1792)) = s5f;
        s6f = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8e, t1f));
        *((a42 + 1800)) = s6f;
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t8a));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3b, t5b));
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t7b, t8b));
        s9f = _mm_add_pd(a72, a82);
        s0g = _mm_sub_pd(a82, a72);
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4d));
        s2g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4d));
        t3f = _mm_add_pd(t29, s9f);
        t4f = _mm_sub_pd(s0g, t49);
        t5f = _mm_sub_pd(t29, s9f);
        t6f = _mm_add_pd(t49, s0g);
        t7f = _mm_add_pd(s7f, s1g);
        t8f = _mm_add_pd(s8f, s2g);
        t9f = _mm_sub_pd(s7f, s1g);
        t0g = _mm_sub_pd(s8f, s2g);
        s3g = _mm_add_pd(t3f, t7f);
        *((a42 + 512)) = s3g;
        s4g = _mm_add_pd(t4f, t8f);
        *((a42 + 520)) = s4g;
        s5g = _mm_sub_pd(t3f, t7f);
        *((a42 + 3584)) = s5g;
        s6g = _mm_sub_pd(t8f, t4f);
        *((a42 + 3592)) = s6g;
        s7g = _mm_add_pd(t5f, t0g);
        *((a42 + 2560)) = s7g;
        s8g = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6f, t9f));
        *((a42 + 2568)) = s8g;
        s9g = _mm_sub_pd(t5f, t0g);
        *((a42 + 1536)) = s9g;
        s0h = _mm_sub_pd(t6f, t9f);
        *((a42 + 1544)) = s0h;
        s1h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1b), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t2b));
        s2h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t1b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2b));
        s3h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3c), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4c));
        s4h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4c));
        s5h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t7d), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8d));
        s6h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7d), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t8d));
        t1g = _mm_add_pd(t79, s3h);
        t2g = _mm_add_pd(t89, s4h);
        t3g = _mm_sub_pd(t79, s3h);
        t4g = _mm_sub_pd(t89, s4h);
        t5g = _mm_add_pd(s1h, s5h);
        t6g = _mm_add_pd(s2h, s6h);
        t7g = _mm_sub_pd(s1h, s5h);
        t8g = _mm_sub_pd(s2h, s6h);
        s7h = _mm_add_pd(t1g, t5g);
        *((a42 + 768)) = s7h;
        s8h = _mm_add_pd(t2g, t6g);
        *((a42 + 776)) = s8h;
        s9h = _mm_sub_pd(t1g, t5g);
        *((a42 + 3328)) = s9h;
        s0i = _mm_sub_pd(t6g, t2g);
        *((a42 + 3336)) = s0i;
        s1i = _mm_add_pd(t3g, t8g);
        *((a42 + 2816)) = s1i;
        s2i = _mm_sub_pd(t4g, t7g);
        *((a42 + 2824)) = s2i;
        s3i = _mm_sub_pd(t3g, t8g);
        *((a42 + 1280)) = s3i;
        s4i = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t4g, t7g));
        *((a42 + 1288)) = s4i;
        {long i3; for(i3 = 0; i3 <= 14; i3++) {
            a92 = (32 * i3);
            b = (((__m128d  *) T2) + a92);
            s5i = *((b + 32));
            s6i = *((b + 48));
            s7i = *((b + 33));
            s8i = *((b + 49));
            s9i = *((b + 34));
            s0j = *((b + 50));
            s1j = *((b + 35));
            s2j = *((b + 51));
            s3j = *((b + 36));
            s4j = *((b + 52));
            s5j = *((b + 37));
            s6j = *((b + 53));
            s7j = *((b + 38));
            s8j = *((b + 54));
            s9j = *((b + 39));
            s0k = *((b + 55));
            s1k = *((b + 40));
            s2k = *((b + 56));
            s3k = *((b + 41));
            s4k = *((b + 57));
            s5k = *((b + 42));
            s6k = *((b + 58));
            s7k = *((b + 43));
            s8k = *((b + 59));
            s9k = *((b + 44));
            s0l = *((b + 60));
            s1l = *((b + 45));
            s2l = *((b + 61));
            s3l = *((b + 46));
            s4l = *((b + 62));
            s5l = *((b + 47));
            s6l = *((b + 63));
            a03 = (D62 + a92);
            a13 = *(a03);
            a23 = *((a03 + 1));
            s7l = _mm_sub_pd(_mm_mul_pd(a13, s5i), _mm_mul_pd(a23, s6i));
            s8l = _mm_add_pd(_mm_mul_pd(a23, s5i), _mm_mul_pd(a13, s6i));
            a33 = *((a03 + 2));
            a43 = *((a03 + 3));
            s9l = _mm_sub_pd(_mm_mul_pd(a33, s7i), _mm_mul_pd(a43, s8i));
            s0m = _mm_add_pd(_mm_mul_pd(a43, s7i), _mm_mul_pd(a33, s8i));
            a53 = *((a03 + 4));
            a63 = *((a03 + 5));
            s1m = _mm_sub_pd(_mm_mul_pd(a53, s9i), _mm_mul_pd(a63, s0j));
            s2m = _mm_add_pd(_mm_mul_pd(a63, s9i), _mm_mul_pd(a53, s0j));
            a73 = *((a03 + 6));
            a83 = *((a03 + 7));
            s3m = _mm_sub_pd(_mm_mul_pd(a73, s1j), _mm_mul_pd(a83, s2j));
            s4m = _mm_add_pd(_mm_mul_pd(a83, s1j), _mm_mul_pd(a73, s2j));
            a93 = *((a03 + 8));
            a04 = *((a03 + 9));
            s5m = _mm_sub_pd(_mm_mul_pd(a93, s3j), _mm_mul_pd(a04, s4j));
            s6m = _mm_add_pd(_mm_mul_pd(a04, s3j), _mm_mul_pd(a93, s4j));
            a14 = *((a03 + 10));
            a24 = *((a03 + 11));
            s7m = _mm_sub_pd(_mm_mul_pd(a14, s5j), _mm_mul_pd(a24, s6j));
            s8m = _mm_add_pd(_mm_mul_pd(a24, s5j), _mm_mul_pd(a14, s6j));
            a34 = *((a03 + 12));
            a44 = *((a03 + 13));
            s9m = _mm_sub_pd(_mm_mul_pd(a34, s7j), _mm_mul_pd(a44, s8j));
            s0n = _mm_add_pd(_mm_mul_pd(a44, s7j), _mm_mul_pd(a34, s8j));
            a54 = *((a03 + 14));
            a64 = *((a03 + 15));
            s1n = _mm_sub_pd(_mm_mul_pd(a54, s9j), _mm_mul_pd(a64, s0k));
            s2n = _mm_add_pd(_mm_mul_pd(a64, s9j), _mm_mul_pd(a54, s0k));
            a74 = *((a03 + 16));
            a84 = *((a03 + 17));
            s3n = _mm_sub_pd(_mm_mul_pd(a74, s1k), _mm_mul_pd(a84, s2k));
            s4n = _mm_add_pd(_mm_mul_pd(a84, s1k), _mm_mul_pd(a74, s2k));
            a94 = *((a03 + 18));
            a05 = *((a03 + 19));
            s5n = _mm_sub_pd(_mm_mul_pd(a94, s3k), _mm_mul_pd(a05, s4k));
            s6n = _mm_add_pd(_mm_mul_pd(a05, s3k), _mm_mul_pd(a94, s4k));
            a15 = *((a03 + 20));
            a25 = *((a03 + 21));
            s7n = _mm_sub_pd(_mm_mul_pd(a15, s5k), _mm_mul_pd(a25, s6k));
            s8n = _mm_add_pd(_mm_mul_pd(a25, s5k), _mm_mul_pd(a15, s6k));
            a35 = *((a03 + 22));
            a45 = *((a03 + 23));
            s9n = _mm_sub_pd(_mm_mul_pd(a35, s7k), _mm_mul_pd(a45, s8k));
            s0o = _mm_add_pd(_mm_mul_pd(a45, s7k), _mm_mul_pd(a35, s8k));
            a55 = *((a03 + 24));
            a65 = *((a03 + 25));
            s1o = _mm_sub_pd(_mm_mul_pd(a55, s9k), _mm_mul_pd(a65, s0l));
            s2o = _mm_add_pd(_mm_mul_pd(a65, s9k), _mm_mul_pd(a55, s0l));
            a75 = *((a03 + 26));
            a85 = *((a03 + 27));
            s3o = _mm_sub_pd(_mm_mul_pd(a75, s1l), _mm_mul_pd(a85, s2l));
            s4o = _mm_add_pd(_mm_mul_pd(a85, s1l), _mm_mul_pd(a75, s2l));
            a95 = *((a03 + 28));
            a06 = *((a03 + 29));
            s5o = _mm_sub_pd(_mm_mul_pd(a95, s3l), _mm_mul_pd(a06, s4l));
            s6o = _mm_add_pd(_mm_mul_pd(a06, s3l), _mm_mul_pd(a95, s4l));
            a16 = *((a03 + 30));
            a26 = *((a03 + 31));
            s7o = _mm_sub_pd(_mm_mul_pd(a16, s5l), _mm_mul_pd(a26, s6l));
            s8o = _mm_add_pd(_mm_mul_pd(a26, s5l), _mm_mul_pd(a16, s6l));
            t9g = _mm_add_pd(s7l, s3n);
            t0h = _mm_add_pd(s8l, s4n);
            t1h = _mm_sub_pd(s7l, s3n);
            t2h = _mm_sub_pd(s8l, s4n);
            t3h = _mm_add_pd(s9l, s5n);
            t4h = _mm_add_pd(s0m, s6n);
            t5h = _mm_sub_pd(s9l, s5n);
            t6h = _mm_sub_pd(s0m, s6n);
            s9o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5h), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6h));
            s0p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6h));
            t7h = _mm_add_pd(s1m, s7n);
            t8h = _mm_add_pd(s2m, s8n);
            a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1m, s7n));
            a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s2m, s8n));
            s1p = _mm_sub_pd(a36, a46);
            s2p = _mm_add_pd(a36, a46);
            t9h = _mm_add_pd(s3m, s9n);
            t0i = _mm_add_pd(s4m, s0o);
            t1i = _mm_sub_pd(s3m, s9n);
            t2i = _mm_sub_pd(s4m, s0o);
            s3p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1i), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2i));
            s4p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1i), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2i));
            t3i = _mm_add_pd(s5m, s1o);
            t4i = _mm_add_pd(s6m, s2o);
            t5i = _mm_sub_pd(s5m, s1o);
            t6i = _mm_sub_pd(s6m, s2o);
            t7i = _mm_add_pd(s7m, s3o);
            t8i = _mm_add_pd(s8m, s4o);
            t9i = _mm_sub_pd(s7m, s3o);
            t0j = _mm_sub_pd(s8m, s4o);
            s5p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9i), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t0j));
            s6p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t9i), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0j));
            t1j = _mm_add_pd(s9m, s5o);
            t2j = _mm_add_pd(s0n, s6o);
            a56 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s9m, s5o));
            a66 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s0n, s6o));
            s7p = _mm_sub_pd(a56, a66);
            s8p = _mm_add_pd(a56, a66);
            t3j = _mm_add_pd(s1n, s7o);
            t4j = _mm_add_pd(s2n, s8o);
            t5j = _mm_sub_pd(s1n, s7o);
            t6j = _mm_sub_pd(s2n, s8o);
            s9p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5j), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6j));
            s0q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5j), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6j));
            t7j = _mm_add_pd(t9g, t3i);
            t8j = _mm_add_pd(t0h, t4i);
            t9j = _mm_sub_pd(t9g, t3i);
            t0k = _mm_sub_pd(t0h, t4i);
            t1k = _mm_add_pd(t7h, t1j);
            t2k = _mm_add_pd(t8h, t2j);
            t3k = _mm_sub_pd(t7h, t1j);
            t4k = _mm_sub_pd(t8h, t2j);
            t5k = _mm_add_pd(t7j, t1k);
            t6k = _mm_add_pd(t8j, t2k);
            t7k = _mm_sub_pd(t7j, t1k);
            t8k = _mm_sub_pd(t8j, t2k);
            t9k = _mm_add_pd(t9j, t4k);
            t0l = _mm_sub_pd(t0k, t3k);
            t1l = _mm_sub_pd(t9j, t4k);
            t2l = _mm_add_pd(t0k, t3k);
            t3l = _mm_add_pd(t3h, t7i);
            t4l = _mm_add_pd(t4h, t8i);
            t5l = _mm_sub_pd(t3h, t7i);
            t6l = _mm_sub_pd(t4h, t8i);
            t7l = _mm_add_pd(t9h, t3j);
            t8l = _mm_add_pd(t0i, t4j);
            t9l = _mm_sub_pd(t9h, t3j);
            t0m = _mm_sub_pd(t0i, t4j);
            t1m = _mm_add_pd(t3l, t7l);
            t2m = _mm_add_pd(t4l, t8l);
            t3m = _mm_sub_pd(t3l, t7l);
            t4m = _mm_sub_pd(t4l, t8l);
            a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t5l, t0m));
            a86 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t6l, t9l));
            s1q = _mm_sub_pd(a76, a86);
            s2q = _mm_add_pd(a76, a86);
            a96 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t5l, t0m));
            a07 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t6l, t9l));
            s3q = _mm_sub_pd(a96, a07);
            s4q = _mm_add_pd(a96, a07);
            a17 = (16 * i3);
            b2 = (((__m128d  *) T) + i);
            b3 = (b2 + a17);
            s5q = _mm_add_pd(t5k, t1m);
            *((b3 + 16)) = s5q;
            s6q = _mm_add_pd(t6k, t2m);
            *((b3 + 24)) = s6q;
            b4 = (b2 - a17);
            s7q = _mm_sub_pd(t5k, t1m);
            *((b4 + 4080)) = s7q;
            s8q = _mm_sub_pd(t2m, t6k);
            *((b4 + 4088)) = s8q;
            s9q = _mm_add_pd(t9k, s1q);
            *((b3 + 1040)) = s9q;
            s0r = _mm_sub_pd(t0l, s2q);
            *((b3 + 1048)) = s0r;
            s1r = _mm_sub_pd(t9k, s1q);
            *((b4 + 3056)) = s1r;
            s2r = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t0l, s2q));
            *((b4 + 3064)) = s2r;
            s3r = _mm_add_pd(t7k, t4m);
            *((b3 + 2064)) = s3r;
            s4r = _mm_sub_pd(t8k, t3m);
            *((b3 + 2072)) = s4r;
            s5r = _mm_sub_pd(t7k, t4m);
            *((b4 + 2032)) = s5r;
            s6r = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8k, t3m));
            *((b4 + 2040)) = s6r;
            s7r = _mm_add_pd(t1l, s3q);
            *((b3 + 3088)) = s7r;
            s8r = _mm_add_pd(t2l, s4q);
            *((b3 + 3096)) = s8r;
            s9r = _mm_sub_pd(t1l, s3q);
            *((b4 + 1008)) = s9r;
            s0s = _mm_sub_pd(s4q, t2l);
            *((b4 + 1016)) = s0s;
            t5m = _mm_add_pd(t1h, t6i);
            t6m = _mm_sub_pd(t2h, t5i);
            t7m = _mm_sub_pd(t1h, t6i);
            t8m = _mm_add_pd(t2h, t5i);
            t9m = _mm_add_pd(s1p, s7p);
            t0n = _mm_sub_pd(s8p, s2p);
            t1n = _mm_sub_pd(s1p, s7p);
            t2n = _mm_add_pd(s2p, s8p);
            t3n = _mm_add_pd(t5m, t9m);
            t4n = _mm_add_pd(t6m, t0n);
            t5n = _mm_sub_pd(t5m, t9m);
            t6n = _mm_sub_pd(t6m, t0n);
            t7n = _mm_sub_pd(t7m, t2n);
            t8n = _mm_sub_pd(t8m, t1n);
            t9n = _mm_add_pd(t7m, t2n);
            t0o = _mm_add_pd(t8m, t1n);
            t1o = _mm_add_pd(s9o, s5p);
            t2o = _mm_add_pd(s0p, s6p);
            t3o = _mm_sub_pd(s9o, s5p);
            t4o = _mm_sub_pd(s0p, s6p);
            t5o = _mm_add_pd(s3p, s9p);
            t6o = _mm_add_pd(s4p, s0q);
            t7o = _mm_sub_pd(s3p, s9p);
            t8o = _mm_sub_pd(s4p, s0q);
            t9o = _mm_add_pd(t1o, t5o);
            t0p = _mm_add_pd(t2o, t6o);
            t1p = _mm_sub_pd(t1o, t5o);
            t2p = _mm_sub_pd(t2o, t6o);
            a27 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t3o, t8o));
            a37 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t4o, t7o));
            s1s = _mm_sub_pd(a27, a37);
            s2s = _mm_add_pd(a27, a37);
            a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3o, t8o));
            a57 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t4o, t7o));
            s3s = _mm_sub_pd(a47, a57);
            s4s = _mm_add_pd(a47, a57);
            s5s = _mm_add_pd(t3n, t9o);
            *((b3 + 528)) = s5s;
            s6s = _mm_add_pd(t4n, t0p);
            *((b3 + 536)) = s6s;
            s7s = _mm_sub_pd(t3n, t9o);
            *((b4 + 3568)) = s7s;
            s8s = _mm_sub_pd(t0p, t4n);
            *((b4 + 3576)) = s8s;
            s9s = _mm_add_pd(t7n, s1s);
            *((b3 + 1552)) = s9s;
            s0t = _mm_sub_pd(t8n, s2s);
            *((b3 + 1560)) = s0t;
            s1t = _mm_sub_pd(t7n, s1s);
            *((b4 + 2544)) = s1t;
            s2t = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t8n, s2s));
            *((b4 + 2552)) = s2t;
            s3t = _mm_add_pd(t5n, t2p);
            *((b3 + 2576)) = s3t;
            s4t = _mm_sub_pd(t6n, t1p);
            *((b3 + 2584)) = s4t;
            s5t = _mm_sub_pd(t5n, t2p);
            *((b4 + 1520)) = s5t;
            s6t = _mm_sub_pd(_mm_set1_pd(0.0), _mm_add_pd(t6n, t1p));
            *((b4 + 1528)) = s6t;
            s7t = _mm_add_pd(t9n, s3s);
            *((b3 + 3600)) = s7t;
            s8t = _mm_add_pd(t0o, s4s);
            *((b3 + 3608)) = s8t;
            s9t = _mm_sub_pd(t9n, s3s);
            *((b4 + 496)) = s9t;
            s0u = _mm_sub_pd(s4s, t0o);
            *((b4 + 504)) = s0u;
        }}
    }}
    a67 = ((__m128d  *) T);
    s1u = *(a67);
    s2u = *((a67 + 8));
    t3p = _mm_add_pd(s1u, s2u);
    t4p = _mm_sub_pd(s1u, s2u);
    s3u = *((a67 + 4));
    s4u = *((a67 + 12));
    t5p = _mm_add_pd(s3u, s4u);
    t6p = _mm_sub_pd(s3u, s4u);
    s5u = *((a67 + 2));
    s6u = *((a67 + 10));
    t7p = _mm_add_pd(s5u, s6u);
    s7u = *((a67 + 6));
    s8u = *((a67 + 14));
    t8p = _mm_add_pd(s7u, s8u);
    t9p = _mm_add_pd(t3p, t5p);
    t0q = _mm_sub_pd(t3p, t5p);
    t1q = _mm_add_pd(t7p, t8p);
    t2q = _mm_sub_pd(t7p, t8p);
    a77 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5u, s6u));
    a87 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7u, s8u));
    s9u = _mm_add_pd(a77, a87);
    s0v = _mm_sub_pd(a87, a77);
    t3q = _mm_add_pd(t4p, s9u);
    t4q = _mm_sub_pd(s0v, t6p);
    t5q = _mm_sub_pd(t4p, s9u);
    t6q = _mm_add_pd(t6p, s0v);
    s1v = *((a67 + 1));
    s2v = *((a67 + 9));
    t7q = _mm_add_pd(s1v, s2v);
    t8q = _mm_sub_pd(s1v, s2v);
    s3v = *((a67 + 5));
    s4v = *((a67 + 13));
    t9q = _mm_add_pd(s3v, s4v);
    t0r = _mm_sub_pd(s3v, s4v);
    s5v = *((a67 + 3));
    s6v = *((a67 + 11));
    t1r = _mm_add_pd(s5v, s6v);
    s7v = *((a67 + 7));
    s8v = *((a67 + 15));
    t2r = _mm_add_pd(s7v, s8v);
    t3r = _mm_add_pd(t7q, t9q);
    t4r = _mm_add_pd(t1r, t2r);
    a97 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5v, s6v));
    a08 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s7v, s8v));
    s9v = _mm_add_pd(a97, a08);
    s0w = _mm_sub_pd(a08, a97);
    t5r = _mm_add_pd(t8q, s9v);
    t6r = _mm_sub_pd(s0w, t0r);
    t7r = _mm_sub_pd(t8q, s9v);
    t8r = _mm_add_pd(t0r, s0w);
    t9r = _mm_add_pd(t9p, t1q);
    t0s = _mm_sub_pd(t9p, t1q);
    t1s = _mm_add_pd(t3r, t4r);
    t2s = _mm_sub_pd(t3r, t4r);
    t3s = _mm_add_pd(t9r, t1s);
    a18 = ((__m128d  *) dst);
    s1w = _mm_add_pd(v_neg03(v_hi2(t3s, t3s)), v_lo2(t3s, t3s));
    *(a18) = s1w;
    s2w = v_neg23(_mm_sub_pd(t9r, t1s));
    *((a18 + 2048)) = s2w;
    s3w = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t0s), _mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t2s));
    s4w = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.70710678118654757), 0.0), t0s), _mm_mul_pd(_mm_set_pd(0.70710678118654757, 1.0), t2s));
    s5w = v_lo2(s3w, s4w);
    s6w = v_hi2(s3w, s4w);
    s7w = _mm_add_pd(s5w, s6w);
    *((a18 + 1024)) = s7w;
    s8w = v_neg23(_mm_sub_pd(s5w, s6w));
    *((a18 + 3072)) = s8w;
    s9w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5r), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t6r));
    s0x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t5r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6r));
    t4s = _mm_add_pd(t3q, s9w);
    t5s = _mm_add_pd(t4q, s0x);
    t6s = _mm_sub_pd(t3q, s9w);
    t7s = _mm_sub_pd(t4q, s0x);
    s1x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t4s), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t5s));
    s2x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 0.0), t4s), _mm_mul_pd(_mm_set_pd(0.98078528040323043, 1.0), t5s));
    s3x = v_lo2(s1x, s2x);
    s4x = v_hi2(s1x, s2x);
    s5x = _mm_add_pd(s3x, s4x);
    *((a18 + 256)) = s5x;
    s6x = v_neg23(_mm_sub_pd(s3x, s4x));
    *((a18 + 3840)) = s6x;
    s7x = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t6s), _mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t7s));
    s8x = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.98078528040323043), 0.0), t6s), _mm_mul_pd(_mm_set_pd((-0.19509032201612828), 1.0), t7s));
    s9x = v_lo2(s7x, s8x);
    s0y = v_hi2(s7x, s8x);
    s1y = _mm_add_pd(s9x, s0y);
    *((a18 + 2304)) = s1y;
    s2y = v_neg23(_mm_sub_pd(s9x, s0y));
    *((a18 + 1792)) = s2y;
    a28 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7q, t9q));
    a38 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t1r, t2r));
    s3y = _mm_add_pd(a28, a38);
    s4y = _mm_sub_pd(a38, a28);
    t8s = _mm_add_pd(t0q, s3y);
    t9s = _mm_sub_pd(s4y, t2q);
    t0t = _mm_sub_pd(t0q, s3y);
    t1t = _mm_add_pd(t2q, s4y);
    s5y = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t8s), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t9s));
    s6y = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 0.0), t8s), _mm_mul_pd(_mm_set_pd(0.92387953251128674, 1.0), t9s));
    s7y = v_lo2(s5y, s6y);
    s8y = v_hi2(s5y, s6y);
    s9y = _mm_add_pd(s7y, s8y);
    *((a18 + 512)) = s9y;
    s0z = v_neg23(_mm_sub_pd(s7y, s8y));
    *((a18 + 3584)) = s0z;
    s1z = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t0t), _mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t1t));
    s2z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.92387953251128674), 0.0), t0t), _mm_mul_pd(_mm_set_pd((-0.38268343236508978), 1.0), t1t));
    s3z = v_lo2(s1z, s2z);
    s4z = v_hi2(s1z, s2z);
    s5z = _mm_add_pd(s3z, s4z);
    *((a18 + 2560)) = s5z;
    s6z = v_neg23(_mm_sub_pd(s3z, s4z));
    *((a18 + 1536)) = s6z;
    s7z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7r), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t8r));
    s8z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t7r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8r));
    t2t = _mm_add_pd(t5q, s7z);
    t3t = _mm_add_pd(t6q, s8z);
    t4t = _mm_sub_pd(t5q, s7z);
    t5t = _mm_sub_pd(t6q, s8z);
    s9z = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t2t), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t3t));
    s0A = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 0.0), t2t), _mm_mul_pd(_mm_set_pd(0.83146961230254524, 1.0), t3t));
    s1A = v_lo2(s9z, s0A);
    s2A = v_hi2(s9z, s0A);
    s3A = _mm_add_pd(s1A, s2A);
    *((a18 + 768)) = s3A;
    s4A = v_neg23(_mm_sub_pd(s1A, s2A));
    *((a18 + 3328)) = s4A;
    s5A = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t4t), _mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t5t));
    s6A = _mm_add_pd(_mm_mul_pd(_mm_set_pd((-0.83146961230254524), 0.0), t4t), _mm_mul_pd(_mm_set_pd((-0.55557023301960218), 1.0), t5t));
    s7A = v_lo2(s5A, s6A);
    s8A = v_hi2(s5A, s6A);
    s9A = _mm_add_pd(s7A, s8A);
    *((a18 + 2816)) = s9A;
    s0B = v_neg23(_mm_sub_pd(s7A, s8A));
    *((a18 + 1280)) = s0B;
    {long i4; for(i4 = 0; i4 <= 254; i4++) {
        a48 = (16 * i4);
        b5 = (((__m128d  *) T) + a48);
        s1B = *((b5 + 16));
        s2B = *((b5 + 24));
        s3B = *((b5 + 20));
        s4B = *((b5 + 28));
        a58 = (D61 + (4 * i4));
        a68 = *(a58);
        a78 = *((a58 + 1));
        s5B = _mm_sub_pd(_mm_mul_pd(a68, s1B), _mm_mul_pd(a78, s2B));
        s6B = _mm_add_pd(_mm_mul_pd(a78, s1B), _mm_mul_pd(a68, s2B));
        a88 = *((a58 + 2));
        a98 = *((a58 + 3));
        s7B = _mm_sub_pd(_mm_mul_pd(a88, s3B), _mm_mul_pd(a98, s4B));
        s8B = _mm_add_pd(_mm_mul_pd(a98, s3B), _mm_mul_pd(a88, s4B));
        t6t = _mm_add_pd(s5B, s7B);
        t7t = _mm_add_pd(s6B, s8B);
        t8t = _mm_sub_pd(s5B, s7B);
        t9t = _mm_sub_pd(s6B, s8B);
        s9B = *((b5 + 17));
        s0C = *((b5 + 25));
        s1C = *((b5 + 21));
        s2C = *((b5 + 29));
        s3C = _mm_sub_pd(_mm_mul_pd(a68, s9B), _mm_mul_pd(a78, s0C));
        s4C = _mm_add_pd(_mm_mul_pd(a78, s9B), _mm_mul_pd(a68, s0C));
        s5C = _mm_sub_pd(_mm_mul_pd(a88, s1C), _mm_mul_pd(a98, s2C));
        s6C = _mm_add_pd(_mm_mul_pd(a98, s1C), _mm_mul_pd(a88, s2C));
        t0u = _mm_add_pd(s3C, s5C);
        t1u = _mm_add_pd(s4C, s6C);
        t2u = _mm_sub_pd(s3C, s5C);
        t3u = _mm_sub_pd(s4C, s6C);
        s7C = *((b5 + 18));
        s8C = *((b5 + 26));
        s9C = *((b5 + 22));
        s0D = *((b5 + 30));
        s1D = _mm_sub_pd(_mm_mul_pd(a68, s7C), _mm_mul_pd(a78, s8C));
        s2D = _mm_add_pd(_mm_mul_pd(a78, s7C), _mm_mul_pd(a68, s8C));
        s3D = _mm_sub_pd(_mm_mul_pd(a88, s9C), _mm_mul_pd(a98, s0D));
        s4D = _mm_add_pd(_mm_mul_pd(a98, s9C), _mm_mul_pd(a88, s0D));
        t4u = _mm_add_pd(s1D, s3D);
        t5u = _mm_add_pd(s2D, s4D);
        t6u = _mm_sub_pd(s1D, s3D);
        t7u = _mm_sub_pd(s2D, s4D);
        s5D = *((b5 + 19));
        s6D = *((b5 + 27));
        s7D = *((b5 + 23));
        s8D = *((b5 + 31));
        s9D = _mm_sub_pd(_mm_mul_pd(a68, s5D), _mm_mul_pd(a78, s6D));
        s0E = _mm_add_pd(_mm_mul_pd(a78, s5D), _mm_mul_pd(a68, s6D));
        s1E = _mm_sub_pd(_mm_mul_pd(a88, s7D), _mm_mul_pd(a98, s8D));
        s2E = _mm_add_pd(_mm_mul_pd(a98, s7D), _mm_mul_pd(a88, s8D));
        t8u = _mm_add_pd(s9D, s1E);
        t9u = _mm_add_pd(s0E, s2E);
        t0v = _mm_sub_pd(s9D, s1E);
        t1v = _mm_sub_pd(s0E, s2E);
        a09 = (D60 + a48);
        a19 = *(a09);
        a29 = *((a09 + 1));
        s3E = _mm_sub_pd(_mm_mul_pd(a19, t6t), _mm_mul_pd(a29, t7t));
        s4E = _mm_add_pd(_mm_mul_pd(a29, t6t), _mm_mul_pd(a19, t7t));
        a39 = *((a09 + 2));
        a49 = *((a09 + 3));
        s5E = _mm_sub_pd(_mm_mul_pd(a39, t0u), _mm_mul_pd(a49, t1u));
        s6E = _mm_add_pd(_mm_mul_pd(a49, t0u), _mm_mul_pd(a39, t1u));
        a59 = *((a09 + 4));
        a69 = *((a09 + 5));
        s7E = _mm_sub_pd(_mm_mul_pd(a59, t4u), _mm_mul_pd(a69, t5u));
        s8E = _mm_add_pd(_mm_mul_pd(a69, t4u), _mm_mul_pd(a59, t5u));
        a79 = *((a09 + 6));
        a89 = *((a09 + 7));
        s9E = _mm_sub_pd(_mm_mul_pd(a79, t8u), _mm_mul_pd(a89, t9u));
        s0F = _mm_add_pd(_mm_mul_pd(a89, t8u), _mm_mul_pd(a79, t9u));
        t2v = _mm_add_pd(s3E, s7E);
        t3v = _mm_add_pd(s4E, s8E);
        t4v = _mm_sub_pd(s3E, s7E);
        t5v = _mm_sub_pd(s4E, s8E);
        t6v = _mm_add_pd(s5E, s9E);
        t7v = _mm_add_pd(s6E, s0F);
        t8v = _mm_sub_pd(s5E, s9E);
        t9v = _mm_sub_pd(s6E, s0F);
        t0w = _mm_add_pd(t2v, t6v);
        t1w = _mm_add_pd(t3v, t7v);
        t2w = _mm_sub_pd(t2v, t6v);
        t3w = _mm_sub_pd(t3v, t7v);
        t4w = _mm_add_pd(t4v, t9v);
        t5w = _mm_sub_pd(t5v, t8v);
        t6w = _mm_sub_pd(t4v, t9v);
        t7w = _mm_add_pd(t5v, t8v);
        a99 = (D56 + a48);
        a0a = *(a99);
        a1a = *((a99 + 1));
        s1F = _mm_sub_pd(_mm_mul_pd(a0a, t0w), _mm_mul_pd(a1a, t1w));
        s2F = _mm_add_pd(_mm_mul_pd(a1a, t0w), _mm_mul_pd(a0a, t1w));
        s3F = v_lo2(s1F, s2F);
        s4F = v_hi2(s1F, s2F);
        a2a = ((__m128d  *) dst);
        b6 = (a2a + i4);
        s5F = _mm_add_pd(s3F, s4F);
        *((b6 + 1)) = s5F;
        b7 = (a2a - i4);
        s6F = v_neg23(_mm_sub_pd(s3F, s4F));
        *((b7 + 4095)) = s6F;
        a3a = *((a99 + 2));
        a4a = *((a99 + 3));
        s7F = _mm_sub_pd(_mm_mul_pd(a3a, t4w), _mm_mul_pd(a4a, t5w));
        s8F = _mm_add_pd(_mm_mul_pd(a4a, t4w), _mm_mul_pd(a3a, t5w));
        s9F = v_lo2(s7F, s8F);
        s0G = v_hi2(s7F, s8F);
        s1G = _mm_add_pd(s9F, s0G);
        *((b6 + 1025)) = s1G;
        s2G = v_neg23(_mm_sub_pd(s9F, s0G));
        *((b7 + 3071)) = s2G;
        a5a = *((a99 + 4));
        a6a = *((a99 + 5));
        s3G = _mm_sub_pd(_mm_mul_pd(a5a, t2w), _mm_mul_pd(a6a, t3w));
        s4G = _mm_add_pd(_mm_mul_pd(a6a, t2w), _mm_mul_pd(a5a, t3w));
        s5G = v_lo2(s3G, s4G);
        s6G = v_hi2(s3G, s4G);
        s7G = _mm_add_pd(s5G, s6G);
        *((b6 + 2049)) = s7G;
        s8G = v_neg23(_mm_sub_pd(s5G, s6G));
        *((b7 + 2047)) = s8G;
        a7a = *((a99 + 6));
        a8a = *((a99 + 7));
        s9G = _mm_sub_pd(_mm_mul_pd(a7a, t6w), _mm_mul_pd(a8a, t7w));
        s0H = _mm_add_pd(_mm_mul_pd(a8a, t6w), _mm_mul_pd(a7a, t7w));
        s1H = v_lo2(s9G, s0H);
        s2H = v_hi2(s9G, s0H);
        s3H = _mm_add_pd(s1H, s2H);
        *((b6 + 3073)) = s3H;
        s4H = v_neg23(_mm_sub_pd(s1H, s2H));
        *((b7 + 1023)) = s4H;
        a9a = *((a09 + 8));
        a0b = *((a09 + 9));
        s5H = _mm_sub_pd(_mm_mul_pd(a9a, t8t), _mm_mul_pd(a0b, t9t));
        s6H = _mm_add_pd(_mm_mul_pd(a0b, t8t), _mm_mul_pd(a9a, t9t));
        a1b = *((a09 + 10));
        a2b = *((a09 + 11));
        s7H = _mm_sub_pd(_mm_mul_pd(a1b, t2u), _mm_mul_pd(a2b, t3u));
        s8H = _mm_add_pd(_mm_mul_pd(a2b, t2u), _mm_mul_pd(a1b, t3u));
        a3b = *((a09 + 12));
        a4b = *((a09 + 13));
        s9H = _mm_sub_pd(_mm_mul_pd(a3b, t6u), _mm_mul_pd(a4b, t7u));
        s0I = _mm_add_pd(_mm_mul_pd(a4b, t6u), _mm_mul_pd(a3b, t7u));
        a5b = *((a09 + 14));
        a6b = *((a09 + 15));
        s1I = _mm_sub_pd(_mm_mul_pd(a5b, t0v), _mm_mul_pd(a6b, t1v));
        s2I = _mm_add_pd(_mm_mul_pd(a6b, t0v), _mm_mul_pd(a5b, t1v));
        t8w = _mm_add_pd(s5H, s9H);
        t9w = _mm_add_pd(s6H, s0I);
        t0x = _mm_sub_pd(s5H, s9H);
        t1x = _mm_sub_pd(s6H, s0I);
        t2x = _mm_add_pd(s7H, s1I);
        t3x = _mm_add_pd(s8H, s2I);
        t4x = _mm_sub_pd(s7H, s1I);
        t5x = _mm_sub_pd(s8H, s2I);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_add_pd(t9w, t3x);
        t8x = _mm_sub_pd(t8w, t2x);
        t9x = _mm_sub_pd(t9w, t3x);
        t0y = _mm_add_pd(t0x, t5x);
        t1y = _mm_sub_pd(t1x, t4x);
        t2y = _mm_sub_pd(t0x, t5x);
        t3y = _mm_add_pd(t1x, t4x);
        a7b = *((a99 + 8));
        a8b = *((a99 + 9));
        s3I = _mm_sub_pd(_mm_mul_pd(a7b, t6x), _mm_mul_pd(a8b, t7x));
        s4I = _mm_add_pd(_mm_mul_pd(a8b, t6x), _mm_mul_pd(a7b, t7x));
        s5I = v_lo2(s3I, s4I);
        s6I = v_hi2(s3I, s4I);
        s7I = _mm_add_pd(s5I, s6I);
        *((b6 + 513)) = s7I;
        s8I = v_neg23(_mm_sub_pd(s5I, s6I));
        *((b7 + 3583)) = s8I;
        a9b = *((a99 + 10));
        a0c = *((a99 + 11));
        s9I = _mm_sub_pd(_mm_mul_pd(a9b, t0y), _mm_mul_pd(a0c, t1y));
        s0J = _mm_add_pd(_mm_mul_pd(a0c, t0y), _mm_mul_pd(a9b, t1y));
        s1J = v_lo2(s9I, s0J);
        s2J = v_hi2(s9I, s0J);
        s3J = _mm_add_pd(s1J, s2J);
        *((b6 + 1537)) = s3J;
        s4J = v_neg23(_mm_sub_pd(s1J, s2J));
        *((b7 + 2559)) = s4J;
        a1c = *((a99 + 12));
        a2c = *((a99 + 13));
        s5J = _mm_sub_pd(_mm_mul_pd(a1c, t8x), _mm_mul_pd(a2c, t9x));
        s6J = _mm_add_pd(_mm_mul_pd(a2c, t8x), _mm_mul_pd(a1c, t9x));
        s7J = v_lo2(s5J, s6J);
        s8J = v_hi2(s5J, s6J);
        s9J = _mm_add_pd(s7J, s8J);
        *((b6 + 2561)) = s9J;
        s0K = v_neg23(_mm_sub_pd(s7J, s8J));
        *((b7 + 1535)) = s0K;
        a3c = *((a99 + 14));
        a4c = *((a99 + 15));
        s1K = _mm_sub_pd(_mm_mul_pd(a3c, t2y), _mm_mul_pd(a4c, t3y));
        s2K = _mm_add_pd(_mm_mul_pd(a4c, t2y), _mm_mul_pd(a3c, t3y));
        s3K = v_lo2(s1K, s2K);
        s4K = v_hi2(s1K, s2K);
        s5K = _mm_add_pd(s3K, s4K);
        *((b6 + 3585)) = s5K;
        s6K = v_neg23(_mm_sub_pd(s3K, s4K));
        *((b7 + 511)) = s6K;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_2)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {double s, s2, s3, s4;
    s = *(src);
    s2 = *((src + 1));
    s3 = (s + s2);
    *(dst) = s3;
    s4 = (s - s2);
    *((dst + 1)) = s4;
    }
    
    return SPIRAL_OK;
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_4_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d s, s2, s3, s4, s5;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 2))));
    s4 = _mm_add_pd(s2, s3);
    _mm_storeu_pd(((double  *) dst), s4);
    s5 = _mm_sub_pd(s2, s3);
    _mm_storeu_pd(((double  *) (dst + 2)), s5);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_4)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_4_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d s, s2, s3, s4, s5;
    __m128d  *a, *a2;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 1)));
    a2 = ((__m128d  *) dst);
    s4 = _mm_add_pd(s2, s3);
    *(a2) = s4;
    s5 = _mm_sub_pd(s2, s3);
    *((a2 + 1)) = s5;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_8)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {double a, a2, s, s01, s02, s11, s2, s21, s3, s31, s4, s41, s5, s51, s6, s61, s7, s71, s8, s81, s9, s91
            , t, t2, t3, t4, t5, t6;
    s = *(src);
    s2 = *((src + 1));
    t = (s + s2);
    t2 = (s - s2);
    s3 = (2**((src + 4)));
    t3 = (t + s3);
    t4 = (t - s3);
    s4 = (2**((src + 5)));
    t5 = (t2 - s4);
    t6 = (t2 + s4);
    s5 = *((src + 2));
    s6 = *((src + 3));
    s7 = *((src + 6));
    s8 = *((src + 7));
    s9 = (2.0*(s5 + s7));
    s01 = (2.0*(s6 - s8));
    a = (1.4142135623730951*(s5 - s7));
    a2 = (1.4142135623730951*(s6 + s8));
    s11 = (a - a2);
    s21 = (a + a2);
    s31 = (t3 + s9);
    *(dst) = s31;
    s41 = (t3 - s9);
    *((dst + 4)) = s41;
    s51 = (t4 - s01);
    *((dst + 2)) = s51;
    s61 = (t4 + s01);
    *((dst + 6)) = s61;
    s71 = (t5 + s11);
    *((dst + 1)) = s71;
    s81 = (t5 - s11);
    *((dst + 5)) = s81;
    s91 = (t6 - s21);
    *((dst + 3)) = s91;
    s02 = (t6 + s21);
    *((dst + 7)) = s02;
    }
    
    return SPIRAL_OK;
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_16_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a2, s, s01, s02, s03, s11, s12, s13, s2, s21, s22, s3, s31, s32, s4, s41, s42, s5, s51, s52, s6
            , s61, s62, s7, s71, s72, s8, s81, s82, s9, s91, s92, t, t01, t11, t2, t21, t3, t31, t4, t41, t5, t6
            , t7, t8, t9;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 8))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 2)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 14))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 4)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 12))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s21), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 6)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 10))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s81), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s91));
    t9 = _mm_add_pd(t, s41);
    t01 = _mm_sub_pd(t, s41);
    t11 = _mm_sub_pd(t2, s51);
    t21 = _mm_add_pd(t2, s51);
    t31 = _mm_add_pd(s8, s02);
    t41 = _mm_sub_pd(s9, s12);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8, s02));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9, s12));
    s22 = _mm_sub_pd(a, a2);
    s32 = _mm_add_pd(a, a2);
    s42 = _mm_add_pd(t9, t31);
    _mm_storeu_pd(((double  *) dst), s42);
    s52 = _mm_sub_pd(t9, t31);
    _mm_storeu_pd(((double  *) (dst + 8)), s52);
    s62 = _mm_sub_pd(t01, t41);
    _mm_storeu_pd(((double  *) (dst + 4)), s62);
    s72 = _mm_add_pd(t01, t41);
    _mm_storeu_pd(((double  *) (dst + 12)), s72);
    s82 = _mm_add_pd(t11, s22);
    _mm_storeu_pd(((double  *) (dst + 2)), s82);
    s92 = _mm_sub_pd(t11, s22);
    _mm_storeu_pd(((double  *) (dst + 10)), s92);
    s03 = _mm_sub_pd(t21, s32);
    _mm_storeu_pd(((double  *) (dst + 6)), s03);
    s13 = _mm_add_pd(t21, s32);
    _mm_storeu_pd(((double  *) (dst + 14)), s13);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_16)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_16_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a2, a3, s, s01, s02, s03, s11, s12, s13, s2, s21, s22, s3, s31, s32, s4, s41, s42, s5, s51, s52, s6
            , s61, s62, s7, s71, s72, s8, s81, s82, s9, s91, s92, t, t01, t11, t2, t21, t3, t31, t4, t41, t5, t6
            , t7, t8, t9;
    __m128d  *a, *a4;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 4)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 1));
    s5 = v_neg23(*((a + 7)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s7));
    s01 = *((a + 2));
    s11 = v_neg23(*((a + 6)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s21), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s31));
    s61 = *((a + 3));
    s71 = v_neg23(*((a + 5)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s81), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s91));
    t9 = _mm_add_pd(t, s41);
    t01 = _mm_sub_pd(t, s41);
    t11 = _mm_sub_pd(t2, s51);
    t21 = _mm_add_pd(t2, s51);
    t31 = _mm_add_pd(s8, s02);
    t41 = _mm_sub_pd(s9, s12);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8, s02));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9, s12));
    s22 = _mm_sub_pd(a2, a3);
    s32 = _mm_add_pd(a2, a3);
    a4 = ((__m128d  *) dst);
    s42 = _mm_add_pd(t9, t31);
    *(a4) = s42;
    s52 = _mm_sub_pd(t9, t31);
    *((a4 + 4)) = s52;
    s62 = _mm_sub_pd(t01, t41);
    *((a4 + 2)) = s62;
    s72 = _mm_add_pd(t01, t41);
    *((a4 + 6)) = s72;
    s82 = _mm_add_pd(t11, s22);
    *((a4 + 1)) = s82;
    s92 = _mm_sub_pd(t11, s22);
    *((a4 + 5)) = s92;
    s03 = _mm_sub_pd(t21, s32);
    *((a4 + 3)) = s03;
    s13 = _mm_add_pd(t21, s32);
    *((a4 + 7)) = s13;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_32_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a2, a3, a4, s, s01, s02, s03, s04, s05, s06, s11, s12, s13, s14, s15, s16, s2, s21, s22, s23, s24
            , s25, s26, s3, s31, s32, s33, s34, s35, s36, s4, s41, s42, s43, s44, s45, s46, s5, s51, s52, s53, s54, s55
            , s56, s6, s61, s62, s63, s64, s65, s66, s7, s71, s72, s73, s74, s75, s76, s8, s81, s82, s83, s84, s85, s86
            , s9, s91, s92, s93, s94, s95, s96, t, t01, t02, t03, t04, t11, t12, t13, t14, t2, t21, t22, t23, t24, t3
            , t31, t32, t33, t34, t4, t41, t42, t43, t44, t5, t51, t52, t53, t6, t61, t62, t63, t7, t71, t72, t73, t8
            , t81, t82, t83, t9, t91, t92, t93;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 16))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 2)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 30))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 4)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 28))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 6)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 26))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 8)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 24))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 10)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 22))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 12)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 20))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 14)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 18))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    s45 = _mm_add_pd(t32, t93);
    _mm_storeu_pd(((double  *) dst), s45);
    s55 = _mm_sub_pd(t32, t93);
    _mm_storeu_pd(((double  *) (dst + 16)), s55);
    s65 = _mm_sub_pd(t42, t04);
    _mm_storeu_pd(((double  *) (dst + 8)), s65);
    s75 = _mm_add_pd(t42, t04);
    _mm_storeu_pd(((double  *) (dst + 24)), s75);
    s85 = _mm_add_pd(t72, s84);
    _mm_storeu_pd(((double  *) (dst + 2)), s85);
    s95 = _mm_sub_pd(t72, s84);
    _mm_storeu_pd(((double  *) (dst + 18)), s95);
    s06 = _mm_sub_pd(t82, s94);
    _mm_storeu_pd(((double  *) (dst + 10)), s06);
    s16 = _mm_add_pd(t82, s94);
    _mm_storeu_pd(((double  *) (dst + 26)), s16);
    s26 = _mm_add_pd(t52, s05);
    _mm_storeu_pd(((double  *) (dst + 4)), s26);
    s36 = _mm_sub_pd(t52, s05);
    _mm_storeu_pd(((double  *) (dst + 20)), s36);
    s46 = _mm_sub_pd(t62, s15);
    _mm_storeu_pd(((double  *) (dst + 12)), s46);
    s56 = _mm_add_pd(t62, s15);
    _mm_storeu_pd(((double  *) (dst + 28)), s56);
    s66 = _mm_add_pd(t92, s25);
    _mm_storeu_pd(((double  *) (dst + 6)), s66);
    s76 = _mm_sub_pd(t92, s25);
    _mm_storeu_pd(((double  *) (dst + 22)), s76);
    s86 = _mm_sub_pd(t03, s35);
    _mm_storeu_pd(((double  *) (dst + 14)), s86);
    s96 = _mm_add_pd(t03, s35);
    _mm_storeu_pd(((double  *) (dst + 30)), s96);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_32)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_32_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a2, a3, a4, a5, s, s01, s02, s03, s04, s05, s06, s11, s12, s13, s14, s15, s16, s2, s21, s22, s23, s24
            , s25, s26, s3, s31, s32, s33, s34, s35, s36, s4, s41, s42, s43, s44, s45, s46, s5, s51, s52, s53, s54, s55
            , s56, s6, s61, s62, s63, s64, s65, s66, s7, s71, s72, s73, s74, s75, s76, s8, s81, s82, s83, s84, s85, s86
            , s9, s91, s92, s93, s94, s95, s96, t, t01, t02, t03, t04, t11, t12, t13, t14, t2, t21, t22, t23, t24, t3
            , t31, t32, t33, t34, t4, t41, t42, t43, t44, t5, t51, t52, t53, t6, t61, t62, t63, t7, t71, t72, t73, t8
            , t81, t82, t83, t9, t91, t92, t93;
    __m128d  *a, *a6;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 8)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 1));
    s5 = v_neg23(*((a + 15)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 2));
    s11 = v_neg23(*((a + 14)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 3));
    s71 = v_neg23(*((a + 13)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 4));
    s32 = v_neg23(*((a + 12)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 5));
    s92 = v_neg23(*((a + 11)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 6));
    s53 = v_neg23(*((a + 10)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 7));
    s14 = v_neg23(*((a + 9)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a6 = ((__m128d  *) dst);
    s45 = _mm_add_pd(t32, t93);
    *(a6) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a6 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a6 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a6 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a6 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a6 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a6 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a6 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a6 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a6 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a6 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a6 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a6 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a6 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a6 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a6 + 15)) = s96;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_64_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a01, a11, a2, a21, a3, a4, a5, a6, a7, a8, a9, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s2
            , s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s3, s31, s32, s33, s34, s35, s36
            , s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c
            , s4d, s4e, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b
            , s7c, s7d, s7e, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s9, s91, s92, s93
            , s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a
            , t0b, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29
            , t2a, t2b, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t4, t41, t42, t43, t44, t45, t46, t47
            , t48, t49, t4a, t4b, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t6, t61, t62, t63, t64, t65
            , t66, t67, t68, t69, t6a, t6b, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 32))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 2)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 62))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 4)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 60))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 6)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 58))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s81), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 8)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 56))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s42), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 10)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 54))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s03), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 12)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 52))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s63), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 14)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 50))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s24), _mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s34));
    s64 = _mm_loadu_pd(((const double  *) (src + 16)));
    s74 = v_neg23(_mm_loadu_pd(((const double  *) (src + 48))));
    t71 = _mm_add_pd(s64, s74);
    t81 = _mm_sub_pd(s64, s74);
    s84 = v_lo2(t71, t81);
    s94 = v_hi2(t71, t81);
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s94));
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s94));
    s25 = _mm_loadu_pd(((const double  *) (src + 18)));
    s35 = v_neg23(_mm_loadu_pd(((const double  *) (src + 46))));
    t91 = _mm_add_pd(s25, s35);
    t02 = _mm_sub_pd(s25, s35);
    s45 = v_lo2(t91, t02);
    s55 = v_hi2(t91, t02);
    s65 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s45), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s55));
    s75 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s45), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s55));
    s85 = _mm_loadu_pd(((const double  *) (src + 20)));
    s95 = v_neg23(_mm_loadu_pd(((const double  *) (src + 44))));
    t12 = _mm_add_pd(s85, s95);
    t22 = _mm_sub_pd(s85, s95);
    s06 = v_lo2(t12, t22);
    s16 = v_hi2(t12, t22);
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s06), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s16));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s06), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s16));
    s46 = _mm_loadu_pd(((const double  *) (src + 22)));
    s56 = v_neg23(_mm_loadu_pd(((const double  *) (src + 42))));
    t32 = _mm_add_pd(s46, s56);
    t42 = _mm_sub_pd(s46, s56);
    s66 = v_lo2(t32, t42);
    s76 = v_hi2(t32, t42);
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s66), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s76));
    s96 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s66), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s76));
    s07 = _mm_loadu_pd(((const double  *) (src + 24)));
    s17 = v_neg23(_mm_loadu_pd(((const double  *) (src + 40))));
    t52 = _mm_add_pd(s07, s17);
    t62 = _mm_sub_pd(s07, s17);
    s27 = v_lo2(t52, t62);
    s37 = v_hi2(t52, t62);
    s47 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s27), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s37));
    s57 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s27), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s37));
    s67 = _mm_loadu_pd(((const double  *) (src + 26)));
    s77 = v_neg23(_mm_loadu_pd(((const double  *) (src + 38))));
    t72 = _mm_add_pd(s67, s77);
    t82 = _mm_sub_pd(s67, s77);
    s87 = v_lo2(t72, t82);
    s97 = v_hi2(t72, t82);
    s08 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s87), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s97));
    s18 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s87), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s97));
    s28 = _mm_loadu_pd(((const double  *) (src + 28)));
    s38 = v_neg23(_mm_loadu_pd(((const double  *) (src + 36))));
    t92 = _mm_add_pd(s28, s38);
    t03 = _mm_sub_pd(s28, s38);
    s48 = v_lo2(t92, t03);
    s58 = v_hi2(t92, t03);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s48), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s58));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s48), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s58));
    s88 = _mm_loadu_pd(((const double  *) (src + 30)));
    s98 = v_neg23(_mm_loadu_pd(((const double  *) (src + 34))));
    t13 = _mm_add_pd(s88, s98);
    t23 = _mm_sub_pd(s88, s98);
    s09 = v_lo2(t13, t23);
    s19 = v_hi2(t13, t23);
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s09), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s19));
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s09), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s19));
    t33 = _mm_add_pd(t, s05);
    t43 = _mm_sub_pd(t, s05);
    t53 = _mm_sub_pd(t2, s15);
    t63 = _mm_add_pd(t2, s15);
    t73 = _mm_add_pd(s62, s47);
    t83 = _mm_sub_pd(s72, s57);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s62, s47));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s72, s57));
    s49 = _mm_sub_pd(a, a2);
    s59 = _mm_add_pd(a, a2);
    t93 = _mm_add_pd(t33, t73);
    t04 = _mm_sub_pd(t33, t73);
    t14 = _mm_sub_pd(t43, t83);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_add_pd(t53, s49);
    t44 = _mm_sub_pd(t53, s49);
    t54 = _mm_sub_pd(t63, s59);
    t64 = _mm_add_pd(t63, s59);
    t74 = _mm_add_pd(s8, s29);
    t84 = _mm_sub_pd(s9, s39);
    t94 = _mm_sub_pd(s8, s29);
    t05 = _mm_add_pd(s9, s39);
    t15 = _mm_add_pd(s65, s44);
    t25 = _mm_sub_pd(s75, s54);
    t35 = _mm_sub_pd(s65, s44);
    t45 = _mm_add_pd(s75, s54);
    t55 = _mm_add_pd(t74, t15);
    t65 = _mm_add_pd(t84, t25);
    t75 = _mm_sub_pd(t74, t15);
    t85 = _mm_sub_pd(t84, t25);
    t95 = _mm_sub_pd(t94, t45);
    t06 = _mm_add_pd(t05, t35);
    t16 = _mm_add_pd(t94, t45);
    t26 = _mm_sub_pd(t05, t35);
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t95), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t06));
    s79 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t95), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t06));
    s89 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t75), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t75), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t85));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t16), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t26));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t16), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t26));
    t36 = _mm_add_pd(s41, s68);
    t46 = _mm_sub_pd(s51, s78);
    t56 = _mm_sub_pd(s41, s68);
    t66 = _mm_add_pd(s51, s78);
    t76 = _mm_add_pd(s26, s83);
    t86 = _mm_sub_pd(s36, s93);
    t96 = _mm_sub_pd(s26, s83);
    t07 = _mm_add_pd(s36, s93);
    t17 = _mm_add_pd(t36, t76);
    t27 = _mm_add_pd(t46, t86);
    t37 = _mm_sub_pd(t56, t07);
    t47 = _mm_add_pd(t66, t96);
    t57 = _mm_add_pd(t56, t07);
    t67 = _mm_sub_pd(t66, t96);
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t37), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t47));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t37), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t47));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t36, t76));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t46, t86));
    s4a = _mm_sub_pd(a3, a4);
    s5a = _mm_add_pd(a3, a4);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    t77 = _mm_add_pd(s02, s08);
    t87 = _mm_sub_pd(s12, s18);
    t97 = _mm_sub_pd(s02, s08);
    t08 = _mm_add_pd(s12, s18);
    t18 = _mm_add_pd(s86, s23);
    t28 = _mm_sub_pd(s96, s33);
    t38 = _mm_sub_pd(s86, s23);
    t48 = _mm_add_pd(s96, s33);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t78), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t88));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t78), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t88));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t19), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t29));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t19), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t29));
    t39 = _mm_add_pd(t93, t17);
    t49 = _mm_sub_pd(t93, t17);
    t59 = _mm_sub_pd(t04, t27);
    t69 = _mm_add_pd(t04, t27);
    t79 = _mm_add_pd(t55, t58);
    t89 = _mm_sub_pd(t65, t68);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t55, t58));
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t65, t68));
    s4b = _mm_sub_pd(a5, a6);
    s5b = _mm_add_pd(a5, a6);
    s6b = _mm_add_pd(t39, t79);
    _mm_storeu_pd(((double  *) dst), s6b);
    s7b = _mm_sub_pd(t39, t79);
    _mm_storeu_pd(((double  *) (dst + 32)), s7b);
    s8b = _mm_sub_pd(t49, t89);
    _mm_storeu_pd(((double  *) (dst + 16)), s8b);
    s9b = _mm_add_pd(t49, t89);
    _mm_storeu_pd(((double  *) (dst + 48)), s9b);
    s0c = _mm_add_pd(t59, s4b);
    _mm_storeu_pd(((double  *) (dst + 8)), s0c);
    s1c = _mm_sub_pd(t59, s4b);
    _mm_storeu_pd(((double  *) (dst + 40)), s1c);
    s2c = _mm_sub_pd(t69, s5b);
    _mm_storeu_pd(((double  *) (dst + 24)), s2c);
    s3c = _mm_add_pd(t69, s5b);
    _mm_storeu_pd(((double  *) (dst + 56)), s3c);
    t99 = _mm_add_pd(t34, s2a);
    t0a = _mm_sub_pd(t34, s2a);
    t1a = _mm_sub_pd(t44, s3a);
    t2a = _mm_add_pd(t44, s3a);
    t3a = _mm_add_pd(s69, s8a);
    t4a = _mm_sub_pd(s79, s9a);
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s69, s8a));
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s79, s9a));
    s4c = _mm_sub_pd(a7, a8);
    s5c = _mm_add_pd(a7, a8);
    s6c = _mm_add_pd(t99, t3a);
    _mm_storeu_pd(((double  *) (dst + 2)), s6c);
    s7c = _mm_sub_pd(t99, t3a);
    _mm_storeu_pd(((double  *) (dst + 34)), s7c);
    s8c = _mm_sub_pd(t0a, t4a);
    _mm_storeu_pd(((double  *) (dst + 18)), s8c);
    s9c = _mm_add_pd(t0a, t4a);
    _mm_storeu_pd(((double  *) (dst + 50)), s9c);
    s0d = _mm_add_pd(t1a, s4c);
    _mm_storeu_pd(((double  *) (dst + 10)), s0d);
    s1d = _mm_sub_pd(t1a, s4c);
    _mm_storeu_pd(((double  *) (dst + 42)), s1d);
    s2d = _mm_sub_pd(t2a, s5c);
    _mm_storeu_pd(((double  *) (dst + 26)), s2d);
    s3d = _mm_add_pd(t2a, s5c);
    _mm_storeu_pd(((double  *) (dst + 58)), s3d);
    t5a = _mm_add_pd(t14, s4a);
    t6a = _mm_sub_pd(t14, s4a);
    t7a = _mm_sub_pd(t24, s5a);
    t8a = _mm_add_pd(t24, s5a);
    t9a = _mm_add_pd(s89, s0b);
    t0b = _mm_sub_pd(s99, s1b);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s89, s0b));
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s99, s1b));
    s4d = _mm_sub_pd(a9, a01);
    s5d = _mm_add_pd(a9, a01);
    s6d = _mm_add_pd(t5a, t9a);
    _mm_storeu_pd(((double  *) (dst + 4)), s6d);
    s7d = _mm_sub_pd(t5a, t9a);
    _mm_storeu_pd(((double  *) (dst + 36)), s7d);
    s8d = _mm_sub_pd(t6a, t0b);
    _mm_storeu_pd(((double  *) (dst + 20)), s8d);
    s9d = _mm_add_pd(t6a, t0b);
    _mm_storeu_pd(((double  *) (dst + 52)), s9d);
    s0e = _mm_add_pd(t7a, s4d);
    _mm_storeu_pd(((double  *) (dst + 12)), s0e);
    s1e = _mm_sub_pd(t7a, s4d);
    _mm_storeu_pd(((double  *) (dst + 44)), s1e);
    s2e = _mm_sub_pd(t8a, s5d);
    _mm_storeu_pd(((double  *) (dst + 28)), s2e);
    s3e = _mm_add_pd(t8a, s5d);
    _mm_storeu_pd(((double  *) (dst + 60)), s3e);
    t1b = _mm_add_pd(t54, s6a);
    t2b = _mm_sub_pd(t54, s6a);
    t3b = _mm_sub_pd(t64, s7a);
    t4b = _mm_add_pd(t64, s7a);
    t5b = _mm_add_pd(s0a, s2b);
    t6b = _mm_sub_pd(s1a, s3b);
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0a, s2b));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1a, s3b));
    s4e = _mm_sub_pd(a11, a21);
    s5e = _mm_add_pd(a11, a21);
    s6e = _mm_add_pd(t1b, t5b);
    _mm_storeu_pd(((double  *) (dst + 6)), s6e);
    s7e = _mm_sub_pd(t1b, t5b);
    _mm_storeu_pd(((double  *) (dst + 38)), s7e);
    s8e = _mm_sub_pd(t2b, t6b);
    _mm_storeu_pd(((double  *) (dst + 22)), s8e);
    s9e = _mm_add_pd(t2b, t6b);
    _mm_storeu_pd(((double  *) (dst + 54)), s9e);
    s0f = _mm_add_pd(t3b, s4e);
    _mm_storeu_pd(((double  *) (dst + 14)), s0f);
    s1f = _mm_sub_pd(t3b, s4e);
    _mm_storeu_pd(((double  *) (dst + 46)), s1f);
    s2f = _mm_sub_pd(t4b, s5e);
    _mm_storeu_pd(((double  *) (dst + 30)), s2f);
    s3f = _mm_add_pd(t4b, s5e);
    _mm_storeu_pd(((double  *) (dst + 62)), s3f);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_64)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_64_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a01, a11, a2, a21, a3, a31, a4, a41, a5, a6, a7, a9, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s2
            , s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s3, s31, s32, s33, s34, s35, s36
            , s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c
            , s4d, s4e, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b
            , s7c, s7d, s7e, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s9, s91, s92, s93
            , s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a
            , t0b, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29
            , t2a, t2b, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t4, t41, t42, t43, t44, t45, t46, t47
            , t48, t49, t4a, t4b, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t6, t61, t62, t63, t64, t65
            , t66, t67, t68, t69, t6a, t6b, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8a, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a;
    __m128d  *a, *a8;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 16)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 1));
    s5 = v_neg23(*((a + 31)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s7));
    s01 = *((a + 2));
    s11 = v_neg23(*((a + 30)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s31));
    s61 = *((a + 3));
    s71 = v_neg23(*((a + 29)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s81), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s91));
    s22 = *((a + 4));
    s32 = v_neg23(*((a + 28)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s42), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s52));
    s82 = *((a + 5));
    s92 = v_neg23(*((a + 27)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s03), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s13));
    s43 = *((a + 6));
    s53 = v_neg23(*((a + 26)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s63), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s73));
    s04 = *((a + 7));
    s14 = v_neg23(*((a + 25)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s24), _mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s34));
    s64 = *((a + 8));
    s74 = v_neg23(*((a + 24)));
    t71 = _mm_add_pd(s64, s74);
    t81 = _mm_sub_pd(s64, s74);
    s84 = v_lo2(t71, t81);
    s94 = v_hi2(t71, t81);
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s94));
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s94));
    s25 = *((a + 9));
    s35 = v_neg23(*((a + 23)));
    t91 = _mm_add_pd(s25, s35);
    t02 = _mm_sub_pd(s25, s35);
    s45 = v_lo2(t91, t02);
    s55 = v_hi2(t91, t02);
    s65 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s45), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s55));
    s75 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s45), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s55));
    s85 = *((a + 10));
    s95 = v_neg23(*((a + 22)));
    t12 = _mm_add_pd(s85, s95);
    t22 = _mm_sub_pd(s85, s95);
    s06 = v_lo2(t12, t22);
    s16 = v_hi2(t12, t22);
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s06), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s16));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s06), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s16));
    s46 = *((a + 11));
    s56 = v_neg23(*((a + 21)));
    t32 = _mm_add_pd(s46, s56);
    t42 = _mm_sub_pd(s46, s56);
    s66 = v_lo2(t32, t42);
    s76 = v_hi2(t32, t42);
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s66), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s76));
    s96 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s66), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s76));
    s07 = *((a + 12));
    s17 = v_neg23(*((a + 20)));
    t52 = _mm_add_pd(s07, s17);
    t62 = _mm_sub_pd(s07, s17);
    s27 = v_lo2(t52, t62);
    s37 = v_hi2(t52, t62);
    s47 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s27), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s37));
    s57 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s27), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s37));
    s67 = *((a + 13));
    s77 = v_neg23(*((a + 19)));
    t72 = _mm_add_pd(s67, s77);
    t82 = _mm_sub_pd(s67, s77);
    s87 = v_lo2(t72, t82);
    s97 = v_hi2(t72, t82);
    s08 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s87), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s97));
    s18 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s87), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s97));
    s28 = *((a + 14));
    s38 = v_neg23(*((a + 18)));
    t92 = _mm_add_pd(s28, s38);
    t03 = _mm_sub_pd(s28, s38);
    s48 = v_lo2(t92, t03);
    s58 = v_hi2(t92, t03);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s48), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s58));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s48), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s58));
    s88 = *((a + 15));
    s98 = v_neg23(*((a + 17)));
    t13 = _mm_add_pd(s88, s98);
    t23 = _mm_sub_pd(s88, s98);
    s09 = v_lo2(t13, t23);
    s19 = v_hi2(t13, t23);
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s09), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s19));
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s09), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s19));
    t33 = _mm_add_pd(t, s05);
    t43 = _mm_sub_pd(t, s05);
    t53 = _mm_sub_pd(t2, s15);
    t63 = _mm_add_pd(t2, s15);
    t73 = _mm_add_pd(s62, s47);
    t83 = _mm_sub_pd(s72, s57);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s62, s47));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s72, s57));
    s49 = _mm_sub_pd(a2, a3);
    s59 = _mm_add_pd(a2, a3);
    t93 = _mm_add_pd(t33, t73);
    t04 = _mm_sub_pd(t33, t73);
    t14 = _mm_sub_pd(t43, t83);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_add_pd(t53, s49);
    t44 = _mm_sub_pd(t53, s49);
    t54 = _mm_sub_pd(t63, s59);
    t64 = _mm_add_pd(t63, s59);
    t74 = _mm_add_pd(s8, s29);
    t84 = _mm_sub_pd(s9, s39);
    t94 = _mm_sub_pd(s8, s29);
    t05 = _mm_add_pd(s9, s39);
    t15 = _mm_add_pd(s65, s44);
    t25 = _mm_sub_pd(s75, s54);
    t35 = _mm_sub_pd(s65, s44);
    t45 = _mm_add_pd(s75, s54);
    t55 = _mm_add_pd(t74, t15);
    t65 = _mm_add_pd(t84, t25);
    t75 = _mm_sub_pd(t74, t15);
    t85 = _mm_sub_pd(t84, t25);
    t95 = _mm_sub_pd(t94, t45);
    t06 = _mm_add_pd(t05, t35);
    t16 = _mm_add_pd(t94, t45);
    t26 = _mm_sub_pd(t05, t35);
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t95), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t06));
    s79 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t95), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t06));
    s89 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t75), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t75), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t85));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t16), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t26));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t16), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t26));
    t36 = _mm_add_pd(s41, s68);
    t46 = _mm_sub_pd(s51, s78);
    t56 = _mm_sub_pd(s41, s68);
    t66 = _mm_add_pd(s51, s78);
    t76 = _mm_add_pd(s26, s83);
    t86 = _mm_sub_pd(s36, s93);
    t96 = _mm_sub_pd(s26, s83);
    t07 = _mm_add_pd(s36, s93);
    t17 = _mm_add_pd(t36, t76);
    t27 = _mm_add_pd(t46, t86);
    t37 = _mm_sub_pd(t56, t07);
    t47 = _mm_add_pd(t66, t96);
    t57 = _mm_add_pd(t56, t07);
    t67 = _mm_sub_pd(t66, t96);
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t37), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t47));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t37), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t47));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t36, t76));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t46, t86));
    s4a = _mm_sub_pd(a4, a5);
    s5a = _mm_add_pd(a4, a5);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    t77 = _mm_add_pd(s02, s08);
    t87 = _mm_sub_pd(s12, s18);
    t97 = _mm_sub_pd(s02, s08);
    t08 = _mm_add_pd(s12, s18);
    t18 = _mm_add_pd(s86, s23);
    t28 = _mm_sub_pd(s96, s33);
    t38 = _mm_sub_pd(s86, s23);
    t48 = _mm_add_pd(s96, s33);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t78), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t88));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t78), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t88));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t19), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t29));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t19), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t29));
    t39 = _mm_add_pd(t93, t17);
    t49 = _mm_sub_pd(t93, t17);
    t59 = _mm_sub_pd(t04, t27);
    t69 = _mm_add_pd(t04, t27);
    t79 = _mm_add_pd(t55, t58);
    t89 = _mm_sub_pd(t65, t68);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t55, t58));
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t65, t68));
    s4b = _mm_sub_pd(a6, a7);
    s5b = _mm_add_pd(a6, a7);
    a8 = ((__m128d  *) dst);
    s6b = _mm_add_pd(t39, t79);
    *(a8) = s6b;
    s7b = _mm_sub_pd(t39, t79);
    *((a8 + 16)) = s7b;
    s8b = _mm_sub_pd(t49, t89);
    *((a8 + 8)) = s8b;
    s9b = _mm_add_pd(t49, t89);
    *((a8 + 24)) = s9b;
    s0c = _mm_add_pd(t59, s4b);
    *((a8 + 4)) = s0c;
    s1c = _mm_sub_pd(t59, s4b);
    *((a8 + 20)) = s1c;
    s2c = _mm_sub_pd(t69, s5b);
    *((a8 + 12)) = s2c;
    s3c = _mm_add_pd(t69, s5b);
    *((a8 + 28)) = s3c;
    t99 = _mm_add_pd(t34, s2a);
    t0a = _mm_sub_pd(t34, s2a);
    t1a = _mm_sub_pd(t44, s3a);
    t2a = _mm_add_pd(t44, s3a);
    t3a = _mm_add_pd(s69, s8a);
    t4a = _mm_sub_pd(s79, s9a);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s69, s8a));
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s79, s9a));
    s4c = _mm_sub_pd(a9, a01);
    s5c = _mm_add_pd(a9, a01);
    s6c = _mm_add_pd(t99, t3a);
    *((a8 + 1)) = s6c;
    s7c = _mm_sub_pd(t99, t3a);
    *((a8 + 17)) = s7c;
    s8c = _mm_sub_pd(t0a, t4a);
    *((a8 + 9)) = s8c;
    s9c = _mm_add_pd(t0a, t4a);
    *((a8 + 25)) = s9c;
    s0d = _mm_add_pd(t1a, s4c);
    *((a8 + 5)) = s0d;
    s1d = _mm_sub_pd(t1a, s4c);
    *((a8 + 21)) = s1d;
    s2d = _mm_sub_pd(t2a, s5c);
    *((a8 + 13)) = s2d;
    s3d = _mm_add_pd(t2a, s5c);
    *((a8 + 29)) = s3d;
    t5a = _mm_add_pd(t14, s4a);
    t6a = _mm_sub_pd(t14, s4a);
    t7a = _mm_sub_pd(t24, s5a);
    t8a = _mm_add_pd(t24, s5a);
    t9a = _mm_add_pd(s89, s0b);
    t0b = _mm_sub_pd(s99, s1b);
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s89, s0b));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s99, s1b));
    s4d = _mm_sub_pd(a11, a21);
    s5d = _mm_add_pd(a11, a21);
    s6d = _mm_add_pd(t5a, t9a);
    *((a8 + 2)) = s6d;
    s7d = _mm_sub_pd(t5a, t9a);
    *((a8 + 18)) = s7d;
    s8d = _mm_sub_pd(t6a, t0b);
    *((a8 + 10)) = s8d;
    s9d = _mm_add_pd(t6a, t0b);
    *((a8 + 26)) = s9d;
    s0e = _mm_add_pd(t7a, s4d);
    *((a8 + 6)) = s0e;
    s1e = _mm_sub_pd(t7a, s4d);
    *((a8 + 22)) = s1e;
    s2e = _mm_sub_pd(t8a, s5d);
    *((a8 + 14)) = s2e;
    s3e = _mm_add_pd(t8a, s5d);
    *((a8 + 30)) = s3e;
    t1b = _mm_add_pd(t54, s6a);
    t2b = _mm_sub_pd(t54, s6a);
    t3b = _mm_sub_pd(t64, s7a);
    t4b = _mm_add_pd(t64, s7a);
    t5b = _mm_add_pd(s0a, s2b);
    t6b = _mm_sub_pd(s1a, s3b);
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0a, s2b));
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1a, s3b));
    s4e = _mm_sub_pd(a31, a41);
    s5e = _mm_add_pd(a31, a41);
    s6e = _mm_add_pd(t1b, t5b);
    *((a8 + 3)) = s6e;
    s7e = _mm_sub_pd(t1b, t5b);
    *((a8 + 19)) = s7e;
    s8e = _mm_sub_pd(t2b, t6b);
    *((a8 + 11)) = s8e;
    s9e = _mm_add_pd(t2b, t6b);
    *((a8 + 27)) = s9e;
    s0f = _mm_add_pd(t3b, s4e);
    *((a8 + 7)) = s0f;
    s1f = _mm_sub_pd(t3b, s4e);
    *((a8 + 23)) = s1f;
    s2f = _mm_sub_pd(t4b, s5e);
    *((a8 + 15)) = s2f;
    s3f = _mm_add_pd(t4b, s5e);
    *((a8 + 31)) = s3f;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_128_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a, a01, a02, a03, a11, a12, a13, a2, a21, a22, a23, a3, a31, a32, a33, a4, a41, a42, a43, a5, a51, a52
            , a6, a61, a62, a7, a71, a72, a8, a81, a82, a9, a91, a92, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v
            , s0w, s0x, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k
            , s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u
            , s2v, s2w, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j
            , s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s4, s41, s42, s43, s44, s45, s46, s47, s48
            , s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u
            , s4v, s4w, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j
            , s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u
            , s6v, s6w, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s8, s81, s82, s83, s84, s85, s86, s87, s88
            , s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u
            , s8v, s8w, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j
            , s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, t, t01, t02, t03, t04, t05, t06, t07, t08
            , t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t11, t12
            , t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o
            , t1p, t1q, t1r, t1s, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h
            , t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a
            , t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t4, t41, t42, t43
            , t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p
            , t4q, t4r, t4s, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i
            , t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b
            , t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q
            , t7r, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k
            , t8l, t8m, t8n, t8o, t8p, t8q, t8r, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e
            , t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 64))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 8)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 120))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 16)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 112))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 24)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 104))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 32)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 96))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 40)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 88))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 48)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 80))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 56)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 72))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    t54 = _mm_add_pd(t32, t93);
    t64 = _mm_sub_pd(t32, t93);
    t74 = _mm_sub_pd(t42, t04);
    t84 = _mm_add_pd(t42, t04);
    t94 = _mm_add_pd(t72, s84);
    t05 = _mm_sub_pd(t72, s84);
    t15 = _mm_sub_pd(t82, s94);
    t25 = _mm_add_pd(t82, s94);
    t35 = _mm_add_pd(t52, s05);
    t45 = _mm_sub_pd(t52, s05);
    t55 = _mm_sub_pd(t62, s15);
    t65 = _mm_add_pd(t62, s15);
    t75 = _mm_add_pd(t92, s25);
    t85 = _mm_sub_pd(t92, s25);
    t95 = _mm_sub_pd(t03, s35);
    t06 = _mm_add_pd(t03, s35);
    s45 = _mm_loadu_pd(((const double  *) (src + 2)));
    s55 = v_neg23(_mm_loadu_pd(((const double  *) (src + 126))));
    t16 = _mm_add_pd(s45, s55);
    t26 = _mm_sub_pd(s45, s55);
    s65 = v_lo2(t16, t26);
    s75 = v_hi2(t16, t26);
    s85 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9975909124103448, 2.0), s65), _mm_mul_pd(_mm_set_pd(0.09813534865483603, 0.0), s75));
    s95 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.09813534865483603, 0.0), s65), _mm_mul_pd(_mm_set_pd(1.9975909124103448, 2.0), s75));
    s06 = _mm_loadu_pd(((const double  *) (src + 18)));
    s16 = v_neg23(_mm_loadu_pd(((const double  *) (src + 110))));
    t36 = _mm_add_pd(s06, s16);
    t46 = _mm_sub_pd(s06, s16);
    s26 = v_lo2(t36, t46);
    s36 = v_hi2(t36, t46);
    s46 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8079785862468867, 2.0), s26), _mm_mul_pd(_mm_set_pd(0.85511018686056417, 0.0), s36));
    s56 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.85511018686056417, 0.0), s26), _mm_mul_pd(_mm_set_pd(1.8079785862468867, 2.0), s36));
    s66 = _mm_loadu_pd(((const double  *) (src + 34)));
    s76 = v_neg23(_mm_loadu_pd(((const double  *) (src + 94))));
    t56 = _mm_add_pd(s66, s76);
    t66 = _mm_sub_pd(s66, s76);
    s86 = v_lo2(t56, t66);
    s96 = v_hi2(t56, t66);
    s07 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.3431179096940369, 2.0), s86), _mm_mul_pd(_mm_set_pd(1.4819022507099182, 0.0), s96));
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4819022507099182, 0.0), s86), _mm_mul_pd(_mm_set_pd(1.3431179096940369, 2.0), s96));
    s27 = _mm_loadu_pd(((const double  *) (src + 50)));
    s37 = v_neg23(_mm_loadu_pd(((const double  *) (src + 78))));
    t76 = _mm_add_pd(s27, s37);
    t86 = _mm_sub_pd(s27, s37);
    s47 = v_lo2(t76, t86);
    s57 = v_hi2(t76, t86);
    s67 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.6737797067844401, 2.0), s47), _mm_mul_pd(_mm_set_pd(1.8830881303660416, 0.0), s57));
    s77 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8830881303660416, 0.0), s47), _mm_mul_pd(_mm_set_pd(0.6737797067844401, 2.0), s57));
    s87 = _mm_loadu_pd(((const double  *) (src + 66)));
    s97 = v_neg23(_mm_loadu_pd(((const double  *) (src + 62))));
    t96 = _mm_add_pd(s87, s97);
    t07 = _mm_sub_pd(s87, s97);
    s08 = v_lo2(t96, t07);
    s18 = v_hi2(t96, t07);
    s28 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.09813534865483603), 2.0), s08), _mm_mul_pd(_mm_set_pd(1.9975909124103448, 0.0), s18));
    s38 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9975909124103448, 0.0), s08), _mm_mul_pd(_mm_set_pd((-0.09813534865483603), 2.0), s18));
    s48 = _mm_loadu_pd(((const double  *) (src + 82)));
    s58 = v_neg23(_mm_loadu_pd(((const double  *) (src + 46))));
    t17 = _mm_add_pd(s48, s58);
    t27 = _mm_sub_pd(s48, s58);
    s68 = v_lo2(t17, t27);
    s78 = v_hi2(t17, t27);
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85511018686056417), 2.0), s68), _mm_mul_pd(_mm_set_pd(1.8079785862468867, 0.0), s78));
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8079785862468867, 0.0), s68), _mm_mul_pd(_mm_set_pd((-0.85511018686056417), 2.0), s78));
    s09 = _mm_loadu_pd(((const double  *) (src + 98)));
    s19 = v_neg23(_mm_loadu_pd(((const double  *) (src + 30))));
    t37 = _mm_add_pd(s09, s19);
    t47 = _mm_sub_pd(s09, s19);
    s29 = v_lo2(t37, t47);
    s39 = v_hi2(t37, t47);
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.4819022507099182), 2.0), s29), _mm_mul_pd(_mm_set_pd(1.3431179096940369, 0.0), s39));
    s59 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.3431179096940369, 0.0), s29), _mm_mul_pd(_mm_set_pd((-1.4819022507099182), 2.0), s39));
    s69 = _mm_loadu_pd(((const double  *) (src + 114)));
    s79 = v_neg23(_mm_loadu_pd(((const double  *) (src + 14))));
    t57 = _mm_add_pd(s69, s79);
    t67 = _mm_sub_pd(s69, s79);
    s89 = v_lo2(t57, t67);
    s99 = v_hi2(t57, t67);
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.8830881303660416), 2.0), s89), _mm_mul_pd(_mm_set_pd(0.6737797067844401, 0.0), s99));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.6737797067844401, 0.0), s89), _mm_mul_pd(_mm_set_pd((-1.8830881303660416), 2.0), s99));
    t77 = _mm_add_pd(s85, s28);
    t87 = _mm_add_pd(s95, s38);
    t97 = _mm_sub_pd(s85, s28);
    t08 = _mm_sub_pd(s95, s38);
    t18 = _mm_add_pd(s07, s49);
    t28 = _mm_add_pd(s17, s59);
    t38 = _mm_sub_pd(s07, s49);
    t48 = _mm_sub_pd(s17, s59);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    t39 = _mm_add_pd(s46, s88);
    t49 = _mm_add_pd(s56, s98);
    t59 = _mm_sub_pd(s46, s88);
    t69 = _mm_sub_pd(s56, s98);
    t79 = _mm_add_pd(s67, s0a);
    t89 = _mm_add_pd(s77, s1a);
    t99 = _mm_sub_pd(s67, s0a);
    t0a = _mm_sub_pd(s77, s1a);
    t1a = _mm_add_pd(t39, t79);
    t2a = _mm_add_pd(t49, t89);
    t3a = _mm_sub_pd(t39, t79);
    t4a = _mm_sub_pd(t49, t89);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t59, t0a));
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t69, t99));
    s2a = _mm_sub_pd(a5, a6);
    s3a = _mm_add_pd(a5, a6);
    a7 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t59, t0a));
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t69, t99));
    s4a = _mm_sub_pd(a7, a8);
    s5a = _mm_add_pd(a7, a8);
    t5a = _mm_add_pd(t58, t1a);
    t6a = _mm_add_pd(t68, t2a);
    t7a = _mm_sub_pd(t58, t1a);
    t8a = _mm_sub_pd(t68, t2a);
    t9a = _mm_add_pd(t98, s2a);
    t0b = _mm_add_pd(t09, s3a);
    t1b = _mm_sub_pd(t98, s2a);
    t2b = _mm_sub_pd(t09, s3a);
    t3b = _mm_sub_pd(t78, t4a);
    t4b = _mm_add_pd(t88, t3a);
    t5b = _mm_add_pd(t78, t4a);
    t6b = _mm_sub_pd(t88, t3a);
    t7b = _mm_add_pd(t19, s4a);
    t8b = _mm_sub_pd(t29, s5a);
    t9b = _mm_sub_pd(t19, s4a);
    t0c = _mm_add_pd(t29, s5a);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t9a), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t0b));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t9a), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t0b));
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3b), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4b));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3b), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4b));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7b), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t8b));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t7b), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8b));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8a));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t1b), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t2b));
    s5b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t1b), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t2b));
    s6b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5b), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6b));
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6b));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t9b), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t0c));
    s9b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t9b), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t0c));
    s0c = _mm_loadu_pd(((const double  *) (src + 4)));
    s1c = v_neg23(_mm_loadu_pd(((const double  *) (src + 124))));
    t1c = _mm_add_pd(s0c, s1c);
    t2c = _mm_sub_pd(s0c, s1c);
    s2c = v_lo2(t1c, t2c);
    s3c = v_hi2(t1c, t2c);
    s4c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s2c), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s3c));
    s5c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s2c), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s3c));
    s6c = _mm_loadu_pd(((const double  *) (src + 20)));
    s7c = v_neg23(_mm_loadu_pd(((const double  *) (src + 108))));
    t3c = _mm_add_pd(s6c, s7c);
    t4c = _mm_sub_pd(s6c, s7c);
    s8c = v_lo2(t3c, t4c);
    s9c = v_hi2(t3c, t4c);
    s0d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s8c), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s9c));
    s1d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s8c), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s9c));
    s2d = _mm_loadu_pd(((const double  *) (src + 36)));
    s3d = v_neg23(_mm_loadu_pd(((const double  *) (src + 92))));
    t5c = _mm_add_pd(s2d, s3d);
    t6c = _mm_sub_pd(s2d, s3d);
    s4d = v_lo2(t5c, t6c);
    s5d = v_hi2(t5c, t6c);
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s4d), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s5d));
    s7d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s4d), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s5d));
    s8d = _mm_loadu_pd(((const double  *) (src + 52)));
    s9d = v_neg23(_mm_loadu_pd(((const double  *) (src + 76))));
    t7c = _mm_add_pd(s8d, s9d);
    t8c = _mm_sub_pd(s8d, s9d);
    s0e = v_lo2(t7c, t8c);
    s1e = v_hi2(t7c, t8c);
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s0e), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s1e));
    s3e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s0e), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s1e));
    s4e = _mm_loadu_pd(((const double  *) (src + 68)));
    s5e = v_neg23(_mm_loadu_pd(((const double  *) (src + 60))));
    t9c = _mm_add_pd(s4e, s5e);
    t0d = _mm_sub_pd(s4e, s5e);
    s6e = v_lo2(t9c, t0d);
    s7e = v_hi2(t9c, t0d);
    s8e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19603428065912121), 2.0), s6e), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s7e));
    s9e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s6e), _mm_mul_pd(_mm_set_pd((-0.19603428065912121), 2.0), s7e));
    s0f = _mm_loadu_pd(((const double  *) (src + 84)));
    s1f = v_neg23(_mm_loadu_pd(((const double  *) (src + 44))));
    t1d = _mm_add_pd(s0f, s1f);
    t2d = _mm_sub_pd(s0f, s1f);
    s2f = v_lo2(t1d, t2d);
    s3f = v_hi2(t1d, t2d);
    s4f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.94279347365199528), 2.0), s2f), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s3f));
    s5f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s2f), _mm_mul_pd(_mm_set_pd((-0.94279347365199528), 2.0), s3f));
    s6f = _mm_loadu_pd(((const double  *) (src + 100)));
    s7f = v_neg23(_mm_loadu_pd(((const double  *) (src + 28))));
    t3d = _mm_add_pd(s6f, s7f);
    t4d = _mm_sub_pd(s6f, s7f);
    s8f = v_lo2(t3d, t4d);
    s9f = v_hi2(t3d, t4d);
    s0g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.546020906725474), 2.0), s8f), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s9f));
    s1g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s8f), _mm_mul_pd(_mm_set_pd((-1.546020906725474), 2.0), s9f));
    s2g = _mm_loadu_pd(((const double  *) (src + 116)));
    s3g = v_neg23(_mm_loadu_pd(((const double  *) (src + 12))));
    t5d = _mm_add_pd(s2g, s3g);
    t6d = _mm_sub_pd(s2g, s3g);
    s4g = v_lo2(t5d, t6d);
    s5g = v_hi2(t5d, t6d);
    s6g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.9138806714644176), 2.0), s4g), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s5g));
    s7g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s4g), _mm_mul_pd(_mm_set_pd((-1.9138806714644176), 2.0), s5g));
    t7d = _mm_add_pd(s4c, s8e);
    t8d = _mm_add_pd(s5c, s9e);
    t9d = _mm_sub_pd(s4c, s8e);
    t0e = _mm_sub_pd(s5c, s9e);
    t1e = _mm_add_pd(s6d, s0g);
    t2e = _mm_add_pd(s7d, s1g);
    t3e = _mm_sub_pd(s6d, s0g);
    t4e = _mm_sub_pd(s7d, s1g);
    t5e = _mm_add_pd(t7d, t1e);
    t6e = _mm_add_pd(t8d, t2e);
    t7e = _mm_sub_pd(t7d, t1e);
    t8e = _mm_sub_pd(t8d, t2e);
    t9e = _mm_sub_pd(t9d, t4e);
    t0f = _mm_add_pd(t0e, t3e);
    t1f = _mm_add_pd(t9d, t4e);
    t2f = _mm_sub_pd(t0e, t3e);
    t3f = _mm_add_pd(s0d, s4f);
    t4f = _mm_add_pd(s1d, s5f);
    t5f = _mm_sub_pd(s0d, s4f);
    t6f = _mm_sub_pd(s1d, s5f);
    t7f = _mm_add_pd(s2e, s6g);
    t8f = _mm_add_pd(s3e, s7g);
    t9f = _mm_sub_pd(s2e, s6g);
    t0g = _mm_sub_pd(s3e, s7g);
    t1g = _mm_add_pd(t3f, t7f);
    t2g = _mm_add_pd(t4f, t8f);
    t3g = _mm_sub_pd(t3f, t7f);
    t4g = _mm_sub_pd(t4f, t8f);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5f, t0g));
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6f, t9f));
    s8g = _mm_sub_pd(a9, a01);
    s9g = _mm_add_pd(a9, a01);
    a11 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5f, t0g));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6f, t9f));
    s0h = _mm_sub_pd(a11, a21);
    s1h = _mm_add_pd(a11, a21);
    t5g = _mm_add_pd(t5e, t1g);
    t6g = _mm_add_pd(t6e, t2g);
    t7g = _mm_add_pd(t9e, s8g);
    t8g = _mm_add_pd(t0f, s9g);
    t9g = _mm_sub_pd(t9e, s8g);
    t0h = _mm_sub_pd(t0f, s9g);
    t1h = _mm_sub_pd(t7e, t4g);
    t2h = _mm_add_pd(t8e, t3g);
    t3h = _mm_add_pd(t7e, t4g);
    t4h = _mm_sub_pd(t8e, t3g);
    t5h = _mm_add_pd(t1f, s0h);
    t6h = _mm_sub_pd(t2f, s1h);
    t7h = _mm_sub_pd(t1f, s0h);
    t8h = _mm_add_pd(t2f, s1h);
    s2h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7g), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8g));
    s3h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7g), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8g));
    s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2h));
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2h));
    s6h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5h), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6h));
    s7h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5h), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6h));
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5e, t1g));
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6e, t2g));
    s8h = _mm_sub_pd(a31, a41);
    s9h = _mm_add_pd(a31, a41);
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0h));
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0h));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4h));
    s3i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4h));
    s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7h), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8h));
    s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7h), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8h));
    s6i = _mm_loadu_pd(((const double  *) (src + 6)));
    s7i = v_neg23(_mm_loadu_pd(((const double  *) (src + 122))));
    t9h = _mm_add_pd(s6i, s7i);
    t0i = _mm_sub_pd(s6i, s7i);
    s8i = v_lo2(t9h, t0i);
    s9i = v_hi2(t9h, t0i);
    s0j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.978353019929562, 2.0), s8i), _mm_mul_pd(_mm_set_pd(0.2934609489107235, 0.0), s9i));
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.2934609489107235, 0.0), s8i), _mm_mul_pd(_mm_set_pd(1.978353019929562, 2.0), s9i));
    s2j = _mm_loadu_pd(((const double  *) (src + 22)));
    s3j = v_neg23(_mm_loadu_pd(((const double  *) (src + 106))));
    t1i = _mm_add_pd(s2j, s3j);
    t2i = _mm_sub_pd(s2j, s3j);
    s4j = v_lo2(t1i, t2i);
    s5j = v_hi2(t1i, t2i);
    s6j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7154572200005442, 2.0), s4j), _mm_mul_pd(_mm_set_pd(1.0282054883864435, 0.0), s5j));
    s7j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.0282054883864435, 0.0), s4j), _mm_mul_pd(_mm_set_pd(1.7154572200005442, 2.0), s5j));
    s8j = _mm_loadu_pd(((const double  *) (src + 38)));
    s9j = v_neg23(_mm_loadu_pd(((const double  *) (src + 90))));
    t3i = _mm_add_pd(s8j, s9j);
    t4i = _mm_sub_pd(s8j, s9j);
    s0k = v_lo2(t3i, t4i);
    s1k = v_hi2(t3i, t4i);
    s2k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1913986089848667, 2.0), s0k), _mm_mul_pd(_mm_set_pd(1.6064150629612899, 0.0), s1k));
    s3k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6064150629612899, 0.0), s0k), _mm_mul_pd(_mm_set_pd(1.1913986089848667, 2.0), s1k));
    s4k = _mm_loadu_pd(((const double  *) (src + 54)));
    s5k = v_neg23(_mm_loadu_pd(((const double  *) (src + 74))));
    t5i = _mm_add_pd(s4k, s5k);
    t6i = _mm_sub_pd(s4k, s5k);
    s6k = v_lo2(t5i, t6i);
    s7k = v_hi2(t5i, t6i);
    s8k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.4859603598065278, 2.0), s6k), _mm_mul_pd(_mm_set_pd(1.9400625063890879, 0.0), s7k));
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9400625063890879, 0.0), s6k), _mm_mul_pd(_mm_set_pd(0.4859603598065278, 2.0), s7k));
    s0l = _mm_loadu_pd(((const double  *) (src + 70)));
    s1l = v_neg23(_mm_loadu_pd(((const double  *) (src + 58))));
    t7i = _mm_add_pd(s0l, s1l);
    t8i = _mm_sub_pd(s0l, s1l);
    s2l = v_lo2(t7i, t8i);
    s3l = v_hi2(t7i, t8i);
    s4l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.2934609489107235), 2.0), s2l), _mm_mul_pd(_mm_set_pd(1.978353019929562, 0.0), s3l));
    s5l = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.978353019929562, 0.0), s2l), _mm_mul_pd(_mm_set_pd((-0.2934609489107235), 2.0), s3l));
    s6l = _mm_loadu_pd(((const double  *) (src + 86)));
    s7l = v_neg23(_mm_loadu_pd(((const double  *) (src + 42))));
    t9i = _mm_add_pd(s6l, s7l);
    t0j = _mm_sub_pd(s6l, s7l);
    s8l = v_lo2(t9i, t0j);
    s9l = v_hi2(t9i, t0j);
    s0m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.0282054883864435), 2.0), s8l), _mm_mul_pd(_mm_set_pd(1.7154572200005442, 0.0), s9l));
    s1m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7154572200005442, 0.0), s8l), _mm_mul_pd(_mm_set_pd((-1.0282054883864435), 2.0), s9l));
    s2m = _mm_loadu_pd(((const double  *) (src + 102)));
    s3m = v_neg23(_mm_loadu_pd(((const double  *) (src + 26))));
    t1j = _mm_add_pd(s2m, s3m);
    t2j = _mm_sub_pd(s2m, s3m);
    s4m = v_lo2(t1j, t2j);
    s5m = v_hi2(t1j, t2j);
    s6m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.6064150629612899), 2.0), s4m), _mm_mul_pd(_mm_set_pd(1.1913986089848667, 0.0), s5m));
    s7m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1913986089848667, 0.0), s4m), _mm_mul_pd(_mm_set_pd((-1.6064150629612899), 2.0), s5m));
    s8m = _mm_loadu_pd(((const double  *) (src + 118)));
    s9m = v_neg23(_mm_loadu_pd(((const double  *) (src + 10))));
    t3j = _mm_add_pd(s8m, s9m);
    t4j = _mm_sub_pd(s8m, s9m);
    s0n = v_lo2(t3j, t4j);
    s1n = v_hi2(t3j, t4j);
    s2n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.9400625063890879), 2.0), s0n), _mm_mul_pd(_mm_set_pd(0.4859603598065278, 0.0), s1n));
    s3n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.4859603598065278, 0.0), s0n), _mm_mul_pd(_mm_set_pd((-1.9400625063890879), 2.0), s1n));
    t5j = _mm_add_pd(s0j, s4l);
    t6j = _mm_add_pd(s1j, s5l);
    t7j = _mm_sub_pd(s0j, s4l);
    t8j = _mm_sub_pd(s1j, s5l);
    t9j = _mm_add_pd(s2k, s6m);
    t0k = _mm_add_pd(s3k, s7m);
    t1k = _mm_sub_pd(s2k, s6m);
    t2k = _mm_sub_pd(s3k, s7m);
    t3k = _mm_add_pd(t5j, t9j);
    t4k = _mm_add_pd(t6j, t0k);
    t5k = _mm_sub_pd(t5j, t9j);
    t6k = _mm_sub_pd(t6j, t0k);
    t7k = _mm_sub_pd(t7j, t2k);
    t8k = _mm_add_pd(t8j, t1k);
    t9k = _mm_add_pd(t7j, t2k);
    t0l = _mm_sub_pd(t8j, t1k);
    t1l = _mm_add_pd(s6j, s0m);
    t2l = _mm_add_pd(s7j, s1m);
    t3l = _mm_sub_pd(s6j, s0m);
    t4l = _mm_sub_pd(s7j, s1m);
    t5l = _mm_add_pd(s8k, s2n);
    t6l = _mm_add_pd(s9k, s3n);
    t7l = _mm_sub_pd(s8k, s2n);
    t8l = _mm_sub_pd(s9k, s3n);
    t9l = _mm_add_pd(t1l, t5l);
    t0m = _mm_add_pd(t2l, t6l);
    t1m = _mm_sub_pd(t1l, t5l);
    t2m = _mm_sub_pd(t2l, t6l);
    a51 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3l, t8l));
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4l, t7l));
    s4n = _mm_sub_pd(a51, a61);
    s5n = _mm_add_pd(a51, a61);
    a71 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3l, t8l));
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4l, t7l));
    s6n = _mm_sub_pd(a71, a81);
    s7n = _mm_add_pd(a71, a81);
    t3m = _mm_add_pd(t3k, t9l);
    t4m = _mm_add_pd(t4k, t0m);
    t5m = _mm_sub_pd(t3k, t9l);
    t6m = _mm_sub_pd(t4k, t0m);
    t7m = _mm_add_pd(t7k, s4n);
    t8m = _mm_add_pd(t8k, s5n);
    t9m = _mm_sub_pd(t7k, s4n);
    t0n = _mm_sub_pd(t8k, s5n);
    t1n = _mm_sub_pd(t5k, t2m);
    t2n = _mm_add_pd(t6k, t1m);
    t3n = _mm_add_pd(t5k, t2m);
    t4n = _mm_sub_pd(t6k, t1m);
    t5n = _mm_add_pd(t9k, s6n);
    t6n = _mm_sub_pd(t0l, s7n);
    t7n = _mm_sub_pd(t9k, s6n);
    t8n = _mm_add_pd(t0l, s7n);
    s8n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7m), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t8m));
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t7m), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8m));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1n), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2n));
    s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1n), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2n));
    s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5n), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6n));
    s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5n), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6n));
    s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5m), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6m));
    s5o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5m), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6m));
    s6o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t9m), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t0n));
    s7o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t9m), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t0n));
    s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3n), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4n));
    s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3n), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4n));
    s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7n), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8n));
    s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7n), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8n));
    t9n = _mm_add_pd(t54, t5g);
    t0o = _mm_sub_pd(t54, t5g);
    t1o = _mm_sub_pd(t64, t6g);
    t2o = _mm_add_pd(t64, t6g);
    t3o = _mm_add_pd(t5a, t3m);
    t4o = _mm_sub_pd(t6a, t4m);
    a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t3m));
    a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6a, t4m));
    s2p = _mm_sub_pd(a91, a02);
    s3p = _mm_add_pd(a91, a02);
    s4p = _mm_add_pd(t9n, t3o);
    _mm_storeu_pd(((double  *) dst), s4p);
    s5p = _mm_sub_pd(t9n, t3o);
    _mm_storeu_pd(((double  *) (dst + 64)), s5p);
    s6p = _mm_sub_pd(t0o, t4o);
    _mm_storeu_pd(((double  *) (dst + 32)), s6p);
    s7p = _mm_add_pd(t0o, t4o);
    _mm_storeu_pd(((double  *) (dst + 96)), s7p);
    s8p = _mm_add_pd(t1o, s2p);
    _mm_storeu_pd(((double  *) (dst + 16)), s8p);
    s9p = _mm_sub_pd(t1o, s2p);
    _mm_storeu_pd(((double  *) (dst + 80)), s9p);
    s0q = _mm_sub_pd(t2o, s3p);
    _mm_storeu_pd(((double  *) (dst + 48)), s0q);
    s1q = _mm_add_pd(t2o, s3p);
    _mm_storeu_pd(((double  *) (dst + 112)), s1q);
    t5o = _mm_add_pd(t94, s2h);
    t6o = _mm_sub_pd(t94, s2h);
    t7o = _mm_sub_pd(t05, s3h);
    t8o = _mm_add_pd(t05, s3h);
    t9o = _mm_add_pd(s6a, s8n);
    t0p = _mm_sub_pd(s7a, s9n);
    a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6a, s8n));
    a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7a, s9n));
    s2q = _mm_sub_pd(a12, a22);
    s3q = _mm_add_pd(a12, a22);
    s4q = _mm_add_pd(t5o, t9o);
    _mm_storeu_pd(((double  *) (dst + 2)), s4q);
    s5q = _mm_sub_pd(t5o, t9o);
    _mm_storeu_pd(((double  *) (dst + 66)), s5q);
    s6q = _mm_sub_pd(t6o, t0p);
    _mm_storeu_pd(((double  *) (dst + 34)), s6q);
    s7q = _mm_add_pd(t6o, t0p);
    _mm_storeu_pd(((double  *) (dst + 98)), s7q);
    s8q = _mm_add_pd(t7o, s2q);
    _mm_storeu_pd(((double  *) (dst + 18)), s8q);
    s9q = _mm_sub_pd(t7o, s2q);
    _mm_storeu_pd(((double  *) (dst + 82)), s9q);
    s0r = _mm_sub_pd(t8o, s3q);
    _mm_storeu_pd(((double  *) (dst + 50)), s0r);
    s1r = _mm_add_pd(t8o, s3q);
    _mm_storeu_pd(((double  *) (dst + 114)), s1r);
    t1p = _mm_add_pd(t35, s4h);
    t2p = _mm_sub_pd(t35, s4h);
    t3p = _mm_sub_pd(t45, s5h);
    t4p = _mm_add_pd(t45, s5h);
    t5p = _mm_add_pd(s8a, s0o);
    t6p = _mm_sub_pd(s9a, s1o);
    a32 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8a, s0o));
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9a, s1o));
    s2r = _mm_sub_pd(a32, a42);
    s3r = _mm_add_pd(a32, a42);
    s4r = _mm_add_pd(t1p, t5p);
    _mm_storeu_pd(((double  *) (dst + 4)), s4r);
    s5r = _mm_sub_pd(t1p, t5p);
    _mm_storeu_pd(((double  *) (dst + 68)), s5r);
    s6r = _mm_sub_pd(t2p, t6p);
    _mm_storeu_pd(((double  *) (dst + 36)), s6r);
    s7r = _mm_add_pd(t2p, t6p);
    _mm_storeu_pd(((double  *) (dst + 100)), s7r);
    s8r = _mm_add_pd(t3p, s2r);
    _mm_storeu_pd(((double  *) (dst + 20)), s8r);
    s9r = _mm_sub_pd(t3p, s2r);
    _mm_storeu_pd(((double  *) (dst + 84)), s9r);
    s0s = _mm_sub_pd(t4p, s3r);
    _mm_storeu_pd(((double  *) (dst + 52)), s0s);
    s1s = _mm_add_pd(t4p, s3r);
    _mm_storeu_pd(((double  *) (dst + 116)), s1s);
    t7p = _mm_add_pd(t75, s6h);
    t8p = _mm_sub_pd(t75, s6h);
    t9p = _mm_sub_pd(t85, s7h);
    t0q = _mm_add_pd(t85, s7h);
    t1q = _mm_add_pd(s0b, s2o);
    t2q = _mm_sub_pd(s1b, s3o);
    a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0b, s2o));
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1b, s3o));
    s2s = _mm_sub_pd(a52, a62);
    s3s = _mm_add_pd(a52, a62);
    s4s = _mm_add_pd(t7p, t1q);
    _mm_storeu_pd(((double  *) (dst + 6)), s4s);
    s5s = _mm_sub_pd(t7p, t1q);
    _mm_storeu_pd(((double  *) (dst + 70)), s5s);
    s6s = _mm_sub_pd(t8p, t2q);
    _mm_storeu_pd(((double  *) (dst + 38)), s6s);
    s7s = _mm_add_pd(t8p, t2q);
    _mm_storeu_pd(((double  *) (dst + 102)), s7s);
    s8s = _mm_add_pd(t9p, s2s);
    _mm_storeu_pd(((double  *) (dst + 22)), s8s);
    s9s = _mm_sub_pd(t9p, s2s);
    _mm_storeu_pd(((double  *) (dst + 86)), s9s);
    s0t = _mm_sub_pd(t0q, s3s);
    _mm_storeu_pd(((double  *) (dst + 54)), s0t);
    s1t = _mm_add_pd(t0q, s3s);
    _mm_storeu_pd(((double  *) (dst + 118)), s1t);
    t3q = _mm_add_pd(t74, s8h);
    t4q = _mm_sub_pd(t74, s8h);
    t5q = _mm_sub_pd(t84, s9h);
    t6q = _mm_add_pd(t84, s9h);
    t7q = _mm_add_pd(s2b, s4o);
    t8q = _mm_sub_pd(s3b, s5o);
    a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2b, s4o));
    a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3b, s5o));
    s2t = _mm_sub_pd(a72, a82);
    s3t = _mm_add_pd(a72, a82);
    s4t = _mm_add_pd(t3q, t7q);
    _mm_storeu_pd(((double  *) (dst + 8)), s4t);
    s5t = _mm_sub_pd(t3q, t7q);
    _mm_storeu_pd(((double  *) (dst + 72)), s5t);
    s6t = _mm_sub_pd(t4q, t8q);
    _mm_storeu_pd(((double  *) (dst + 40)), s6t);
    s7t = _mm_add_pd(t4q, t8q);
    _mm_storeu_pd(((double  *) (dst + 104)), s7t);
    s8t = _mm_add_pd(t5q, s2t);
    _mm_storeu_pd(((double  *) (dst + 24)), s8t);
    s9t = _mm_sub_pd(t5q, s2t);
    _mm_storeu_pd(((double  *) (dst + 88)), s9t);
    s0u = _mm_sub_pd(t6q, s3t);
    _mm_storeu_pd(((double  *) (dst + 56)), s0u);
    s1u = _mm_add_pd(t6q, s3t);
    _mm_storeu_pd(((double  *) (dst + 120)), s1u);
    t9q = _mm_add_pd(t15, s0i);
    t0r = _mm_sub_pd(t15, s0i);
    t1r = _mm_sub_pd(t25, s1i);
    t2r = _mm_add_pd(t25, s1i);
    t3r = _mm_add_pd(s4b, s6o);
    t4r = _mm_sub_pd(s5b, s7o);
    a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4b, s6o));
    a03 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5b, s7o));
    s2u = _mm_sub_pd(a92, a03);
    s3u = _mm_add_pd(a92, a03);
    s4u = _mm_add_pd(t9q, t3r);
    _mm_storeu_pd(((double  *) (dst + 10)), s4u);
    s5u = _mm_sub_pd(t9q, t3r);
    _mm_storeu_pd(((double  *) (dst + 74)), s5u);
    s6u = _mm_sub_pd(t0r, t4r);
    _mm_storeu_pd(((double  *) (dst + 42)), s6u);
    s7u = _mm_add_pd(t0r, t4r);
    _mm_storeu_pd(((double  *) (dst + 106)), s7u);
    s8u = _mm_add_pd(t1r, s2u);
    _mm_storeu_pd(((double  *) (dst + 26)), s8u);
    s9u = _mm_sub_pd(t1r, s2u);
    _mm_storeu_pd(((double  *) (dst + 90)), s9u);
    s0v = _mm_sub_pd(t2r, s3u);
    _mm_storeu_pd(((double  *) (dst + 58)), s0v);
    s1v = _mm_add_pd(t2r, s3u);
    _mm_storeu_pd(((double  *) (dst + 122)), s1v);
    t5r = _mm_add_pd(t55, s2i);
    t6r = _mm_sub_pd(t55, s2i);
    t7r = _mm_sub_pd(t65, s3i);
    t8r = _mm_add_pd(t65, s3i);
    t9r = _mm_add_pd(s6b, s8o);
    t0s = _mm_sub_pd(s7b, s9o);
    a13 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6b, s8o));
    a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7b, s9o));
    s2v = _mm_sub_pd(a13, a23);
    s3v = _mm_add_pd(a13, a23);
    s4v = _mm_add_pd(t5r, t9r);
    _mm_storeu_pd(((double  *) (dst + 12)), s4v);
    s5v = _mm_sub_pd(t5r, t9r);
    _mm_storeu_pd(((double  *) (dst + 76)), s5v);
    s6v = _mm_sub_pd(t6r, t0s);
    _mm_storeu_pd(((double  *) (dst + 44)), s6v);
    s7v = _mm_add_pd(t6r, t0s);
    _mm_storeu_pd(((double  *) (dst + 108)), s7v);
    s8v = _mm_add_pd(t7r, s2v);
    _mm_storeu_pd(((double  *) (dst + 28)), s8v);
    s9v = _mm_sub_pd(t7r, s2v);
    _mm_storeu_pd(((double  *) (dst + 92)), s9v);
    s0w = _mm_sub_pd(t8r, s3v);
    _mm_storeu_pd(((double  *) (dst + 60)), s0w);
    s1w = _mm_add_pd(t8r, s3v);
    _mm_storeu_pd(((double  *) (dst + 124)), s1w);
    t1s = _mm_add_pd(t95, s4i);
    t2s = _mm_sub_pd(t95, s4i);
    t3s = _mm_sub_pd(t06, s5i);
    t4s = _mm_add_pd(t06, s5i);
    t5s = _mm_add_pd(s8b, s0p);
    t6s = _mm_sub_pd(s9b, s1p);
    a33 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8b, s0p));
    a43 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9b, s1p));
    s2w = _mm_sub_pd(a33, a43);
    s3w = _mm_add_pd(a33, a43);
    s4w = _mm_add_pd(t1s, t5s);
    _mm_storeu_pd(((double  *) (dst + 14)), s4w);
    s5w = _mm_sub_pd(t1s, t5s);
    _mm_storeu_pd(((double  *) (dst + 78)), s5w);
    s6w = _mm_sub_pd(t2s, t6s);
    _mm_storeu_pd(((double  *) (dst + 46)), s6w);
    s7w = _mm_add_pd(t2s, t6s);
    _mm_storeu_pd(((double  *) (dst + 110)), s7w);
    s8w = _mm_add_pd(t3s, s2w);
    _mm_storeu_pd(((double  *) (dst + 30)), s8w);
    s9w = _mm_sub_pd(t3s, s2w);
    _mm_storeu_pd(((double  *) (dst + 94)), s9w);
    s0x = _mm_sub_pd(t4s, s3w);
    _mm_storeu_pd(((double  *) (dst + 62)), s0x);
    s1x = _mm_add_pd(t4s, s3w);
    _mm_storeu_pd(((double  *) (dst + 126)), s1x);
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_128)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_128_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    {__m128d a01, a02, a03, a11, a12, a13, a2, a21, a23, a3, a31, a32, a33, a4, a41, a42, a43, a5, a51, a52, a53, a6
            , a61, a62, a63, a7, a71, a72, a8, a81, a82, a9, a91, a92, s, s01, s02, s03, s04, s05, s06, s07, s08, s09
            , s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v
            , s0w, s0x, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k
            , s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u
            , s2v, s2w, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j
            , s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s4, s41, s42, s43, s44, s45, s46, s47, s48
            , s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u
            , s4v, s4w, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j
            , s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u
            , s6v, s6w, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j
            , s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s8, s81, s82, s83, s84, s85, s86, s87, s88
            , s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u
            , s8v, s8w, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j
            , s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, t, t01, t02, t03, t04, t05, t06, t07, t08
            , t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t11, t12
            , t13, t14, t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o
            , t1p, t1q, t1r, t1s, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h
            , t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a
            , t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t4, t41, t42, t43
            , t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p
            , t4q, t4r, t4s, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i
            , t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b
            , t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q
            , t7r, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k
            , t8l, t8m, t8n, t8o, t8p, t8q, t8r, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e
            , t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r;
    __m128d  *a, *a22;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 32)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 4));
    s5 = v_neg23(*((a + 60)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 8));
    s11 = v_neg23(*((a + 56)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 12));
    s71 = v_neg23(*((a + 52)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 16));
    s32 = v_neg23(*((a + 48)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 20));
    s92 = v_neg23(*((a + 44)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 24));
    s53 = v_neg23(*((a + 40)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 28));
    s14 = v_neg23(*((a + 36)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    t54 = _mm_add_pd(t32, t93);
    t64 = _mm_sub_pd(t32, t93);
    t74 = _mm_sub_pd(t42, t04);
    t84 = _mm_add_pd(t42, t04);
    t94 = _mm_add_pd(t72, s84);
    t05 = _mm_sub_pd(t72, s84);
    t15 = _mm_sub_pd(t82, s94);
    t25 = _mm_add_pd(t82, s94);
    t35 = _mm_add_pd(t52, s05);
    t45 = _mm_sub_pd(t52, s05);
    t55 = _mm_sub_pd(t62, s15);
    t65 = _mm_add_pd(t62, s15);
    t75 = _mm_add_pd(t92, s25);
    t85 = _mm_sub_pd(t92, s25);
    t95 = _mm_sub_pd(t03, s35);
    t06 = _mm_add_pd(t03, s35);
    s45 = *((a + 1));
    s55 = v_neg23(*((a + 63)));
    t16 = _mm_add_pd(s45, s55);
    t26 = _mm_sub_pd(s45, s55);
    s65 = v_lo2(t16, t26);
    s75 = v_hi2(t16, t26);
    s85 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9975909124103448, 2.0), s65), _mm_mul_pd(_mm_set_pd(0.09813534865483603, 0.0), s75));
    s95 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.09813534865483603, 0.0), s65), _mm_mul_pd(_mm_set_pd(1.9975909124103448, 2.0), s75));
    s06 = *((a + 9));
    s16 = v_neg23(*((a + 55)));
    t36 = _mm_add_pd(s06, s16);
    t46 = _mm_sub_pd(s06, s16);
    s26 = v_lo2(t36, t46);
    s36 = v_hi2(t36, t46);
    s46 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8079785862468867, 2.0), s26), _mm_mul_pd(_mm_set_pd(0.85511018686056417, 0.0), s36));
    s56 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.85511018686056417, 0.0), s26), _mm_mul_pd(_mm_set_pd(1.8079785862468867, 2.0), s36));
    s66 = *((a + 17));
    s76 = v_neg23(*((a + 47)));
    t56 = _mm_add_pd(s66, s76);
    t66 = _mm_sub_pd(s66, s76);
    s86 = v_lo2(t56, t66);
    s96 = v_hi2(t56, t66);
    s07 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.3431179096940369, 2.0), s86), _mm_mul_pd(_mm_set_pd(1.4819022507099182, 0.0), s96));
    s17 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4819022507099182, 0.0), s86), _mm_mul_pd(_mm_set_pd(1.3431179096940369, 2.0), s96));
    s27 = *((a + 25));
    s37 = v_neg23(*((a + 39)));
    t76 = _mm_add_pd(s27, s37);
    t86 = _mm_sub_pd(s27, s37);
    s47 = v_lo2(t76, t86);
    s57 = v_hi2(t76, t86);
    s67 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.6737797067844401, 2.0), s47), _mm_mul_pd(_mm_set_pd(1.8830881303660416, 0.0), s57));
    s77 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8830881303660416, 0.0), s47), _mm_mul_pd(_mm_set_pd(0.6737797067844401, 2.0), s57));
    s87 = *((a + 33));
    s97 = v_neg23(*((a + 31)));
    t96 = _mm_add_pd(s87, s97);
    t07 = _mm_sub_pd(s87, s97);
    s08 = v_lo2(t96, t07);
    s18 = v_hi2(t96, t07);
    s28 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.09813534865483603), 2.0), s08), _mm_mul_pd(_mm_set_pd(1.9975909124103448, 0.0), s18));
    s38 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9975909124103448, 0.0), s08), _mm_mul_pd(_mm_set_pd((-0.09813534865483603), 2.0), s18));
    s48 = *((a + 41));
    s58 = v_neg23(*((a + 23)));
    t17 = _mm_add_pd(s48, s58);
    t27 = _mm_sub_pd(s48, s58);
    s68 = v_lo2(t17, t27);
    s78 = v_hi2(t17, t27);
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.85511018686056417), 2.0), s68), _mm_mul_pd(_mm_set_pd(1.8079785862468867, 0.0), s78));
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8079785862468867, 0.0), s68), _mm_mul_pd(_mm_set_pd((-0.85511018686056417), 2.0), s78));
    s09 = *((a + 49));
    s19 = v_neg23(*((a + 15)));
    t37 = _mm_add_pd(s09, s19);
    t47 = _mm_sub_pd(s09, s19);
    s29 = v_lo2(t37, t47);
    s39 = v_hi2(t37, t47);
    s49 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.4819022507099182), 2.0), s29), _mm_mul_pd(_mm_set_pd(1.3431179096940369, 0.0), s39));
    s59 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.3431179096940369, 0.0), s29), _mm_mul_pd(_mm_set_pd((-1.4819022507099182), 2.0), s39));
    s69 = *((a + 57));
    s79 = v_neg23(*((a + 7)));
    t57 = _mm_add_pd(s69, s79);
    t67 = _mm_sub_pd(s69, s79);
    s89 = v_lo2(t57, t67);
    s99 = v_hi2(t57, t67);
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.8830881303660416), 2.0), s89), _mm_mul_pd(_mm_set_pd(0.6737797067844401, 0.0), s99));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.6737797067844401, 0.0), s89), _mm_mul_pd(_mm_set_pd((-1.8830881303660416), 2.0), s99));
    t77 = _mm_add_pd(s85, s28);
    t87 = _mm_add_pd(s95, s38);
    t97 = _mm_sub_pd(s85, s28);
    t08 = _mm_sub_pd(s95, s38);
    t18 = _mm_add_pd(s07, s49);
    t28 = _mm_add_pd(s17, s59);
    t38 = _mm_sub_pd(s07, s49);
    t48 = _mm_sub_pd(s17, s59);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    t39 = _mm_add_pd(s46, s88);
    t49 = _mm_add_pd(s56, s98);
    t59 = _mm_sub_pd(s46, s88);
    t69 = _mm_sub_pd(s56, s98);
    t79 = _mm_add_pd(s67, s0a);
    t89 = _mm_add_pd(s77, s1a);
    t99 = _mm_sub_pd(s67, s0a);
    t0a = _mm_sub_pd(s77, s1a);
    t1a = _mm_add_pd(t39, t79);
    t2a = _mm_add_pd(t49, t89);
    t3a = _mm_sub_pd(t39, t79);
    t4a = _mm_sub_pd(t49, t89);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t59, t0a));
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t69, t99));
    s2a = _mm_sub_pd(a6, a7);
    s3a = _mm_add_pd(a6, a7);
    a8 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t59, t0a));
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t69, t99));
    s4a = _mm_sub_pd(a8, a9);
    s5a = _mm_add_pd(a8, a9);
    t5a = _mm_add_pd(t58, t1a);
    t6a = _mm_add_pd(t68, t2a);
    t7a = _mm_sub_pd(t58, t1a);
    t8a = _mm_sub_pd(t68, t2a);
    t9a = _mm_add_pd(t98, s2a);
    t0b = _mm_add_pd(t09, s3a);
    t1b = _mm_sub_pd(t98, s2a);
    t2b = _mm_sub_pd(t09, s3a);
    t3b = _mm_sub_pd(t78, t4a);
    t4b = _mm_add_pd(t88, t3a);
    t5b = _mm_add_pd(t78, t4a);
    t6b = _mm_sub_pd(t88, t3a);
    t7b = _mm_add_pd(t19, s4a);
    t8b = _mm_sub_pd(t29, s5a);
    t9b = _mm_sub_pd(t19, s4a);
    t0c = _mm_add_pd(t29, s5a);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t9a), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t0b));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t9a), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t0b));
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3b), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4b));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3b), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4b));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7b), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t8b));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t7b), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8b));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8a));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8a));
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t1b), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t2b));
    s5b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t1b), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t2b));
    s6b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5b), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6b));
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5b), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6b));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t9b), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t0c));
    s9b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t9b), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t0c));
    s0c = *((a + 2));
    s1c = v_neg23(*((a + 62)));
    t1c = _mm_add_pd(s0c, s1c);
    t2c = _mm_sub_pd(s0c, s1c);
    s2c = v_lo2(t1c, t2c);
    s3c = v_hi2(t1c, t2c);
    s4c = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s2c), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s3c));
    s5c = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s2c), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s3c));
    s6c = *((a + 10));
    s7c = v_neg23(*((a + 54)));
    t3c = _mm_add_pd(s6c, s7c);
    t4c = _mm_sub_pd(s6c, s7c);
    s8c = v_lo2(t3c, t4c);
    s9c = v_hi2(t3c, t4c);
    s0d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s8c), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s9c));
    s1d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s8c), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s9c));
    s2d = *((a + 18));
    s3d = v_neg23(*((a + 46)));
    t5c = _mm_add_pd(s2d, s3d);
    t6c = _mm_sub_pd(s2d, s3d);
    s4d = v_lo2(t5c, t6c);
    s5d = v_hi2(t5c, t6c);
    s6d = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s4d), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s5d));
    s7d = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s4d), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s5d));
    s8d = *((a + 26));
    s9d = v_neg23(*((a + 38)));
    t7c = _mm_add_pd(s8d, s9d);
    t8c = _mm_sub_pd(s8d, s9d);
    s0e = v_lo2(t7c, t8c);
    s1e = v_hi2(t7c, t8c);
    s2e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s0e), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s1e));
    s3e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s0e), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s1e));
    s4e = *((a + 34));
    s5e = v_neg23(*((a + 30)));
    t9c = _mm_add_pd(s4e, s5e);
    t0d = _mm_sub_pd(s4e, s5e);
    s6e = v_lo2(t9c, t0d);
    s7e = v_hi2(t9c, t0d);
    s8e = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.19603428065912121), 2.0), s6e), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s7e));
    s9e = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s6e), _mm_mul_pd(_mm_set_pd((-0.19603428065912121), 2.0), s7e));
    s0f = *((a + 42));
    s1f = v_neg23(*((a + 22)));
    t1d = _mm_add_pd(s0f, s1f);
    t2d = _mm_sub_pd(s0f, s1f);
    s2f = v_lo2(t1d, t2d);
    s3f = v_hi2(t1d, t2d);
    s4f = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.94279347365199528), 2.0), s2f), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s3f));
    s5f = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s2f), _mm_mul_pd(_mm_set_pd((-0.94279347365199528), 2.0), s3f));
    s6f = *((a + 50));
    s7f = v_neg23(*((a + 14)));
    t3d = _mm_add_pd(s6f, s7f);
    t4d = _mm_sub_pd(s6f, s7f);
    s8f = v_lo2(t3d, t4d);
    s9f = v_hi2(t3d, t4d);
    s0g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.546020906725474), 2.0), s8f), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s9f));
    s1g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s8f), _mm_mul_pd(_mm_set_pd((-1.546020906725474), 2.0), s9f));
    s2g = *((a + 58));
    s3g = v_neg23(*((a + 6)));
    t5d = _mm_add_pd(s2g, s3g);
    t6d = _mm_sub_pd(s2g, s3g);
    s4g = v_lo2(t5d, t6d);
    s5g = v_hi2(t5d, t6d);
    s6g = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.9138806714644176), 2.0), s4g), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s5g));
    s7g = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s4g), _mm_mul_pd(_mm_set_pd((-1.9138806714644176), 2.0), s5g));
    t7d = _mm_add_pd(s4c, s8e);
    t8d = _mm_add_pd(s5c, s9e);
    t9d = _mm_sub_pd(s4c, s8e);
    t0e = _mm_sub_pd(s5c, s9e);
    t1e = _mm_add_pd(s6d, s0g);
    t2e = _mm_add_pd(s7d, s1g);
    t3e = _mm_sub_pd(s6d, s0g);
    t4e = _mm_sub_pd(s7d, s1g);
    t5e = _mm_add_pd(t7d, t1e);
    t6e = _mm_add_pd(t8d, t2e);
    t7e = _mm_sub_pd(t7d, t1e);
    t8e = _mm_sub_pd(t8d, t2e);
    t9e = _mm_sub_pd(t9d, t4e);
    t0f = _mm_add_pd(t0e, t3e);
    t1f = _mm_add_pd(t9d, t4e);
    t2f = _mm_sub_pd(t0e, t3e);
    t3f = _mm_add_pd(s0d, s4f);
    t4f = _mm_add_pd(s1d, s5f);
    t5f = _mm_sub_pd(s0d, s4f);
    t6f = _mm_sub_pd(s1d, s5f);
    t7f = _mm_add_pd(s2e, s6g);
    t8f = _mm_add_pd(s3e, s7g);
    t9f = _mm_sub_pd(s2e, s6g);
    t0g = _mm_sub_pd(s3e, s7g);
    t1g = _mm_add_pd(t3f, t7f);
    t2g = _mm_add_pd(t4f, t8f);
    t3g = _mm_sub_pd(t3f, t7f);
    t4g = _mm_sub_pd(t4f, t8f);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5f, t0g));
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6f, t9f));
    s8g = _mm_sub_pd(a01, a11);
    s9g = _mm_add_pd(a01, a11);
    a21 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5f, t0g));
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6f, t9f));
    s0h = _mm_sub_pd(a21, a31);
    s1h = _mm_add_pd(a21, a31);
    t5g = _mm_add_pd(t5e, t1g);
    t6g = _mm_add_pd(t6e, t2g);
    t7g = _mm_add_pd(t9e, s8g);
    t8g = _mm_add_pd(t0f, s9g);
    t9g = _mm_sub_pd(t9e, s8g);
    t0h = _mm_sub_pd(t0f, s9g);
    t1h = _mm_sub_pd(t7e, t4g);
    t2h = _mm_add_pd(t8e, t3g);
    t3h = _mm_add_pd(t7e, t4g);
    t4h = _mm_sub_pd(t8e, t3g);
    t5h = _mm_add_pd(t1f, s0h);
    t6h = _mm_sub_pd(t2f, s1h);
    t7h = _mm_sub_pd(t1f, s0h);
    t8h = _mm_add_pd(t2f, s1h);
    s2h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7g), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8g));
    s3h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7g), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8g));
    s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2h));
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2h));
    s6h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5h), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6h));
    s7h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5h), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6h));
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5e, t1g));
    a51 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6e, t2g));
    s8h = _mm_sub_pd(a41, a51);
    s9h = _mm_add_pd(a41, a51);
    s0i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0h));
    s1i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0h));
    s2i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4h));
    s3i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4h));
    s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7h), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8h));
    s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7h), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8h));
    s6i = *((a + 3));
    s7i = v_neg23(*((a + 61)));
    t9h = _mm_add_pd(s6i, s7i);
    t0i = _mm_sub_pd(s6i, s7i);
    s8i = v_lo2(t9h, t0i);
    s9i = v_hi2(t9h, t0i);
    s0j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.978353019929562, 2.0), s8i), _mm_mul_pd(_mm_set_pd(0.2934609489107235, 0.0), s9i));
    s1j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.2934609489107235, 0.0), s8i), _mm_mul_pd(_mm_set_pd(1.978353019929562, 2.0), s9i));
    s2j = *((a + 11));
    s3j = v_neg23(*((a + 53)));
    t1i = _mm_add_pd(s2j, s3j);
    t2i = _mm_sub_pd(s2j, s3j);
    s4j = v_lo2(t1i, t2i);
    s5j = v_hi2(t1i, t2i);
    s6j = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7154572200005442, 2.0), s4j), _mm_mul_pd(_mm_set_pd(1.0282054883864435, 0.0), s5j));
    s7j = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.0282054883864435, 0.0), s4j), _mm_mul_pd(_mm_set_pd(1.7154572200005442, 2.0), s5j));
    s8j = *((a + 19));
    s9j = v_neg23(*((a + 45)));
    t3i = _mm_add_pd(s8j, s9j);
    t4i = _mm_sub_pd(s8j, s9j);
    s0k = v_lo2(t3i, t4i);
    s1k = v_hi2(t3i, t4i);
    s2k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1913986089848667, 2.0), s0k), _mm_mul_pd(_mm_set_pd(1.6064150629612899, 0.0), s1k));
    s3k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6064150629612899, 0.0), s0k), _mm_mul_pd(_mm_set_pd(1.1913986089848667, 2.0), s1k));
    s4k = *((a + 27));
    s5k = v_neg23(*((a + 37)));
    t5i = _mm_add_pd(s4k, s5k);
    t6i = _mm_sub_pd(s4k, s5k);
    s6k = v_lo2(t5i, t6i);
    s7k = v_hi2(t5i, t6i);
    s8k = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.4859603598065278, 2.0), s6k), _mm_mul_pd(_mm_set_pd(1.9400625063890879, 0.0), s7k));
    s9k = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9400625063890879, 0.0), s6k), _mm_mul_pd(_mm_set_pd(0.4859603598065278, 2.0), s7k));
    s0l = *((a + 35));
    s1l = v_neg23(*((a + 29)));
    t7i = _mm_add_pd(s0l, s1l);
    t8i = _mm_sub_pd(s0l, s1l);
    s2l = v_lo2(t7i, t8i);
    s3l = v_hi2(t7i, t8i);
    s4l = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-0.2934609489107235), 2.0), s2l), _mm_mul_pd(_mm_set_pd(1.978353019929562, 0.0), s3l));
    s5l = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.978353019929562, 0.0), s2l), _mm_mul_pd(_mm_set_pd((-0.2934609489107235), 2.0), s3l));
    s6l = *((a + 43));
    s7l = v_neg23(*((a + 21)));
    t9i = _mm_add_pd(s6l, s7l);
    t0j = _mm_sub_pd(s6l, s7l);
    s8l = v_lo2(t9i, t0j);
    s9l = v_hi2(t9i, t0j);
    s0m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.0282054883864435), 2.0), s8l), _mm_mul_pd(_mm_set_pd(1.7154572200005442, 0.0), s9l));
    s1m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7154572200005442, 0.0), s8l), _mm_mul_pd(_mm_set_pd((-1.0282054883864435), 2.0), s9l));
    s2m = *((a + 51));
    s3m = v_neg23(*((a + 13)));
    t1j = _mm_add_pd(s2m, s3m);
    t2j = _mm_sub_pd(s2m, s3m);
    s4m = v_lo2(t1j, t2j);
    s5m = v_hi2(t1j, t2j);
    s6m = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.6064150629612899), 2.0), s4m), _mm_mul_pd(_mm_set_pd(1.1913986089848667, 0.0), s5m));
    s7m = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1913986089848667, 0.0), s4m), _mm_mul_pd(_mm_set_pd((-1.6064150629612899), 2.0), s5m));
    s8m = *((a + 59));
    s9m = v_neg23(*((a + 5)));
    t3j = _mm_add_pd(s8m, s9m);
    t4j = _mm_sub_pd(s8m, s9m);
    s0n = v_lo2(t3j, t4j);
    s1n = v_hi2(t3j, t4j);
    s2n = _mm_sub_pd(_mm_mul_pd(_mm_set_pd((-1.9400625063890879), 2.0), s0n), _mm_mul_pd(_mm_set_pd(0.4859603598065278, 0.0), s1n));
    s3n = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.4859603598065278, 0.0), s0n), _mm_mul_pd(_mm_set_pd((-1.9400625063890879), 2.0), s1n));
    t5j = _mm_add_pd(s0j, s4l);
    t6j = _mm_add_pd(s1j, s5l);
    t7j = _mm_sub_pd(s0j, s4l);
    t8j = _mm_sub_pd(s1j, s5l);
    t9j = _mm_add_pd(s2k, s6m);
    t0k = _mm_add_pd(s3k, s7m);
    t1k = _mm_sub_pd(s2k, s6m);
    t2k = _mm_sub_pd(s3k, s7m);
    t3k = _mm_add_pd(t5j, t9j);
    t4k = _mm_add_pd(t6j, t0k);
    t5k = _mm_sub_pd(t5j, t9j);
    t6k = _mm_sub_pd(t6j, t0k);
    t7k = _mm_sub_pd(t7j, t2k);
    t8k = _mm_add_pd(t8j, t1k);
    t9k = _mm_add_pd(t7j, t2k);
    t0l = _mm_sub_pd(t8j, t1k);
    t1l = _mm_add_pd(s6j, s0m);
    t2l = _mm_add_pd(s7j, s1m);
    t3l = _mm_sub_pd(s6j, s0m);
    t4l = _mm_sub_pd(s7j, s1m);
    t5l = _mm_add_pd(s8k, s2n);
    t6l = _mm_add_pd(s9k, s3n);
    t7l = _mm_sub_pd(s8k, s2n);
    t8l = _mm_sub_pd(s9k, s3n);
    t9l = _mm_add_pd(t1l, t5l);
    t0m = _mm_add_pd(t2l, t6l);
    t1m = _mm_sub_pd(t1l, t5l);
    t2m = _mm_sub_pd(t2l, t6l);
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3l, t8l));
    a71 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4l, t7l));
    s4n = _mm_sub_pd(a61, a71);
    s5n = _mm_add_pd(a61, a71);
    a81 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3l, t8l));
    a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4l, t7l));
    s6n = _mm_sub_pd(a81, a91);
    s7n = _mm_add_pd(a81, a91);
    t3m = _mm_add_pd(t3k, t9l);
    t4m = _mm_add_pd(t4k, t0m);
    t5m = _mm_sub_pd(t3k, t9l);
    t6m = _mm_sub_pd(t4k, t0m);
    t7m = _mm_add_pd(t7k, s4n);
    t8m = _mm_add_pd(t8k, s5n);
    t9m = _mm_sub_pd(t7k, s4n);
    t0n = _mm_sub_pd(t8k, s5n);
    t1n = _mm_sub_pd(t5k, t2m);
    t2n = _mm_add_pd(t6k, t1m);
    t3n = _mm_add_pd(t5k, t2m);
    t4n = _mm_sub_pd(t6k, t1m);
    t5n = _mm_add_pd(t9k, s6n);
    t6n = _mm_sub_pd(t0l, s7n);
    t7n = _mm_sub_pd(t9k, s6n);
    t8n = _mm_add_pd(t0l, s7n);
    s8n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t7m), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t8m));
    s9n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t7m), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t8m));
    s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1n), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2n));
    s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1n), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2n));
    s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5n), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6n));
    s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5n), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6n));
    s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5m), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6m));
    s5o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5m), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6m));
    s6o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t9m), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t0n));
    s7o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t9m), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t0n));
    s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3n), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4n));
    s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3n), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4n));
    s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7n), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8n));
    s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7n), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8n));
    t9n = _mm_add_pd(t54, t5g);
    t0o = _mm_sub_pd(t54, t5g);
    t1o = _mm_sub_pd(t64, t6g);
    t2o = _mm_add_pd(t64, t6g);
    t3o = _mm_add_pd(t5a, t3m);
    t4o = _mm_sub_pd(t6a, t4m);
    a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5a, t3m));
    a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6a, t4m));
    s2p = _mm_sub_pd(a02, a12);
    s3p = _mm_add_pd(a02, a12);
    a22 = ((__m128d  *) dst);
    s4p = _mm_add_pd(t9n, t3o);
    *(a22) = s4p;
    s5p = _mm_sub_pd(t9n, t3o);
    *((a22 + 32)) = s5p;
    s6p = _mm_sub_pd(t0o, t4o);
    *((a22 + 16)) = s6p;
    s7p = _mm_add_pd(t0o, t4o);
    *((a22 + 48)) = s7p;
    s8p = _mm_add_pd(t1o, s2p);
    *((a22 + 8)) = s8p;
    s9p = _mm_sub_pd(t1o, s2p);
    *((a22 + 40)) = s9p;
    s0q = _mm_sub_pd(t2o, s3p);
    *((a22 + 24)) = s0q;
    s1q = _mm_add_pd(t2o, s3p);
    *((a22 + 56)) = s1q;
    t5o = _mm_add_pd(t94, s2h);
    t6o = _mm_sub_pd(t94, s2h);
    t7o = _mm_sub_pd(t05, s3h);
    t8o = _mm_add_pd(t05, s3h);
    t9o = _mm_add_pd(s6a, s8n);
    t0p = _mm_sub_pd(s7a, s9n);
    a32 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6a, s8n));
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7a, s9n));
    s2q = _mm_sub_pd(a32, a42);
    s3q = _mm_add_pd(a32, a42);
    s4q = _mm_add_pd(t5o, t9o);
    *((a22 + 1)) = s4q;
    s5q = _mm_sub_pd(t5o, t9o);
    *((a22 + 33)) = s5q;
    s6q = _mm_sub_pd(t6o, t0p);
    *((a22 + 17)) = s6q;
    s7q = _mm_add_pd(t6o, t0p);
    *((a22 + 49)) = s7q;
    s8q = _mm_add_pd(t7o, s2q);
    *((a22 + 9)) = s8q;
    s9q = _mm_sub_pd(t7o, s2q);
    *((a22 + 41)) = s9q;
    s0r = _mm_sub_pd(t8o, s3q);
    *((a22 + 25)) = s0r;
    s1r = _mm_add_pd(t8o, s3q);
    *((a22 + 57)) = s1r;
    t1p = _mm_add_pd(t35, s4h);
    t2p = _mm_sub_pd(t35, s4h);
    t3p = _mm_sub_pd(t45, s5h);
    t4p = _mm_add_pd(t45, s5h);
    t5p = _mm_add_pd(s8a, s0o);
    t6p = _mm_sub_pd(s9a, s1o);
    a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8a, s0o));
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9a, s1o));
    s2r = _mm_sub_pd(a52, a62);
    s3r = _mm_add_pd(a52, a62);
    s4r = _mm_add_pd(t1p, t5p);
    *((a22 + 2)) = s4r;
    s5r = _mm_sub_pd(t1p, t5p);
    *((a22 + 34)) = s5r;
    s6r = _mm_sub_pd(t2p, t6p);
    *((a22 + 18)) = s6r;
    s7r = _mm_add_pd(t2p, t6p);
    *((a22 + 50)) = s7r;
    s8r = _mm_add_pd(t3p, s2r);
    *((a22 + 10)) = s8r;
    s9r = _mm_sub_pd(t3p, s2r);
    *((a22 + 42)) = s9r;
    s0s = _mm_sub_pd(t4p, s3r);
    *((a22 + 26)) = s0s;
    s1s = _mm_add_pd(t4p, s3r);
    *((a22 + 58)) = s1s;
    t7p = _mm_add_pd(t75, s6h);
    t8p = _mm_sub_pd(t75, s6h);
    t9p = _mm_sub_pd(t85, s7h);
    t0q = _mm_add_pd(t85, s7h);
    t1q = _mm_add_pd(s0b, s2o);
    t2q = _mm_sub_pd(s1b, s3o);
    a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0b, s2o));
    a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1b, s3o));
    s2s = _mm_sub_pd(a72, a82);
    s3s = _mm_add_pd(a72, a82);
    s4s = _mm_add_pd(t7p, t1q);
    *((a22 + 3)) = s4s;
    s5s = _mm_sub_pd(t7p, t1q);
    *((a22 + 35)) = s5s;
    s6s = _mm_sub_pd(t8p, t2q);
    *((a22 + 19)) = s6s;
    s7s = _mm_add_pd(t8p, t2q);
    *((a22 + 51)) = s7s;
    s8s = _mm_add_pd(t9p, s2s);
    *((a22 + 11)) = s8s;
    s9s = _mm_sub_pd(t9p, s2s);
    *((a22 + 43)) = s9s;
    s0t = _mm_sub_pd(t0q, s3s);
    *((a22 + 27)) = s0t;
    s1t = _mm_add_pd(t0q, s3s);
    *((a22 + 59)) = s1t;
    t3q = _mm_add_pd(t74, s8h);
    t4q = _mm_sub_pd(t74, s8h);
    t5q = _mm_sub_pd(t84, s9h);
    t6q = _mm_add_pd(t84, s9h);
    t7q = _mm_add_pd(s2b, s4o);
    t8q = _mm_sub_pd(s3b, s5o);
    a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2b, s4o));
    a03 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3b, s5o));
    s2t = _mm_sub_pd(a92, a03);
    s3t = _mm_add_pd(a92, a03);
    s4t = _mm_add_pd(t3q, t7q);
    *((a22 + 4)) = s4t;
    s5t = _mm_sub_pd(t3q, t7q);
    *((a22 + 36)) = s5t;
    s6t = _mm_sub_pd(t4q, t8q);
    *((a22 + 20)) = s6t;
    s7t = _mm_add_pd(t4q, t8q);
    *((a22 + 52)) = s7t;
    s8t = _mm_add_pd(t5q, s2t);
    *((a22 + 12)) = s8t;
    s9t = _mm_sub_pd(t5q, s2t);
    *((a22 + 44)) = s9t;
    s0u = _mm_sub_pd(t6q, s3t);
    *((a22 + 28)) = s0u;
    s1u = _mm_add_pd(t6q, s3t);
    *((a22 + 60)) = s1u;
    t9q = _mm_add_pd(t15, s0i);
    t0r = _mm_sub_pd(t15, s0i);
    t1r = _mm_sub_pd(t25, s1i);
    t2r = _mm_add_pd(t25, s1i);
    t3r = _mm_add_pd(s4b, s6o);
    t4r = _mm_sub_pd(s5b, s7o);
    a13 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4b, s6o));
    a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5b, s7o));
    s2u = _mm_sub_pd(a13, a23);
    s3u = _mm_add_pd(a13, a23);
    s4u = _mm_add_pd(t9q, t3r);
    *((a22 + 5)) = s4u;
    s5u = _mm_sub_pd(t9q, t3r);
    *((a22 + 37)) = s5u;
    s6u = _mm_sub_pd(t0r, t4r);
    *((a22 + 21)) = s6u;
    s7u = _mm_add_pd(t0r, t4r);
    *((a22 + 53)) = s7u;
    s8u = _mm_add_pd(t1r, s2u);
    *((a22 + 13)) = s8u;
    s9u = _mm_sub_pd(t1r, s2u);
    *((a22 + 45)) = s9u;
    s0v = _mm_sub_pd(t2r, s3u);
    *((a22 + 29)) = s0v;
    s1v = _mm_add_pd(t2r, s3u);
    *((a22 + 61)) = s1v;
    t5r = _mm_add_pd(t55, s2i);
    t6r = _mm_sub_pd(t55, s2i);
    t7r = _mm_sub_pd(t65, s3i);
    t8r = _mm_add_pd(t65, s3i);
    t9r = _mm_add_pd(s6b, s8o);
    t0s = _mm_sub_pd(s7b, s9o);
    a33 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6b, s8o));
    a43 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7b, s9o));
    s2v = _mm_sub_pd(a33, a43);
    s3v = _mm_add_pd(a33, a43);
    s4v = _mm_add_pd(t5r, t9r);
    *((a22 + 6)) = s4v;
    s5v = _mm_sub_pd(t5r, t9r);
    *((a22 + 38)) = s5v;
    s6v = _mm_sub_pd(t6r, t0s);
    *((a22 + 22)) = s6v;
    s7v = _mm_add_pd(t6r, t0s);
    *((a22 + 54)) = s7v;
    s8v = _mm_add_pd(t7r, s2v);
    *((a22 + 14)) = s8v;
    s9v = _mm_sub_pd(t7r, s2v);
    *((a22 + 46)) = s9v;
    s0w = _mm_sub_pd(t8r, s3v);
    *((a22 + 30)) = s0w;
    s1w = _mm_add_pd(t8r, s3v);
    *((a22 + 62)) = s1w;
    t1s = _mm_add_pd(t95, s4i);
    t2s = _mm_sub_pd(t95, s4i);
    t3s = _mm_sub_pd(t06, s5i);
    t4s = _mm_add_pd(t06, s5i);
    t5s = _mm_add_pd(s8b, s0p);
    t6s = _mm_sub_pd(s9b, s1p);
    a53 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8b, s0p));
    a63 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9b, s1p));
    s2w = _mm_sub_pd(a53, a63);
    s3w = _mm_add_pd(a53, a63);
    s4w = _mm_add_pd(t1s, t5s);
    *((a22 + 7)) = s4w;
    s5w = _mm_sub_pd(t1s, t5s);
    *((a22 + 39)) = s5w;
    s6w = _mm_sub_pd(t2s, t6s);
    *((a22 + 23)) = s6w;
    s7w = _mm_add_pd(t2s, t6s);
    *((a22 + 55)) = s7w;
    s8w = _mm_add_pd(t3s, s2w);
    *((a22 + 15)) = s8w;
    s9w = _mm_sub_pd(t3s, s2w);
    *((a22 + 47)) = s9w;
    s0x = _mm_sub_pd(t4s, s3w);
    *((a22 + 31)) = s0x;
    s1x = _mm_add_pd(t4s, s3w);
    *((a22 + 63)) = s1x;
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_256_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[256]);
    __m128d a, a01, a02, a03, a04, a05, a11, a12, a13, a14, a2, a21, a22, a23, a24, a3, a31, a32, a33, a34, a4, a41
            , a42, a43, a44, a51, a52, a53, a54, a61, a62, a63, a71, a72, a73, a74, a81, a82, a83, a84, a9, a91, a93, a94
            , s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s11, s12, s13, s14
            , s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c
            , s3d, s3e, s3f, s3g, s3h, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g
            , s4h, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s6, s61, s62
            , s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s7, s71, s72, s73, s74, s75, s76
            , s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a
            , s8b, s8c, s8d, s8e, s8f, s8g, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f
            , s9g, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t11, t12, t13, t14, t15, t16, t17
            , t18, t19, t1a, t1b, t1c, t1d, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t3, t31
            , t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a
            , t4b, t4c, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t6, t61, t62, t63, t64, t65, t66
            , t67, t68, t69, t6a, t6b, t6c, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t8, t81, t82
            , t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b
            , t9c;
    __m128d  *a5, *a64, *a8, *a92, *b3;
    double  *a15;
    const double  *b, *b2;
    int a6, a7;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 128))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 16)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 240))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 32)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 224))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 48)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 208))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 64)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 192))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 80)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 176))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 96)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 160))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 112)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 144))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a5 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a5) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a5 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a5 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a5 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a5 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a5 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a5 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a5 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a5 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a5 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a5 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a5 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a5 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a5 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a5 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a5 + 15)) = s96;
    {long i; for(i = 0; i <= 6; i++) {
        a6 = (2 * i);
        b = (src + a6);
        s07 = _mm_loadu_pd(((const double  *) (b + 2)));
        b2 = (src - a6);
        s17 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 254))));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a7 = (16 * i);
        a8 = (D64 + a7);
        a9 = *(a8);
        a01 = *((a8 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a9, s27), _mm_mul_pd(a01, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a9, s37), _mm_mul_pd(a01, s27));
        s67 = _mm_loadu_pd(((const double  *) (b + 34)));
        s77 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 222))));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a11 = *((a8 + 2));
        a21 = *((a8 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a11, s87), _mm_mul_pd(a21, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a11, s97), _mm_mul_pd(a21, s87));
        s28 = _mm_loadu_pd(((const double  *) (b + 66)));
        s38 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 190))));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a31 = *((a8 + 4));
        a41 = *((a8 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a31, s48), _mm_mul_pd(a41, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a31, s58), _mm_mul_pd(a41, s48));
        s88 = _mm_loadu_pd(((const double  *) (b + 98)));
        s98 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 158))));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a51 = *((a8 + 6));
        a61 = *((a8 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a51, s09), _mm_mul_pd(a61, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a51, s19), _mm_mul_pd(a61, s09));
        s49 = _mm_loadu_pd(((const double  *) (b + 130)));
        s59 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 126))));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a71 = *((a8 + 8));
        a81 = *((a8 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a71, s69), _mm_mul_pd(a81, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a71, s79), _mm_mul_pd(a81, s69));
        s0a = _mm_loadu_pd(((const double  *) (b + 162)));
        s1a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 94))));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a91 = *((a8 + 10));
        a02 = *((a8 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a91, s2a), _mm_mul_pd(a02, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a91, s3a), _mm_mul_pd(a02, s2a));
        s6a = _mm_loadu_pd(((const double  *) (b + 194)));
        s7a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 62))));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a12 = *((a8 + 12));
        a22 = *((a8 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a12, s8a), _mm_mul_pd(a22, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a12, s9a), _mm_mul_pd(a22, s8a));
        s2b = _mm_loadu_pd(((const double  *) (b + 226)));
        s3b = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 30))));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a32 = *((a8 + 14));
        a42 = *((a8 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a32, s4b), _mm_mul_pd(a42, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a32, s5b), _mm_mul_pd(a42, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a52, a62);
        s9b = _mm_add_pd(a52, a62);
        a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a72, a82);
        s1c = _mm_add_pd(a72, a82);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a92 = (D63 + a7);
        a03 = *(a92);
        a13 = *((a92 + 1));
        a23 = *((a92 + 2));
        a33 = *((a92 + 3));
        a43 = *((a92 + 4));
        a53 = *((a92 + 5));
        a63 = *((a92 + 6));
        a73 = *((a92 + 7));
        a83 = *((a92 + 8));
        a93 = *((a92 + 9));
        a04 = *((a92 + 10));
        a14 = *((a92 + 11));
        a24 = *((a92 + 12));
        a34 = *((a92 + 13));
        a44 = *((a92 + 14));
        a54 = *((a92 + 15));
        b3 = (((__m128d  *) T) + a7);
        s2c = _mm_sub_pd(_mm_mul_pd(a03, t98), _mm_mul_pd(a13, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a03, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a23, t39), _mm_mul_pd(a33, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a23, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a43, t79), _mm_mul_pd(a53, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a43, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a63, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a63, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a83, t19), _mm_mul_pd(a93, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a83, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a04, t59), _mm_mul_pd(a14, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a04, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a24, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a24, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a44, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a44, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a64 = (((__m128d  *) T) + i2);
        s8d = *(a64);
        s9d = *((a64 + 64));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a64 + 8));
        s1e = *((a64 + 72));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a64 + 32));
        s3e = *((a64 + 40));
        s4e = *((a64 + 96));
        s5e = *((a64 + 104));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a74, a84);
        s7e = _mm_add_pd(a74, a84);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a64 + 16));
        s9e = *((a64 + 24));
        s0f = *((a64 + 112));
        s1f = *((a64 + 120));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a64 + 80));
        s3f = *((a64 + 88));
        s4f = *((a64 + 48));
        s5f = *((a64 + 56));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t1c, t6c);
        t0d = _mm_add_pd(t2c, t5c);
        t1d = _mm_add_pd(t1c, t6c);
        t2d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9b, t3c));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0c, t4c));
        s8f = _mm_sub_pd(a94, a05);
        s9f = _mm_add_pd(a94, a05);
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d));
        a15 = (dst + (2 * i2));
        s2g = _mm_add_pd(t1b, t7c);
        _mm_storeu_pd(((double  *) a15), s2g);
        s3g = _mm_sub_pd(t1b, t7c);
        _mm_storeu_pd(((double  *) (a15 + 128)), s3g);
        s4g = _mm_sub_pd(t2b, t8c);
        _mm_storeu_pd(((double  *) (a15 + 64)), s4g);
        s5g = _mm_add_pd(t2b, t8c);
        _mm_storeu_pd(((double  *) (a15 + 192)), s5g);
        s6g = _mm_add_pd(t5b, s6f);
        _mm_storeu_pd(((double  *) (a15 + 16)), s6g);
        s7g = _mm_sub_pd(t5b, s6f);
        _mm_storeu_pd(((double  *) (a15 + 144)), s7g);
        s8g = _mm_sub_pd(t6b, s7f);
        _mm_storeu_pd(((double  *) (a15 + 80)), s8g);
        s9g = _mm_add_pd(t6b, s7f);
        _mm_storeu_pd(((double  *) (a15 + 208)), s9g);
        s0h = _mm_add_pd(t3b, s8f);
        _mm_storeu_pd(((double  *) (a15 + 32)), s0h);
        s1h = _mm_sub_pd(t3b, s8f);
        _mm_storeu_pd(((double  *) (a15 + 160)), s1h);
        s2h = _mm_sub_pd(t4b, s9f);
        _mm_storeu_pd(((double  *) (a15 + 96)), s2h);
        s3h = _mm_add_pd(t4b, s9f);
        _mm_storeu_pd(((double  *) (a15 + 224)), s3h);
        s4h = _mm_add_pd(t7b, s0g);
        _mm_storeu_pd(((double  *) (a15 + 48)), s4h);
        s5h = _mm_sub_pd(t7b, s0g);
        _mm_storeu_pd(((double  *) (a15 + 176)), s5h);
        s6h = _mm_sub_pd(t8b, s1g);
        _mm_storeu_pd(((double  *) (a15 + 112)), s6h);
        s7h = _mm_add_pd(t8b, s1g);
        _mm_storeu_pd(((double  *) (a15 + 240)), s7h);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_256)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_256_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[256]);
    __m128d a01, a02, a04, a05, a11, a12, a13, a14, a15, a2, a21, a22, a23, a24, a3, a31, a32, a33, a34, a4, a41, a42
            , a43, a44, a5, a51, a52, a53, a54, a61, a62, a63, a64, a71, a72, a73, a81, a82, a83, a84, a91, a92, a93, a94
            , s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s11, s12, s13, s14
            , s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c
            , s3d, s3e, s3f, s3g, s3h, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g
            , s4h, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s6, s61, s62
            , s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s7, s71, s72, s73, s74, s75, s76
            , s77, s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a
            , s8b, s8c, s8d, s8e, s8f, s8g, s9, s91, s92, s93, s94, s95, s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f
            , s9g, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t11, t12, t13, t14, t15, t16, t17
            , t18, t19, t1a, t1b, t1c, t1d, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t3, t31
            , t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a
            , t4b, t4c, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t6, t61, t62, t63, t64, t65, t66
            , t67, t68, t69, t6a, t6b, t6c, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t8, t81, t82
            , t83, t84, t85, t86, t87, t88, t89, t8a, t8b, t8c, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b
            , t9c;
    __m128d  *a, *a03, *a25, *a6, *a7, *a74, *a9, *b, *b2, *b3;
    int a8;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 64)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 8));
    s5 = v_neg23(*((a + 120)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 16));
    s11 = v_neg23(*((a + 112)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 24));
    s71 = v_neg23(*((a + 104)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 32));
    s32 = v_neg23(*((a + 96)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 40));
    s92 = v_neg23(*((a + 88)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 48));
    s53 = v_neg23(*((a + 80)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 56));
    s14 = v_neg23(*((a + 72)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a6 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a6) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a6 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a6 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a6 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a6 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a6 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a6 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a6 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a6 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a6 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a6 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a6 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a6 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a6 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a6 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a6 + 15)) = s96;
    {long i; for(i = 0; i <= 6; i++) {
        a7 = ((__m128d  *) src);
        b = (a7 + i);
        s07 = *((b + 1));
        b2 = (a7 - i);
        s17 = v_neg23(*((b2 + 127)));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a8 = (16 * i);
        a9 = (D64 + a8);
        a01 = *(a9);
        a11 = *((a9 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a01, s27), _mm_mul_pd(a11, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a01, s37), _mm_mul_pd(a11, s27));
        s67 = *((b + 17));
        s77 = v_neg23(*((b2 + 111)));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a21 = *((a9 + 2));
        a31 = *((a9 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a21, s87), _mm_mul_pd(a31, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a21, s97), _mm_mul_pd(a31, s87));
        s28 = *((b + 33));
        s38 = v_neg23(*((b2 + 95)));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a41 = *((a9 + 4));
        a51 = *((a9 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a41, s48), _mm_mul_pd(a51, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a41, s58), _mm_mul_pd(a51, s48));
        s88 = *((b + 49));
        s98 = v_neg23(*((b2 + 79)));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a61 = *((a9 + 6));
        a71 = *((a9 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a61, s09), _mm_mul_pd(a71, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a61, s19), _mm_mul_pd(a71, s09));
        s49 = *((b + 65));
        s59 = v_neg23(*((b2 + 63)));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a81 = *((a9 + 8));
        a91 = *((a9 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a81, s69), _mm_mul_pd(a91, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a81, s79), _mm_mul_pd(a91, s69));
        s0a = *((b + 81));
        s1a = v_neg23(*((b2 + 47)));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a02 = *((a9 + 10));
        a12 = *((a9 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a02, s2a), _mm_mul_pd(a12, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a02, s3a), _mm_mul_pd(a12, s2a));
        s6a = *((b + 97));
        s7a = v_neg23(*((b2 + 31)));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a22 = *((a9 + 12));
        a32 = *((a9 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a22, s8a), _mm_mul_pd(a32, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a22, s9a), _mm_mul_pd(a32, s8a));
        s2b = *((b + 113));
        s3b = v_neg23(*((b2 + 15)));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a42 = *((a9 + 14));
        a52 = *((a9 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a42, s4b), _mm_mul_pd(a52, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a42, s5b), _mm_mul_pd(a52, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a62, a72);
        s9b = _mm_add_pd(a62, a72);
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a82, a92);
        s1c = _mm_add_pd(a82, a92);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a03 = (D65 + a8);
        a13 = *(a03);
        a23 = *((a03 + 1));
        a33 = *((a03 + 2));
        a43 = *((a03 + 3));
        a53 = *((a03 + 4));
        a63 = *((a03 + 5));
        a73 = *((a03 + 6));
        a83 = *((a03 + 7));
        a93 = *((a03 + 8));
        a04 = *((a03 + 9));
        a14 = *((a03 + 10));
        a24 = *((a03 + 11));
        a34 = *((a03 + 12));
        a44 = *((a03 + 13));
        a54 = *((a03 + 14));
        a64 = *((a03 + 15));
        b3 = (((__m128d  *) T) + a8);
        s2c = _mm_sub_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a23, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a23, t98), _mm_mul_pd(a13, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a43, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a43, t39), _mm_mul_pd(a33, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a63, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a63, t79), _mm_mul_pd(a53, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a83, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a83, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a04, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a04, t19), _mm_mul_pd(a93, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a24, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a24, t59), _mm_mul_pd(a14, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a44, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a44, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a64, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a64, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a74 = (((__m128d  *) T) + i2);
        s8d = *(a74);
        s9d = *((a74 + 64));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a74 + 8));
        s1e = *((a74 + 72));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a74 + 32));
        s3e = *((a74 + 40));
        s4e = *((a74 + 96));
        s5e = *((a74 + 104));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a84, a94);
        s7e = _mm_add_pd(a84, a94);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a74 + 16));
        s9e = *((a74 + 24));
        s0f = *((a74 + 112));
        s1f = *((a74 + 120));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a74 + 80));
        s3f = *((a74 + 88));
        s4f = *((a74 + 48));
        s5f = *((a74 + 56));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t1c, t6c);
        t0d = _mm_add_pd(t2c, t5c);
        t1d = _mm_add_pd(t1c, t6c);
        t2d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9b, t3c));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0c, t4c));
        s8f = _mm_sub_pd(a05, a15);
        s9f = _mm_add_pd(a05, a15);
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d));
        a25 = (((__m128d  *) dst) + i2);
        s2g = _mm_add_pd(t1b, t7c);
        *(a25) = s2g;
        s3g = _mm_sub_pd(t1b, t7c);
        *((a25 + 64)) = s3g;
        s4g = _mm_sub_pd(t2b, t8c);
        *((a25 + 32)) = s4g;
        s5g = _mm_add_pd(t2b, t8c);
        *((a25 + 96)) = s5g;
        s6g = _mm_add_pd(t5b, s6f);
        *((a25 + 8)) = s6g;
        s7g = _mm_sub_pd(t5b, s6f);
        *((a25 + 72)) = s7g;
        s8g = _mm_sub_pd(t6b, s7f);
        *((a25 + 40)) = s8g;
        s9g = _mm_add_pd(t6b, s7f);
        *((a25 + 104)) = s9g;
        s0h = _mm_add_pd(t3b, s8f);
        *((a25 + 16)) = s0h;
        s1h = _mm_sub_pd(t3b, s8f);
        *((a25 + 80)) = s1h;
        s2h = _mm_sub_pd(t4b, s9f);
        *((a25 + 48)) = s2h;
        s3h = _mm_add_pd(t4b, s9f);
        *((a25 + 112)) = s3h;
        s4h = _mm_add_pd(t7b, s0g);
        *((a25 + 24)) = s4h;
        s5h = _mm_sub_pd(t7b, s0g);
        *((a25 + 88)) = s5h;
        s6h = _mm_sub_pd(t8b, s1g);
        *((a25 + 56)) = s6h;
        s7h = _mm_add_pd(t8b, s1g);
        *((a25 + 120)) = s7h;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_512_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[512]);
    __m128d a, a01, a02, a03, a04, a05, a11, a12, a13, a14, a15, a2, a21, a22, a23, a24, a25, a3, a31, a32, a33, a34
            , a4, a41, a42, a43, a44, a45, a51, a52, a53, a54, a55, a61, a62, a63, a65, a71, a72, a73, a74, a75, a81, a82
            , a83, a84, a85, a9, a91, a93, a94, a95, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d
            , s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d
            , s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c
            , s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b
            , s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59
            , s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s7, s71, s72, s73, s74, s75, s76, s77
            , s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s8, s81, s82, s83, s84, s85, s86
            , s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s9, s91, s92, s93, s94, s95
            , s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, t, t01, t02, t03, t04
            , t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t11, t12, t13, t14, t15, t16, t17, t18
            , t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b
            , t2c, t2d, t2e, t2f, t2g, t2h, t2i, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e
            , t3f, t3g, t3h, t3i, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h
            , t4i, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t6, t61
            , t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t8, t81, t82, t83, t84, t85, t86, t87
            , t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a
            , t9b, t9c, t9d, t9e, t9f, t9g, t9h;
    __m128d  *a5, *a64, *a8, *a92, *b3;
    double  *a35;
    const double  *b, *b2;
    int a6, a7;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 256))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 32)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 480))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 64)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 448))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 96)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 416))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 128)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 384))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 160)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 352))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 192)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 320))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 224)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 288))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a5 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a5) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a5 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a5 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a5 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a5 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a5 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a5 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a5 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a5 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a5 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a5 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a5 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a5 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a5 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a5 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a5 + 15)) = s96;
    {long i; for(i = 0; i <= 14; i++) {
        a6 = (2 * i);
        b = (src + a6);
        s07 = _mm_loadu_pd(((const double  *) (b + 2)));
        b2 = (src - a6);
        s17 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 510))));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a7 = (16 * i);
        a8 = (D67 + a7);
        a9 = *(a8);
        a01 = *((a8 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a9, s27), _mm_mul_pd(a01, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a9, s37), _mm_mul_pd(a01, s27));
        s67 = _mm_loadu_pd(((const double  *) (b + 66)));
        s77 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 446))));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a11 = *((a8 + 2));
        a21 = *((a8 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a11, s87), _mm_mul_pd(a21, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a11, s97), _mm_mul_pd(a21, s87));
        s28 = _mm_loadu_pd(((const double  *) (b + 130)));
        s38 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 382))));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a31 = *((a8 + 4));
        a41 = *((a8 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a31, s48), _mm_mul_pd(a41, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a31, s58), _mm_mul_pd(a41, s48));
        s88 = _mm_loadu_pd(((const double  *) (b + 194)));
        s98 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 318))));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a51 = *((a8 + 6));
        a61 = *((a8 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a51, s09), _mm_mul_pd(a61, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a51, s19), _mm_mul_pd(a61, s09));
        s49 = _mm_loadu_pd(((const double  *) (b + 258)));
        s59 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 254))));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a71 = *((a8 + 8));
        a81 = *((a8 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a71, s69), _mm_mul_pd(a81, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a71, s79), _mm_mul_pd(a81, s69));
        s0a = _mm_loadu_pd(((const double  *) (b + 322)));
        s1a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 190))));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a91 = *((a8 + 10));
        a02 = *((a8 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a91, s2a), _mm_mul_pd(a02, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a91, s3a), _mm_mul_pd(a02, s2a));
        s6a = _mm_loadu_pd(((const double  *) (b + 386)));
        s7a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 126))));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a12 = *((a8 + 12));
        a22 = *((a8 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a12, s8a), _mm_mul_pd(a22, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a12, s9a), _mm_mul_pd(a22, s8a));
        s2b = _mm_loadu_pd(((const double  *) (b + 450)));
        s3b = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 62))));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a32 = *((a8 + 14));
        a42 = *((a8 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a32, s4b), _mm_mul_pd(a42, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a32, s5b), _mm_mul_pd(a42, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a52, a62);
        s9b = _mm_add_pd(a52, a62);
        a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a72, a82);
        s1c = _mm_add_pd(a72, a82);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a92 = (D66 + a7);
        a03 = *(a92);
        a13 = *((a92 + 1));
        a23 = *((a92 + 2));
        a33 = *((a92 + 3));
        a43 = *((a92 + 4));
        a53 = *((a92 + 5));
        a63 = *((a92 + 6));
        a73 = *((a92 + 7));
        a83 = *((a92 + 8));
        a93 = *((a92 + 9));
        a04 = *((a92 + 10));
        a14 = *((a92 + 11));
        a24 = *((a92 + 12));
        a34 = *((a92 + 13));
        a44 = *((a92 + 14));
        a54 = *((a92 + 15));
        b3 = (((__m128d  *) T) + a7);
        s2c = _mm_sub_pd(_mm_mul_pd(a03, t98), _mm_mul_pd(a13, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a03, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a23, t39), _mm_mul_pd(a33, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a23, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a43, t79), _mm_mul_pd(a53, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a43, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a63, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a63, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a83, t19), _mm_mul_pd(a93, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a83, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a04, t59), _mm_mul_pd(a14, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a04, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a24, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a24, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a44, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a44, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a64 = (((__m128d  *) T) + i2);
        s8d = *(a64);
        s9d = *((a64 + 128));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a64 + 8));
        s1e = *((a64 + 136));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a64 + 64));
        s3e = *((a64 + 72));
        s4e = *((a64 + 192));
        s5e = *((a64 + 200));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a74, a84);
        s7e = _mm_add_pd(a74, a84);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a64 + 16));
        s9e = *((a64 + 24));
        s0f = *((a64 + 240));
        s1f = *((a64 + 248));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a64 + 144));
        s3f = *((a64 + 152));
        s4f = *((a64 + 112));
        s5f = *((a64 + 120));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t9b, t3c);
        t0d = _mm_sub_pd(t0c, t4c);
        t1d = _mm_sub_pd(t1c, t6c);
        t2d = _mm_add_pd(t2c, t5c);
        t3d = _mm_add_pd(t1c, t6c);
        t4d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1d), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1d), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2d));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s9f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3d), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4d));
        s2g = *((a64 + 32));
        s3g = *((a64 + 40));
        s4g = *((a64 + 224));
        s5g = *((a64 + 232));
        t5d = _mm_add_pd(s2g, s4g);
        t6d = _mm_sub_pd(s3g, s5g);
        t7d = _mm_sub_pd(s2g, s4g);
        t8d = _mm_add_pd(s3g, s5g);
        s6g = *((a64 + 160));
        s7g = *((a64 + 168));
        s8g = *((a64 + 96));
        s9g = *((a64 + 104));
        t9d = _mm_add_pd(s6g, s8g);
        t0e = _mm_sub_pd(s7g, s9g);
        t1e = _mm_sub_pd(s6g, s8g);
        t2e = _mm_add_pd(s7g, s9g);
        t3e = _mm_add_pd(t5d, t9d);
        t4e = _mm_add_pd(t6d, t0e);
        t5e = _mm_sub_pd(t7d, t2e);
        t6e = _mm_add_pd(t8d, t1e);
        t7e = _mm_add_pd(t7d, t2e);
        t8e = _mm_sub_pd(t8d, t1e);
        s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6e));
        s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6e));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t9d));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6d, t0e));
        s2h = _mm_sub_pd(a94, a05);
        s3h = _mm_add_pd(a94, a05);
        s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8e));
        s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8e));
        s6h = *((a64 + 48));
        s7h = *((a64 + 56));
        s8h = *((a64 + 208));
        s9h = *((a64 + 216));
        t9e = _mm_add_pd(s6h, s8h);
        t0f = _mm_sub_pd(s7h, s9h);
        t1f = _mm_sub_pd(s6h, s8h);
        t2f = _mm_add_pd(s7h, s9h);
        s0i = *((a64 + 176));
        s1i = *((a64 + 184));
        s2i = *((a64 + 80));
        s3i = *((a64 + 88));
        t3f = _mm_add_pd(s0i, s2i);
        t4f = _mm_sub_pd(s1i, s3i);
        t5f = _mm_sub_pd(s0i, s2i);
        t6f = _mm_add_pd(s1i, s3i);
        t7f = _mm_add_pd(t9e, t3f);
        t8f = _mm_add_pd(t0f, t4f);
        t9f = _mm_sub_pd(t9e, t3f);
        t0g = _mm_sub_pd(t0f, t4f);
        t1g = _mm_sub_pd(t1f, t6f);
        t2g = _mm_add_pd(t2f, t5f);
        t3g = _mm_add_pd(t1f, t6f);
        t4g = _mm_sub_pd(t2f, t5f);
        s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2g));
        s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2g));
        s6i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0g));
        s7i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0g));
        s8i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3g), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4g));
        s9i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3g), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4g));
        t5g = _mm_add_pd(t1b, t3e);
        t6g = _mm_sub_pd(t1b, t3e);
        t7g = _mm_sub_pd(t2b, t4e);
        t8g = _mm_add_pd(t2b, t4e);
        t9g = _mm_add_pd(t7c, t7f);
        t0h = _mm_sub_pd(t8c, t8f);
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7c, t7f));
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8c, t8f));
        s0j = _mm_sub_pd(a15, a25);
        s1j = _mm_add_pd(a15, a25);
        a35 = (dst + (2 * i2));
        s2j = _mm_add_pd(t5g, t9g);
        _mm_storeu_pd(((double  *) a35), s2j);
        s3j = _mm_sub_pd(t5g, t9g);
        _mm_storeu_pd(((double  *) (a35 + 256)), s3j);
        s4j = _mm_sub_pd(t6g, t0h);
        _mm_storeu_pd(((double  *) (a35 + 128)), s4j);
        s5j = _mm_add_pd(t6g, t0h);
        _mm_storeu_pd(((double  *) (a35 + 384)), s5j);
        s6j = _mm_add_pd(t7g, s0j);
        _mm_storeu_pd(((double  *) (a35 + 64)), s6j);
        s7j = _mm_sub_pd(t7g, s0j);
        _mm_storeu_pd(((double  *) (a35 + 320)), s7j);
        s8j = _mm_sub_pd(t8g, s1j);
        _mm_storeu_pd(((double  *) (a35 + 192)), s8j);
        s9j = _mm_add_pd(t8g, s1j);
        _mm_storeu_pd(((double  *) (a35 + 448)), s9j);
        t1h = _mm_add_pd(t5b, s0h);
        t2h = _mm_sub_pd(t5b, s0h);
        t3h = _mm_sub_pd(t6b, s1h);
        t4h = _mm_add_pd(t6b, s1h);
        t5h = _mm_add_pd(s6f, s4i);
        t6h = _mm_sub_pd(s7f, s5i);
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6f, s4i));
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7f, s5i));
        s0k = _mm_sub_pd(a45, a55);
        s1k = _mm_add_pd(a45, a55);
        s2k = _mm_add_pd(t1h, t5h);
        _mm_storeu_pd(((double  *) (a35 + 16)), s2k);
        s3k = _mm_sub_pd(t1h, t5h);
        _mm_storeu_pd(((double  *) (a35 + 272)), s3k);
        s4k = _mm_sub_pd(t2h, t6h);
        _mm_storeu_pd(((double  *) (a35 + 144)), s4k);
        s5k = _mm_add_pd(t2h, t6h);
        _mm_storeu_pd(((double  *) (a35 + 400)), s5k);
        s6k = _mm_add_pd(t3h, s0k);
        _mm_storeu_pd(((double  *) (a35 + 80)), s6k);
        s7k = _mm_sub_pd(t3h, s0k);
        _mm_storeu_pd(((double  *) (a35 + 336)), s7k);
        s8k = _mm_sub_pd(t4h, s1k);
        _mm_storeu_pd(((double  *) (a35 + 208)), s8k);
        s9k = _mm_add_pd(t4h, s1k);
        _mm_storeu_pd(((double  *) (a35 + 464)), s9k);
        t7h = _mm_add_pd(t3b, s2h);
        t8h = _mm_sub_pd(t3b, s2h);
        t9h = _mm_sub_pd(t4b, s3h);
        t0i = _mm_add_pd(t4b, s3h);
        t1i = _mm_add_pd(s8f, s6i);
        t2i = _mm_sub_pd(s9f, s7i);
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8f, s6i));
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9f, s7i));
        s0l = _mm_sub_pd(a65, a75);
        s1l = _mm_add_pd(a65, a75);
        s2l = _mm_add_pd(t7h, t1i);
        _mm_storeu_pd(((double  *) (a35 + 32)), s2l);
        s3l = _mm_sub_pd(t7h, t1i);
        _mm_storeu_pd(((double  *) (a35 + 288)), s3l);
        s4l = _mm_sub_pd(t8h, t2i);
        _mm_storeu_pd(((double  *) (a35 + 160)), s4l);
        s5l = _mm_add_pd(t8h, t2i);
        _mm_storeu_pd(((double  *) (a35 + 416)), s5l);
        s6l = _mm_add_pd(t9h, s0l);
        _mm_storeu_pd(((double  *) (a35 + 96)), s6l);
        s7l = _mm_sub_pd(t9h, s0l);
        _mm_storeu_pd(((double  *) (a35 + 352)), s7l);
        s8l = _mm_sub_pd(t0i, s1l);
        _mm_storeu_pd(((double  *) (a35 + 224)), s8l);
        s9l = _mm_add_pd(t0i, s1l);
        _mm_storeu_pd(((double  *) (a35 + 480)), s9l);
        t3i = _mm_add_pd(t7b, s4h);
        t4i = _mm_sub_pd(t7b, s4h);
        t5i = _mm_sub_pd(t8b, s5h);
        t6i = _mm_add_pd(t8b, s5h);
        t7i = _mm_add_pd(s0g, s8i);
        t8i = _mm_sub_pd(s1g, s9i);
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0g, s8i));
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1g, s9i));
        s0m = _mm_sub_pd(a85, a95);
        s1m = _mm_add_pd(a85, a95);
        s2m = _mm_add_pd(t3i, t7i);
        _mm_storeu_pd(((double  *) (a35 + 48)), s2m);
        s3m = _mm_sub_pd(t3i, t7i);
        _mm_storeu_pd(((double  *) (a35 + 304)), s3m);
        s4m = _mm_sub_pd(t4i, t8i);
        _mm_storeu_pd(((double  *) (a35 + 176)), s4m);
        s5m = _mm_add_pd(t4i, t8i);
        _mm_storeu_pd(((double  *) (a35 + 432)), s5m);
        s6m = _mm_add_pd(t5i, s0m);
        _mm_storeu_pd(((double  *) (a35 + 112)), s6m);
        s7m = _mm_sub_pd(t5i, s0m);
        _mm_storeu_pd(((double  *) (a35 + 368)), s7m);
        s8m = _mm_sub_pd(t6i, s1m);
        _mm_storeu_pd(((double  *) (a35 + 240)), s8m);
        s9m = _mm_add_pd(t6i, s1m);
        _mm_storeu_pd(((double  *) (a35 + 496)), s9m);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_512)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_512_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[512]);
    __m128d a01, a02, a04, a05, a06, a11, a12, a13, a14, a15, a2, a21, a22, a23, a24, a25, a3, a31, a32, a33, a34, a35
            , a4, a41, a42, a43, a44, a5, a51, a52, a53, a54, a55, a61, a62, a63, a64, a65, a71, a72, a73, a75, a81, a82
            , a83, a84, a85, a91, a92, a93, a94, a95, s, s01, s02, s03, s04, s05, s06, s07, s08, s09, s0a, s0b, s0c, s0d
            , s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d
            , s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c
            , s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b
            , s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a
            , s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59
            , s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s6, s61, s62, s63, s64, s65, s66, s67, s68
            , s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s7, s71, s72, s73, s74, s75, s76, s77
            , s78, s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s8, s81, s82, s83, s84, s85, s86
            , s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m, s9, s91, s92, s93, s94, s95
            , s96, s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, t, t01, t02, t03, t04
            , t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t11, t12, t13, t14, t15, t16, t17, t18
            , t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b
            , t2c, t2d, t2e, t2f, t2g, t2h, t2i, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e
            , t3f, t3g, t3h, t3i, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h
            , t4i, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t6, t61
            , t62, t63, t64, t65, t66, t67, t68, t69, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t8, t81, t82, t83, t84, t85, t86, t87
            , t88, t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a
            , t9b, t9c, t9d, t9e, t9f, t9g, t9h;
    __m128d  *a, *a03, *a45, *a6, *a7, *a74, *a9, *b, *b2, *b3;
    int a8;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 128)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 16));
    s5 = v_neg23(*((a + 240)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 32));
    s11 = v_neg23(*((a + 224)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 48));
    s71 = v_neg23(*((a + 208)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 64));
    s32 = v_neg23(*((a + 192)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 80));
    s92 = v_neg23(*((a + 176)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 96));
    s53 = v_neg23(*((a + 160)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 112));
    s14 = v_neg23(*((a + 144)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a6 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a6) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a6 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a6 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a6 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a6 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a6 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a6 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a6 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a6 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a6 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a6 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a6 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a6 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a6 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a6 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a6 + 15)) = s96;
    {long i; for(i = 0; i <= 14; i++) {
        a7 = ((__m128d  *) src);
        b = (a7 + i);
        s07 = *((b + 1));
        b2 = (a7 - i);
        s17 = v_neg23(*((b2 + 255)));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a8 = (16 * i);
        a9 = (D67 + a8);
        a01 = *(a9);
        a11 = *((a9 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a01, s27), _mm_mul_pd(a11, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a01, s37), _mm_mul_pd(a11, s27));
        s67 = *((b + 33));
        s77 = v_neg23(*((b2 + 223)));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a21 = *((a9 + 2));
        a31 = *((a9 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a21, s87), _mm_mul_pd(a31, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a21, s97), _mm_mul_pd(a31, s87));
        s28 = *((b + 65));
        s38 = v_neg23(*((b2 + 191)));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a41 = *((a9 + 4));
        a51 = *((a9 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a41, s48), _mm_mul_pd(a51, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a41, s58), _mm_mul_pd(a51, s48));
        s88 = *((b + 97));
        s98 = v_neg23(*((b2 + 159)));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a61 = *((a9 + 6));
        a71 = *((a9 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a61, s09), _mm_mul_pd(a71, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a61, s19), _mm_mul_pd(a71, s09));
        s49 = *((b + 129));
        s59 = v_neg23(*((b2 + 127)));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a81 = *((a9 + 8));
        a91 = *((a9 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a81, s69), _mm_mul_pd(a91, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a81, s79), _mm_mul_pd(a91, s69));
        s0a = *((b + 161));
        s1a = v_neg23(*((b2 + 95)));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a02 = *((a9 + 10));
        a12 = *((a9 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a02, s2a), _mm_mul_pd(a12, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a02, s3a), _mm_mul_pd(a12, s2a));
        s6a = *((b + 193));
        s7a = v_neg23(*((b2 + 63)));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a22 = *((a9 + 12));
        a32 = *((a9 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a22, s8a), _mm_mul_pd(a32, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a22, s9a), _mm_mul_pd(a32, s8a));
        s2b = *((b + 225));
        s3b = v_neg23(*((b2 + 31)));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a42 = *((a9 + 14));
        a52 = *((a9 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a42, s4b), _mm_mul_pd(a52, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a42, s5b), _mm_mul_pd(a52, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a62, a72);
        s9b = _mm_add_pd(a62, a72);
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a82, a92);
        s1c = _mm_add_pd(a82, a92);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a03 = (D68 + a8);
        a13 = *(a03);
        a23 = *((a03 + 1));
        a33 = *((a03 + 2));
        a43 = *((a03 + 3));
        a53 = *((a03 + 4));
        a63 = *((a03 + 5));
        a73 = *((a03 + 6));
        a83 = *((a03 + 7));
        a93 = *((a03 + 8));
        a04 = *((a03 + 9));
        a14 = *((a03 + 10));
        a24 = *((a03 + 11));
        a34 = *((a03 + 12));
        a44 = *((a03 + 13));
        a54 = *((a03 + 14));
        a64 = *((a03 + 15));
        b3 = (((__m128d  *) T) + a8);
        s2c = _mm_sub_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a23, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a23, t98), _mm_mul_pd(a13, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a43, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a43, t39), _mm_mul_pd(a33, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a63, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a63, t79), _mm_mul_pd(a53, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a83, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a83, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a04, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a04, t19), _mm_mul_pd(a93, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a24, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a24, t59), _mm_mul_pd(a14, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a44, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a44, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a64, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a64, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a74 = (((__m128d  *) T) + i2);
        s8d = *(a74);
        s9d = *((a74 + 128));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a74 + 8));
        s1e = *((a74 + 136));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a74 + 64));
        s3e = *((a74 + 72));
        s4e = *((a74 + 192));
        s5e = *((a74 + 200));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a84, a94);
        s7e = _mm_add_pd(a84, a94);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a74 + 16));
        s9e = *((a74 + 24));
        s0f = *((a74 + 240));
        s1f = *((a74 + 248));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a74 + 144));
        s3f = *((a74 + 152));
        s4f = *((a74 + 112));
        s5f = *((a74 + 120));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t9b, t3c);
        t0d = _mm_sub_pd(t0c, t4c);
        t1d = _mm_sub_pd(t1c, t6c);
        t2d = _mm_add_pd(t2c, t5c);
        t3d = _mm_add_pd(t1c, t6c);
        t4d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1d), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1d), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2d));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s9f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3d), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3d), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4d));
        s2g = *((a74 + 32));
        s3g = *((a74 + 40));
        s4g = *((a74 + 224));
        s5g = *((a74 + 232));
        t5d = _mm_add_pd(s2g, s4g);
        t6d = _mm_sub_pd(s3g, s5g);
        t7d = _mm_sub_pd(s2g, s4g);
        t8d = _mm_add_pd(s3g, s5g);
        s6g = *((a74 + 160));
        s7g = *((a74 + 168));
        s8g = *((a74 + 96));
        s9g = *((a74 + 104));
        t9d = _mm_add_pd(s6g, s8g);
        t0e = _mm_sub_pd(s7g, s9g);
        t1e = _mm_sub_pd(s6g, s8g);
        t2e = _mm_add_pd(s7g, s9g);
        t3e = _mm_add_pd(t5d, t9d);
        t4e = _mm_add_pd(t6d, t0e);
        t5e = _mm_sub_pd(t7d, t2e);
        t6e = _mm_add_pd(t8d, t1e);
        t7e = _mm_add_pd(t7d, t2e);
        t8e = _mm_sub_pd(t8d, t1e);
        s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6e));
        s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6e));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5d, t9d));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6d, t0e));
        s2h = _mm_sub_pd(a05, a15);
        s3h = _mm_add_pd(a05, a15);
        s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8e));
        s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8e));
        s6h = *((a74 + 48));
        s7h = *((a74 + 56));
        s8h = *((a74 + 208));
        s9h = *((a74 + 216));
        t9e = _mm_add_pd(s6h, s8h);
        t0f = _mm_sub_pd(s7h, s9h);
        t1f = _mm_sub_pd(s6h, s8h);
        t2f = _mm_add_pd(s7h, s9h);
        s0i = *((a74 + 176));
        s1i = *((a74 + 184));
        s2i = *((a74 + 80));
        s3i = *((a74 + 88));
        t3f = _mm_add_pd(s0i, s2i);
        t4f = _mm_sub_pd(s1i, s3i);
        t5f = _mm_sub_pd(s0i, s2i);
        t6f = _mm_add_pd(s1i, s3i);
        t7f = _mm_add_pd(t9e, t3f);
        t8f = _mm_add_pd(t0f, t4f);
        t9f = _mm_sub_pd(t9e, t3f);
        t0g = _mm_sub_pd(t0f, t4f);
        t1g = _mm_sub_pd(t1f, t6f);
        t2g = _mm_add_pd(t2f, t5f);
        t3g = _mm_add_pd(t1f, t6f);
        t4g = _mm_sub_pd(t2f, t5f);
        s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2g));
        s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2g));
        s6i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0g));
        s7i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0g));
        s8i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3g), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4g));
        s9i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3g), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4g));
        t5g = _mm_add_pd(t1b, t3e);
        t6g = _mm_sub_pd(t1b, t3e);
        t7g = _mm_sub_pd(t2b, t4e);
        t8g = _mm_add_pd(t2b, t4e);
        t9g = _mm_add_pd(t7c, t7f);
        t0h = _mm_sub_pd(t8c, t8f);
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7c, t7f));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8c, t8f));
        s0j = _mm_sub_pd(a25, a35);
        s1j = _mm_add_pd(a25, a35);
        a45 = (((__m128d  *) dst) + i2);
        s2j = _mm_add_pd(t5g, t9g);
        *(a45) = s2j;
        s3j = _mm_sub_pd(t5g, t9g);
        *((a45 + 128)) = s3j;
        s4j = _mm_sub_pd(t6g, t0h);
        *((a45 + 64)) = s4j;
        s5j = _mm_add_pd(t6g, t0h);
        *((a45 + 192)) = s5j;
        s6j = _mm_add_pd(t7g, s0j);
        *((a45 + 32)) = s6j;
        s7j = _mm_sub_pd(t7g, s0j);
        *((a45 + 160)) = s7j;
        s8j = _mm_sub_pd(t8g, s1j);
        *((a45 + 96)) = s8j;
        s9j = _mm_add_pd(t8g, s1j);
        *((a45 + 224)) = s9j;
        t1h = _mm_add_pd(t5b, s0h);
        t2h = _mm_sub_pd(t5b, s0h);
        t3h = _mm_sub_pd(t6b, s1h);
        t4h = _mm_add_pd(t6b, s1h);
        t5h = _mm_add_pd(s6f, s4i);
        t6h = _mm_sub_pd(s7f, s5i);
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6f, s4i));
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7f, s5i));
        s0k = _mm_sub_pd(a55, a65);
        s1k = _mm_add_pd(a55, a65);
        s2k = _mm_add_pd(t1h, t5h);
        *((a45 + 8)) = s2k;
        s3k = _mm_sub_pd(t1h, t5h);
        *((a45 + 136)) = s3k;
        s4k = _mm_sub_pd(t2h, t6h);
        *((a45 + 72)) = s4k;
        s5k = _mm_add_pd(t2h, t6h);
        *((a45 + 200)) = s5k;
        s6k = _mm_add_pd(t3h, s0k);
        *((a45 + 40)) = s6k;
        s7k = _mm_sub_pd(t3h, s0k);
        *((a45 + 168)) = s7k;
        s8k = _mm_sub_pd(t4h, s1k);
        *((a45 + 104)) = s8k;
        s9k = _mm_add_pd(t4h, s1k);
        *((a45 + 232)) = s9k;
        t7h = _mm_add_pd(t3b, s2h);
        t8h = _mm_sub_pd(t3b, s2h);
        t9h = _mm_sub_pd(t4b, s3h);
        t0i = _mm_add_pd(t4b, s3h);
        t1i = _mm_add_pd(s8f, s6i);
        t2i = _mm_sub_pd(s9f, s7i);
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8f, s6i));
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9f, s7i));
        s0l = _mm_sub_pd(a75, a85);
        s1l = _mm_add_pd(a75, a85);
        s2l = _mm_add_pd(t7h, t1i);
        *((a45 + 16)) = s2l;
        s3l = _mm_sub_pd(t7h, t1i);
        *((a45 + 144)) = s3l;
        s4l = _mm_sub_pd(t8h, t2i);
        *((a45 + 80)) = s4l;
        s5l = _mm_add_pd(t8h, t2i);
        *((a45 + 208)) = s5l;
        s6l = _mm_add_pd(t9h, s0l);
        *((a45 + 48)) = s6l;
        s7l = _mm_sub_pd(t9h, s0l);
        *((a45 + 176)) = s7l;
        s8l = _mm_sub_pd(t0i, s1l);
        *((a45 + 112)) = s8l;
        s9l = _mm_add_pd(t0i, s1l);
        *((a45 + 240)) = s9l;
        t3i = _mm_add_pd(t7b, s4h);
        t4i = _mm_sub_pd(t7b, s4h);
        t5i = _mm_sub_pd(t8b, s5h);
        t6i = _mm_add_pd(t8b, s5h);
        t7i = _mm_add_pd(s0g, s8i);
        t8i = _mm_sub_pd(s1g, s9i);
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0g, s8i));
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1g, s9i));
        s0m = _mm_sub_pd(a95, a06);
        s1m = _mm_add_pd(a95, a06);
        s2m = _mm_add_pd(t3i, t7i);
        *((a45 + 24)) = s2m;
        s3m = _mm_sub_pd(t3i, t7i);
        *((a45 + 152)) = s3m;
        s4m = _mm_sub_pd(t4i, t8i);
        *((a45 + 88)) = s4m;
        s5m = _mm_add_pd(t4i, t8i);
        *((a45 + 216)) = s5m;
        s6m = _mm_add_pd(t5i, s0m);
        *((a45 + 56)) = s6m;
        s7m = _mm_sub_pd(t5i, s0m);
        *((a45 + 184)) = s7m;
        s8m = _mm_sub_pd(t6i, s1m);
        *((a45 + 120)) = s8m;
        s9m = _mm_add_pd(t6i, s1m);
        *((a45 + 248)) = s9m;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_1024_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[1024]);
    __m128d a, a01, a02, a03, a04, a05, a06, a11, a12, a13, a14, a15, a16, a2, a21, a22, a23, a24, a25, a26, a3, a31
            , a32, a33, a34, a35, a36, a4, a41, a42, a43, a44, a45, a46, a51, a52, a53, a54, a56, a61, a62, a63, a65, a66
            , a71, a72, a73, a74, a75, a76, a81, a82, a83, a84, a85, a9, a91, a93, a94, a95, s, s01, s02, s03, s04, s05
            , s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r
            , s0s, s0t, s0u, s0v, s0w, s0x, s0y, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f
            , s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s2, s21, s22
            , s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c
            , s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s4
            , s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m
            , s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a
            , s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w
            , s5x, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k
            , s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s7, s71, s72, s73, s74, s75, s76, s77, s78
            , s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u
            , s7v, s7w, s7x, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i
            , s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s9, s91, s92, s93, s94, s95, s96
            , s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s
            , s9t, s9u, s9v, s9w, s9x, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g
            , t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t11, t12, t13, t14
            , t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q
            , t1r, t1s, t1t, t1u, t1v, t1w, t1x, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e
            , t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t3, t31, t32
            , t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o
            , t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c
            , t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t5
            , t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m
            , t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w
            , t6x, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k
            , t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t8, t81, t82, t83, t84, t85, t86, t87, t88
            , t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u
            , t8v, t8w, t8x, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i
            , t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x;
    __m128d  *a5, *a64, *a8, *a92, *b3;
    double  *a55;
    const double  *b, *b2;
    int a6, a7;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 512))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 64)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 960))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 128)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 896))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 192)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 832))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 256)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 768))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 320)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 704))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 384)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 640))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 448)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 576))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a5 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a5) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a5 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a5 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a5 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a5 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a5 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a5 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a5 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a5 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a5 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a5 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a5 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a5 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a5 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a5 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a5 + 15)) = s96;
    {long i; for(i = 0; i <= 30; i++) {
        a6 = (2 * i);
        b = (src + a6);
        s07 = _mm_loadu_pd(((const double  *) (b + 2)));
        b2 = (src - a6);
        s17 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1022))));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a7 = (16 * i);
        a8 = (D70 + a7);
        a9 = *(a8);
        a01 = *((a8 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a9, s27), _mm_mul_pd(a01, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a9, s37), _mm_mul_pd(a01, s27));
        s67 = _mm_loadu_pd(((const double  *) (b + 130)));
        s77 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 894))));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a11 = *((a8 + 2));
        a21 = *((a8 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a11, s87), _mm_mul_pd(a21, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a11, s97), _mm_mul_pd(a21, s87));
        s28 = _mm_loadu_pd(((const double  *) (b + 258)));
        s38 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 766))));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a31 = *((a8 + 4));
        a41 = *((a8 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a31, s48), _mm_mul_pd(a41, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a31, s58), _mm_mul_pd(a41, s48));
        s88 = _mm_loadu_pd(((const double  *) (b + 386)));
        s98 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 638))));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a51 = *((a8 + 6));
        a61 = *((a8 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a51, s09), _mm_mul_pd(a61, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a51, s19), _mm_mul_pd(a61, s09));
        s49 = _mm_loadu_pd(((const double  *) (b + 514)));
        s59 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 510))));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a71 = *((a8 + 8));
        a81 = *((a8 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a71, s69), _mm_mul_pd(a81, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a71, s79), _mm_mul_pd(a81, s69));
        s0a = _mm_loadu_pd(((const double  *) (b + 642)));
        s1a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 382))));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a91 = *((a8 + 10));
        a02 = *((a8 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a91, s2a), _mm_mul_pd(a02, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a91, s3a), _mm_mul_pd(a02, s2a));
        s6a = _mm_loadu_pd(((const double  *) (b + 770)));
        s7a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 254))));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a12 = *((a8 + 12));
        a22 = *((a8 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a12, s8a), _mm_mul_pd(a22, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a12, s9a), _mm_mul_pd(a22, s8a));
        s2b = _mm_loadu_pd(((const double  *) (b + 898)));
        s3b = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 126))));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a32 = *((a8 + 14));
        a42 = *((a8 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a32, s4b), _mm_mul_pd(a42, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a32, s5b), _mm_mul_pd(a42, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a52, a62);
        s9b = _mm_add_pd(a52, a62);
        a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a72, a82);
        s1c = _mm_add_pd(a72, a82);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a92 = (D69 + a7);
        a03 = *(a92);
        a13 = *((a92 + 1));
        a23 = *((a92 + 2));
        a33 = *((a92 + 3));
        a43 = *((a92 + 4));
        a53 = *((a92 + 5));
        a63 = *((a92 + 6));
        a73 = *((a92 + 7));
        a83 = *((a92 + 8));
        a93 = *((a92 + 9));
        a04 = *((a92 + 10));
        a14 = *((a92 + 11));
        a24 = *((a92 + 12));
        a34 = *((a92 + 13));
        a44 = *((a92 + 14));
        a54 = *((a92 + 15));
        b3 = (((__m128d  *) T) + a7);
        s2c = _mm_sub_pd(_mm_mul_pd(a03, t98), _mm_mul_pd(a13, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a03, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a23, t39), _mm_mul_pd(a33, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a23, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a43, t79), _mm_mul_pd(a53, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a43, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a63, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a63, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a83, t19), _mm_mul_pd(a93, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a83, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a04, t59), _mm_mul_pd(a14, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a04, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a24, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a24, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a44, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a44, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a64 = (((__m128d  *) T) + i2);
        s8d = *(a64);
        s9d = *((a64 + 256));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a64 + 8));
        s1e = *((a64 + 264));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a64 + 128));
        s3e = *((a64 + 136));
        s4e = *((a64 + 384));
        s5e = *((a64 + 392));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a74, a84);
        s7e = _mm_add_pd(a74, a84);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a64 + 16));
        s9e = *((a64 + 24));
        s0f = *((a64 + 496));
        s1f = *((a64 + 504));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a64 + 272));
        s3f = *((a64 + 280));
        s4f = *((a64 + 240));
        s5f = *((a64 + 248));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t9b, t3c);
        t0d = _mm_sub_pd(t0c, t4c);
        t1d = _mm_sub_pd(t1c, t6c);
        t2d = _mm_add_pd(t2c, t5c);
        t3d = _mm_add_pd(t1c, t6c);
        t4d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1d), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1d), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2d));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0d));
        s9f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0d));
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3d), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3d), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4d));
        s2g = *((a64 + 32));
        s3g = *((a64 + 40));
        s4g = *((a64 + 480));
        s5g = *((a64 + 488));
        t5d = _mm_add_pd(s2g, s4g);
        t6d = _mm_sub_pd(s3g, s5g);
        t7d = _mm_sub_pd(s2g, s4g);
        t8d = _mm_add_pd(s3g, s5g);
        s6g = *((a64 + 288));
        s7g = *((a64 + 296));
        s8g = *((a64 + 224));
        s9g = *((a64 + 232));
        t9d = _mm_add_pd(s6g, s8g);
        t0e = _mm_sub_pd(s7g, s9g);
        t1e = _mm_sub_pd(s6g, s8g);
        t2e = _mm_add_pd(s7g, s9g);
        t3e = _mm_add_pd(t5d, t9d);
        t4e = _mm_add_pd(t6d, t0e);
        t5e = _mm_sub_pd(t5d, t9d);
        t6e = _mm_sub_pd(t6d, t0e);
        t7e = _mm_sub_pd(t7d, t2e);
        t8e = _mm_add_pd(t8d, t1e);
        t9e = _mm_add_pd(t7d, t2e);
        t0f = _mm_sub_pd(t8d, t1e);
        s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7e), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8e));
        s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7e), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8e));
        s2h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6e));
        s3h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6e));
        s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9e), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0f));
        s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9e), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0f));
        s6h = *((a64 + 48));
        s7h = *((a64 + 56));
        s8h = *((a64 + 464));
        s9h = *((a64 + 472));
        t1f = _mm_add_pd(s6h, s8h);
        t2f = _mm_sub_pd(s7h, s9h);
        t3f = _mm_sub_pd(s6h, s8h);
        t4f = _mm_add_pd(s7h, s9h);
        s0i = *((a64 + 304));
        s1i = *((a64 + 312));
        s2i = *((a64 + 208));
        s3i = *((a64 + 216));
        t5f = _mm_add_pd(s0i, s2i);
        t6f = _mm_sub_pd(s1i, s3i);
        t7f = _mm_sub_pd(s0i, s2i);
        t8f = _mm_add_pd(s1i, s3i);
        t9f = _mm_add_pd(t1f, t5f);
        t0g = _mm_add_pd(t2f, t6f);
        t1g = _mm_sub_pd(t1f, t5f);
        t2g = _mm_sub_pd(t2f, t6f);
        t3g = _mm_sub_pd(t3f, t8f);
        t4g = _mm_add_pd(t4f, t7f);
        t5g = _mm_add_pd(t3f, t8f);
        t6g = _mm_sub_pd(t4f, t7f);
        s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3g), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4g));
        s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4g));
        s6i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2g));
        s7i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2g));
        s8i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5g), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6g));
        s9i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5g), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6g));
        s0j = *((a64 + 64));
        s1j = *((a64 + 72));
        s2j = *((a64 + 448));
        s3j = *((a64 + 456));
        t7g = _mm_add_pd(s0j, s2j);
        t8g = _mm_sub_pd(s1j, s3j);
        t9g = _mm_sub_pd(s0j, s2j);
        t0h = _mm_add_pd(s1j, s3j);
        s4j = *((a64 + 320));
        s5j = *((a64 + 328));
        s6j = *((a64 + 192));
        s7j = *((a64 + 200));
        t1h = _mm_add_pd(s4j, s6j);
        t2h = _mm_sub_pd(s5j, s7j);
        t3h = _mm_sub_pd(s4j, s6j);
        t4h = _mm_add_pd(s5j, s7j);
        t5h = _mm_add_pd(t7g, t1h);
        t6h = _mm_add_pd(t8g, t2h);
        t7h = _mm_sub_pd(t9g, t4h);
        t8h = _mm_add_pd(t0h, t3h);
        t9h = _mm_add_pd(t9g, t4h);
        t0i = _mm_sub_pd(t0h, t3h);
        s8j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8h));
        s9j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8h));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7g, t1h));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8g, t2h));
        s0k = _mm_sub_pd(a94, a05);
        s1k = _mm_add_pd(a94, a05);
        s2k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0i));
        s3k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0i));
        s4k = *((a64 + 80));
        s5k = *((a64 + 88));
        s6k = *((a64 + 432));
        s7k = *((a64 + 440));
        t1i = _mm_add_pd(s4k, s6k);
        t2i = _mm_sub_pd(s5k, s7k);
        t3i = _mm_sub_pd(s4k, s6k);
        t4i = _mm_add_pd(s5k, s7k);
        s8k = *((a64 + 336));
        s9k = *((a64 + 344));
        s0l = *((a64 + 176));
        s1l = *((a64 + 184));
        t5i = _mm_add_pd(s8k, s0l);
        t6i = _mm_sub_pd(s9k, s1l);
        t7i = _mm_sub_pd(s8k, s0l);
        t8i = _mm_add_pd(s9k, s1l);
        t9i = _mm_add_pd(t1i, t5i);
        t0j = _mm_add_pd(t2i, t6i);
        t1j = _mm_sub_pd(t1i, t5i);
        t2j = _mm_sub_pd(t2i, t6i);
        t3j = _mm_sub_pd(t3i, t8i);
        t4j = _mm_add_pd(t4i, t7i);
        t5j = _mm_add_pd(t3i, t8i);
        t6j = _mm_sub_pd(t4i, t7i);
        s2l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t3j), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t4j));
        s3l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t3j), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t4j));
        s4l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1j), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2j));
        s5l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1j), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2j));
        s6l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t5j), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t6j));
        s7l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t5j), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t6j));
        s8l = *((a64 + 96));
        s9l = *((a64 + 104));
        s0m = *((a64 + 416));
        s1m = *((a64 + 424));
        t7j = _mm_add_pd(s8l, s0m);
        t8j = _mm_sub_pd(s9l, s1m);
        t9j = _mm_sub_pd(s8l, s0m);
        t0k = _mm_add_pd(s9l, s1m);
        s2m = *((a64 + 352));
        s3m = *((a64 + 360));
        s4m = *((a64 + 160));
        s5m = *((a64 + 168));
        t1k = _mm_add_pd(s2m, s4m);
        t2k = _mm_sub_pd(s3m, s5m);
        t3k = _mm_sub_pd(s2m, s4m);
        t4k = _mm_add_pd(s3m, s5m);
        t5k = _mm_add_pd(t7j, t1k);
        t6k = _mm_add_pd(t8j, t2k);
        t7k = _mm_sub_pd(t7j, t1k);
        t8k = _mm_sub_pd(t8j, t2k);
        t9k = _mm_sub_pd(t9j, t4k);
        t0l = _mm_add_pd(t0k, t3k);
        t1l = _mm_add_pd(t9j, t4k);
        t2l = _mm_sub_pd(t0k, t3k);
        s6m = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9k), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0l));
        s7m = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9k), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0l));
        s8m = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k));
        s9m = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8k));
        s0n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1l), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2l));
        s1n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1l), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2l));
        s2n = *((a64 + 112));
        s3n = *((a64 + 120));
        s4n = *((a64 + 400));
        s5n = *((a64 + 408));
        t3l = _mm_add_pd(s2n, s4n);
        t4l = _mm_sub_pd(s3n, s5n);
        t5l = _mm_sub_pd(s2n, s4n);
        t6l = _mm_add_pd(s3n, s5n);
        s6n = *((a64 + 368));
        s7n = *((a64 + 376));
        s8n = *((a64 + 144));
        s9n = *((a64 + 152));
        t7l = _mm_add_pd(s6n, s8n);
        t8l = _mm_sub_pd(s7n, s9n);
        t9l = _mm_sub_pd(s6n, s8n);
        t0m = _mm_add_pd(s7n, s9n);
        t1m = _mm_add_pd(t3l, t7l);
        t2m = _mm_add_pd(t4l, t8l);
        t3m = _mm_sub_pd(t3l, t7l);
        t4m = _mm_sub_pd(t4l, t8l);
        t5m = _mm_sub_pd(t5l, t0m);
        t6m = _mm_add_pd(t6l, t9l);
        t7m = _mm_add_pd(t5l, t0m);
        t8m = _mm_sub_pd(t6l, t9l);
        s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5m), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6m));
        s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5m), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6m));
        s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3m), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4m));
        s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3m), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4m));
        s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7m), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8m));
        s5o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7m), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8m));
        t9m = _mm_add_pd(t1b, t5h);
        t0n = _mm_sub_pd(t1b, t5h);
        t1n = _mm_sub_pd(t2b, t6h);
        t2n = _mm_add_pd(t2b, t6h);
        t3n = _mm_add_pd(t3e, t5k);
        t4n = _mm_sub_pd(t4e, t6k);
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3e, t5k));
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4e, t6k));
        s6o = _mm_sub_pd(a15, a25);
        s7o = _mm_add_pd(a15, a25);
        t5n = _mm_add_pd(t9m, t3n);
        t6n = _mm_sub_pd(t9m, t3n);
        t7n = _mm_sub_pd(t0n, t4n);
        t8n = _mm_add_pd(t0n, t4n);
        t9n = _mm_add_pd(t1n, s6o);
        t0o = _mm_sub_pd(t1n, s6o);
        t1o = _mm_sub_pd(t2n, s7o);
        t2o = _mm_add_pd(t2n, s7o);
        t3o = _mm_add_pd(t7c, t1m);
        t4o = _mm_sub_pd(t8c, t2m);
        t5o = _mm_sub_pd(t7c, t1m);
        t6o = _mm_add_pd(t8c, t2m);
        t7o = _mm_add_pd(t9i, t9f);
        t8o = _mm_sub_pd(t0j, t0g);
        t9o = _mm_sub_pd(t9i, t9f);
        t0p = _mm_add_pd(t0j, t0g);
        t1p = _mm_add_pd(t3o, t7o);
        t2p = _mm_add_pd(t4o, t8o);
        t3p = _mm_sub_pd(t5o, t0p);
        t4p = _mm_add_pd(t6o, t9o);
        t5p = _mm_add_pd(t5o, t0p);
        t6p = _mm_sub_pd(t6o, t9o);
        s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4p));
        s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4p));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3o, t7o));
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4o, t8o));
        s0p = _mm_sub_pd(a35, a45);
        s1p = _mm_add_pd(a35, a45);
        s2p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6p));
        s3p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6p));
        a55 = (dst + (2 * i2));
        s4p = _mm_add_pd(t5n, t1p);
        _mm_storeu_pd(((double  *) a55), s4p);
        s5p = _mm_sub_pd(t5n, t1p);
        _mm_storeu_pd(((double  *) (a55 + 512)), s5p);
        s6p = _mm_sub_pd(t6n, t2p);
        _mm_storeu_pd(((double  *) (a55 + 256)), s6p);
        s7p = _mm_add_pd(t6n, t2p);
        _mm_storeu_pd(((double  *) (a55 + 768)), s7p);
        s8p = _mm_add_pd(t9n, s8o);
        _mm_storeu_pd(((double  *) (a55 + 64)), s8p);
        s9p = _mm_sub_pd(t9n, s8o);
        _mm_storeu_pd(((double  *) (a55 + 576)), s9p);
        s0q = _mm_sub_pd(t0o, s9o);
        _mm_storeu_pd(((double  *) (a55 + 320)), s0q);
        s1q = _mm_add_pd(t0o, s9o);
        _mm_storeu_pd(((double  *) (a55 + 832)), s1q);
        s2q = _mm_add_pd(t7n, s0p);
        _mm_storeu_pd(((double  *) (a55 + 128)), s2q);
        s3q = _mm_sub_pd(t7n, s0p);
        _mm_storeu_pd(((double  *) (a55 + 640)), s3q);
        s4q = _mm_sub_pd(t8n, s1p);
        _mm_storeu_pd(((double  *) (a55 + 384)), s4q);
        s5q = _mm_add_pd(t8n, s1p);
        _mm_storeu_pd(((double  *) (a55 + 896)), s5q);
        s6q = _mm_add_pd(t1o, s2p);
        _mm_storeu_pd(((double  *) (a55 + 192)), s6q);
        s7q = _mm_sub_pd(t1o, s2p);
        _mm_storeu_pd(((double  *) (a55 + 704)), s7q);
        s8q = _mm_sub_pd(t2o, s3p);
        _mm_storeu_pd(((double  *) (a55 + 448)), s8q);
        s9q = _mm_add_pd(t2o, s3p);
        _mm_storeu_pd(((double  *) (a55 + 960)), s9q);
        t7p = _mm_add_pd(t5b, s8j);
        t8p = _mm_sub_pd(t5b, s8j);
        t9p = _mm_sub_pd(t6b, s9j);
        t0q = _mm_add_pd(t6b, s9j);
        t1q = _mm_add_pd(s0h, s6m);
        t2q = _mm_sub_pd(s1h, s7m);
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0h, s6m));
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1h, s7m));
        s0r = _mm_sub_pd(a65, a75);
        s1r = _mm_add_pd(a65, a75);
        t3q = _mm_add_pd(t7p, t1q);
        t4q = _mm_sub_pd(t7p, t1q);
        t5q = _mm_sub_pd(t8p, t2q);
        t6q = _mm_add_pd(t8p, t2q);
        t7q = _mm_add_pd(t9p, s0r);
        t8q = _mm_sub_pd(t9p, s0r);
        t9q = _mm_sub_pd(t0q, s1r);
        t0r = _mm_add_pd(t0q, s1r);
        t1r = _mm_add_pd(s6f, s0o);
        t2r = _mm_sub_pd(s7f, s1o);
        t3r = _mm_sub_pd(s6f, s0o);
        t4r = _mm_add_pd(s7f, s1o);
        t5r = _mm_add_pd(s2l, s4i);
        t6r = _mm_sub_pd(s3l, s5i);
        t7r = _mm_sub_pd(s2l, s4i);
        t8r = _mm_add_pd(s3l, s5i);
        t9r = _mm_add_pd(t1r, t5r);
        t0s = _mm_add_pd(t2r, t6r);
        t1s = _mm_sub_pd(t3r, t8r);
        t2s = _mm_add_pd(t4r, t7r);
        t3s = _mm_add_pd(t3r, t8r);
        t4s = _mm_sub_pd(t4r, t7r);
        s2r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2s));
        s3r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1s), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2s));
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1r, t5r));
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2r, t6r));
        s4r = _mm_sub_pd(a85, a95);
        s5r = _mm_add_pd(a85, a95);
        s6r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3s), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4s));
        s7r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4s));
        s8r = _mm_add_pd(t3q, t9r);
        _mm_storeu_pd(((double  *) (a55 + 16)), s8r);
        s9r = _mm_sub_pd(t3q, t9r);
        _mm_storeu_pd(((double  *) (a55 + 528)), s9r);
        s0s = _mm_sub_pd(t4q, t0s);
        _mm_storeu_pd(((double  *) (a55 + 272)), s0s);
        s1s = _mm_add_pd(t4q, t0s);
        _mm_storeu_pd(((double  *) (a55 + 784)), s1s);
        s2s = _mm_add_pd(t7q, s2r);
        _mm_storeu_pd(((double  *) (a55 + 80)), s2s);
        s3s = _mm_sub_pd(t7q, s2r);
        _mm_storeu_pd(((double  *) (a55 + 592)), s3s);
        s4s = _mm_sub_pd(t8q, s3r);
        _mm_storeu_pd(((double  *) (a55 + 336)), s4s);
        s5s = _mm_add_pd(t8q, s3r);
        _mm_storeu_pd(((double  *) (a55 + 848)), s5s);
        s6s = _mm_add_pd(t5q, s4r);
        _mm_storeu_pd(((double  *) (a55 + 144)), s6s);
        s7s = _mm_sub_pd(t5q, s4r);
        _mm_storeu_pd(((double  *) (a55 + 656)), s7s);
        s8s = _mm_sub_pd(t6q, s5r);
        _mm_storeu_pd(((double  *) (a55 + 400)), s8s);
        s9s = _mm_add_pd(t6q, s5r);
        _mm_storeu_pd(((double  *) (a55 + 912)), s9s);
        s0t = _mm_add_pd(t9q, s6r);
        _mm_storeu_pd(((double  *) (a55 + 208)), s0t);
        s1t = _mm_sub_pd(t9q, s6r);
        _mm_storeu_pd(((double  *) (a55 + 720)), s1t);
        s2t = _mm_sub_pd(t0r, s7r);
        _mm_storeu_pd(((double  *) (a55 + 464)), s2t);
        s3t = _mm_add_pd(t0r, s7r);
        _mm_storeu_pd(((double  *) (a55 + 976)), s3t);
        t5s = _mm_add_pd(t3b, s0k);
        t6s = _mm_sub_pd(t3b, s0k);
        t7s = _mm_sub_pd(t4b, s1k);
        t8s = _mm_add_pd(t4b, s1k);
        t9s = _mm_add_pd(s2h, s8m);
        t0t = _mm_sub_pd(s3h, s9m);
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2h, s8m));
        a16 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3h, s9m));
        s4t = _mm_sub_pd(a06, a16);
        s5t = _mm_add_pd(a06, a16);
        t1t = _mm_add_pd(t5s, t9s);
        t2t = _mm_sub_pd(t5s, t9s);
        t3t = _mm_sub_pd(t6s, t0t);
        t4t = _mm_add_pd(t6s, t0t);
        t5t = _mm_add_pd(t7s, s4t);
        t6t = _mm_sub_pd(t7s, s4t);
        t7t = _mm_sub_pd(t8s, s5t);
        t8t = _mm_add_pd(t8s, s5t);
        t9t = _mm_add_pd(s8f, s2o);
        t0u = _mm_sub_pd(s9f, s3o);
        t1u = _mm_sub_pd(s8f, s2o);
        t2u = _mm_add_pd(s9f, s3o);
        t3u = _mm_add_pd(s4l, s6i);
        t4u = _mm_sub_pd(s5l, s7i);
        t5u = _mm_sub_pd(s4l, s6i);
        t6u = _mm_add_pd(s5l, s7i);
        t7u = _mm_add_pd(t9t, t3u);
        t8u = _mm_add_pd(t0u, t4u);
        t9u = _mm_sub_pd(t1u, t6u);
        t0v = _mm_add_pd(t2u, t5u);
        t1v = _mm_add_pd(t1u, t6u);
        t2v = _mm_sub_pd(t2u, t5u);
        s6t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9u), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0v));
        s7t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9u), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0v));
        a26 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9t, t3u));
        a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0u, t4u));
        s8t = _mm_sub_pd(a26, a36);
        s9t = _mm_add_pd(a26, a36);
        s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2v));
        s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2v));
        s2u = _mm_add_pd(t1t, t7u);
        _mm_storeu_pd(((double  *) (a55 + 32)), s2u);
        s3u = _mm_sub_pd(t1t, t7u);
        _mm_storeu_pd(((double  *) (a55 + 544)), s3u);
        s4u = _mm_sub_pd(t2t, t8u);
        _mm_storeu_pd(((double  *) (a55 + 288)), s4u);
        s5u = _mm_add_pd(t2t, t8u);
        _mm_storeu_pd(((double  *) (a55 + 800)), s5u);
        s6u = _mm_add_pd(t5t, s6t);
        _mm_storeu_pd(((double  *) (a55 + 96)), s6u);
        s7u = _mm_sub_pd(t5t, s6t);
        _mm_storeu_pd(((double  *) (a55 + 608)), s7u);
        s8u = _mm_sub_pd(t6t, s7t);
        _mm_storeu_pd(((double  *) (a55 + 352)), s8u);
        s9u = _mm_add_pd(t6t, s7t);
        _mm_storeu_pd(((double  *) (a55 + 864)), s9u);
        s0v = _mm_add_pd(t3t, s8t);
        _mm_storeu_pd(((double  *) (a55 + 160)), s0v);
        s1v = _mm_sub_pd(t3t, s8t);
        _mm_storeu_pd(((double  *) (a55 + 672)), s1v);
        s2v = _mm_sub_pd(t4t, s9t);
        _mm_storeu_pd(((double  *) (a55 + 416)), s2v);
        s3v = _mm_add_pd(t4t, s9t);
        _mm_storeu_pd(((double  *) (a55 + 928)), s3v);
        s4v = _mm_add_pd(t7t, s0u);
        _mm_storeu_pd(((double  *) (a55 + 224)), s4v);
        s5v = _mm_sub_pd(t7t, s0u);
        _mm_storeu_pd(((double  *) (a55 + 736)), s5v);
        s6v = _mm_sub_pd(t8t, s1u);
        _mm_storeu_pd(((double  *) (a55 + 480)), s6v);
        s7v = _mm_add_pd(t8t, s1u);
        _mm_storeu_pd(((double  *) (a55 + 992)), s7v);
        t3v = _mm_add_pd(t7b, s2k);
        t4v = _mm_sub_pd(t7b, s2k);
        t5v = _mm_sub_pd(t8b, s3k);
        t6v = _mm_add_pd(t8b, s3k);
        t7v = _mm_add_pd(s4h, s0n);
        t8v = _mm_sub_pd(s5h, s1n);
        a46 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4h, s0n));
        a56 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5h, s1n));
        s8v = _mm_sub_pd(a46, a56);
        s9v = _mm_add_pd(a46, a56);
        t9v = _mm_add_pd(t3v, t7v);
        t0w = _mm_sub_pd(t3v, t7v);
        t1w = _mm_sub_pd(t4v, t8v);
        t2w = _mm_add_pd(t4v, t8v);
        t3w = _mm_add_pd(t5v, s8v);
        t4w = _mm_sub_pd(t5v, s8v);
        t5w = _mm_sub_pd(t6v, s9v);
        t6w = _mm_add_pd(t6v, s9v);
        t7w = _mm_add_pd(s0g, s4o);
        t8w = _mm_sub_pd(s1g, s5o);
        t9w = _mm_sub_pd(s0g, s4o);
        t0x = _mm_add_pd(s1g, s5o);
        t1x = _mm_add_pd(s6l, s8i);
        t2x = _mm_sub_pd(s7l, s9i);
        t3x = _mm_sub_pd(s6l, s8i);
        t4x = _mm_add_pd(s7l, s9i);
        t5x = _mm_add_pd(t7w, t1x);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_sub_pd(t9w, t4x);
        t8x = _mm_add_pd(t0x, t3x);
        t9x = _mm_add_pd(t9w, t4x);
        t0y = _mm_sub_pd(t0x, t3x);
        s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8x));
        s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8x));
        a66 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7w, t1x));
        a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8w, t2x));
        s2w = _mm_sub_pd(a66, a76);
        s3w = _mm_add_pd(a66, a76);
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0y));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0y));
        s6w = _mm_add_pd(t9v, t5x);
        _mm_storeu_pd(((double  *) (a55 + 48)), s6w);
        s7w = _mm_sub_pd(t9v, t5x);
        _mm_storeu_pd(((double  *) (a55 + 560)), s7w);
        s8w = _mm_sub_pd(t0w, t6x);
        _mm_storeu_pd(((double  *) (a55 + 304)), s8w);
        s9w = _mm_add_pd(t0w, t6x);
        _mm_storeu_pd(((double  *) (a55 + 816)), s9w);
        s0x = _mm_add_pd(t3w, s0w);
        _mm_storeu_pd(((double  *) (a55 + 112)), s0x);
        s1x = _mm_sub_pd(t3w, s0w);
        _mm_storeu_pd(((double  *) (a55 + 624)), s1x);
        s2x = _mm_sub_pd(t4w, s1w);
        _mm_storeu_pd(((double  *) (a55 + 368)), s2x);
        s3x = _mm_add_pd(t4w, s1w);
        _mm_storeu_pd(((double  *) (a55 + 880)), s3x);
        s4x = _mm_add_pd(t1w, s2w);
        _mm_storeu_pd(((double  *) (a55 + 176)), s4x);
        s5x = _mm_sub_pd(t1w, s2w);
        _mm_storeu_pd(((double  *) (a55 + 688)), s5x);
        s6x = _mm_sub_pd(t2w, s3w);
        _mm_storeu_pd(((double  *) (a55 + 432)), s6x);
        s7x = _mm_add_pd(t2w, s3w);
        _mm_storeu_pd(((double  *) (a55 + 944)), s7x);
        s8x = _mm_add_pd(t5w, s4w);
        _mm_storeu_pd(((double  *) (a55 + 240)), s8x);
        s9x = _mm_sub_pd(t5w, s4w);
        _mm_storeu_pd(((double  *) (a55 + 752)), s9x);
        s0y = _mm_sub_pd(t6w, s5w);
        _mm_storeu_pd(((double  *) (a55 + 496)), s0y);
        s1y = _mm_add_pd(t6w, s5w);
        _mm_storeu_pd(((double  *) (a55 + 1008)), s1y);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_1024)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_1024_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[1024]);
    __m128d a01, a02, a04, a05, a06, a11, a12, a13, a14, a15, a16, a2, a21, a22, a23, a24, a25, a26, a3, a31, a32, a33
            , a34, a35, a36, a4, a41, a42, a43, a44, a45, a46, a5, a51, a52, a53, a54, a55, a56, a61, a62, a63, a64, a66
            , a71, a72, a73, a75, a76, a81, a82, a83, a84, a85, a86, a91, a92, a93, a94, a95, s, s01, s02, s03, s04, s05
            , s06, s07, s08, s09, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r
            , s0s, s0t, s0u, s0v, s0w, s0x, s0y, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1a, s1b, s1c, s1d, s1e, s1f
            , s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s2, s21, s22
            , s23, s24, s25, s26, s27, s28, s29, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3a, s3b, s3c
            , s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s4
            , s41, s42, s43, s44, s45, s46, s47, s48, s49, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m
            , s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5a
            , s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w
            , s5x, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6a, s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k
            , s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s7, s71, s72, s73, s74, s75, s76, s77, s78
            , s79, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u
            , s7v, s7w, s7x, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i
            , s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s9, s91, s92, s93, s94, s95, s96
            , s97, s98, s99, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s
            , s9t, s9u, s9v, s9w, s9x, t, t01, t02, t03, t04, t05, t06, t07, t08, t09, t0a, t0b, t0c, t0d, t0e, t0f, t0g
            , t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t11, t12, t13, t14
            , t15, t16, t17, t18, t19, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q
            , t1r, t1s, t1t, t1u, t1v, t1w, t1x, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2a, t2b, t2c, t2d, t2e
            , t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t3, t31, t32
            , t33, t34, t35, t36, t37, t38, t39, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o
            , t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4a, t4b, t4c
            , t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t5
            , t51, t52, t53, t54, t55, t56, t57, t58, t59, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m
            , t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6a
            , t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w
            , t6x, t7, t71, t72, t73, t74, t75, t76, t77, t78, t79, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k
            , t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t8, t81, t82, t83, t84, t85, t86, t87, t88
            , t89, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u
            , t8v, t8w, t8x, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i
            , t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x;
    __m128d  *a, *a03, *a6, *a65, *a7, *a74, *a9, *b, *b2, *b3;
    int a8;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 256)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 32));
    s5 = v_neg23(*((a + 480)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 64));
    s11 = v_neg23(*((a + 448)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 96));
    s71 = v_neg23(*((a + 416)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 128));
    s32 = v_neg23(*((a + 384)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 160));
    s92 = v_neg23(*((a + 352)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 192));
    s53 = v_neg23(*((a + 320)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 224));
    s14 = v_neg23(*((a + 288)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a6 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a6) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a6 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a6 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a6 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a6 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a6 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a6 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a6 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a6 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a6 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a6 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a6 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a6 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a6 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a6 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a6 + 15)) = s96;
    {long i; for(i = 0; i <= 30; i++) {
        a7 = ((__m128d  *) src);
        b = (a7 + i);
        s07 = *((b + 1));
        b2 = (a7 - i);
        s17 = v_neg23(*((b2 + 511)));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a8 = (16 * i);
        a9 = (D70 + a8);
        a01 = *(a9);
        a11 = *((a9 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a01, s27), _mm_mul_pd(a11, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a01, s37), _mm_mul_pd(a11, s27));
        s67 = *((b + 65));
        s77 = v_neg23(*((b2 + 447)));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a21 = *((a9 + 2));
        a31 = *((a9 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a21, s87), _mm_mul_pd(a31, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a21, s97), _mm_mul_pd(a31, s87));
        s28 = *((b + 129));
        s38 = v_neg23(*((b2 + 383)));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a41 = *((a9 + 4));
        a51 = *((a9 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a41, s48), _mm_mul_pd(a51, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a41, s58), _mm_mul_pd(a51, s48));
        s88 = *((b + 193));
        s98 = v_neg23(*((b2 + 319)));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a61 = *((a9 + 6));
        a71 = *((a9 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a61, s09), _mm_mul_pd(a71, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a61, s19), _mm_mul_pd(a71, s09));
        s49 = *((b + 257));
        s59 = v_neg23(*((b2 + 255)));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a81 = *((a9 + 8));
        a91 = *((a9 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a81, s69), _mm_mul_pd(a91, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a81, s79), _mm_mul_pd(a91, s69));
        s0a = *((b + 321));
        s1a = v_neg23(*((b2 + 191)));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a02 = *((a9 + 10));
        a12 = *((a9 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a02, s2a), _mm_mul_pd(a12, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a02, s3a), _mm_mul_pd(a12, s2a));
        s6a = *((b + 385));
        s7a = v_neg23(*((b2 + 127)));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a22 = *((a9 + 12));
        a32 = *((a9 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a22, s8a), _mm_mul_pd(a32, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a22, s9a), _mm_mul_pd(a32, s8a));
        s2b = *((b + 449));
        s3b = v_neg23(*((b2 + 63)));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a42 = *((a9 + 14));
        a52 = *((a9 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a42, s4b), _mm_mul_pd(a52, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a42, s5b), _mm_mul_pd(a52, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a62, a72);
        s9b = _mm_add_pd(a62, a72);
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a82, a92);
        s1c = _mm_add_pd(a82, a92);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a03 = (D71 + a8);
        a13 = *(a03);
        a23 = *((a03 + 1));
        a33 = *((a03 + 2));
        a43 = *((a03 + 3));
        a53 = *((a03 + 4));
        a63 = *((a03 + 5));
        a73 = *((a03 + 6));
        a83 = *((a03 + 7));
        a93 = *((a03 + 8));
        a04 = *((a03 + 9));
        a14 = *((a03 + 10));
        a24 = *((a03 + 11));
        a34 = *((a03 + 12));
        a44 = *((a03 + 13));
        a54 = *((a03 + 14));
        a64 = *((a03 + 15));
        b3 = (((__m128d  *) T) + a8);
        s2c = _mm_sub_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a23, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a23, t98), _mm_mul_pd(a13, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a43, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a43, t39), _mm_mul_pd(a33, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a63, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a63, t79), _mm_mul_pd(a53, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a83, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a83, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a04, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a04, t19), _mm_mul_pd(a93, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a24, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a24, t59), _mm_mul_pd(a14, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a44, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a44, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a64, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a64, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a74 = (((__m128d  *) T) + i2);
        s8d = *(a74);
        s9d = *((a74 + 256));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a74 + 8));
        s1e = *((a74 + 264));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a74 + 128));
        s3e = *((a74 + 136));
        s4e = *((a74 + 384));
        s5e = *((a74 + 392));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a84, a94);
        s7e = _mm_add_pd(a84, a94);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a74 + 16));
        s9e = *((a74 + 24));
        s0f = *((a74 + 496));
        s1f = *((a74 + 504));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a74 + 272));
        s3f = *((a74 + 280));
        s4f = *((a74 + 240));
        s5f = *((a74 + 248));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t9b, t3c);
        t0d = _mm_sub_pd(t0c, t4c);
        t1d = _mm_sub_pd(t1c, t6c);
        t2d = _mm_add_pd(t2c, t5c);
        t3d = _mm_add_pd(t1c, t6c);
        t4d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1d), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1d), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2d));
        s8f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0d));
        s9f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0d));
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3d), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3d), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4d));
        s2g = *((a74 + 32));
        s3g = *((a74 + 40));
        s4g = *((a74 + 480));
        s5g = *((a74 + 488));
        t5d = _mm_add_pd(s2g, s4g);
        t6d = _mm_sub_pd(s3g, s5g);
        t7d = _mm_sub_pd(s2g, s4g);
        t8d = _mm_add_pd(s3g, s5g);
        s6g = *((a74 + 288));
        s7g = *((a74 + 296));
        s8g = *((a74 + 224));
        s9g = *((a74 + 232));
        t9d = _mm_add_pd(s6g, s8g);
        t0e = _mm_sub_pd(s7g, s9g);
        t1e = _mm_sub_pd(s6g, s8g);
        t2e = _mm_add_pd(s7g, s9g);
        t3e = _mm_add_pd(t5d, t9d);
        t4e = _mm_add_pd(t6d, t0e);
        t5e = _mm_sub_pd(t5d, t9d);
        t6e = _mm_sub_pd(t6d, t0e);
        t7e = _mm_sub_pd(t7d, t2e);
        t8e = _mm_add_pd(t8d, t1e);
        t9e = _mm_add_pd(t7d, t2e);
        t0f = _mm_sub_pd(t8d, t1e);
        s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7e), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8e));
        s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7e), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8e));
        s2h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6e));
        s3h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6e));
        s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9e), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0f));
        s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9e), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0f));
        s6h = *((a74 + 48));
        s7h = *((a74 + 56));
        s8h = *((a74 + 464));
        s9h = *((a74 + 472));
        t1f = _mm_add_pd(s6h, s8h);
        t2f = _mm_sub_pd(s7h, s9h);
        t3f = _mm_sub_pd(s6h, s8h);
        t4f = _mm_add_pd(s7h, s9h);
        s0i = *((a74 + 304));
        s1i = *((a74 + 312));
        s2i = *((a74 + 208));
        s3i = *((a74 + 216));
        t5f = _mm_add_pd(s0i, s2i);
        t6f = _mm_sub_pd(s1i, s3i);
        t7f = _mm_sub_pd(s0i, s2i);
        t8f = _mm_add_pd(s1i, s3i);
        t9f = _mm_add_pd(t1f, t5f);
        t0g = _mm_add_pd(t2f, t6f);
        t1g = _mm_sub_pd(t1f, t5f);
        t2g = _mm_sub_pd(t2f, t6f);
        t3g = _mm_sub_pd(t3f, t8f);
        t4g = _mm_add_pd(t4f, t7f);
        t5g = _mm_add_pd(t3f, t8f);
        t6g = _mm_sub_pd(t4f, t7f);
        s4i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3g), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4g));
        s5i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3g), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4g));
        s6i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1g), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2g));
        s7i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1g), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2g));
        s8i = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5g), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6g));
        s9i = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5g), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6g));
        s0j = *((a74 + 64));
        s1j = *((a74 + 72));
        s2j = *((a74 + 448));
        s3j = *((a74 + 456));
        t7g = _mm_add_pd(s0j, s2j);
        t8g = _mm_sub_pd(s1j, s3j);
        t9g = _mm_sub_pd(s0j, s2j);
        t0h = _mm_add_pd(s1j, s3j);
        s4j = *((a74 + 320));
        s5j = *((a74 + 328));
        s6j = *((a74 + 192));
        s7j = *((a74 + 200));
        t1h = _mm_add_pd(s4j, s6j);
        t2h = _mm_sub_pd(s5j, s7j);
        t3h = _mm_sub_pd(s4j, s6j);
        t4h = _mm_add_pd(s5j, s7j);
        t5h = _mm_add_pd(t7g, t1h);
        t6h = _mm_add_pd(t8g, t2h);
        t7h = _mm_sub_pd(t9g, t4h);
        t8h = _mm_add_pd(t0h, t3h);
        t9h = _mm_add_pd(t9g, t4h);
        t0i = _mm_sub_pd(t0h, t3h);
        s8j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8h));
        s9j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8h));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7g, t1h));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8g, t2h));
        s0k = _mm_sub_pd(a05, a15);
        s1k = _mm_add_pd(a05, a15);
        s2k = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0i));
        s3k = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0i));
        s4k = *((a74 + 80));
        s5k = *((a74 + 88));
        s6k = *((a74 + 432));
        s7k = *((a74 + 440));
        t1i = _mm_add_pd(s4k, s6k);
        t2i = _mm_sub_pd(s5k, s7k);
        t3i = _mm_sub_pd(s4k, s6k);
        t4i = _mm_add_pd(s5k, s7k);
        s8k = *((a74 + 336));
        s9k = *((a74 + 344));
        s0l = *((a74 + 176));
        s1l = *((a74 + 184));
        t5i = _mm_add_pd(s8k, s0l);
        t6i = _mm_sub_pd(s9k, s1l);
        t7i = _mm_sub_pd(s8k, s0l);
        t8i = _mm_add_pd(s9k, s1l);
        t9i = _mm_add_pd(t1i, t5i);
        t0j = _mm_add_pd(t2i, t6i);
        t1j = _mm_sub_pd(t1i, t5i);
        t2j = _mm_sub_pd(t2i, t6i);
        t3j = _mm_sub_pd(t3i, t8i);
        t4j = _mm_add_pd(t4i, t7i);
        t5j = _mm_add_pd(t3i, t8i);
        t6j = _mm_sub_pd(t4i, t7i);
        s2l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t3j), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t4j));
        s3l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t3j), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t4j));
        s4l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1j), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2j));
        s5l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1j), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2j));
        s6l = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t5j), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t6j));
        s7l = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t5j), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t6j));
        s8l = *((a74 + 96));
        s9l = *((a74 + 104));
        s0m = *((a74 + 416));
        s1m = *((a74 + 424));
        t7j = _mm_add_pd(s8l, s0m);
        t8j = _mm_sub_pd(s9l, s1m);
        t9j = _mm_sub_pd(s8l, s0m);
        t0k = _mm_add_pd(s9l, s1m);
        s2m = *((a74 + 352));
        s3m = *((a74 + 360));
        s4m = *((a74 + 160));
        s5m = *((a74 + 168));
        t1k = _mm_add_pd(s2m, s4m);
        t2k = _mm_sub_pd(s3m, s5m);
        t3k = _mm_sub_pd(s2m, s4m);
        t4k = _mm_add_pd(s3m, s5m);
        t5k = _mm_add_pd(t7j, t1k);
        t6k = _mm_add_pd(t8j, t2k);
        t7k = _mm_sub_pd(t7j, t1k);
        t8k = _mm_sub_pd(t8j, t2k);
        t9k = _mm_sub_pd(t9j, t4k);
        t0l = _mm_add_pd(t0k, t3k);
        t1l = _mm_add_pd(t9j, t4k);
        t2l = _mm_sub_pd(t0k, t3k);
        s6m = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9k), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0l));
        s7m = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9k), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0l));
        s8m = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k));
        s9m = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8k));
        s0n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1l), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2l));
        s1n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1l), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2l));
        s2n = *((a74 + 112));
        s3n = *((a74 + 120));
        s4n = *((a74 + 400));
        s5n = *((a74 + 408));
        t3l = _mm_add_pd(s2n, s4n);
        t4l = _mm_sub_pd(s3n, s5n);
        t5l = _mm_sub_pd(s2n, s4n);
        t6l = _mm_add_pd(s3n, s5n);
        s6n = *((a74 + 368));
        s7n = *((a74 + 376));
        s8n = *((a74 + 144));
        s9n = *((a74 + 152));
        t7l = _mm_add_pd(s6n, s8n);
        t8l = _mm_sub_pd(s7n, s9n);
        t9l = _mm_sub_pd(s6n, s8n);
        t0m = _mm_add_pd(s7n, s9n);
        t1m = _mm_add_pd(t3l, t7l);
        t2m = _mm_add_pd(t4l, t8l);
        t3m = _mm_sub_pd(t3l, t7l);
        t4m = _mm_sub_pd(t4l, t8l);
        t5m = _mm_sub_pd(t5l, t0m);
        t6m = _mm_add_pd(t6l, t9l);
        t7m = _mm_add_pd(t5l, t0m);
        t8m = _mm_sub_pd(t6l, t9l);
        s0o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5m), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6m));
        s1o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5m), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6m));
        s2o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3m), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4m));
        s3o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3m), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4m));
        s4o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7m), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8m));
        s5o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7m), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8m));
        t9m = _mm_add_pd(t1b, t5h);
        t0n = _mm_sub_pd(t1b, t5h);
        t1n = _mm_sub_pd(t2b, t6h);
        t2n = _mm_add_pd(t2b, t6h);
        t3n = _mm_add_pd(t3e, t5k);
        t4n = _mm_sub_pd(t4e, t6k);
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3e, t5k));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4e, t6k));
        s6o = _mm_sub_pd(a25, a35);
        s7o = _mm_add_pd(a25, a35);
        t5n = _mm_add_pd(t9m, t3n);
        t6n = _mm_sub_pd(t9m, t3n);
        t7n = _mm_sub_pd(t0n, t4n);
        t8n = _mm_add_pd(t0n, t4n);
        t9n = _mm_add_pd(t1n, s6o);
        t0o = _mm_sub_pd(t1n, s6o);
        t1o = _mm_sub_pd(t2n, s7o);
        t2o = _mm_add_pd(t2n, s7o);
        t3o = _mm_add_pd(t7c, t1m);
        t4o = _mm_sub_pd(t8c, t2m);
        t5o = _mm_sub_pd(t7c, t1m);
        t6o = _mm_add_pd(t8c, t2m);
        t7o = _mm_add_pd(t9i, t9f);
        t8o = _mm_sub_pd(t0j, t0g);
        t9o = _mm_sub_pd(t9i, t9f);
        t0p = _mm_add_pd(t0j, t0g);
        t1p = _mm_add_pd(t3o, t7o);
        t2p = _mm_add_pd(t4o, t8o);
        t3p = _mm_sub_pd(t5o, t0p);
        t4p = _mm_add_pd(t6o, t9o);
        t5p = _mm_add_pd(t5o, t0p);
        t6p = _mm_sub_pd(t6o, t9o);
        s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4p));
        s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4p));
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3o, t7o));
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4o, t8o));
        s0p = _mm_sub_pd(a45, a55);
        s1p = _mm_add_pd(a45, a55);
        s2p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6p));
        s3p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6p));
        a65 = (((__m128d  *) dst) + i2);
        s4p = _mm_add_pd(t5n, t1p);
        *(a65) = s4p;
        s5p = _mm_sub_pd(t5n, t1p);
        *((a65 + 256)) = s5p;
        s6p = _mm_sub_pd(t6n, t2p);
        *((a65 + 128)) = s6p;
        s7p = _mm_add_pd(t6n, t2p);
        *((a65 + 384)) = s7p;
        s8p = _mm_add_pd(t9n, s8o);
        *((a65 + 32)) = s8p;
        s9p = _mm_sub_pd(t9n, s8o);
        *((a65 + 288)) = s9p;
        s0q = _mm_sub_pd(t0o, s9o);
        *((a65 + 160)) = s0q;
        s1q = _mm_add_pd(t0o, s9o);
        *((a65 + 416)) = s1q;
        s2q = _mm_add_pd(t7n, s0p);
        *((a65 + 64)) = s2q;
        s3q = _mm_sub_pd(t7n, s0p);
        *((a65 + 320)) = s3q;
        s4q = _mm_sub_pd(t8n, s1p);
        *((a65 + 192)) = s4q;
        s5q = _mm_add_pd(t8n, s1p);
        *((a65 + 448)) = s5q;
        s6q = _mm_add_pd(t1o, s2p);
        *((a65 + 96)) = s6q;
        s7q = _mm_sub_pd(t1o, s2p);
        *((a65 + 352)) = s7q;
        s8q = _mm_sub_pd(t2o, s3p);
        *((a65 + 224)) = s8q;
        s9q = _mm_add_pd(t2o, s3p);
        *((a65 + 480)) = s9q;
        t7p = _mm_add_pd(t5b, s8j);
        t8p = _mm_sub_pd(t5b, s8j);
        t9p = _mm_sub_pd(t6b, s9j);
        t0q = _mm_add_pd(t6b, s9j);
        t1q = _mm_add_pd(s0h, s6m);
        t2q = _mm_sub_pd(s1h, s7m);
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0h, s6m));
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1h, s7m));
        s0r = _mm_sub_pd(a75, a85);
        s1r = _mm_add_pd(a75, a85);
        t3q = _mm_add_pd(t7p, t1q);
        t4q = _mm_sub_pd(t7p, t1q);
        t5q = _mm_sub_pd(t8p, t2q);
        t6q = _mm_add_pd(t8p, t2q);
        t7q = _mm_add_pd(t9p, s0r);
        t8q = _mm_sub_pd(t9p, s0r);
        t9q = _mm_sub_pd(t0q, s1r);
        t0r = _mm_add_pd(t0q, s1r);
        t1r = _mm_add_pd(s6f, s0o);
        t2r = _mm_sub_pd(s7f, s1o);
        t3r = _mm_sub_pd(s6f, s0o);
        t4r = _mm_add_pd(s7f, s1o);
        t5r = _mm_add_pd(s2l, s4i);
        t6r = _mm_sub_pd(s3l, s5i);
        t7r = _mm_sub_pd(s2l, s4i);
        t8r = _mm_add_pd(s3l, s5i);
        t9r = _mm_add_pd(t1r, t5r);
        t0s = _mm_add_pd(t2r, t6r);
        t1s = _mm_sub_pd(t3r, t8r);
        t2s = _mm_add_pd(t4r, t7r);
        t3s = _mm_add_pd(t3r, t8r);
        t4s = _mm_sub_pd(t4r, t7r);
        s2r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2s));
        s3r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1s), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2s));
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1r, t5r));
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2r, t6r));
        s4r = _mm_sub_pd(a95, a06);
        s5r = _mm_add_pd(a95, a06);
        s6r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3s), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4s));
        s7r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3s), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4s));
        s8r = _mm_add_pd(t3q, t9r);
        *((a65 + 8)) = s8r;
        s9r = _mm_sub_pd(t3q, t9r);
        *((a65 + 264)) = s9r;
        s0s = _mm_sub_pd(t4q, t0s);
        *((a65 + 136)) = s0s;
        s1s = _mm_add_pd(t4q, t0s);
        *((a65 + 392)) = s1s;
        s2s = _mm_add_pd(t7q, s2r);
        *((a65 + 40)) = s2s;
        s3s = _mm_sub_pd(t7q, s2r);
        *((a65 + 296)) = s3s;
        s4s = _mm_sub_pd(t8q, s3r);
        *((a65 + 168)) = s4s;
        s5s = _mm_add_pd(t8q, s3r);
        *((a65 + 424)) = s5s;
        s6s = _mm_add_pd(t5q, s4r);
        *((a65 + 72)) = s6s;
        s7s = _mm_sub_pd(t5q, s4r);
        *((a65 + 328)) = s7s;
        s8s = _mm_sub_pd(t6q, s5r);
        *((a65 + 200)) = s8s;
        s9s = _mm_add_pd(t6q, s5r);
        *((a65 + 456)) = s9s;
        s0t = _mm_add_pd(t9q, s6r);
        *((a65 + 104)) = s0t;
        s1t = _mm_sub_pd(t9q, s6r);
        *((a65 + 360)) = s1t;
        s2t = _mm_sub_pd(t0r, s7r);
        *((a65 + 232)) = s2t;
        s3t = _mm_add_pd(t0r, s7r);
        *((a65 + 488)) = s3t;
        t5s = _mm_add_pd(t3b, s0k);
        t6s = _mm_sub_pd(t3b, s0k);
        t7s = _mm_sub_pd(t4b, s1k);
        t8s = _mm_add_pd(t4b, s1k);
        t9s = _mm_add_pd(s2h, s8m);
        t0t = _mm_sub_pd(s3h, s9m);
        a16 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2h, s8m));
        a26 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3h, s9m));
        s4t = _mm_sub_pd(a16, a26);
        s5t = _mm_add_pd(a16, a26);
        t1t = _mm_add_pd(t5s, t9s);
        t2t = _mm_sub_pd(t5s, t9s);
        t3t = _mm_sub_pd(t6s, t0t);
        t4t = _mm_add_pd(t6s, t0t);
        t5t = _mm_add_pd(t7s, s4t);
        t6t = _mm_sub_pd(t7s, s4t);
        t7t = _mm_sub_pd(t8s, s5t);
        t8t = _mm_add_pd(t8s, s5t);
        t9t = _mm_add_pd(s8f, s2o);
        t0u = _mm_sub_pd(s9f, s3o);
        t1u = _mm_sub_pd(s8f, s2o);
        t2u = _mm_add_pd(s9f, s3o);
        t3u = _mm_add_pd(s4l, s6i);
        t4u = _mm_sub_pd(s5l, s7i);
        t5u = _mm_sub_pd(s4l, s6i);
        t6u = _mm_add_pd(s5l, s7i);
        t7u = _mm_add_pd(t9t, t3u);
        t8u = _mm_add_pd(t0u, t4u);
        t9u = _mm_sub_pd(t1u, t6u);
        t0v = _mm_add_pd(t2u, t5u);
        t1v = _mm_add_pd(t1u, t6u);
        t2v = _mm_sub_pd(t2u, t5u);
        s6t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9u), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0v));
        s7t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9u), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0v));
        a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9t, t3u));
        a46 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0u, t4u));
        s8t = _mm_sub_pd(a36, a46);
        s9t = _mm_add_pd(a36, a46);
        s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2v));
        s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2v));
        s2u = _mm_add_pd(t1t, t7u);
        *((a65 + 16)) = s2u;
        s3u = _mm_sub_pd(t1t, t7u);
        *((a65 + 272)) = s3u;
        s4u = _mm_sub_pd(t2t, t8u);
        *((a65 + 144)) = s4u;
        s5u = _mm_add_pd(t2t, t8u);
        *((a65 + 400)) = s5u;
        s6u = _mm_add_pd(t5t, s6t);
        *((a65 + 48)) = s6u;
        s7u = _mm_sub_pd(t5t, s6t);
        *((a65 + 304)) = s7u;
        s8u = _mm_sub_pd(t6t, s7t);
        *((a65 + 176)) = s8u;
        s9u = _mm_add_pd(t6t, s7t);
        *((a65 + 432)) = s9u;
        s0v = _mm_add_pd(t3t, s8t);
        *((a65 + 80)) = s0v;
        s1v = _mm_sub_pd(t3t, s8t);
        *((a65 + 336)) = s1v;
        s2v = _mm_sub_pd(t4t, s9t);
        *((a65 + 208)) = s2v;
        s3v = _mm_add_pd(t4t, s9t);
        *((a65 + 464)) = s3v;
        s4v = _mm_add_pd(t7t, s0u);
        *((a65 + 112)) = s4v;
        s5v = _mm_sub_pd(t7t, s0u);
        *((a65 + 368)) = s5v;
        s6v = _mm_sub_pd(t8t, s1u);
        *((a65 + 240)) = s6v;
        s7v = _mm_add_pd(t8t, s1u);
        *((a65 + 496)) = s7v;
        t3v = _mm_add_pd(t7b, s2k);
        t4v = _mm_sub_pd(t7b, s2k);
        t5v = _mm_sub_pd(t8b, s3k);
        t6v = _mm_add_pd(t8b, s3k);
        t7v = _mm_add_pd(s4h, s0n);
        t8v = _mm_sub_pd(s5h, s1n);
        a56 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4h, s0n));
        a66 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5h, s1n));
        s8v = _mm_sub_pd(a56, a66);
        s9v = _mm_add_pd(a56, a66);
        t9v = _mm_add_pd(t3v, t7v);
        t0w = _mm_sub_pd(t3v, t7v);
        t1w = _mm_sub_pd(t4v, t8v);
        t2w = _mm_add_pd(t4v, t8v);
        t3w = _mm_add_pd(t5v, s8v);
        t4w = _mm_sub_pd(t5v, s8v);
        t5w = _mm_sub_pd(t6v, s9v);
        t6w = _mm_add_pd(t6v, s9v);
        t7w = _mm_add_pd(s0g, s4o);
        t8w = _mm_sub_pd(s1g, s5o);
        t9w = _mm_sub_pd(s0g, s4o);
        t0x = _mm_add_pd(s1g, s5o);
        t1x = _mm_add_pd(s6l, s8i);
        t2x = _mm_sub_pd(s7l, s9i);
        t3x = _mm_sub_pd(s6l, s8i);
        t4x = _mm_add_pd(s7l, s9i);
        t5x = _mm_add_pd(t7w, t1x);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_sub_pd(t9w, t4x);
        t8x = _mm_add_pd(t0x, t3x);
        t9x = _mm_add_pd(t9w, t4x);
        t0y = _mm_sub_pd(t0x, t3x);
        s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8x));
        s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8x));
        a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7w, t1x));
        a86 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8w, t2x));
        s2w = _mm_sub_pd(a76, a86);
        s3w = _mm_add_pd(a76, a86);
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0y));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0y));
        s6w = _mm_add_pd(t9v, t5x);
        *((a65 + 24)) = s6w;
        s7w = _mm_sub_pd(t9v, t5x);
        *((a65 + 280)) = s7w;
        s8w = _mm_sub_pd(t0w, t6x);
        *((a65 + 152)) = s8w;
        s9w = _mm_add_pd(t0w, t6x);
        *((a65 + 408)) = s9w;
        s0x = _mm_add_pd(t3w, s0w);
        *((a65 + 56)) = s0x;
        s1x = _mm_sub_pd(t3w, s0w);
        *((a65 + 312)) = s1x;
        s2x = _mm_sub_pd(t4w, s1w);
        *((a65 + 184)) = s2x;
        s3x = _mm_add_pd(t4w, s1w);
        *((a65 + 440)) = s3x;
        s4x = _mm_add_pd(t1w, s2w);
        *((a65 + 88)) = s4x;
        s5x = _mm_sub_pd(t1w, s2w);
        *((a65 + 344)) = s5x;
        s6x = _mm_sub_pd(t2w, s3w);
        *((a65 + 216)) = s6x;
        s7x = _mm_add_pd(t2w, s3w);
        *((a65 + 472)) = s7x;
        s8x = _mm_add_pd(t5w, s4w);
        *((a65 + 120)) = s8x;
        s9x = _mm_sub_pd(t5w, s4w);
        *((a65 + 376)) = s9x;
        s0y = _mm_sub_pd(t6w, s5w);
        *((a65 + 248)) = s0y;
        s1y = _mm_add_pd(t6w, s5w);
        *((a65 + 504)) = s1y;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_2048_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[2048]);
    __m128d a, a01, a02, a03, a04, a05, a06, a07, a08, a09, a0a, a0b, a11, a12, a13, a14, a15, a17, a18, a19, a1a, a1b
            , a2, a21, a22, a23, a24, a25, a26, a27, a28, a29, a2a, a2b, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39
            , a3b, a4, a42, a43, a44, a45, a46, a47, a48, a4a, a4b, a5, a52, a53, a54, a55, a56, a57, a58, a59, a5a, a5b
            , a6, a62, a63, a64, a65, a66, a67, a68, a69, a6a, a71, a72, a73, a74, a75, a76, a77, a78, a79, a7a, a8, a81
            , a82, a83, a84, a85, a86, a87, a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u
            , s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H
            , s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o
            , s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A
            , s2B, s2C, s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h
            , s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33
            , s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G, s3H, s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3a
            , s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w
            , s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I
            , s4J, s4K, s4L, s4M, s4N, s4O, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p
            , s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B
            , s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5L, s5M, s5N, s5O, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i
            , s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7K
            , s7L, s7M, s7N, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s
            , s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E
            , s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9a, s9b, s9c, s9d, s9e, s9f, s9g
            , s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02
            , t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0G, t0H, t0I, t0J, t0K, t0L, t0M, t0N, t0O
            , t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v
            , t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1A, t1B, t1C, t1D, t1E, t1F, t1G, t1H, t1I
            , t1J, t1K, t1L, t1M, t1N, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q
            , t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2A, t2B, t2C
            , t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2L, t2M, t2N, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k
            , t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36
            , t37, t38, t39, t3A, t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3L, t3M, t3N, t3a, t3b, t3c, t3d, t3e
            , t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4
            , t41, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4L, t4M
            , t4N, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u
            , t4v, t4w, t4x, t4y, t4z, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5F, t5G
            , t5H, t5I, t5J, t5K, t5L, t5M, t5N, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o
            , t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y, t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A
            , t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K, t6L, t6M, t6N, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i
            , t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7F, t7G, t7H, t7I, t7J, t7K, t7L, t7M, t7N, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t7y
            , t7z, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8F, t8G, t8H, t8I, t8J, t8K
            , t8L, t8M, t8N, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s
            , t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9A, t9B, t9C, t9D, t9E
            , t9F, t9G, t9H, t9I, t9J, t9K, t9L, t9M, t9N, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m
            , t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a16, *a49, *a61, *a7, *b3;
    double  *a3a;
    const double  *b, *b2;
    int a41, a51;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 1024))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 64)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1984))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 128)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1920))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 192)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1856))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s81), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 256)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1792))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s42), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 320)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1728))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s03), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 384)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1664))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s63), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 448)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1600))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s24), _mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s34));
    s64 = _mm_loadu_pd(((const double  *) (src + 512)));
    s74 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1536))));
    t71 = _mm_add_pd(s64, s74);
    t81 = _mm_sub_pd(s64, s74);
    s84 = v_lo2(t71, t81);
    s94 = v_hi2(t71, t81);
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s94));
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s94));
    s25 = _mm_loadu_pd(((const double  *) (src + 576)));
    s35 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1472))));
    t91 = _mm_add_pd(s25, s35);
    t02 = _mm_sub_pd(s25, s35);
    s45 = v_lo2(t91, t02);
    s55 = v_hi2(t91, t02);
    s65 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s45), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s55));
    s75 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s45), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s55));
    s85 = _mm_loadu_pd(((const double  *) (src + 640)));
    s95 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1408))));
    t12 = _mm_add_pd(s85, s95);
    t22 = _mm_sub_pd(s85, s95);
    s06 = v_lo2(t12, t22);
    s16 = v_hi2(t12, t22);
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s06), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s16));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s06), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s16));
    s46 = _mm_loadu_pd(((const double  *) (src + 704)));
    s56 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1344))));
    t32 = _mm_add_pd(s46, s56);
    t42 = _mm_sub_pd(s46, s56);
    s66 = v_lo2(t32, t42);
    s76 = v_hi2(t32, t42);
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s66), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s76));
    s96 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s66), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s76));
    s07 = _mm_loadu_pd(((const double  *) (src + 768)));
    s17 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1280))));
    t52 = _mm_add_pd(s07, s17);
    t62 = _mm_sub_pd(s07, s17);
    s27 = v_lo2(t52, t62);
    s37 = v_hi2(t52, t62);
    s47 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s27), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s37));
    s57 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s27), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s37));
    s67 = _mm_loadu_pd(((const double  *) (src + 832)));
    s77 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1216))));
    t72 = _mm_add_pd(s67, s77);
    t82 = _mm_sub_pd(s67, s77);
    s87 = v_lo2(t72, t82);
    s97 = v_hi2(t72, t82);
    s08 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s87), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s97));
    s18 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s87), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s97));
    s28 = _mm_loadu_pd(((const double  *) (src + 896)));
    s38 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1152))));
    t92 = _mm_add_pd(s28, s38);
    t03 = _mm_sub_pd(s28, s38);
    s48 = v_lo2(t92, t03);
    s58 = v_hi2(t92, t03);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s48), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s58));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s48), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s58));
    s88 = _mm_loadu_pd(((const double  *) (src + 960)));
    s98 = v_neg23(_mm_loadu_pd(((const double  *) (src + 1088))));
    t13 = _mm_add_pd(s88, s98);
    t23 = _mm_sub_pd(s88, s98);
    s09 = v_lo2(t13, t23);
    s19 = v_hi2(t13, t23);
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s09), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s19));
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s09), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s19));
    t33 = _mm_add_pd(t, s05);
    t43 = _mm_sub_pd(t, s05);
    t53 = _mm_sub_pd(t2, s15);
    t63 = _mm_add_pd(t2, s15);
    t73 = _mm_add_pd(s62, s47);
    t83 = _mm_sub_pd(s72, s57);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s62, s47));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s72, s57));
    s49 = _mm_sub_pd(a, a2);
    s59 = _mm_add_pd(a, a2);
    t93 = _mm_add_pd(t33, t73);
    t04 = _mm_sub_pd(t33, t73);
    t14 = _mm_sub_pd(t43, t83);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_add_pd(t53, s49);
    t44 = _mm_sub_pd(t53, s49);
    t54 = _mm_sub_pd(t63, s59);
    t64 = _mm_add_pd(t63, s59);
    t74 = _mm_add_pd(s8, s29);
    t84 = _mm_sub_pd(s9, s39);
    t94 = _mm_sub_pd(s8, s29);
    t05 = _mm_add_pd(s9, s39);
    t15 = _mm_add_pd(s65, s44);
    t25 = _mm_sub_pd(s75, s54);
    t35 = _mm_sub_pd(s65, s44);
    t45 = _mm_add_pd(s75, s54);
    t55 = _mm_add_pd(t74, t15);
    t65 = _mm_add_pd(t84, t25);
    t75 = _mm_sub_pd(t74, t15);
    t85 = _mm_sub_pd(t84, t25);
    t95 = _mm_sub_pd(t94, t45);
    t06 = _mm_add_pd(t05, t35);
    t16 = _mm_add_pd(t94, t45);
    t26 = _mm_sub_pd(t05, t35);
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t95), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t06));
    s79 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t95), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t06));
    s89 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t75), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t75), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t85));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t16), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t26));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t16), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t26));
    t36 = _mm_add_pd(s41, s68);
    t46 = _mm_sub_pd(s51, s78);
    t56 = _mm_sub_pd(s41, s68);
    t66 = _mm_add_pd(s51, s78);
    t76 = _mm_add_pd(s26, s83);
    t86 = _mm_sub_pd(s36, s93);
    t96 = _mm_sub_pd(s26, s83);
    t07 = _mm_add_pd(s36, s93);
    t17 = _mm_add_pd(t36, t76);
    t27 = _mm_add_pd(t46, t86);
    t37 = _mm_sub_pd(t56, t07);
    t47 = _mm_add_pd(t66, t96);
    t57 = _mm_add_pd(t56, t07);
    t67 = _mm_sub_pd(t66, t96);
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t37), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t47));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t37), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t47));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t36, t76));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t46, t86));
    s4a = _mm_sub_pd(a3, a4);
    s5a = _mm_add_pd(a3, a4);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    t77 = _mm_add_pd(s02, s08);
    t87 = _mm_sub_pd(s12, s18);
    t97 = _mm_sub_pd(s02, s08);
    t08 = _mm_add_pd(s12, s18);
    t18 = _mm_add_pd(s86, s23);
    t28 = _mm_sub_pd(s96, s33);
    t38 = _mm_sub_pd(s86, s23);
    t48 = _mm_add_pd(s96, s33);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t78), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t88));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t78), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t88));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t19), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t29));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t19), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t29));
    t39 = _mm_add_pd(t93, t17);
    t49 = _mm_sub_pd(t93, t17);
    t59 = _mm_sub_pd(t04, t27);
    t69 = _mm_add_pd(t04, t27);
    t79 = _mm_add_pd(t55, t58);
    t89 = _mm_sub_pd(t65, t68);
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t55, t58));
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t65, t68));
    s4b = _mm_sub_pd(a5, a6);
    s5b = _mm_add_pd(a5, a6);
    a7 = ((__m128d  *) T);
    s6b = _mm_add_pd(t39, t79);
    *(a7) = s6b;
    s7b = _mm_sub_pd(t39, t79);
    *((a7 + 16)) = s7b;
    s8b = _mm_sub_pd(t49, t89);
    *((a7 + 8)) = s8b;
    s9b = _mm_add_pd(t49, t89);
    *((a7 + 24)) = s9b;
    s0c = _mm_add_pd(t59, s4b);
    *((a7 + 4)) = s0c;
    s1c = _mm_sub_pd(t59, s4b);
    *((a7 + 20)) = s1c;
    s2c = _mm_sub_pd(t69, s5b);
    *((a7 + 12)) = s2c;
    s3c = _mm_add_pd(t69, s5b);
    *((a7 + 28)) = s3c;
    t99 = _mm_add_pd(t34, s2a);
    t0a = _mm_sub_pd(t34, s2a);
    t1a = _mm_sub_pd(t44, s3a);
    t2a = _mm_add_pd(t44, s3a);
    t3a = _mm_add_pd(s69, s8a);
    t4a = _mm_sub_pd(s79, s9a);
    a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s69, s8a));
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s79, s9a));
    s4c = _mm_sub_pd(a8, a9);
    s5c = _mm_add_pd(a8, a9);
    s6c = _mm_add_pd(t99, t3a);
    *((a7 + 1)) = s6c;
    s7c = _mm_sub_pd(t99, t3a);
    *((a7 + 17)) = s7c;
    s8c = _mm_sub_pd(t0a, t4a);
    *((a7 + 9)) = s8c;
    s9c = _mm_add_pd(t0a, t4a);
    *((a7 + 25)) = s9c;
    s0d = _mm_add_pd(t1a, s4c);
    *((a7 + 5)) = s0d;
    s1d = _mm_sub_pd(t1a, s4c);
    *((a7 + 21)) = s1d;
    s2d = _mm_sub_pd(t2a, s5c);
    *((a7 + 13)) = s2d;
    s3d = _mm_add_pd(t2a, s5c);
    *((a7 + 29)) = s3d;
    t5a = _mm_add_pd(t14, s4a);
    t6a = _mm_sub_pd(t14, s4a);
    t7a = _mm_sub_pd(t24, s5a);
    t8a = _mm_add_pd(t24, s5a);
    t9a = _mm_add_pd(s89, s0b);
    t0b = _mm_sub_pd(s99, s1b);
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s89, s0b));
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s99, s1b));
    s4d = _mm_sub_pd(a01, a11);
    s5d = _mm_add_pd(a01, a11);
    s6d = _mm_add_pd(t5a, t9a);
    *((a7 + 2)) = s6d;
    s7d = _mm_sub_pd(t5a, t9a);
    *((a7 + 18)) = s7d;
    s8d = _mm_sub_pd(t6a, t0b);
    *((a7 + 10)) = s8d;
    s9d = _mm_add_pd(t6a, t0b);
    *((a7 + 26)) = s9d;
    s0e = _mm_add_pd(t7a, s4d);
    *((a7 + 6)) = s0e;
    s1e = _mm_sub_pd(t7a, s4d);
    *((a7 + 22)) = s1e;
    s2e = _mm_sub_pd(t8a, s5d);
    *((a7 + 14)) = s2e;
    s3e = _mm_add_pd(t8a, s5d);
    *((a7 + 30)) = s3e;
    t1b = _mm_add_pd(t54, s6a);
    t2b = _mm_sub_pd(t54, s6a);
    t3b = _mm_sub_pd(t64, s7a);
    t4b = _mm_add_pd(t64, s7a);
    t5b = _mm_add_pd(s0a, s2b);
    t6b = _mm_sub_pd(s1a, s3b);
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0a, s2b));
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1a, s3b));
    s4e = _mm_sub_pd(a21, a31);
    s5e = _mm_add_pd(a21, a31);
    s6e = _mm_add_pd(t1b, t5b);
    *((a7 + 3)) = s6e;
    s7e = _mm_sub_pd(t1b, t5b);
    *((a7 + 19)) = s7e;
    s8e = _mm_sub_pd(t2b, t6b);
    *((a7 + 11)) = s8e;
    s9e = _mm_add_pd(t2b, t6b);
    *((a7 + 27)) = s9e;
    s0f = _mm_add_pd(t3b, s4e);
    *((a7 + 7)) = s0f;
    s1f = _mm_sub_pd(t3b, s4e);
    *((a7 + 23)) = s1f;
    s2f = _mm_sub_pd(t4b, s5e);
    *((a7 + 15)) = s2f;
    s3f = _mm_add_pd(t4b, s5e);
    *((a7 + 31)) = s3f;
    {long i; for(i = 0; i <= 30; i++) {
        a41 = (2 * i);
        b = (src + a41);
        s4f = _mm_loadu_pd(((const double  *) (b + 2)));
        b2 = (src - a41);
        s5f = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 2046))));
        t7b = _mm_add_pd(s4f, s5f);
        t8b = _mm_sub_pd(s4f, s5f);
        s6f = v_lo2(t7b, t8b);
        s7f = v_hi2(t7b, t8b);
        a51 = (32 * i);
        a61 = (D73 + a51);
        a71 = *(a61);
        a81 = *((a61 + 1));
        s8f = _mm_add_pd(_mm_mul_pd(a71, s6f), _mm_mul_pd(a81, s7f));
        s9f = _mm_sub_pd(_mm_mul_pd(a71, s7f), _mm_mul_pd(a81, s6f));
        s0g = _mm_loadu_pd(((const double  *) (b + 130)));
        s1g = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1918))));
        t9b = _mm_add_pd(s0g, s1g);
        t0c = _mm_sub_pd(s0g, s1g);
        s2g = v_lo2(t9b, t0c);
        s3g = v_hi2(t9b, t0c);
        a91 = *((a61 + 2));
        a02 = *((a61 + 3));
        s4g = _mm_add_pd(_mm_mul_pd(a91, s2g), _mm_mul_pd(a02, s3g));
        s5g = _mm_sub_pd(_mm_mul_pd(a91, s3g), _mm_mul_pd(a02, s2g));
        s6g = _mm_loadu_pd(((const double  *) (b + 258)));
        s7g = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1790))));
        t1c = _mm_add_pd(s6g, s7g);
        t2c = _mm_sub_pd(s6g, s7g);
        s8g = v_lo2(t1c, t2c);
        s9g = v_hi2(t1c, t2c);
        a12 = *((a61 + 4));
        a22 = *((a61 + 5));
        s0h = _mm_add_pd(_mm_mul_pd(a12, s8g), _mm_mul_pd(a22, s9g));
        s1h = _mm_sub_pd(_mm_mul_pd(a12, s9g), _mm_mul_pd(a22, s8g));
        s2h = _mm_loadu_pd(((const double  *) (b + 386)));
        s3h = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1662))));
        t3c = _mm_add_pd(s2h, s3h);
        t4c = _mm_sub_pd(s2h, s3h);
        s4h = v_lo2(t3c, t4c);
        s5h = v_hi2(t3c, t4c);
        a32 = *((a61 + 6));
        a42 = *((a61 + 7));
        s6h = _mm_add_pd(_mm_mul_pd(a32, s4h), _mm_mul_pd(a42, s5h));
        s7h = _mm_sub_pd(_mm_mul_pd(a32, s5h), _mm_mul_pd(a42, s4h));
        s8h = _mm_loadu_pd(((const double  *) (b + 514)));
        s9h = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1534))));
        t5c = _mm_add_pd(s8h, s9h);
        t6c = _mm_sub_pd(s8h, s9h);
        s0i = v_lo2(t5c, t6c);
        s1i = v_hi2(t5c, t6c);
        a52 = *((a61 + 8));
        a62 = *((a61 + 9));
        s2i = _mm_add_pd(_mm_mul_pd(a52, s0i), _mm_mul_pd(a62, s1i));
        s3i = _mm_sub_pd(_mm_mul_pd(a52, s1i), _mm_mul_pd(a62, s0i));
        s4i = _mm_loadu_pd(((const double  *) (b + 642)));
        s5i = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1406))));
        t7c = _mm_add_pd(s4i, s5i);
        t8c = _mm_sub_pd(s4i, s5i);
        s6i = v_lo2(t7c, t8c);
        s7i = v_hi2(t7c, t8c);
        a72 = *((a61 + 10));
        a82 = *((a61 + 11));
        s8i = _mm_add_pd(_mm_mul_pd(a72, s6i), _mm_mul_pd(a82, s7i));
        s9i = _mm_sub_pd(_mm_mul_pd(a72, s7i), _mm_mul_pd(a82, s6i));
        s0j = _mm_loadu_pd(((const double  *) (b + 770)));
        s1j = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1278))));
        t9c = _mm_add_pd(s0j, s1j);
        t0d = _mm_sub_pd(s0j, s1j);
        s2j = v_lo2(t9c, t0d);
        s3j = v_hi2(t9c, t0d);
        a92 = *((a61 + 12));
        a03 = *((a61 + 13));
        s4j = _mm_add_pd(_mm_mul_pd(a92, s2j), _mm_mul_pd(a03, s3j));
        s5j = _mm_sub_pd(_mm_mul_pd(a92, s3j), _mm_mul_pd(a03, s2j));
        s6j = _mm_loadu_pd(((const double  *) (b + 898)));
        s7j = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1150))));
        t1d = _mm_add_pd(s6j, s7j);
        t2d = _mm_sub_pd(s6j, s7j);
        s8j = v_lo2(t1d, t2d);
        s9j = v_hi2(t1d, t2d);
        a13 = *((a61 + 14));
        a23 = *((a61 + 15));
        s0k = _mm_add_pd(_mm_mul_pd(a13, s8j), _mm_mul_pd(a23, s9j));
        s1k = _mm_sub_pd(_mm_mul_pd(a13, s9j), _mm_mul_pd(a23, s8j));
        s2k = _mm_loadu_pd(((const double  *) (b + 1026)));
        s3k = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1022))));
        t3d = _mm_add_pd(s2k, s3k);
        t4d = _mm_sub_pd(s2k, s3k);
        s4k = v_lo2(t3d, t4d);
        s5k = v_hi2(t3d, t4d);
        a33 = *((a61 + 16));
        a43 = *((a61 + 17));
        s6k = _mm_add_pd(_mm_mul_pd(a33, s4k), _mm_mul_pd(a43, s5k));
        s7k = _mm_sub_pd(_mm_mul_pd(a33, s5k), _mm_mul_pd(a43, s4k));
        s8k = _mm_loadu_pd(((const double  *) (b + 1154)));
        s9k = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 894))));
        t5d = _mm_add_pd(s8k, s9k);
        t6d = _mm_sub_pd(s8k, s9k);
        s0l = v_lo2(t5d, t6d);
        s1l = v_hi2(t5d, t6d);
        a53 = *((a61 + 18));
        a63 = *((a61 + 19));
        s2l = _mm_add_pd(_mm_mul_pd(a53, s0l), _mm_mul_pd(a63, s1l));
        s3l = _mm_sub_pd(_mm_mul_pd(a53, s1l), _mm_mul_pd(a63, s0l));
        s4l = _mm_loadu_pd(((const double  *) (b + 1282)));
        s5l = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 766))));
        t7d = _mm_add_pd(s4l, s5l);
        t8d = _mm_sub_pd(s4l, s5l);
        s6l = v_lo2(t7d, t8d);
        s7l = v_hi2(t7d, t8d);
        a73 = *((a61 + 20));
        a83 = *((a61 + 21));
        s8l = _mm_add_pd(_mm_mul_pd(a73, s6l), _mm_mul_pd(a83, s7l));
        s9l = _mm_sub_pd(_mm_mul_pd(a73, s7l), _mm_mul_pd(a83, s6l));
        s0m = _mm_loadu_pd(((const double  *) (b + 1410)));
        s1m = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 638))));
        t9d = _mm_add_pd(s0m, s1m);
        t0e = _mm_sub_pd(s0m, s1m);
        s2m = v_lo2(t9d, t0e);
        s3m = v_hi2(t9d, t0e);
        a93 = *((a61 + 22));
        a04 = *((a61 + 23));
        s4m = _mm_add_pd(_mm_mul_pd(a93, s2m), _mm_mul_pd(a04, s3m));
        s5m = _mm_sub_pd(_mm_mul_pd(a93, s3m), _mm_mul_pd(a04, s2m));
        s6m = _mm_loadu_pd(((const double  *) (b + 1538)));
        s7m = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 510))));
        t1e = _mm_add_pd(s6m, s7m);
        t2e = _mm_sub_pd(s6m, s7m);
        s8m = v_lo2(t1e, t2e);
        s9m = v_hi2(t1e, t2e);
        a14 = *((a61 + 24));
        a24 = *((a61 + 25));
        s0n = _mm_add_pd(_mm_mul_pd(a14, s8m), _mm_mul_pd(a24, s9m));
        s1n = _mm_sub_pd(_mm_mul_pd(a14, s9m), _mm_mul_pd(a24, s8m));
        s2n = _mm_loadu_pd(((const double  *) (b + 1666)));
        s3n = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 382))));
        t3e = _mm_add_pd(s2n, s3n);
        t4e = _mm_sub_pd(s2n, s3n);
        s4n = v_lo2(t3e, t4e);
        s5n = v_hi2(t3e, t4e);
        a34 = *((a61 + 26));
        a44 = *((a61 + 27));
        s6n = _mm_add_pd(_mm_mul_pd(a34, s4n), _mm_mul_pd(a44, s5n));
        s7n = _mm_sub_pd(_mm_mul_pd(a34, s5n), _mm_mul_pd(a44, s4n));
        s8n = _mm_loadu_pd(((const double  *) (b + 1794)));
        s9n = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 254))));
        t5e = _mm_add_pd(s8n, s9n);
        t6e = _mm_sub_pd(s8n, s9n);
        s0o = v_lo2(t5e, t6e);
        s1o = v_hi2(t5e, t6e);
        a54 = *((a61 + 28));
        a64 = *((a61 + 29));
        s2o = _mm_add_pd(_mm_mul_pd(a54, s0o), _mm_mul_pd(a64, s1o));
        s3o = _mm_sub_pd(_mm_mul_pd(a54, s1o), _mm_mul_pd(a64, s0o));
        s4o = _mm_loadu_pd(((const double  *) (b + 1922)));
        s5o = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 126))));
        t7e = _mm_add_pd(s4o, s5o);
        t8e = _mm_sub_pd(s4o, s5o);
        s6o = v_lo2(t7e, t8e);
        s7o = v_hi2(t7e, t8e);
        a74 = *((a61 + 30));
        a84 = *((a61 + 31));
        s8o = _mm_add_pd(_mm_mul_pd(a74, s6o), _mm_mul_pd(a84, s7o));
        s9o = _mm_sub_pd(_mm_mul_pd(a74, s7o), _mm_mul_pd(a84, s6o));
        t9e = _mm_add_pd(s8f, s6k);
        t0f = _mm_add_pd(s9f, s7k);
        t1f = _mm_sub_pd(s8f, s6k);
        t2f = _mm_sub_pd(s9f, s7k);
        t3f = _mm_add_pd(s4g, s2l);
        t4f = _mm_add_pd(s5g, s3l);
        t5f = _mm_sub_pd(s4g, s2l);
        t6f = _mm_sub_pd(s5g, s3l);
        s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6f));
        s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6f));
        t7f = _mm_add_pd(s0h, s8l);
        t8f = _mm_add_pd(s1h, s9l);
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0h, s8l));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1h, s9l));
        s2p = _mm_sub_pd(a94, a05);
        s3p = _mm_add_pd(a94, a05);
        t9f = _mm_add_pd(s6h, s4m);
        t0g = _mm_add_pd(s7h, s5m);
        t1g = _mm_sub_pd(s6h, s4m);
        t2g = _mm_sub_pd(s7h, s5m);
        s4p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1g), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2g));
        s5p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1g), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2g));
        t3g = _mm_add_pd(s2i, s0n);
        t4g = _mm_add_pd(s3i, s1n);
        t5g = _mm_sub_pd(s2i, s0n);
        t6g = _mm_sub_pd(s3i, s1n);
        t7g = _mm_add_pd(s8i, s6n);
        t8g = _mm_add_pd(s9i, s7n);
        t9g = _mm_sub_pd(s8i, s6n);
        t0h = _mm_sub_pd(s9i, s7n);
        s6p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9g), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0h));
        s7p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9g), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0h));
        t1h = _mm_add_pd(s4j, s2o);
        t2h = _mm_add_pd(s5j, s3o);
        a15 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s4j, s2o));
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5j, s3o));
        s8p = _mm_sub_pd(a15, a25);
        s9p = _mm_add_pd(a15, a25);
        t3h = _mm_add_pd(s0k, s8o);
        t4h = _mm_add_pd(s1k, s9o);
        t5h = _mm_sub_pd(s0k, s8o);
        t6h = _mm_sub_pd(s1k, s9o);
        s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6h));
        s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5h), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6h));
        t7h = _mm_add_pd(t9e, t3g);
        t8h = _mm_add_pd(t0f, t4g);
        t9h = _mm_sub_pd(t9e, t3g);
        t0i = _mm_sub_pd(t0f, t4g);
        t1i = _mm_add_pd(t7f, t1h);
        t2i = _mm_add_pd(t8f, t2h);
        t3i = _mm_sub_pd(t7f, t1h);
        t4i = _mm_sub_pd(t8f, t2h);
        t5i = _mm_add_pd(t7h, t1i);
        t6i = _mm_add_pd(t8h, t2i);
        t7i = _mm_sub_pd(t7h, t1i);
        t8i = _mm_sub_pd(t8h, t2i);
        t9i = _mm_sub_pd(t9h, t4i);
        t0j = _mm_add_pd(t0i, t3i);
        t1j = _mm_add_pd(t9h, t4i);
        t2j = _mm_sub_pd(t0i, t3i);
        t3j = _mm_add_pd(t3f, t7g);
        t4j = _mm_add_pd(t4f, t8g);
        t5j = _mm_sub_pd(t3f, t7g);
        t6j = _mm_sub_pd(t4f, t8g);
        t7j = _mm_add_pd(t9f, t3h);
        t8j = _mm_add_pd(t0g, t4h);
        t9j = _mm_sub_pd(t9f, t3h);
        t0k = _mm_sub_pd(t0g, t4h);
        t1k = _mm_add_pd(t3j, t7j);
        t2k = _mm_add_pd(t4j, t8j);
        t3k = _mm_sub_pd(t3j, t7j);
        t4k = _mm_sub_pd(t4j, t8j);
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5j, t0k));
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6j, t9j));
        s2q = _mm_sub_pd(a35, a45);
        s3q = _mm_add_pd(a35, a45);
        a55 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5j, t0k));
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6j, t9j));
        s4q = _mm_sub_pd(a55, a65);
        s5q = _mm_add_pd(a55, a65);
        t5k = _mm_add_pd(t5i, t1k);
        t6k = _mm_add_pd(t6i, t2k);
        t7k = _mm_sub_pd(t5i, t1k);
        t8k = _mm_sub_pd(t6i, t2k);
        t9k = _mm_add_pd(t9i, s2q);
        t0l = _mm_add_pd(t0j, s3q);
        t1l = _mm_sub_pd(t9i, s2q);
        t2l = _mm_sub_pd(t0j, s3q);
        t3l = _mm_sub_pd(t7i, t4k);
        t4l = _mm_add_pd(t8i, t3k);
        t5l = _mm_add_pd(t7i, t4k);
        t6l = _mm_sub_pd(t8i, t3k);
        t7l = _mm_add_pd(t1j, s4q);
        t8l = _mm_sub_pd(t2j, s5q);
        t9l = _mm_sub_pd(t1j, s4q);
        t0m = _mm_add_pd(t2j, s5q);
        t1m = _mm_sub_pd(t1f, t6g);
        t2m = _mm_add_pd(t2f, t5g);
        t3m = _mm_add_pd(t1f, t6g);
        t4m = _mm_sub_pd(t2f, t5g);
        t5m = _mm_add_pd(s2p, s8p);
        t6m = _mm_sub_pd(s3p, s9p);
        t7m = _mm_sub_pd(s2p, s8p);
        t8m = _mm_add_pd(s3p, s9p);
        t9m = _mm_add_pd(t1m, t5m);
        t0n = _mm_add_pd(t2m, t6m);
        t1n = _mm_sub_pd(t1m, t5m);
        t2n = _mm_sub_pd(t2m, t6m);
        t3n = _mm_sub_pd(t3m, t8m);
        t4n = _mm_add_pd(t4m, t7m);
        t5n = _mm_add_pd(t3m, t8m);
        t6n = _mm_sub_pd(t4m, t7m);
        t7n = _mm_add_pd(s0p, s6p);
        t8n = _mm_add_pd(s1p, s7p);
        t9n = _mm_sub_pd(s0p, s6p);
        t0o = _mm_sub_pd(s1p, s7p);
        t1o = _mm_add_pd(s4p, s0q);
        t2o = _mm_add_pd(s5p, s1q);
        t3o = _mm_sub_pd(s4p, s0q);
        t4o = _mm_sub_pd(s5p, s1q);
        t5o = _mm_add_pd(t7n, t1o);
        t6o = _mm_add_pd(t8n, t2o);
        t7o = _mm_sub_pd(t7n, t1o);
        t8o = _mm_sub_pd(t8n, t2o);
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9n, t4o));
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0o, t3o));
        s6q = _mm_sub_pd(a75, a85);
        s7q = _mm_add_pd(a75, a85);
        a95 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t9n, t4o));
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0o, t3o));
        s8q = _mm_sub_pd(a95, a06);
        s9q = _mm_add_pd(a95, a06);
        t9o = _mm_add_pd(t9m, t5o);
        t0p = _mm_add_pd(t0n, t6o);
        t1p = _mm_sub_pd(t9m, t5o);
        t2p = _mm_sub_pd(t0n, t6o);
        t3p = _mm_add_pd(t3n, s6q);
        t4p = _mm_add_pd(t4n, s7q);
        t5p = _mm_sub_pd(t3n, s6q);
        t6p = _mm_sub_pd(t4n, s7q);
        t7p = _mm_sub_pd(t1n, t8o);
        t8p = _mm_add_pd(t2n, t7o);
        t9p = _mm_add_pd(t1n, t8o);
        t0q = _mm_sub_pd(t2n, t7o);
        t1q = _mm_add_pd(t5n, s8q);
        t2q = _mm_sub_pd(t6n, s9q);
        t3q = _mm_sub_pd(t5n, s8q);
        t4q = _mm_add_pd(t6n, s9q);
        a16 = (D72 + a51);
        a26 = *(a16);
        a36 = *((a16 + 1));
        a46 = *((a16 + 2));
        a56 = *((a16 + 3));
        a66 = *((a16 + 4));
        a76 = *((a16 + 5));
        a86 = *((a16 + 6));
        a96 = *((a16 + 7));
        a07 = *((a16 + 8));
        a17 = *((a16 + 9));
        a27 = *((a16 + 10));
        a37 = *((a16 + 11));
        a47 = *((a16 + 12));
        a57 = *((a16 + 13));
        a67 = *((a16 + 14));
        a77 = *((a16 + 15));
        a87 = *((a16 + 16));
        a97 = *((a16 + 17));
        a08 = *((a16 + 18));
        a18 = *((a16 + 19));
        a28 = *((a16 + 20));
        a38 = *((a16 + 21));
        a48 = *((a16 + 22));
        a58 = *((a16 + 23));
        a68 = *((a16 + 24));
        a78 = *((a16 + 25));
        a88 = *((a16 + 26));
        a98 = *((a16 + 27));
        a09 = *((a16 + 28));
        a19 = *((a16 + 29));
        a29 = *((a16 + 30));
        a39 = *((a16 + 31));
        b3 = (((__m128d  *) T) + a51);
        s0r = _mm_sub_pd(_mm_mul_pd(a26, t5k), _mm_mul_pd(a36, t6k));
        *((b3 + 32)) = s0r;
        s1r = _mm_add_pd(_mm_mul_pd(a36, t5k), _mm_mul_pd(a26, t6k));
        *((b3 + 48)) = s1r;
        s2r = _mm_sub_pd(_mm_mul_pd(a46, t9o), _mm_mul_pd(a56, t0p));
        *((b3 + 33)) = s2r;
        s3r = _mm_add_pd(_mm_mul_pd(a56, t9o), _mm_mul_pd(a46, t0p));
        *((b3 + 49)) = s3r;
        s4r = _mm_sub_pd(_mm_mul_pd(a66, t9k), _mm_mul_pd(a76, t0l));
        *((b3 + 34)) = s4r;
        s5r = _mm_add_pd(_mm_mul_pd(a76, t9k), _mm_mul_pd(a66, t0l));
        *((b3 + 50)) = s5r;
        s6r = _mm_sub_pd(_mm_mul_pd(a86, t3p), _mm_mul_pd(a96, t4p));
        *((b3 + 35)) = s6r;
        s7r = _mm_add_pd(_mm_mul_pd(a96, t3p), _mm_mul_pd(a86, t4p));
        *((b3 + 51)) = s7r;
        s8r = _mm_sub_pd(_mm_mul_pd(a07, t3l), _mm_mul_pd(a17, t4l));
        *((b3 + 36)) = s8r;
        s9r = _mm_add_pd(_mm_mul_pd(a17, t3l), _mm_mul_pd(a07, t4l));
        *((b3 + 52)) = s9r;
        s0s = _mm_sub_pd(_mm_mul_pd(a27, t7p), _mm_mul_pd(a37, t8p));
        *((b3 + 37)) = s0s;
        s1s = _mm_add_pd(_mm_mul_pd(a37, t7p), _mm_mul_pd(a27, t8p));
        *((b3 + 53)) = s1s;
        s2s = _mm_sub_pd(_mm_mul_pd(a47, t7l), _mm_mul_pd(a57, t8l));
        *((b3 + 38)) = s2s;
        s3s = _mm_add_pd(_mm_mul_pd(a57, t7l), _mm_mul_pd(a47, t8l));
        *((b3 + 54)) = s3s;
        s4s = _mm_sub_pd(_mm_mul_pd(a67, t1q), _mm_mul_pd(a77, t2q));
        *((b3 + 39)) = s4s;
        s5s = _mm_add_pd(_mm_mul_pd(a77, t1q), _mm_mul_pd(a67, t2q));
        *((b3 + 55)) = s5s;
        s6s = _mm_sub_pd(_mm_mul_pd(a87, t7k), _mm_mul_pd(a97, t8k));
        *((b3 + 40)) = s6s;
        s7s = _mm_add_pd(_mm_mul_pd(a97, t7k), _mm_mul_pd(a87, t8k));
        *((b3 + 56)) = s7s;
        s8s = _mm_sub_pd(_mm_mul_pd(a08, t1p), _mm_mul_pd(a18, t2p));
        *((b3 + 41)) = s8s;
        s9s = _mm_add_pd(_mm_mul_pd(a18, t1p), _mm_mul_pd(a08, t2p));
        *((b3 + 57)) = s9s;
        s0t = _mm_sub_pd(_mm_mul_pd(a28, t1l), _mm_mul_pd(a38, t2l));
        *((b3 + 42)) = s0t;
        s1t = _mm_add_pd(_mm_mul_pd(a38, t1l), _mm_mul_pd(a28, t2l));
        *((b3 + 58)) = s1t;
        s2t = _mm_sub_pd(_mm_mul_pd(a48, t5p), _mm_mul_pd(a58, t6p));
        *((b3 + 43)) = s2t;
        s3t = _mm_add_pd(_mm_mul_pd(a58, t5p), _mm_mul_pd(a48, t6p));
        *((b3 + 59)) = s3t;
        s4t = _mm_sub_pd(_mm_mul_pd(a68, t5l), _mm_mul_pd(a78, t6l));
        *((b3 + 44)) = s4t;
        s5t = _mm_add_pd(_mm_mul_pd(a78, t5l), _mm_mul_pd(a68, t6l));
        *((b3 + 60)) = s5t;
        s6t = _mm_sub_pd(_mm_mul_pd(a88, t9p), _mm_mul_pd(a98, t0q));
        *((b3 + 45)) = s6t;
        s7t = _mm_add_pd(_mm_mul_pd(a98, t9p), _mm_mul_pd(a88, t0q));
        *((b3 + 61)) = s7t;
        s8t = _mm_sub_pd(_mm_mul_pd(a09, t9l), _mm_mul_pd(a19, t0m));
        *((b3 + 46)) = s8t;
        s9t = _mm_add_pd(_mm_mul_pd(a19, t9l), _mm_mul_pd(a09, t0m));
        *((b3 + 62)) = s9t;
        s0u = _mm_sub_pd(_mm_mul_pd(a29, t3q), _mm_mul_pd(a39, t4q));
        *((b3 + 47)) = s0u;
        s1u = _mm_add_pd(_mm_mul_pd(a39, t3q), _mm_mul_pd(a29, t4q));
        *((b3 + 63)) = s1u;
    }}
    {long i2; for(i2 = 0; i2 <= 15; i2++) {
        a49 = (((__m128d  *) T) + i2);
        s2u = *(a49);
        s3u = *((a49 + 512));
        t5q = _mm_add_pd(s2u, s3u);
        t6q = _mm_sub_pd(s2u, s3u);
        s4u = *((a49 + 16));
        s5u = *((a49 + 528));
        t7q = _mm_sub_pd(s4u, s5u);
        t8q = _mm_add_pd(s4u, s5u);
        s6u = *((a49 + 256));
        s7u = *((a49 + 272));
        s8u = *((a49 + 768));
        s9u = *((a49 + 784));
        t9q = _mm_add_pd(s6u, s8u);
        t0r = _mm_sub_pd(s7u, s9u);
        a59 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6u, s8u));
        a69 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7u, s9u));
        s0v = _mm_sub_pd(a59, a69);
        s1v = _mm_add_pd(a59, a69);
        t1r = _mm_add_pd(t5q, t9q);
        t2r = _mm_sub_pd(t5q, t9q);
        t3r = _mm_sub_pd(t6q, t0r);
        t4r = _mm_add_pd(t6q, t0r);
        t5r = _mm_add_pd(t7q, s0v);
        t6r = _mm_sub_pd(t7q, s0v);
        t7r = _mm_sub_pd(t8q, s1v);
        t8r = _mm_add_pd(t8q, s1v);
        s2v = *((a49 + 32));
        s3v = *((a49 + 48));
        s4v = *((a49 + 992));
        s5v = *((a49 + 1008));
        t9r = _mm_add_pd(s2v, s4v);
        t0s = _mm_sub_pd(s3v, s5v);
        t1s = _mm_sub_pd(s2v, s4v);
        t2s = _mm_add_pd(s3v, s5v);
        s6v = *((a49 + 544));
        s7v = *((a49 + 560));
        s8v = *((a49 + 480));
        s9v = *((a49 + 496));
        t3s = _mm_add_pd(s6v, s8v);
        t4s = _mm_sub_pd(s7v, s9v);
        t5s = _mm_sub_pd(s6v, s8v);
        t6s = _mm_add_pd(s7v, s9v);
        t7s = _mm_add_pd(t9r, t3s);
        t8s = _mm_add_pd(t0s, t4s);
        t9s = _mm_sub_pd(t9r, t3s);
        t0t = _mm_sub_pd(t0s, t4s);
        t1t = _mm_sub_pd(t1s, t6s);
        t2t = _mm_add_pd(t2s, t5s);
        t3t = _mm_add_pd(t1s, t6s);
        t4t = _mm_sub_pd(t2s, t5s);
        s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1t), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2t));
        s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1t), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2t));
        s2w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9s), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0t));
        s3w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9s), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0t));
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3t), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4t));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3t), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4t));
        s6w = *((a49 + 64));
        s7w = *((a49 + 80));
        s8w = *((a49 + 960));
        s9w = *((a49 + 976));
        t5t = _mm_add_pd(s6w, s8w);
        t6t = _mm_sub_pd(s7w, s9w);
        t7t = _mm_sub_pd(s6w, s8w);
        t8t = _mm_add_pd(s7w, s9w);
        s0x = *((a49 + 576));
        s1x = *((a49 + 592));
        s2x = *((a49 + 448));
        s3x = *((a49 + 464));
        t9t = _mm_add_pd(s0x, s2x);
        t0u = _mm_sub_pd(s1x, s3x);
        t1u = _mm_sub_pd(s0x, s2x);
        t2u = _mm_add_pd(s1x, s3x);
        t3u = _mm_add_pd(t5t, t9t);
        t4u = _mm_add_pd(t6t, t0u);
        t5u = _mm_sub_pd(t5t, t9t);
        t6u = _mm_sub_pd(t6t, t0u);
        t7u = _mm_sub_pd(t7t, t2u);
        t8u = _mm_add_pd(t8t, t1u);
        t9u = _mm_add_pd(t7t, t2u);
        t0v = _mm_sub_pd(t8t, t1u);
        s4x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7u), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8u));
        s5x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7u), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8u));
        s6x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5u), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6u));
        s7x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5u), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6u));
        s8x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9u), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0v));
        s9x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9u), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0v));
        s0y = *((a49 + 96));
        s1y = *((a49 + 112));
        s2y = *((a49 + 928));
        s3y = *((a49 + 944));
        t1v = _mm_add_pd(s0y, s2y);
        t2v = _mm_sub_pd(s1y, s3y);
        t3v = _mm_sub_pd(s0y, s2y);
        t4v = _mm_add_pd(s1y, s3y);
        s4y = *((a49 + 608));
        s5y = *((a49 + 624));
        s6y = *((a49 + 416));
        s7y = *((a49 + 432));
        t5v = _mm_add_pd(s4y, s6y);
        t6v = _mm_sub_pd(s5y, s7y);
        t7v = _mm_sub_pd(s4y, s6y);
        t8v = _mm_add_pd(s5y, s7y);
        t9v = _mm_add_pd(t1v, t5v);
        t0w = _mm_add_pd(t2v, t6v);
        t1w = _mm_sub_pd(t1v, t5v);
        t2w = _mm_sub_pd(t2v, t6v);
        t3w = _mm_sub_pd(t3v, t8v);
        t4w = _mm_add_pd(t4v, t7v);
        t5w = _mm_add_pd(t3v, t8v);
        t6w = _mm_sub_pd(t4v, t7v);
        s8y = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3w), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4w));
        s9y = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3w), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4w));
        s0z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1w), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2w));
        s1z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1w), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2w));
        s2z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5w), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6w));
        s3z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5w), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6w));
        s4z = *((a49 + 128));
        s5z = *((a49 + 144));
        s6z = *((a49 + 896));
        s7z = *((a49 + 912));
        t7w = _mm_add_pd(s4z, s6z);
        t8w = _mm_sub_pd(s5z, s7z);
        t9w = _mm_sub_pd(s4z, s6z);
        t0x = _mm_add_pd(s5z, s7z);
        s8z = *((a49 + 640));
        s9z = *((a49 + 656));
        s0A = *((a49 + 384));
        s1A = *((a49 + 400));
        t1x = _mm_add_pd(s8z, s0A);
        t2x = _mm_sub_pd(s9z, s1A);
        t3x = _mm_sub_pd(s8z, s0A);
        t4x = _mm_add_pd(s9z, s1A);
        t5x = _mm_add_pd(t7w, t1x);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_sub_pd(t9w, t4x);
        t8x = _mm_add_pd(t0x, t3x);
        t9x = _mm_add_pd(t9w, t4x);
        t0y = _mm_sub_pd(t0x, t3x);
        s2A = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8x));
        s3A = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8x));
        a79 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7w, t1x));
        a89 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8w, t2x));
        s4A = _mm_sub_pd(a79, a89);
        s5A = _mm_add_pd(a79, a89);
        s6A = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0y));
        s7A = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0y));
        s8A = *((a49 + 160));
        s9A = *((a49 + 176));
        s0B = *((a49 + 864));
        s1B = *((a49 + 880));
        t1y = _mm_add_pd(s8A, s0B);
        t2y = _mm_sub_pd(s9A, s1B);
        t3y = _mm_sub_pd(s8A, s0B);
        t4y = _mm_add_pd(s9A, s1B);
        s2B = *((a49 + 672));
        s3B = *((a49 + 688));
        s4B = *((a49 + 352));
        s5B = *((a49 + 368));
        t5y = _mm_add_pd(s2B, s4B);
        t6y = _mm_sub_pd(s3B, s5B);
        t7y = _mm_sub_pd(s2B, s4B);
        t8y = _mm_add_pd(s3B, s5B);
        t9y = _mm_add_pd(t1y, t5y);
        t0z = _mm_add_pd(t2y, t6y);
        t1z = _mm_sub_pd(t1y, t5y);
        t2z = _mm_sub_pd(t2y, t6y);
        t3z = _mm_sub_pd(t3y, t8y);
        t4z = _mm_add_pd(t4y, t7y);
        t5z = _mm_add_pd(t3y, t8y);
        t6z = _mm_sub_pd(t4y, t7y);
        s6B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t3z), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t4z));
        s7B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t3z), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t4z));
        s8B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1z), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2z));
        s9B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1z), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2z));
        s0C = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t5z), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t6z));
        s1C = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t5z), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t6z));
        s2C = *((a49 + 192));
        s3C = *((a49 + 208));
        s4C = *((a49 + 832));
        s5C = *((a49 + 848));
        t7z = _mm_add_pd(s2C, s4C);
        t8z = _mm_sub_pd(s3C, s5C);
        t9z = _mm_sub_pd(s2C, s4C);
        t0A = _mm_add_pd(s3C, s5C);
        s6C = *((a49 + 704));
        s7C = *((a49 + 720));
        s8C = *((a49 + 320));
        s9C = *((a49 + 336));
        t1A = _mm_add_pd(s6C, s8C);
        t2A = _mm_sub_pd(s7C, s9C);
        t3A = _mm_sub_pd(s6C, s8C);
        t4A = _mm_add_pd(s7C, s9C);
        t5A = _mm_add_pd(t7z, t1A);
        t6A = _mm_add_pd(t8z, t2A);
        t7A = _mm_sub_pd(t7z, t1A);
        t8A = _mm_sub_pd(t8z, t2A);
        t9A = _mm_sub_pd(t9z, t4A);
        t0B = _mm_add_pd(t0A, t3A);
        t1B = _mm_add_pd(t9z, t4A);
        t2B = _mm_sub_pd(t0A, t3A);
        s0D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9A), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0B));
        s1D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9A), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0B));
        s2D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8A));
        s3D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8A));
        s4D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1B), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2B));
        s5D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1B), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2B));
        s6D = *((a49 + 224));
        s7D = *((a49 + 240));
        s8D = *((a49 + 800));
        s9D = *((a49 + 816));
        t3B = _mm_add_pd(s6D, s8D);
        t4B = _mm_sub_pd(s7D, s9D);
        t5B = _mm_sub_pd(s6D, s8D);
        t6B = _mm_add_pd(s7D, s9D);
        s0E = *((a49 + 736));
        s1E = *((a49 + 752));
        s2E = *((a49 + 288));
        s3E = *((a49 + 304));
        t7B = _mm_add_pd(s0E, s2E);
        t8B = _mm_sub_pd(s1E, s3E);
        t9B = _mm_sub_pd(s0E, s2E);
        t0C = _mm_add_pd(s1E, s3E);
        t1C = _mm_add_pd(t3B, t7B);
        t2C = _mm_add_pd(t4B, t8B);
        t3C = _mm_sub_pd(t3B, t7B);
        t4C = _mm_sub_pd(t4B, t8B);
        t5C = _mm_sub_pd(t5B, t0C);
        t6C = _mm_add_pd(t6B, t9B);
        t7C = _mm_add_pd(t5B, t0C);
        t8C = _mm_sub_pd(t6B, t9B);
        s4E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5C), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6C));
        s5E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5C), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6C));
        s6E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3C), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4C));
        s7E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3C), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4C));
        s8E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7C), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8C));
        s9E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7C), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8C));
        t9C = _mm_add_pd(t1r, t5x);
        t0D = _mm_sub_pd(t1r, t5x);
        t1D = _mm_sub_pd(t2r, t6x);
        t2D = _mm_add_pd(t2r, t6x);
        t3D = _mm_add_pd(t3u, t5A);
        t4D = _mm_sub_pd(t4u, t6A);
        a99 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3u, t5A));
        a0a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4u, t6A));
        s0F = _mm_sub_pd(a99, a0a);
        s1F = _mm_add_pd(a99, a0a);
        t5D = _mm_add_pd(t9C, t3D);
        t6D = _mm_sub_pd(t9C, t3D);
        t7D = _mm_sub_pd(t0D, t4D);
        t8D = _mm_add_pd(t0D, t4D);
        t9D = _mm_add_pd(t1D, s0F);
        t0E = _mm_sub_pd(t1D, s0F);
        t1E = _mm_sub_pd(t2D, s1F);
        t2E = _mm_add_pd(t2D, s1F);
        t3E = _mm_add_pd(t7s, t1C);
        t4E = _mm_sub_pd(t8s, t2C);
        t5E = _mm_sub_pd(t7s, t1C);
        t6E = _mm_add_pd(t8s, t2C);
        t7E = _mm_add_pd(t9y, t9v);
        t8E = _mm_sub_pd(t0z, t0w);
        t9E = _mm_sub_pd(t9y, t9v);
        t0F = _mm_add_pd(t0z, t0w);
        t1F = _mm_add_pd(t3E, t7E);
        t2F = _mm_add_pd(t4E, t8E);
        t3F = _mm_sub_pd(t5E, t0F);
        t4F = _mm_add_pd(t6E, t9E);
        t5F = _mm_add_pd(t5E, t0F);
        t6F = _mm_sub_pd(t6E, t9E);
        s2F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4F));
        s3F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4F));
        a1a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3E, t7E));
        a2a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4E, t8E));
        s4F = _mm_sub_pd(a1a, a2a);
        s5F = _mm_add_pd(a1a, a2a);
        s6F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6F));
        s7F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6F));
        a3a = (dst + (2 * i2));
        s8F = _mm_add_pd(t5D, t1F);
        _mm_storeu_pd(((double  *) a3a), s8F);
        s9F = _mm_sub_pd(t5D, t1F);
        _mm_storeu_pd(((double  *) (a3a + 1024)), s9F);
        s0G = _mm_sub_pd(t6D, t2F);
        _mm_storeu_pd(((double  *) (a3a + 512)), s0G);
        s1G = _mm_add_pd(t6D, t2F);
        _mm_storeu_pd(((double  *) (a3a + 1536)), s1G);
        s2G = _mm_add_pd(t9D, s2F);
        _mm_storeu_pd(((double  *) (a3a + 128)), s2G);
        s3G = _mm_sub_pd(t9D, s2F);
        _mm_storeu_pd(((double  *) (a3a + 1152)), s3G);
        s4G = _mm_sub_pd(t0E, s3F);
        _mm_storeu_pd(((double  *) (a3a + 640)), s4G);
        s5G = _mm_add_pd(t0E, s3F);
        _mm_storeu_pd(((double  *) (a3a + 1664)), s5G);
        s6G = _mm_add_pd(t7D, s4F);
        _mm_storeu_pd(((double  *) (a3a + 256)), s6G);
        s7G = _mm_sub_pd(t7D, s4F);
        _mm_storeu_pd(((double  *) (a3a + 1280)), s7G);
        s8G = _mm_sub_pd(t8D, s5F);
        _mm_storeu_pd(((double  *) (a3a + 768)), s8G);
        s9G = _mm_add_pd(t8D, s5F);
        _mm_storeu_pd(((double  *) (a3a + 1792)), s9G);
        s0H = _mm_add_pd(t1E, s6F);
        _mm_storeu_pd(((double  *) (a3a + 384)), s0H);
        s1H = _mm_sub_pd(t1E, s6F);
        _mm_storeu_pd(((double  *) (a3a + 1408)), s1H);
        s2H = _mm_sub_pd(t2E, s7F);
        _mm_storeu_pd(((double  *) (a3a + 896)), s2H);
        s3H = _mm_add_pd(t2E, s7F);
        _mm_storeu_pd(((double  *) (a3a + 1920)), s3H);
        t7F = _mm_add_pd(t5r, s2A);
        t8F = _mm_sub_pd(t5r, s2A);
        t9F = _mm_sub_pd(t6r, s3A);
        t0G = _mm_add_pd(t6r, s3A);
        t1G = _mm_add_pd(s4x, s0D);
        t2G = _mm_sub_pd(s5x, s1D);
        a4a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4x, s0D));
        a5a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5x, s1D));
        s4H = _mm_sub_pd(a4a, a5a);
        s5H = _mm_add_pd(a4a, a5a);
        t3G = _mm_add_pd(t7F, t1G);
        t4G = _mm_sub_pd(t7F, t1G);
        t5G = _mm_sub_pd(t8F, t2G);
        t6G = _mm_add_pd(t8F, t2G);
        t7G = _mm_add_pd(t9F, s4H);
        t8G = _mm_sub_pd(t9F, s4H);
        t9G = _mm_sub_pd(t0G, s5H);
        t0H = _mm_add_pd(t0G, s5H);
        t1H = _mm_add_pd(s0w, s4E);
        t2H = _mm_sub_pd(s1w, s5E);
        t3H = _mm_sub_pd(s0w, s4E);
        t4H = _mm_add_pd(s1w, s5E);
        t5H = _mm_add_pd(s6B, s8y);
        t6H = _mm_sub_pd(s7B, s9y);
        t7H = _mm_sub_pd(s6B, s8y);
        t8H = _mm_add_pd(s7B, s9y);
        t9H = _mm_add_pd(t1H, t5H);
        t0I = _mm_add_pd(t2H, t6H);
        t1I = _mm_sub_pd(t3H, t8H);
        t2I = _mm_add_pd(t4H, t7H);
        t3I = _mm_add_pd(t3H, t8H);
        t4I = _mm_sub_pd(t4H, t7H);
        s6H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1I), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2I));
        s7H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1I), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2I));
        a6a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1H, t5H));
        a7a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2H, t6H));
        s8H = _mm_sub_pd(a6a, a7a);
        s9H = _mm_add_pd(a6a, a7a);
        s0I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3I), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4I));
        s1I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3I), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4I));
        s2I = _mm_add_pd(t3G, t9H);
        _mm_storeu_pd(((double  *) (a3a + 32)), s2I);
        s3I = _mm_sub_pd(t3G, t9H);
        _mm_storeu_pd(((double  *) (a3a + 1056)), s3I);
        s4I = _mm_sub_pd(t4G, t0I);
        _mm_storeu_pd(((double  *) (a3a + 544)), s4I);
        s5I = _mm_add_pd(t4G, t0I);
        _mm_storeu_pd(((double  *) (a3a + 1568)), s5I);
        s6I = _mm_add_pd(t7G, s6H);
        _mm_storeu_pd(((double  *) (a3a + 160)), s6I);
        s7I = _mm_sub_pd(t7G, s6H);
        _mm_storeu_pd(((double  *) (a3a + 1184)), s7I);
        s8I = _mm_sub_pd(t8G, s7H);
        _mm_storeu_pd(((double  *) (a3a + 672)), s8I);
        s9I = _mm_add_pd(t8G, s7H);
        _mm_storeu_pd(((double  *) (a3a + 1696)), s9I);
        s0J = _mm_add_pd(t5G, s8H);
        _mm_storeu_pd(((double  *) (a3a + 288)), s0J);
        s1J = _mm_sub_pd(t5G, s8H);
        _mm_storeu_pd(((double  *) (a3a + 1312)), s1J);
        s2J = _mm_sub_pd(t6G, s9H);
        _mm_storeu_pd(((double  *) (a3a + 800)), s2J);
        s3J = _mm_add_pd(t6G, s9H);
        _mm_storeu_pd(((double  *) (a3a + 1824)), s3J);
        s4J = _mm_add_pd(t9G, s0I);
        _mm_storeu_pd(((double  *) (a3a + 416)), s4J);
        s5J = _mm_sub_pd(t9G, s0I);
        _mm_storeu_pd(((double  *) (a3a + 1440)), s5J);
        s6J = _mm_sub_pd(t0H, s1I);
        _mm_storeu_pd(((double  *) (a3a + 928)), s6J);
        s7J = _mm_add_pd(t0H, s1I);
        _mm_storeu_pd(((double  *) (a3a + 1952)), s7J);
        t5I = _mm_add_pd(t3r, s4A);
        t6I = _mm_sub_pd(t3r, s4A);
        t7I = _mm_sub_pd(t4r, s5A);
        t8I = _mm_add_pd(t4r, s5A);
        t9I = _mm_add_pd(s6x, s2D);
        t0J = _mm_sub_pd(s7x, s3D);
        a8a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6x, s2D));
        a9a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7x, s3D));
        s8J = _mm_sub_pd(a8a, a9a);
        s9J = _mm_add_pd(a8a, a9a);
        t1J = _mm_add_pd(t5I, t9I);
        t2J = _mm_sub_pd(t5I, t9I);
        t3J = _mm_sub_pd(t6I, t0J);
        t4J = _mm_add_pd(t6I, t0J);
        t5J = _mm_add_pd(t7I, s8J);
        t6J = _mm_sub_pd(t7I, s8J);
        t7J = _mm_sub_pd(t8I, s9J);
        t8J = _mm_add_pd(t8I, s9J);
        t9J = _mm_add_pd(s2w, s6E);
        t0K = _mm_sub_pd(s3w, s7E);
        t1K = _mm_sub_pd(s2w, s6E);
        t2K = _mm_add_pd(s3w, s7E);
        t3K = _mm_add_pd(s8B, s0z);
        t4K = _mm_sub_pd(s9B, s1z);
        t5K = _mm_sub_pd(s8B, s0z);
        t6K = _mm_add_pd(s9B, s1z);
        t7K = _mm_add_pd(t9J, t3K);
        t8K = _mm_add_pd(t0K, t4K);
        t9K = _mm_sub_pd(t1K, t6K);
        t0L = _mm_add_pd(t2K, t5K);
        t1L = _mm_add_pd(t1K, t6K);
        t2L = _mm_sub_pd(t2K, t5K);
        s0K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9K), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0L));
        s1K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9K), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0L));
        a0b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9J, t3K));
        a1b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0K, t4K));
        s2K = _mm_sub_pd(a0b, a1b);
        s3K = _mm_add_pd(a0b, a1b);
        s4K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1L), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2L));
        s5K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1L), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2L));
        s6K = _mm_add_pd(t1J, t7K);
        _mm_storeu_pd(((double  *) (a3a + 64)), s6K);
        s7K = _mm_sub_pd(t1J, t7K);
        _mm_storeu_pd(((double  *) (a3a + 1088)), s7K);
        s8K = _mm_sub_pd(t2J, t8K);
        _mm_storeu_pd(((double  *) (a3a + 576)), s8K);
        s9K = _mm_add_pd(t2J, t8K);
        _mm_storeu_pd(((double  *) (a3a + 1600)), s9K);
        s0L = _mm_add_pd(t5J, s0K);
        _mm_storeu_pd(((double  *) (a3a + 192)), s0L);
        s1L = _mm_sub_pd(t5J, s0K);
        _mm_storeu_pd(((double  *) (a3a + 1216)), s1L);
        s2L = _mm_sub_pd(t6J, s1K);
        _mm_storeu_pd(((double  *) (a3a + 704)), s2L);
        s3L = _mm_add_pd(t6J, s1K);
        _mm_storeu_pd(((double  *) (a3a + 1728)), s3L);
        s4L = _mm_add_pd(t3J, s2K);
        _mm_storeu_pd(((double  *) (a3a + 320)), s4L);
        s5L = _mm_sub_pd(t3J, s2K);
        _mm_storeu_pd(((double  *) (a3a + 1344)), s5L);
        s6L = _mm_sub_pd(t4J, s3K);
        _mm_storeu_pd(((double  *) (a3a + 832)), s6L);
        s7L = _mm_add_pd(t4J, s3K);
        _mm_storeu_pd(((double  *) (a3a + 1856)), s7L);
        s8L = _mm_add_pd(t7J, s4K);
        _mm_storeu_pd(((double  *) (a3a + 448)), s8L);
        s9L = _mm_sub_pd(t7J, s4K);
        _mm_storeu_pd(((double  *) (a3a + 1472)), s9L);
        s0M = _mm_sub_pd(t8J, s5K);
        _mm_storeu_pd(((double  *) (a3a + 960)), s0M);
        s1M = _mm_add_pd(t8J, s5K);
        _mm_storeu_pd(((double  *) (a3a + 1984)), s1M);
        t3L = _mm_add_pd(t7r, s6A);
        t4L = _mm_sub_pd(t7r, s6A);
        t5L = _mm_sub_pd(t8r, s7A);
        t6L = _mm_add_pd(t8r, s7A);
        t7L = _mm_add_pd(s8x, s4D);
        t8L = _mm_sub_pd(s9x, s5D);
        a2b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8x, s4D));
        a3b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9x, s5D));
        s2M = _mm_sub_pd(a2b, a3b);
        s3M = _mm_add_pd(a2b, a3b);
        t9L = _mm_add_pd(t3L, t7L);
        t0M = _mm_sub_pd(t3L, t7L);
        t1M = _mm_sub_pd(t4L, t8L);
        t2M = _mm_add_pd(t4L, t8L);
        t3M = _mm_add_pd(t5L, s2M);
        t4M = _mm_sub_pd(t5L, s2M);
        t5M = _mm_sub_pd(t6L, s3M);
        t6M = _mm_add_pd(t6L, s3M);
        t7M = _mm_add_pd(s4w, s8E);
        t8M = _mm_sub_pd(s5w, s9E);
        t9M = _mm_sub_pd(s4w, s8E);
        t0N = _mm_add_pd(s5w, s9E);
        t1N = _mm_add_pd(s0C, s2z);
        t2N = _mm_sub_pd(s1C, s3z);
        t3N = _mm_sub_pd(s0C, s2z);
        t4N = _mm_add_pd(s1C, s3z);
        t5N = _mm_add_pd(t7M, t1N);
        t6N = _mm_add_pd(t8M, t2N);
        t7N = _mm_sub_pd(t9M, t4N);
        t8N = _mm_add_pd(t0N, t3N);
        t9N = _mm_add_pd(t9M, t4N);
        t0O = _mm_sub_pd(t0N, t3N);
        s4M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7N), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8N));
        s5M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7N), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8N));
        a4b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7M, t1N));
        a5b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8M, t2N));
        s6M = _mm_sub_pd(a4b, a5b);
        s7M = _mm_add_pd(a4b, a5b);
        s8M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9N), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0O));
        s9M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9N), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0O));
        s0N = _mm_add_pd(t9L, t5N);
        _mm_storeu_pd(((double  *) (a3a + 96)), s0N);
        s1N = _mm_sub_pd(t9L, t5N);
        _mm_storeu_pd(((double  *) (a3a + 1120)), s1N);
        s2N = _mm_sub_pd(t0M, t6N);
        _mm_storeu_pd(((double  *) (a3a + 608)), s2N);
        s3N = _mm_add_pd(t0M, t6N);
        _mm_storeu_pd(((double  *) (a3a + 1632)), s3N);
        s4N = _mm_add_pd(t3M, s4M);
        _mm_storeu_pd(((double  *) (a3a + 224)), s4N);
        s5N = _mm_sub_pd(t3M, s4M);
        _mm_storeu_pd(((double  *) (a3a + 1248)), s5N);
        s6N = _mm_sub_pd(t4M, s5M);
        _mm_storeu_pd(((double  *) (a3a + 736)), s6N);
        s7N = _mm_add_pd(t4M, s5M);
        _mm_storeu_pd(((double  *) (a3a + 1760)), s7N);
        s8N = _mm_add_pd(t1M, s6M);
        _mm_storeu_pd(((double  *) (a3a + 352)), s8N);
        s9N = _mm_sub_pd(t1M, s6M);
        _mm_storeu_pd(((double  *) (a3a + 1376)), s9N);
        s0O = _mm_sub_pd(t2M, s7M);
        _mm_storeu_pd(((double  *) (a3a + 864)), s0O);
        s1O = _mm_add_pd(t2M, s7M);
        _mm_storeu_pd(((double  *) (a3a + 1888)), s1O);
        s2O = _mm_add_pd(t5M, s8M);
        _mm_storeu_pd(((double  *) (a3a + 480)), s2O);
        s3O = _mm_sub_pd(t5M, s8M);
        _mm_storeu_pd(((double  *) (a3a + 1504)), s3O);
        s4O = _mm_sub_pd(t6M, s9M);
        _mm_storeu_pd(((double  *) (a3a + 992)), s4O);
        s5O = _mm_add_pd(t6M, s9M);
        _mm_storeu_pd(((double  *) (a3a + 2016)), s5O);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_2048)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_2048_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[2048]);
    __m128d a01, a02, a03, a04, a05, a06, a07, a08, a09, a0a, a0b, a11, a12, a13, a14, a15, a16, a17, a18, a19, a1a, a1b
            , a2, a21, a22, a23, a24, a25, a27, a28, a29, a2a, a2b, a3, a31, a32, a33, a34, a35, a36, a37, a38, a39, a3a
            , a3b, a4, a41, a42, a43, a44, a45, a46, a47, a48, a49, a4b, a5, a52, a53, a54, a55, a56, a57, a58, a5a, a5b
            , a6, a62, a63, a64, a65, a66, a67, a68, a69, a6a, a6b, a7, a72, a73, a74, a75, a76, a77, a78, a79, a7a, a81
            , a82, a83, a84, a85, a86, a87, a88, a89, a8a, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u
            , s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H
            , s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o
            , s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A
            , s2B, s2C, s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h
            , s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33
            , s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G, s3H, s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3a
            , s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w
            , s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I
            , s4J, s4K, s4L, s4M, s4N, s4O, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p
            , s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B
            , s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5L, s5M, s5N, s5O, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i
            , s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64
            , s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6a, s6b, s6c
            , s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w, s6x, s6y
            , s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I, s7J, s7K
            , s7L, s7M, s7N, s7a, s7b, s7c, s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s
            , s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E
            , s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9a, s9b, s9c, s9d, s9e, s9f, s9g
            , s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02
            , t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0G, t0H, t0I, t0J, t0K, t0L, t0M, t0N, t0O
            , t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v
            , t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17, t18, t19, t1A, t1B, t1C, t1D, t1E, t1F, t1G, t1H, t1I
            , t1J, t1K, t1L, t1M, t1N, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q
            , t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29, t2A, t2B, t2C
            , t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2L, t2M, t2N, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k
            , t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36
            , t37, t38, t39, t3A, t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3L, t3M, t3N, t3a, t3b, t3c, t3d, t3e
            , t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s, t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4
            , t41, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4L, t4M
            , t4N, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u
            , t4v, t4w, t4x, t4y, t4z, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5F, t5G
            , t5H, t5I, t5J, t5K, t5L, t5M, t5N, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o
            , t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y, t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A
            , t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K, t6L, t6M, t6N, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h, t6i
            , t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71, t72, t73, t74
            , t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7F, t7G, t7H, t7I, t7J, t7K, t7L, t7M, t7N, t7a, t7b, t7c
            , t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t7y
            , t7z, t8, t81, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8F, t8G, t8H, t8I, t8J, t8K
            , t8L, t8M, t8N, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s
            , t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97, t98, t99, t9A, t9B, t9C, t9D, t9E
            , t9F, t9G, t9H, t9I, t9J, t9K, t9L, t9M, t9N, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m
            , t9n, t9o, t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a, *a26, *a4a, *a51, *a59, *a71, *a8, *b, *b2, *b3;
    int a61;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 512)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 32));
    s5 = v_neg23(*((a + 992)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 2.0), s7));
    s01 = *((a + 64));
    s11 = v_neg23(*((a + 960)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s31));
    s61 = *((a + 96));
    s71 = v_neg23(*((a + 928)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s81), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 2.0), s91));
    s22 = *((a + 128));
    s32 = v_neg23(*((a + 896)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s42), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s52));
    s82 = *((a + 160));
    s92 = v_neg23(*((a + 864)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s03), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 2.0), s13));
    s43 = *((a + 192));
    s53 = v_neg23(*((a + 832)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s63), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s73));
    s04 = *((a + 224));
    s14 = v_neg23(*((a + 800)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 0.0), s24), _mm_mul_pd(_mm_set_pd(1.546020906725474, 2.0), s34));
    s64 = *((a + 256));
    s74 = v_neg23(*((a + 768)));
    t71 = _mm_add_pd(s64, s74);
    t81 = _mm_sub_pd(s64, s74);
    s84 = v_lo2(t71, t81);
    s94 = v_hi2(t71, t81);
    s05 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s94));
    s15 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s84), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s94));
    s25 = *((a + 288));
    s35 = v_neg23(*((a + 736)));
    t91 = _mm_add_pd(s25, s35);
    t02 = _mm_sub_pd(s25, s35);
    s45 = v_lo2(t91, t02);
    s55 = v_hi2(t91, t02);
    s65 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s45), _mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s55));
    s75 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.546020906725474, 0.0), s45), _mm_mul_pd(_mm_set_pd(1.268786568327291, 2.0), s55));
    s85 = *((a + 320));
    s95 = v_neg23(*((a + 704)));
    t12 = _mm_add_pd(s85, s95);
    t22 = _mm_sub_pd(s85, s95);
    s06 = v_lo2(t12, t22);
    s16 = v_hi2(t12, t22);
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s06), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s16));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s06), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s16));
    s46 = *((a + 352));
    s56 = v_neg23(*((a + 672)));
    t32 = _mm_add_pd(s46, s56);
    t42 = _mm_sub_pd(s46, s56);
    s66 = v_lo2(t32, t42);
    s76 = v_hi2(t32, t42);
    s86 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s66), _mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s76));
    s96 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.7638425286967101, 0.0), s66), _mm_mul_pd(_mm_set_pd(0.94279347365199528, 2.0), s76));
    s07 = *((a + 384));
    s17 = v_neg23(*((a + 640)));
    t52 = _mm_add_pd(s07, s17);
    t62 = _mm_sub_pd(s07, s17);
    s27 = v_lo2(t52, t62);
    s37 = v_hi2(t52, t62);
    s47 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s27), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s37));
    s57 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s27), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s37));
    s67 = *((a + 416));
    s77 = v_neg23(*((a + 608)));
    t72 = _mm_add_pd(s67, s77);
    t82 = _mm_sub_pd(s67, s77);
    s87 = v_lo2(t72, t82);
    s97 = v_hi2(t72, t82);
    s08 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s87), _mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s97));
    s18 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9138806714644176, 0.0), s87), _mm_mul_pd(_mm_set_pd(0.58056935450892477, 2.0), s97));
    s28 = *((a + 448));
    s38 = v_neg23(*((a + 576)));
    t92 = _mm_add_pd(s28, s38);
    t03 = _mm_sub_pd(s28, s38);
    s48 = v_lo2(t92, t03);
    s58 = v_hi2(t92, t03);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s48), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s58));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s48), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s58));
    s88 = *((a + 480));
    s98 = v_neg23(*((a + 544)));
    t13 = _mm_add_pd(s88, s98);
    t23 = _mm_sub_pd(s88, s98);
    s09 = v_lo2(t13, t23);
    s19 = v_hi2(t13, t23);
    s29 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s09), _mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s19));
    s39 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9903694533443939, 0.0), s09), _mm_mul_pd(_mm_set_pd(0.19603428065912121, 2.0), s19));
    t33 = _mm_add_pd(t, s05);
    t43 = _mm_sub_pd(t, s05);
    t53 = _mm_sub_pd(t2, s15);
    t63 = _mm_add_pd(t2, s15);
    t73 = _mm_add_pd(s62, s47);
    t83 = _mm_sub_pd(s72, s57);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s62, s47));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s72, s57));
    s49 = _mm_sub_pd(a2, a3);
    s59 = _mm_add_pd(a2, a3);
    t93 = _mm_add_pd(t33, t73);
    t04 = _mm_sub_pd(t33, t73);
    t14 = _mm_sub_pd(t43, t83);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_add_pd(t53, s49);
    t44 = _mm_sub_pd(t53, s49);
    t54 = _mm_sub_pd(t63, s59);
    t64 = _mm_add_pd(t63, s59);
    t74 = _mm_add_pd(s8, s29);
    t84 = _mm_sub_pd(s9, s39);
    t94 = _mm_sub_pd(s8, s29);
    t05 = _mm_add_pd(s9, s39);
    t15 = _mm_add_pd(s65, s44);
    t25 = _mm_sub_pd(s75, s54);
    t35 = _mm_sub_pd(s65, s44);
    t45 = _mm_add_pd(s75, s54);
    t55 = _mm_add_pd(t74, t15);
    t65 = _mm_add_pd(t84, t25);
    t75 = _mm_sub_pd(t74, t15);
    t85 = _mm_sub_pd(t84, t25);
    t95 = _mm_sub_pd(t94, t45);
    t06 = _mm_add_pd(t05, t35);
    t16 = _mm_add_pd(t94, t45);
    t26 = _mm_sub_pd(t05, t35);
    s69 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t95), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t06));
    s79 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t95), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t06));
    s89 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t75), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t85));
    s99 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t75), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t85));
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t16), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t26));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t16), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t26));
    t36 = _mm_add_pd(s41, s68);
    t46 = _mm_sub_pd(s51, s78);
    t56 = _mm_sub_pd(s41, s68);
    t66 = _mm_add_pd(s51, s78);
    t76 = _mm_add_pd(s26, s83);
    t86 = _mm_sub_pd(s36, s93);
    t96 = _mm_sub_pd(s26, s83);
    t07 = _mm_add_pd(s36, s93);
    t17 = _mm_add_pd(t36, t76);
    t27 = _mm_add_pd(t46, t86);
    t37 = _mm_sub_pd(t56, t07);
    t47 = _mm_add_pd(t66, t96);
    t57 = _mm_add_pd(t56, t07);
    t67 = _mm_sub_pd(t66, t96);
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t37), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t47));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t37), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t47));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t36, t76));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t46, t86));
    s4a = _mm_sub_pd(a4, a5);
    s5a = _mm_add_pd(a4, a5);
    s6a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    s7a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    t77 = _mm_add_pd(s02, s08);
    t87 = _mm_sub_pd(s12, s18);
    t97 = _mm_sub_pd(s02, s08);
    t08 = _mm_add_pd(s12, s18);
    t18 = _mm_add_pd(s86, s23);
    t28 = _mm_sub_pd(s96, s33);
    t38 = _mm_sub_pd(s86, s23);
    t48 = _mm_add_pd(s96, s33);
    t58 = _mm_add_pd(t77, t18);
    t68 = _mm_add_pd(t87, t28);
    t78 = _mm_sub_pd(t77, t18);
    t88 = _mm_sub_pd(t87, t28);
    t98 = _mm_sub_pd(t97, t48);
    t09 = _mm_add_pd(t08, t38);
    t19 = _mm_add_pd(t97, t48);
    t29 = _mm_sub_pd(t08, t38);
    s8a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s9a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s0b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t78), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t88));
    s1b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t78), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t88));
    s2b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t19), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t29));
    s3b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t19), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t29));
    t39 = _mm_add_pd(t93, t17);
    t49 = _mm_sub_pd(t93, t17);
    t59 = _mm_sub_pd(t04, t27);
    t69 = _mm_add_pd(t04, t27);
    t79 = _mm_add_pd(t55, t58);
    t89 = _mm_sub_pd(t65, t68);
    a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t55, t58));
    a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t65, t68));
    s4b = _mm_sub_pd(a6, a7);
    s5b = _mm_add_pd(a6, a7);
    a8 = ((__m128d  *) T);
    s6b = _mm_add_pd(t39, t79);
    *(a8) = s6b;
    s7b = _mm_sub_pd(t39, t79);
    *((a8 + 16)) = s7b;
    s8b = _mm_sub_pd(t49, t89);
    *((a8 + 8)) = s8b;
    s9b = _mm_add_pd(t49, t89);
    *((a8 + 24)) = s9b;
    s0c = _mm_add_pd(t59, s4b);
    *((a8 + 4)) = s0c;
    s1c = _mm_sub_pd(t59, s4b);
    *((a8 + 20)) = s1c;
    s2c = _mm_sub_pd(t69, s5b);
    *((a8 + 12)) = s2c;
    s3c = _mm_add_pd(t69, s5b);
    *((a8 + 28)) = s3c;
    t99 = _mm_add_pd(t34, s2a);
    t0a = _mm_sub_pd(t34, s2a);
    t1a = _mm_sub_pd(t44, s3a);
    t2a = _mm_add_pd(t44, s3a);
    t3a = _mm_add_pd(s69, s8a);
    t4a = _mm_sub_pd(s79, s9a);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s69, s8a));
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s79, s9a));
    s4c = _mm_sub_pd(a9, a01);
    s5c = _mm_add_pd(a9, a01);
    s6c = _mm_add_pd(t99, t3a);
    *((a8 + 1)) = s6c;
    s7c = _mm_sub_pd(t99, t3a);
    *((a8 + 17)) = s7c;
    s8c = _mm_sub_pd(t0a, t4a);
    *((a8 + 9)) = s8c;
    s9c = _mm_add_pd(t0a, t4a);
    *((a8 + 25)) = s9c;
    s0d = _mm_add_pd(t1a, s4c);
    *((a8 + 5)) = s0d;
    s1d = _mm_sub_pd(t1a, s4c);
    *((a8 + 21)) = s1d;
    s2d = _mm_sub_pd(t2a, s5c);
    *((a8 + 13)) = s2d;
    s3d = _mm_add_pd(t2a, s5c);
    *((a8 + 29)) = s3d;
    t5a = _mm_add_pd(t14, s4a);
    t6a = _mm_sub_pd(t14, s4a);
    t7a = _mm_sub_pd(t24, s5a);
    t8a = _mm_add_pd(t24, s5a);
    t9a = _mm_add_pd(s89, s0b);
    t0b = _mm_sub_pd(s99, s1b);
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s89, s0b));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s99, s1b));
    s4d = _mm_sub_pd(a11, a21);
    s5d = _mm_add_pd(a11, a21);
    s6d = _mm_add_pd(t5a, t9a);
    *((a8 + 2)) = s6d;
    s7d = _mm_sub_pd(t5a, t9a);
    *((a8 + 18)) = s7d;
    s8d = _mm_sub_pd(t6a, t0b);
    *((a8 + 10)) = s8d;
    s9d = _mm_add_pd(t6a, t0b);
    *((a8 + 26)) = s9d;
    s0e = _mm_add_pd(t7a, s4d);
    *((a8 + 6)) = s0e;
    s1e = _mm_sub_pd(t7a, s4d);
    *((a8 + 22)) = s1e;
    s2e = _mm_sub_pd(t8a, s5d);
    *((a8 + 14)) = s2e;
    s3e = _mm_add_pd(t8a, s5d);
    *((a8 + 30)) = s3e;
    t1b = _mm_add_pd(t54, s6a);
    t2b = _mm_sub_pd(t54, s6a);
    t3b = _mm_sub_pd(t64, s7a);
    t4b = _mm_add_pd(t64, s7a);
    t5b = _mm_add_pd(s0a, s2b);
    t6b = _mm_sub_pd(s1a, s3b);
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0a, s2b));
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1a, s3b));
    s4e = _mm_sub_pd(a31, a41);
    s5e = _mm_add_pd(a31, a41);
    s6e = _mm_add_pd(t1b, t5b);
    *((a8 + 3)) = s6e;
    s7e = _mm_sub_pd(t1b, t5b);
    *((a8 + 19)) = s7e;
    s8e = _mm_sub_pd(t2b, t6b);
    *((a8 + 11)) = s8e;
    s9e = _mm_add_pd(t2b, t6b);
    *((a8 + 27)) = s9e;
    s0f = _mm_add_pd(t3b, s4e);
    *((a8 + 7)) = s0f;
    s1f = _mm_sub_pd(t3b, s4e);
    *((a8 + 23)) = s1f;
    s2f = _mm_sub_pd(t4b, s5e);
    *((a8 + 15)) = s2f;
    s3f = _mm_add_pd(t4b, s5e);
    *((a8 + 31)) = s3f;
    {long i; for(i = 0; i <= 30; i++) {
        a51 = ((__m128d  *) src);
        b = (a51 + i);
        s4f = *((b + 1));
        b2 = (a51 - i);
        s5f = v_neg23(*((b2 + 1023)));
        t7b = _mm_add_pd(s4f, s5f);
        t8b = _mm_sub_pd(s4f, s5f);
        s6f = v_lo2(t7b, t8b);
        s7f = v_hi2(t7b, t8b);
        a61 = (32 * i);
        a71 = (D73 + a61);
        a81 = *(a71);
        a91 = *((a71 + 1));
        s8f = _mm_add_pd(_mm_mul_pd(a81, s6f), _mm_mul_pd(a91, s7f));
        s9f = _mm_sub_pd(_mm_mul_pd(a81, s7f), _mm_mul_pd(a91, s6f));
        s0g = *((b + 65));
        s1g = v_neg23(*((b2 + 959)));
        t9b = _mm_add_pd(s0g, s1g);
        t0c = _mm_sub_pd(s0g, s1g);
        s2g = v_lo2(t9b, t0c);
        s3g = v_hi2(t9b, t0c);
        a02 = *((a71 + 2));
        a12 = *((a71 + 3));
        s4g = _mm_add_pd(_mm_mul_pd(a02, s2g), _mm_mul_pd(a12, s3g));
        s5g = _mm_sub_pd(_mm_mul_pd(a02, s3g), _mm_mul_pd(a12, s2g));
        s6g = *((b + 129));
        s7g = v_neg23(*((b2 + 895)));
        t1c = _mm_add_pd(s6g, s7g);
        t2c = _mm_sub_pd(s6g, s7g);
        s8g = v_lo2(t1c, t2c);
        s9g = v_hi2(t1c, t2c);
        a22 = *((a71 + 4));
        a32 = *((a71 + 5));
        s0h = _mm_add_pd(_mm_mul_pd(a22, s8g), _mm_mul_pd(a32, s9g));
        s1h = _mm_sub_pd(_mm_mul_pd(a22, s9g), _mm_mul_pd(a32, s8g));
        s2h = *((b + 193));
        s3h = v_neg23(*((b2 + 831)));
        t3c = _mm_add_pd(s2h, s3h);
        t4c = _mm_sub_pd(s2h, s3h);
        s4h = v_lo2(t3c, t4c);
        s5h = v_hi2(t3c, t4c);
        a42 = *((a71 + 6));
        a52 = *((a71 + 7));
        s6h = _mm_add_pd(_mm_mul_pd(a42, s4h), _mm_mul_pd(a52, s5h));
        s7h = _mm_sub_pd(_mm_mul_pd(a42, s5h), _mm_mul_pd(a52, s4h));
        s8h = *((b + 257));
        s9h = v_neg23(*((b2 + 767)));
        t5c = _mm_add_pd(s8h, s9h);
        t6c = _mm_sub_pd(s8h, s9h);
        s0i = v_lo2(t5c, t6c);
        s1i = v_hi2(t5c, t6c);
        a62 = *((a71 + 8));
        a72 = *((a71 + 9));
        s2i = _mm_add_pd(_mm_mul_pd(a62, s0i), _mm_mul_pd(a72, s1i));
        s3i = _mm_sub_pd(_mm_mul_pd(a62, s1i), _mm_mul_pd(a72, s0i));
        s4i = *((b + 321));
        s5i = v_neg23(*((b2 + 703)));
        t7c = _mm_add_pd(s4i, s5i);
        t8c = _mm_sub_pd(s4i, s5i);
        s6i = v_lo2(t7c, t8c);
        s7i = v_hi2(t7c, t8c);
        a82 = *((a71 + 10));
        a92 = *((a71 + 11));
        s8i = _mm_add_pd(_mm_mul_pd(a82, s6i), _mm_mul_pd(a92, s7i));
        s9i = _mm_sub_pd(_mm_mul_pd(a82, s7i), _mm_mul_pd(a92, s6i));
        s0j = *((b + 385));
        s1j = v_neg23(*((b2 + 639)));
        t9c = _mm_add_pd(s0j, s1j);
        t0d = _mm_sub_pd(s0j, s1j);
        s2j = v_lo2(t9c, t0d);
        s3j = v_hi2(t9c, t0d);
        a03 = *((a71 + 12));
        a13 = *((a71 + 13));
        s4j = _mm_add_pd(_mm_mul_pd(a03, s2j), _mm_mul_pd(a13, s3j));
        s5j = _mm_sub_pd(_mm_mul_pd(a03, s3j), _mm_mul_pd(a13, s2j));
        s6j = *((b + 449));
        s7j = v_neg23(*((b2 + 575)));
        t1d = _mm_add_pd(s6j, s7j);
        t2d = _mm_sub_pd(s6j, s7j);
        s8j = v_lo2(t1d, t2d);
        s9j = v_hi2(t1d, t2d);
        a23 = *((a71 + 14));
        a33 = *((a71 + 15));
        s0k = _mm_add_pd(_mm_mul_pd(a23, s8j), _mm_mul_pd(a33, s9j));
        s1k = _mm_sub_pd(_mm_mul_pd(a23, s9j), _mm_mul_pd(a33, s8j));
        s2k = *((b + 513));
        s3k = v_neg23(*((b2 + 511)));
        t3d = _mm_add_pd(s2k, s3k);
        t4d = _mm_sub_pd(s2k, s3k);
        s4k = v_lo2(t3d, t4d);
        s5k = v_hi2(t3d, t4d);
        a43 = *((a71 + 16));
        a53 = *((a71 + 17));
        s6k = _mm_add_pd(_mm_mul_pd(a43, s4k), _mm_mul_pd(a53, s5k));
        s7k = _mm_sub_pd(_mm_mul_pd(a43, s5k), _mm_mul_pd(a53, s4k));
        s8k = *((b + 577));
        s9k = v_neg23(*((b2 + 447)));
        t5d = _mm_add_pd(s8k, s9k);
        t6d = _mm_sub_pd(s8k, s9k);
        s0l = v_lo2(t5d, t6d);
        s1l = v_hi2(t5d, t6d);
        a63 = *((a71 + 18));
        a73 = *((a71 + 19));
        s2l = _mm_add_pd(_mm_mul_pd(a63, s0l), _mm_mul_pd(a73, s1l));
        s3l = _mm_sub_pd(_mm_mul_pd(a63, s1l), _mm_mul_pd(a73, s0l));
        s4l = *((b + 641));
        s5l = v_neg23(*((b2 + 383)));
        t7d = _mm_add_pd(s4l, s5l);
        t8d = _mm_sub_pd(s4l, s5l);
        s6l = v_lo2(t7d, t8d);
        s7l = v_hi2(t7d, t8d);
        a83 = *((a71 + 20));
        a93 = *((a71 + 21));
        s8l = _mm_add_pd(_mm_mul_pd(a83, s6l), _mm_mul_pd(a93, s7l));
        s9l = _mm_sub_pd(_mm_mul_pd(a83, s7l), _mm_mul_pd(a93, s6l));
        s0m = *((b + 705));
        s1m = v_neg23(*((b2 + 319)));
        t9d = _mm_add_pd(s0m, s1m);
        t0e = _mm_sub_pd(s0m, s1m);
        s2m = v_lo2(t9d, t0e);
        s3m = v_hi2(t9d, t0e);
        a04 = *((a71 + 22));
        a14 = *((a71 + 23));
        s4m = _mm_add_pd(_mm_mul_pd(a04, s2m), _mm_mul_pd(a14, s3m));
        s5m = _mm_sub_pd(_mm_mul_pd(a04, s3m), _mm_mul_pd(a14, s2m));
        s6m = *((b + 769));
        s7m = v_neg23(*((b2 + 255)));
        t1e = _mm_add_pd(s6m, s7m);
        t2e = _mm_sub_pd(s6m, s7m);
        s8m = v_lo2(t1e, t2e);
        s9m = v_hi2(t1e, t2e);
        a24 = *((a71 + 24));
        a34 = *((a71 + 25));
        s0n = _mm_add_pd(_mm_mul_pd(a24, s8m), _mm_mul_pd(a34, s9m));
        s1n = _mm_sub_pd(_mm_mul_pd(a24, s9m), _mm_mul_pd(a34, s8m));
        s2n = *((b + 833));
        s3n = v_neg23(*((b2 + 191)));
        t3e = _mm_add_pd(s2n, s3n);
        t4e = _mm_sub_pd(s2n, s3n);
        s4n = v_lo2(t3e, t4e);
        s5n = v_hi2(t3e, t4e);
        a44 = *((a71 + 26));
        a54 = *((a71 + 27));
        s6n = _mm_add_pd(_mm_mul_pd(a44, s4n), _mm_mul_pd(a54, s5n));
        s7n = _mm_sub_pd(_mm_mul_pd(a44, s5n), _mm_mul_pd(a54, s4n));
        s8n = *((b + 897));
        s9n = v_neg23(*((b2 + 127)));
        t5e = _mm_add_pd(s8n, s9n);
        t6e = _mm_sub_pd(s8n, s9n);
        s0o = v_lo2(t5e, t6e);
        s1o = v_hi2(t5e, t6e);
        a64 = *((a71 + 28));
        a74 = *((a71 + 29));
        s2o = _mm_add_pd(_mm_mul_pd(a64, s0o), _mm_mul_pd(a74, s1o));
        s3o = _mm_sub_pd(_mm_mul_pd(a64, s1o), _mm_mul_pd(a74, s0o));
        s4o = *((b + 961));
        s5o = v_neg23(*((b2 + 63)));
        t7e = _mm_add_pd(s4o, s5o);
        t8e = _mm_sub_pd(s4o, s5o);
        s6o = v_lo2(t7e, t8e);
        s7o = v_hi2(t7e, t8e);
        a84 = *((a71 + 30));
        a94 = *((a71 + 31));
        s8o = _mm_add_pd(_mm_mul_pd(a84, s6o), _mm_mul_pd(a94, s7o));
        s9o = _mm_sub_pd(_mm_mul_pd(a84, s7o), _mm_mul_pd(a94, s6o));
        t9e = _mm_add_pd(s8f, s6k);
        t0f = _mm_add_pd(s9f, s7k);
        t1f = _mm_sub_pd(s8f, s6k);
        t2f = _mm_sub_pd(s9f, s7k);
        t3f = _mm_add_pd(s4g, s2l);
        t4f = _mm_add_pd(s5g, s3l);
        t5f = _mm_sub_pd(s4g, s2l);
        t6f = _mm_sub_pd(s5g, s3l);
        s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6f));
        s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6f));
        t7f = _mm_add_pd(s0h, s8l);
        t8f = _mm_add_pd(s1h, s9l);
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0h, s8l));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s1h, s9l));
        s2p = _mm_sub_pd(a05, a15);
        s3p = _mm_add_pd(a05, a15);
        t9f = _mm_add_pd(s6h, s4m);
        t0g = _mm_add_pd(s7h, s5m);
        t1g = _mm_sub_pd(s6h, s4m);
        t2g = _mm_sub_pd(s7h, s5m);
        s4p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1g), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2g));
        s5p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1g), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2g));
        t3g = _mm_add_pd(s2i, s0n);
        t4g = _mm_add_pd(s3i, s1n);
        t5g = _mm_sub_pd(s2i, s0n);
        t6g = _mm_sub_pd(s3i, s1n);
        t7g = _mm_add_pd(s8i, s6n);
        t8g = _mm_add_pd(s9i, s7n);
        t9g = _mm_sub_pd(s8i, s6n);
        t0h = _mm_sub_pd(s9i, s7n);
        s6p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9g), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0h));
        s7p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9g), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0h));
        t1h = _mm_add_pd(s4j, s2o);
        t2h = _mm_add_pd(s5j, s3o);
        a25 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(s4j, s2o));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s5j, s3o));
        s8p = _mm_sub_pd(a25, a35);
        s9p = _mm_add_pd(a25, a35);
        t3h = _mm_add_pd(s0k, s8o);
        t4h = _mm_add_pd(s1k, s9o);
        t5h = _mm_sub_pd(s0k, s8o);
        t6h = _mm_sub_pd(s1k, s9o);
        s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t5h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6h));
        s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5h), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t6h));
        t7h = _mm_add_pd(t9e, t3g);
        t8h = _mm_add_pd(t0f, t4g);
        t9h = _mm_sub_pd(t9e, t3g);
        t0i = _mm_sub_pd(t0f, t4g);
        t1i = _mm_add_pd(t7f, t1h);
        t2i = _mm_add_pd(t8f, t2h);
        t3i = _mm_sub_pd(t7f, t1h);
        t4i = _mm_sub_pd(t8f, t2h);
        t5i = _mm_add_pd(t7h, t1i);
        t6i = _mm_add_pd(t8h, t2i);
        t7i = _mm_sub_pd(t7h, t1i);
        t8i = _mm_sub_pd(t8h, t2i);
        t9i = _mm_sub_pd(t9h, t4i);
        t0j = _mm_add_pd(t0i, t3i);
        t1j = _mm_add_pd(t9h, t4i);
        t2j = _mm_sub_pd(t0i, t3i);
        t3j = _mm_add_pd(t3f, t7g);
        t4j = _mm_add_pd(t4f, t8g);
        t5j = _mm_sub_pd(t3f, t7g);
        t6j = _mm_sub_pd(t4f, t8g);
        t7j = _mm_add_pd(t9f, t3h);
        t8j = _mm_add_pd(t0g, t4h);
        t9j = _mm_sub_pd(t9f, t3h);
        t0k = _mm_sub_pd(t0g, t4h);
        t1k = _mm_add_pd(t3j, t7j);
        t2k = _mm_add_pd(t4j, t8j);
        t3k = _mm_sub_pd(t3j, t7j);
        t4k = _mm_sub_pd(t4j, t8j);
        a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5j, t0k));
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6j, t9j));
        s2q = _mm_sub_pd(a45, a55);
        s3q = _mm_add_pd(a45, a55);
        a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5j, t0k));
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6j, t9j));
        s4q = _mm_sub_pd(a65, a75);
        s5q = _mm_add_pd(a65, a75);
        t5k = _mm_add_pd(t5i, t1k);
        t6k = _mm_add_pd(t6i, t2k);
        t7k = _mm_sub_pd(t5i, t1k);
        t8k = _mm_sub_pd(t6i, t2k);
        t9k = _mm_add_pd(t9i, s2q);
        t0l = _mm_add_pd(t0j, s3q);
        t1l = _mm_sub_pd(t9i, s2q);
        t2l = _mm_sub_pd(t0j, s3q);
        t3l = _mm_sub_pd(t7i, t4k);
        t4l = _mm_add_pd(t8i, t3k);
        t5l = _mm_add_pd(t7i, t4k);
        t6l = _mm_sub_pd(t8i, t3k);
        t7l = _mm_add_pd(t1j, s4q);
        t8l = _mm_sub_pd(t2j, s5q);
        t9l = _mm_sub_pd(t1j, s4q);
        t0m = _mm_add_pd(t2j, s5q);
        t1m = _mm_sub_pd(t1f, t6g);
        t2m = _mm_add_pd(t2f, t5g);
        t3m = _mm_add_pd(t1f, t6g);
        t4m = _mm_sub_pd(t2f, t5g);
        t5m = _mm_add_pd(s2p, s8p);
        t6m = _mm_sub_pd(s3p, s9p);
        t7m = _mm_sub_pd(s2p, s8p);
        t8m = _mm_add_pd(s3p, s9p);
        t9m = _mm_add_pd(t1m, t5m);
        t0n = _mm_add_pd(t2m, t6m);
        t1n = _mm_sub_pd(t1m, t5m);
        t2n = _mm_sub_pd(t2m, t6m);
        t3n = _mm_sub_pd(t3m, t8m);
        t4n = _mm_add_pd(t4m, t7m);
        t5n = _mm_add_pd(t3m, t8m);
        t6n = _mm_sub_pd(t4m, t7m);
        t7n = _mm_add_pd(s0p, s6p);
        t8n = _mm_add_pd(s1p, s7p);
        t9n = _mm_sub_pd(s0p, s6p);
        t0o = _mm_sub_pd(s1p, s7p);
        t1o = _mm_add_pd(s4p, s0q);
        t2o = _mm_add_pd(s5p, s1q);
        t3o = _mm_sub_pd(s4p, s0q);
        t4o = _mm_sub_pd(s5p, s1q);
        t5o = _mm_add_pd(t7n, t1o);
        t6o = _mm_add_pd(t8n, t2o);
        t7o = _mm_sub_pd(t7n, t1o);
        t8o = _mm_sub_pd(t8n, t2o);
        a85 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9n, t4o));
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t0o, t3o));
        s6q = _mm_sub_pd(a85, a95);
        s7q = _mm_add_pd(a85, a95);
        a06 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t9n, t4o));
        a16 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0o, t3o));
        s8q = _mm_sub_pd(a06, a16);
        s9q = _mm_add_pd(a06, a16);
        t9o = _mm_add_pd(t9m, t5o);
        t0p = _mm_add_pd(t0n, t6o);
        t1p = _mm_sub_pd(t9m, t5o);
        t2p = _mm_sub_pd(t0n, t6o);
        t3p = _mm_add_pd(t3n, s6q);
        t4p = _mm_add_pd(t4n, s7q);
        t5p = _mm_sub_pd(t3n, s6q);
        t6p = _mm_sub_pd(t4n, s7q);
        t7p = _mm_sub_pd(t1n, t8o);
        t8p = _mm_add_pd(t2n, t7o);
        t9p = _mm_add_pd(t1n, t8o);
        t0q = _mm_sub_pd(t2n, t7o);
        t1q = _mm_add_pd(t5n, s8q);
        t2q = _mm_sub_pd(t6n, s9q);
        t3q = _mm_sub_pd(t5n, s8q);
        t4q = _mm_add_pd(t6n, s9q);
        a26 = (D74 + a61);
        a36 = *(a26);
        a46 = *((a26 + 1));
        a56 = *((a26 + 2));
        a66 = *((a26 + 3));
        a76 = *((a26 + 4));
        a86 = *((a26 + 5));
        a96 = *((a26 + 6));
        a07 = *((a26 + 7));
        a17 = *((a26 + 8));
        a27 = *((a26 + 9));
        a37 = *((a26 + 10));
        a47 = *((a26 + 11));
        a57 = *((a26 + 12));
        a67 = *((a26 + 13));
        a77 = *((a26 + 14));
        a87 = *((a26 + 15));
        a97 = *((a26 + 16));
        a08 = *((a26 + 17));
        a18 = *((a26 + 18));
        a28 = *((a26 + 19));
        a38 = *((a26 + 20));
        a48 = *((a26 + 21));
        a58 = *((a26 + 22));
        a68 = *((a26 + 23));
        a78 = *((a26 + 24));
        a88 = *((a26 + 25));
        a98 = *((a26 + 26));
        a09 = *((a26 + 27));
        a19 = *((a26 + 28));
        a29 = *((a26 + 29));
        a39 = *((a26 + 30));
        a49 = *((a26 + 31));
        b3 = (((__m128d  *) T) + a61);
        s0r = _mm_sub_pd(_mm_mul_pd(a36, t5k), _mm_mul_pd(a46, t6k));
        *((b3 + 32)) = s0r;
        s1r = _mm_add_pd(_mm_mul_pd(a46, t5k), _mm_mul_pd(a36, t6k));
        *((b3 + 48)) = s1r;
        s2r = _mm_sub_pd(_mm_mul_pd(a56, t9o), _mm_mul_pd(a66, t0p));
        *((b3 + 33)) = s2r;
        s3r = _mm_add_pd(_mm_mul_pd(a66, t9o), _mm_mul_pd(a56, t0p));
        *((b3 + 49)) = s3r;
        s4r = _mm_sub_pd(_mm_mul_pd(a76, t9k), _mm_mul_pd(a86, t0l));
        *((b3 + 34)) = s4r;
        s5r = _mm_add_pd(_mm_mul_pd(a86, t9k), _mm_mul_pd(a76, t0l));
        *((b3 + 50)) = s5r;
        s6r = _mm_sub_pd(_mm_mul_pd(a96, t3p), _mm_mul_pd(a07, t4p));
        *((b3 + 35)) = s6r;
        s7r = _mm_add_pd(_mm_mul_pd(a07, t3p), _mm_mul_pd(a96, t4p));
        *((b3 + 51)) = s7r;
        s8r = _mm_sub_pd(_mm_mul_pd(a17, t3l), _mm_mul_pd(a27, t4l));
        *((b3 + 36)) = s8r;
        s9r = _mm_add_pd(_mm_mul_pd(a27, t3l), _mm_mul_pd(a17, t4l));
        *((b3 + 52)) = s9r;
        s0s = _mm_sub_pd(_mm_mul_pd(a37, t7p), _mm_mul_pd(a47, t8p));
        *((b3 + 37)) = s0s;
        s1s = _mm_add_pd(_mm_mul_pd(a47, t7p), _mm_mul_pd(a37, t8p));
        *((b3 + 53)) = s1s;
        s2s = _mm_sub_pd(_mm_mul_pd(a57, t7l), _mm_mul_pd(a67, t8l));
        *((b3 + 38)) = s2s;
        s3s = _mm_add_pd(_mm_mul_pd(a67, t7l), _mm_mul_pd(a57, t8l));
        *((b3 + 54)) = s3s;
        s4s = _mm_sub_pd(_mm_mul_pd(a77, t1q), _mm_mul_pd(a87, t2q));
        *((b3 + 39)) = s4s;
        s5s = _mm_add_pd(_mm_mul_pd(a87, t1q), _mm_mul_pd(a77, t2q));
        *((b3 + 55)) = s5s;
        s6s = _mm_sub_pd(_mm_mul_pd(a97, t7k), _mm_mul_pd(a08, t8k));
        *((b3 + 40)) = s6s;
        s7s = _mm_add_pd(_mm_mul_pd(a08, t7k), _mm_mul_pd(a97, t8k));
        *((b3 + 56)) = s7s;
        s8s = _mm_sub_pd(_mm_mul_pd(a18, t1p), _mm_mul_pd(a28, t2p));
        *((b3 + 41)) = s8s;
        s9s = _mm_add_pd(_mm_mul_pd(a28, t1p), _mm_mul_pd(a18, t2p));
        *((b3 + 57)) = s9s;
        s0t = _mm_sub_pd(_mm_mul_pd(a38, t1l), _mm_mul_pd(a48, t2l));
        *((b3 + 42)) = s0t;
        s1t = _mm_add_pd(_mm_mul_pd(a48, t1l), _mm_mul_pd(a38, t2l));
        *((b3 + 58)) = s1t;
        s2t = _mm_sub_pd(_mm_mul_pd(a58, t5p), _mm_mul_pd(a68, t6p));
        *((b3 + 43)) = s2t;
        s3t = _mm_add_pd(_mm_mul_pd(a68, t5p), _mm_mul_pd(a58, t6p));
        *((b3 + 59)) = s3t;
        s4t = _mm_sub_pd(_mm_mul_pd(a78, t5l), _mm_mul_pd(a88, t6l));
        *((b3 + 44)) = s4t;
        s5t = _mm_add_pd(_mm_mul_pd(a88, t5l), _mm_mul_pd(a78, t6l));
        *((b3 + 60)) = s5t;
        s6t = _mm_sub_pd(_mm_mul_pd(a98, t9p), _mm_mul_pd(a09, t0q));
        *((b3 + 45)) = s6t;
        s7t = _mm_add_pd(_mm_mul_pd(a09, t9p), _mm_mul_pd(a98, t0q));
        *((b3 + 61)) = s7t;
        s8t = _mm_sub_pd(_mm_mul_pd(a19, t9l), _mm_mul_pd(a29, t0m));
        *((b3 + 46)) = s8t;
        s9t = _mm_add_pd(_mm_mul_pd(a29, t9l), _mm_mul_pd(a19, t0m));
        *((b3 + 62)) = s9t;
        s0u = _mm_sub_pd(_mm_mul_pd(a39, t3q), _mm_mul_pd(a49, t4q));
        *((b3 + 47)) = s0u;
        s1u = _mm_add_pd(_mm_mul_pd(a49, t3q), _mm_mul_pd(a39, t4q));
        *((b3 + 63)) = s1u;
    }}
    {long i2; for(i2 = 0; i2 <= 15; i2++) {
        a59 = (((__m128d  *) T) + i2);
        s2u = *(a59);
        s3u = *((a59 + 512));
        t5q = _mm_add_pd(s2u, s3u);
        t6q = _mm_sub_pd(s2u, s3u);
        s4u = *((a59 + 16));
        s5u = *((a59 + 528));
        t7q = _mm_sub_pd(s4u, s5u);
        t8q = _mm_add_pd(s4u, s5u);
        s6u = *((a59 + 256));
        s7u = *((a59 + 272));
        s8u = *((a59 + 768));
        s9u = *((a59 + 784));
        t9q = _mm_add_pd(s6u, s8u);
        t0r = _mm_sub_pd(s7u, s9u);
        a69 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6u, s8u));
        a79 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7u, s9u));
        s0v = _mm_sub_pd(a69, a79);
        s1v = _mm_add_pd(a69, a79);
        t1r = _mm_add_pd(t5q, t9q);
        t2r = _mm_sub_pd(t5q, t9q);
        t3r = _mm_sub_pd(t6q, t0r);
        t4r = _mm_add_pd(t6q, t0r);
        t5r = _mm_add_pd(t7q, s0v);
        t6r = _mm_sub_pd(t7q, s0v);
        t7r = _mm_sub_pd(t8q, s1v);
        t8r = _mm_add_pd(t8q, s1v);
        s2v = *((a59 + 32));
        s3v = *((a59 + 48));
        s4v = *((a59 + 992));
        s5v = *((a59 + 1008));
        t9r = _mm_add_pd(s2v, s4v);
        t0s = _mm_sub_pd(s3v, s5v);
        t1s = _mm_sub_pd(s2v, s4v);
        t2s = _mm_add_pd(s3v, s5v);
        s6v = *((a59 + 544));
        s7v = *((a59 + 560));
        s8v = *((a59 + 480));
        s9v = *((a59 + 496));
        t3s = _mm_add_pd(s6v, s8v);
        t4s = _mm_sub_pd(s7v, s9v);
        t5s = _mm_sub_pd(s6v, s8v);
        t6s = _mm_add_pd(s7v, s9v);
        t7s = _mm_add_pd(t9r, t3s);
        t8s = _mm_add_pd(t0s, t4s);
        t9s = _mm_sub_pd(t9r, t3s);
        t0t = _mm_sub_pd(t0s, t4s);
        t1t = _mm_sub_pd(t1s, t6s);
        t2t = _mm_add_pd(t2s, t5s);
        t3t = _mm_add_pd(t1s, t6s);
        t4t = _mm_sub_pd(t2s, t5s);
        s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1t), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2t));
        s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1t), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2t));
        s2w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9s), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0t));
        s3w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9s), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0t));
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3t), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4t));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3t), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4t));
        s6w = *((a59 + 64));
        s7w = *((a59 + 80));
        s8w = *((a59 + 960));
        s9w = *((a59 + 976));
        t5t = _mm_add_pd(s6w, s8w);
        t6t = _mm_sub_pd(s7w, s9w);
        t7t = _mm_sub_pd(s6w, s8w);
        t8t = _mm_add_pd(s7w, s9w);
        s0x = *((a59 + 576));
        s1x = *((a59 + 592));
        s2x = *((a59 + 448));
        s3x = *((a59 + 464));
        t9t = _mm_add_pd(s0x, s2x);
        t0u = _mm_sub_pd(s1x, s3x);
        t1u = _mm_sub_pd(s0x, s2x);
        t2u = _mm_add_pd(s1x, s3x);
        t3u = _mm_add_pd(t5t, t9t);
        t4u = _mm_add_pd(t6t, t0u);
        t5u = _mm_sub_pd(t5t, t9t);
        t6u = _mm_sub_pd(t6t, t0u);
        t7u = _mm_sub_pd(t7t, t2u);
        t8u = _mm_add_pd(t8t, t1u);
        t9u = _mm_add_pd(t7t, t2u);
        t0v = _mm_sub_pd(t8t, t1u);
        s4x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7u), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8u));
        s5x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7u), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8u));
        s6x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5u), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6u));
        s7x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5u), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6u));
        s8x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9u), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0v));
        s9x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9u), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0v));
        s0y = *((a59 + 96));
        s1y = *((a59 + 112));
        s2y = *((a59 + 928));
        s3y = *((a59 + 944));
        t1v = _mm_add_pd(s0y, s2y);
        t2v = _mm_sub_pd(s1y, s3y);
        t3v = _mm_sub_pd(s0y, s2y);
        t4v = _mm_add_pd(s1y, s3y);
        s4y = *((a59 + 608));
        s5y = *((a59 + 624));
        s6y = *((a59 + 416));
        s7y = *((a59 + 432));
        t5v = _mm_add_pd(s4y, s6y);
        t6v = _mm_sub_pd(s5y, s7y);
        t7v = _mm_sub_pd(s4y, s6y);
        t8v = _mm_add_pd(s5y, s7y);
        t9v = _mm_add_pd(t1v, t5v);
        t0w = _mm_add_pd(t2v, t6v);
        t1w = _mm_sub_pd(t1v, t5v);
        t2w = _mm_sub_pd(t2v, t6v);
        t3w = _mm_sub_pd(t3v, t8v);
        t4w = _mm_add_pd(t4v, t7v);
        t5w = _mm_add_pd(t3v, t8v);
        t6w = _mm_sub_pd(t4v, t7v);
        s8y = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3w), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4w));
        s9y = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3w), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4w));
        s0z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1w), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2w));
        s1z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1w), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2w));
        s2z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5w), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6w));
        s3z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5w), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6w));
        s4z = *((a59 + 128));
        s5z = *((a59 + 144));
        s6z = *((a59 + 896));
        s7z = *((a59 + 912));
        t7w = _mm_add_pd(s4z, s6z);
        t8w = _mm_sub_pd(s5z, s7z);
        t9w = _mm_sub_pd(s4z, s6z);
        t0x = _mm_add_pd(s5z, s7z);
        s8z = *((a59 + 640));
        s9z = *((a59 + 656));
        s0A = *((a59 + 384));
        s1A = *((a59 + 400));
        t1x = _mm_add_pd(s8z, s0A);
        t2x = _mm_sub_pd(s9z, s1A);
        t3x = _mm_sub_pd(s8z, s0A);
        t4x = _mm_add_pd(s9z, s1A);
        t5x = _mm_add_pd(t7w, t1x);
        t6x = _mm_add_pd(t8w, t2x);
        t7x = _mm_sub_pd(t9w, t4x);
        t8x = _mm_add_pd(t0x, t3x);
        t9x = _mm_add_pd(t9w, t4x);
        t0y = _mm_sub_pd(t0x, t3x);
        s2A = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8x));
        s3A = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8x));
        a89 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7w, t1x));
        a99 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8w, t2x));
        s4A = _mm_sub_pd(a89, a99);
        s5A = _mm_add_pd(a89, a99);
        s6A = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9x), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0y));
        s7A = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9x), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0y));
        s8A = *((a59 + 160));
        s9A = *((a59 + 176));
        s0B = *((a59 + 864));
        s1B = *((a59 + 880));
        t1y = _mm_add_pd(s8A, s0B);
        t2y = _mm_sub_pd(s9A, s1B);
        t3y = _mm_sub_pd(s8A, s0B);
        t4y = _mm_add_pd(s9A, s1B);
        s2B = *((a59 + 672));
        s3B = *((a59 + 688));
        s4B = *((a59 + 352));
        s5B = *((a59 + 368));
        t5y = _mm_add_pd(s2B, s4B);
        t6y = _mm_sub_pd(s3B, s5B);
        t7y = _mm_sub_pd(s2B, s4B);
        t8y = _mm_add_pd(s3B, s5B);
        t9y = _mm_add_pd(t1y, t5y);
        t0z = _mm_add_pd(t2y, t6y);
        t1z = _mm_sub_pd(t1y, t5y);
        t2z = _mm_sub_pd(t2y, t6y);
        t3z = _mm_sub_pd(t3y, t8y);
        t4z = _mm_add_pd(t4y, t7y);
        t5z = _mm_add_pd(t3y, t8y);
        t6z = _mm_sub_pd(t4y, t7y);
        s6B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t3z), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t4z));
        s7B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t3z), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t4z));
        s8B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1z), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2z));
        s9B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1z), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2z));
        s0C = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t5z), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t6z));
        s1C = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t5z), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t6z));
        s2C = *((a59 + 192));
        s3C = *((a59 + 208));
        s4C = *((a59 + 832));
        s5C = *((a59 + 848));
        t7z = _mm_add_pd(s2C, s4C);
        t8z = _mm_sub_pd(s3C, s5C);
        t9z = _mm_sub_pd(s2C, s4C);
        t0A = _mm_add_pd(s3C, s5C);
        s6C = *((a59 + 704));
        s7C = *((a59 + 720));
        s8C = *((a59 + 320));
        s9C = *((a59 + 336));
        t1A = _mm_add_pd(s6C, s8C);
        t2A = _mm_sub_pd(s7C, s9C);
        t3A = _mm_sub_pd(s6C, s8C);
        t4A = _mm_add_pd(s7C, s9C);
        t5A = _mm_add_pd(t7z, t1A);
        t6A = _mm_add_pd(t8z, t2A);
        t7A = _mm_sub_pd(t7z, t1A);
        t8A = _mm_sub_pd(t8z, t2A);
        t9A = _mm_sub_pd(t9z, t4A);
        t0B = _mm_add_pd(t0A, t3A);
        t1B = _mm_add_pd(t9z, t4A);
        t2B = _mm_sub_pd(t0A, t3A);
        s0D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9A), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0B));
        s1D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9A), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0B));
        s2D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8A));
        s3D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8A));
        s4D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t1B), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2B));
        s5D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1B), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t2B));
        s6D = *((a59 + 224));
        s7D = *((a59 + 240));
        s8D = *((a59 + 800));
        s9D = *((a59 + 816));
        t3B = _mm_add_pd(s6D, s8D);
        t4B = _mm_sub_pd(s7D, s9D);
        t5B = _mm_sub_pd(s6D, s8D);
        t6B = _mm_add_pd(s7D, s9D);
        s0E = *((a59 + 736));
        s1E = *((a59 + 752));
        s2E = *((a59 + 288));
        s3E = *((a59 + 304));
        t7B = _mm_add_pd(s0E, s2E);
        t8B = _mm_sub_pd(s1E, s3E);
        t9B = _mm_sub_pd(s0E, s2E);
        t0C = _mm_add_pd(s1E, s3E);
        t1C = _mm_add_pd(t3B, t7B);
        t2C = _mm_add_pd(t4B, t8B);
        t3C = _mm_sub_pd(t3B, t7B);
        t4C = _mm_sub_pd(t4B, t8B);
        t5C = _mm_sub_pd(t5B, t0C);
        t6C = _mm_add_pd(t6B, t9B);
        t7C = _mm_add_pd(t5B, t0C);
        t8C = _mm_sub_pd(t6B, t9B);
        s4E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5C), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6C));
        s5E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5C), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6C));
        s6E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3C), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4C));
        s7E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3C), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4C));
        s8E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t7C), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t8C));
        s9E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t7C), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t8C));
        t9C = _mm_add_pd(t1r, t5x);
        t0D = _mm_sub_pd(t1r, t5x);
        t1D = _mm_sub_pd(t2r, t6x);
        t2D = _mm_add_pd(t2r, t6x);
        t3D = _mm_add_pd(t3u, t5A);
        t4D = _mm_sub_pd(t4u, t6A);
        a0a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3u, t5A));
        a1a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4u, t6A));
        s0F = _mm_sub_pd(a0a, a1a);
        s1F = _mm_add_pd(a0a, a1a);
        t5D = _mm_add_pd(t9C, t3D);
        t6D = _mm_sub_pd(t9C, t3D);
        t7D = _mm_sub_pd(t0D, t4D);
        t8D = _mm_add_pd(t0D, t4D);
        t9D = _mm_add_pd(t1D, s0F);
        t0E = _mm_sub_pd(t1D, s0F);
        t1E = _mm_sub_pd(t2D, s1F);
        t2E = _mm_add_pd(t2D, s1F);
        t3E = _mm_add_pd(t7s, t1C);
        t4E = _mm_sub_pd(t8s, t2C);
        t5E = _mm_sub_pd(t7s, t1C);
        t6E = _mm_add_pd(t8s, t2C);
        t7E = _mm_add_pd(t9y, t9v);
        t8E = _mm_sub_pd(t0z, t0w);
        t9E = _mm_sub_pd(t9y, t9v);
        t0F = _mm_add_pd(t0z, t0w);
        t1F = _mm_add_pd(t3E, t7E);
        t2F = _mm_add_pd(t4E, t8E);
        t3F = _mm_sub_pd(t5E, t0F);
        t4F = _mm_add_pd(t6E, t9E);
        t5F = _mm_add_pd(t5E, t0F);
        t6F = _mm_sub_pd(t6E, t9E);
        s2F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4F));
        s3F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4F));
        a2a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3E, t7E));
        a3a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4E, t8E));
        s4F = _mm_sub_pd(a2a, a3a);
        s5F = _mm_add_pd(a2a, a3a);
        s6F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6F));
        s7F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6F));
        a4a = (((__m128d  *) dst) + i2);
        s8F = _mm_add_pd(t5D, t1F);
        *(a4a) = s8F;
        s9F = _mm_sub_pd(t5D, t1F);
        *((a4a + 512)) = s9F;
        s0G = _mm_sub_pd(t6D, t2F);
        *((a4a + 256)) = s0G;
        s1G = _mm_add_pd(t6D, t2F);
        *((a4a + 768)) = s1G;
        s2G = _mm_add_pd(t9D, s2F);
        *((a4a + 64)) = s2G;
        s3G = _mm_sub_pd(t9D, s2F);
        *((a4a + 576)) = s3G;
        s4G = _mm_sub_pd(t0E, s3F);
        *((a4a + 320)) = s4G;
        s5G = _mm_add_pd(t0E, s3F);
        *((a4a + 832)) = s5G;
        s6G = _mm_add_pd(t7D, s4F);
        *((a4a + 128)) = s6G;
        s7G = _mm_sub_pd(t7D, s4F);
        *((a4a + 640)) = s7G;
        s8G = _mm_sub_pd(t8D, s5F);
        *((a4a + 384)) = s8G;
        s9G = _mm_add_pd(t8D, s5F);
        *((a4a + 896)) = s9G;
        s0H = _mm_add_pd(t1E, s6F);
        *((a4a + 192)) = s0H;
        s1H = _mm_sub_pd(t1E, s6F);
        *((a4a + 704)) = s1H;
        s2H = _mm_sub_pd(t2E, s7F);
        *((a4a + 448)) = s2H;
        s3H = _mm_add_pd(t2E, s7F);
        *((a4a + 960)) = s3H;
        t7F = _mm_add_pd(t5r, s2A);
        t8F = _mm_sub_pd(t5r, s2A);
        t9F = _mm_sub_pd(t6r, s3A);
        t0G = _mm_add_pd(t6r, s3A);
        t1G = _mm_add_pd(s4x, s0D);
        t2G = _mm_sub_pd(s5x, s1D);
        a5a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4x, s0D));
        a6a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5x, s1D));
        s4H = _mm_sub_pd(a5a, a6a);
        s5H = _mm_add_pd(a5a, a6a);
        t3G = _mm_add_pd(t7F, t1G);
        t4G = _mm_sub_pd(t7F, t1G);
        t5G = _mm_sub_pd(t8F, t2G);
        t6G = _mm_add_pd(t8F, t2G);
        t7G = _mm_add_pd(t9F, s4H);
        t8G = _mm_sub_pd(t9F, s4H);
        t9G = _mm_sub_pd(t0G, s5H);
        t0H = _mm_add_pd(t0G, s5H);
        t1H = _mm_add_pd(s0w, s4E);
        t2H = _mm_sub_pd(s1w, s5E);
        t3H = _mm_sub_pd(s0w, s4E);
        t4H = _mm_add_pd(s1w, s5E);
        t5H = _mm_add_pd(s6B, s8y);
        t6H = _mm_sub_pd(s7B, s9y);
        t7H = _mm_sub_pd(s6B, s8y);
        t8H = _mm_add_pd(s7B, s9y);
        t9H = _mm_add_pd(t1H, t5H);
        t0I = _mm_add_pd(t2H, t6H);
        t1I = _mm_sub_pd(t3H, t8H);
        t2I = _mm_add_pd(t4H, t7H);
        t3I = _mm_add_pd(t3H, t8H);
        t4I = _mm_sub_pd(t4H, t7H);
        s6H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1I), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2I));
        s7H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1I), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2I));
        a7a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1H, t5H));
        a8a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2H, t6H));
        s8H = _mm_sub_pd(a7a, a8a);
        s9H = _mm_add_pd(a7a, a8a);
        s0I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3I), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4I));
        s1I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3I), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4I));
        s2I = _mm_add_pd(t3G, t9H);
        *((a4a + 16)) = s2I;
        s3I = _mm_sub_pd(t3G, t9H);
        *((a4a + 528)) = s3I;
        s4I = _mm_sub_pd(t4G, t0I);
        *((a4a + 272)) = s4I;
        s5I = _mm_add_pd(t4G, t0I);
        *((a4a + 784)) = s5I;
        s6I = _mm_add_pd(t7G, s6H);
        *((a4a + 80)) = s6I;
        s7I = _mm_sub_pd(t7G, s6H);
        *((a4a + 592)) = s7I;
        s8I = _mm_sub_pd(t8G, s7H);
        *((a4a + 336)) = s8I;
        s9I = _mm_add_pd(t8G, s7H);
        *((a4a + 848)) = s9I;
        s0J = _mm_add_pd(t5G, s8H);
        *((a4a + 144)) = s0J;
        s1J = _mm_sub_pd(t5G, s8H);
        *((a4a + 656)) = s1J;
        s2J = _mm_sub_pd(t6G, s9H);
        *((a4a + 400)) = s2J;
        s3J = _mm_add_pd(t6G, s9H);
        *((a4a + 912)) = s3J;
        s4J = _mm_add_pd(t9G, s0I);
        *((a4a + 208)) = s4J;
        s5J = _mm_sub_pd(t9G, s0I);
        *((a4a + 720)) = s5J;
        s6J = _mm_sub_pd(t0H, s1I);
        *((a4a + 464)) = s6J;
        s7J = _mm_add_pd(t0H, s1I);
        *((a4a + 976)) = s7J;
        t5I = _mm_add_pd(t3r, s4A);
        t6I = _mm_sub_pd(t3r, s4A);
        t7I = _mm_sub_pd(t4r, s5A);
        t8I = _mm_add_pd(t4r, s5A);
        t9I = _mm_add_pd(s6x, s2D);
        t0J = _mm_sub_pd(s7x, s3D);
        a9a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6x, s2D));
        a0b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7x, s3D));
        s8J = _mm_sub_pd(a9a, a0b);
        s9J = _mm_add_pd(a9a, a0b);
        t1J = _mm_add_pd(t5I, t9I);
        t2J = _mm_sub_pd(t5I, t9I);
        t3J = _mm_sub_pd(t6I, t0J);
        t4J = _mm_add_pd(t6I, t0J);
        t5J = _mm_add_pd(t7I, s8J);
        t6J = _mm_sub_pd(t7I, s8J);
        t7J = _mm_sub_pd(t8I, s9J);
        t8J = _mm_add_pd(t8I, s9J);
        t9J = _mm_add_pd(s2w, s6E);
        t0K = _mm_sub_pd(s3w, s7E);
        t1K = _mm_sub_pd(s2w, s6E);
        t2K = _mm_add_pd(s3w, s7E);
        t3K = _mm_add_pd(s8B, s0z);
        t4K = _mm_sub_pd(s9B, s1z);
        t5K = _mm_sub_pd(s8B, s0z);
        t6K = _mm_add_pd(s9B, s1z);
        t7K = _mm_add_pd(t9J, t3K);
        t8K = _mm_add_pd(t0K, t4K);
        t9K = _mm_sub_pd(t1K, t6K);
        t0L = _mm_add_pd(t2K, t5K);
        t1L = _mm_add_pd(t1K, t6K);
        t2L = _mm_sub_pd(t2K, t5K);
        s0K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9K), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0L));
        s1K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9K), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0L));
        a1b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9J, t3K));
        a2b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0K, t4K));
        s2K = _mm_sub_pd(a1b, a2b);
        s3K = _mm_add_pd(a1b, a2b);
        s4K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1L), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2L));
        s5K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1L), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2L));
        s6K = _mm_add_pd(t1J, t7K);
        *((a4a + 32)) = s6K;
        s7K = _mm_sub_pd(t1J, t7K);
        *((a4a + 544)) = s7K;
        s8K = _mm_sub_pd(t2J, t8K);
        *((a4a + 288)) = s8K;
        s9K = _mm_add_pd(t2J, t8K);
        *((a4a + 800)) = s9K;
        s0L = _mm_add_pd(t5J, s0K);
        *((a4a + 96)) = s0L;
        s1L = _mm_sub_pd(t5J, s0K);
        *((a4a + 608)) = s1L;
        s2L = _mm_sub_pd(t6J, s1K);
        *((a4a + 352)) = s2L;
        s3L = _mm_add_pd(t6J, s1K);
        *((a4a + 864)) = s3L;
        s4L = _mm_add_pd(t3J, s2K);
        *((a4a + 160)) = s4L;
        s5L = _mm_sub_pd(t3J, s2K);
        *((a4a + 672)) = s5L;
        s6L = _mm_sub_pd(t4J, s3K);
        *((a4a + 416)) = s6L;
        s7L = _mm_add_pd(t4J, s3K);
        *((a4a + 928)) = s7L;
        s8L = _mm_add_pd(t7J, s4K);
        *((a4a + 224)) = s8L;
        s9L = _mm_sub_pd(t7J, s4K);
        *((a4a + 736)) = s9L;
        s0M = _mm_sub_pd(t8J, s5K);
        *((a4a + 480)) = s0M;
        s1M = _mm_add_pd(t8J, s5K);
        *((a4a + 992)) = s1M;
        t3L = _mm_add_pd(t7r, s6A);
        t4L = _mm_sub_pd(t7r, s6A);
        t5L = _mm_sub_pd(t8r, s7A);
        t6L = _mm_add_pd(t8r, s7A);
        t7L = _mm_add_pd(s8x, s4D);
        t8L = _mm_sub_pd(s9x, s5D);
        a3b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8x, s4D));
        a4b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9x, s5D));
        s2M = _mm_sub_pd(a3b, a4b);
        s3M = _mm_add_pd(a3b, a4b);
        t9L = _mm_add_pd(t3L, t7L);
        t0M = _mm_sub_pd(t3L, t7L);
        t1M = _mm_sub_pd(t4L, t8L);
        t2M = _mm_add_pd(t4L, t8L);
        t3M = _mm_add_pd(t5L, s2M);
        t4M = _mm_sub_pd(t5L, s2M);
        t5M = _mm_sub_pd(t6L, s3M);
        t6M = _mm_add_pd(t6L, s3M);
        t7M = _mm_add_pd(s4w, s8E);
        t8M = _mm_sub_pd(s5w, s9E);
        t9M = _mm_sub_pd(s4w, s8E);
        t0N = _mm_add_pd(s5w, s9E);
        t1N = _mm_add_pd(s0C, s2z);
        t2N = _mm_sub_pd(s1C, s3z);
        t3N = _mm_sub_pd(s0C, s2z);
        t4N = _mm_add_pd(s1C, s3z);
        t5N = _mm_add_pd(t7M, t1N);
        t6N = _mm_add_pd(t8M, t2N);
        t7N = _mm_sub_pd(t9M, t4N);
        t8N = _mm_add_pd(t0N, t3N);
        t9N = _mm_add_pd(t9M, t4N);
        t0O = _mm_sub_pd(t0N, t3N);
        s4M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7N), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8N));
        s5M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7N), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8N));
        a5b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7M, t1N));
        a6b = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8M, t2N));
        s6M = _mm_sub_pd(a5b, a6b);
        s7M = _mm_add_pd(a5b, a6b);
        s8M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9N), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0O));
        s9M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9N), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0O));
        s0N = _mm_add_pd(t9L, t5N);
        *((a4a + 48)) = s0N;
        s1N = _mm_sub_pd(t9L, t5N);
        *((a4a + 560)) = s1N;
        s2N = _mm_sub_pd(t0M, t6N);
        *((a4a + 304)) = s2N;
        s3N = _mm_add_pd(t0M, t6N);
        *((a4a + 816)) = s3N;
        s4N = _mm_add_pd(t3M, s4M);
        *((a4a + 112)) = s4N;
        s5N = _mm_sub_pd(t3M, s4M);
        *((a4a + 624)) = s5N;
        s6N = _mm_sub_pd(t4M, s5M);
        *((a4a + 368)) = s6N;
        s7N = _mm_add_pd(t4M, s5M);
        *((a4a + 880)) = s7N;
        s8N = _mm_add_pd(t1M, s6M);
        *((a4a + 176)) = s8N;
        s9N = _mm_sub_pd(t1M, s6M);
        *((a4a + 688)) = s9N;
        s0O = _mm_sub_pd(t2M, s7M);
        *((a4a + 432)) = s0O;
        s1O = _mm_add_pd(t2M, s7M);
        *((a4a + 944)) = s1O;
        s2O = _mm_add_pd(t5M, s8M);
        *((a4a + 240)) = s2O;
        s3O = _mm_sub_pd(t5M, s8M);
        *((a4a + 752)) = s3O;
        s4O = _mm_sub_pd(t6M, s9M);
        *((a4a + 496)) = s4O;
        s5O = _mm_add_pd(t6M, s9M);
        *((a4a + 1008)) = s5O;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_4096_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[4096]);
     SPIRAL_ALIGNED(double T2[4096]);
    __m128d a02, a03, a04, a06, a07, a08, a09, a0a, a0b, a0c, a0d, a0e, a11, a12, a13, a14, a16, a17, a18, a19, a1a, a1b
            , a1c, a1d, a1e, a2, a21, a22, a23, a24, a25, a26, a27, a28, a29, a2a, a2b, a2c, a2d, a3, a31, a33, a34, a35
            , a36, a37, a38, a39, a3a, a3b, a3c, a3d, a4, a41, a43, a44, a45, a46, a47, a48, a49, a4a, a4b, a4c, a4d, a5
            , a51, a53, a54, a55, a56, a57, a58, a59, a5a, a5b, a5c, a5d, a6, a61, a62, a63, a64, a65, a66, a68, a69, a6a
            , a6b, a6c, a6d, a7, a71, a72, a74, a75, a76, a78, a79, a7a, a7b, a7c, a7d, a8, a81, a83, a84, a85, a86, a87
            , a88, a89, a8a, a8b, a8c, a8d, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, a9b, a9c, a9d, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0P, s0Q, s0R, s0S, s0T, s0U, s0V, s0W, s0X, s0Y, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k
            , s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17
            , s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H, s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1P, s1Q, s1R, s1S, s1T
            , s1U, s1V, s1W, s1X, s1Y, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2P, s2Q, s2R, s2S, s2T, s2U, s2V, s2W, s2X, s2Y
            , s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v
            , s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G, s3H
            , s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3P, s3Q, s3R, s3S, s3T, s3U, s3V, s3W, s3X, s3Y, s3a, s3b, s3c, s3d, s3e
            , s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4
            , s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4L, s4M
            , s4N, s4O, s4P, s4Q, s4R, s4S, s4T, s4U, s4V, s4W, s4X, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k
            , s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56
            , s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5L, s5M, s5N, s5O, s5P, s5Q, s5R, s5S
            , s5T, s5U, s5V, s5W, s5X, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q
            , s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C
            , s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6O, s6P, s6Q, s6R, s6S, s6T, s6U, s6V, s6W, s6X, s6a
            , s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w
            , s6x, s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I
            , s7J, s7K, s7L, s7M, s7N, s7O, s7P, s7Q, s7R, s7S, s7T, s7U, s7V, s7W, s7X, s7a, s7b, s7c, s7d, s7e, s7f, s7g
            , s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82
            , s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8O
            , s8P, s8Q, s8R, s8S, s8T, s8U, s8V, s8W, s8X, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9O, s9P, s9Q, s9R, s9S, s9T, s9U
            , s9V, s9W, s9X, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s
            , s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t010, t011, t012, t013, t014, t015, t016, t017, t018, t019, t01a, t01b, t01c
            , t01d, t01e, t01f, t02, t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0G, t0H, t0I, t0J, t0K
            , t0L, t0M, t0N, t0O, t0P, t0Q, t0R, t0S, t0T, t0U, t0V, t0W, t0X, t0Y, t0Z, t0a, t0b, t0c, t0d, t0e, t0f, t0g
            , t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t110, t111
            , t112, t113, t114, t115, t116, t117, t118, t119, t11a, t11b, t11c, t11d, t11e, t12, t13, t14, t15, t16, t17, t18, t19, t1A
            , t1B, t1C, t1D, t1E, t1F, t1G, t1H, t1I, t1J, t1K, t1L, t1M, t1N, t1O, t1P, t1Q, t1R, t1S, t1T, t1U, t1V, t1W
            , t1X, t1Y, t1Z, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s
            , t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t210, t211, t212, t213, t214, t215, t216, t217, t218, t219, t21a, t21b, t21c
            , t21d, t21e, t22, t23, t24, t25, t26, t27, t28, t29, t2A, t2B, t2C, t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2L
            , t2M, t2N, t2O, t2P, t2Q, t2R, t2S, t2T, t2U, t2V, t2W, t2X, t2Y, t2Z, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h
            , t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t310, t311
            , t312, t313, t314, t315, t316, t317, t318, t319, t31a, t31b, t31c, t31d, t31e, t32, t33, t34, t35, t36, t37, t38, t39, t3A
            , t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3L, t3M, t3N, t3O, t3P, t3Q, t3R, t3S, t3T, t3U, t3V, t3W
            , t3X, t3Y, t3Z, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s
            , t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t410, t411, t412, t413, t414, t415, t416, t417, t418, t419, t41a, t41b, t41c
            , t41d, t41e, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4L
            , t4M, t4N, t4O, t4P, t4Q, t4R, t4S, t4T, t4U, t4V, t4W, t4X, t4Y, t4Z, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h
            , t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t4y, t4z, t5, t51, t510, t511
            , t512, t513, t514, t515, t516, t517, t518, t519, t51a, t51b, t51c, t51d, t51e, t52, t53, t54, t55, t56, t57, t58, t59, t5A
            , t5B, t5C, t5D, t5E, t5F, t5G, t5H, t5I, t5J, t5K, t5L, t5M, t5N, t5O, t5P, t5Q, t5R, t5S, t5T, t5U, t5V, t5W
            , t5X, t5Y, t5Z, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s
            , t5t, t5u, t5v, t5w, t5x, t5y, t5z, t6, t61, t610, t611, t612, t613, t614, t615, t616, t617, t618, t619, t61a, t61b, t61c
            , t61d, t61e, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K, t6L
            , t6M, t6N, t6O, t6P, t6Q, t6R, t6S, t6T, t6U, t6V, t6W, t6X, t6Y, t6Z, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h
            , t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71, t710, t711
            , t712, t713, t714, t715, t716, t717, t718, t719, t71a, t71b, t71c, t71d, t71e, t72, t73, t74, t75, t76, t77, t78, t79, t7A
            , t7B, t7C, t7D, t7E, t7F, t7G, t7H, t7I, t7J, t7K, t7L, t7M, t7N, t7O, t7P, t7Q, t7R, t7S, t7T, t7U, t7V, t7W
            , t7X, t7Y, t7Z, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s
            , t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t810, t811, t812, t813, t814, t815, t816, t817, t818, t819, t81a, t81b, t81c
            , t81d, t81e, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8F, t8G, t8H, t8I, t8J, t8K, t8L
            , t8M, t8N, t8O, t8P, t8Q, t8R, t8S, t8T, t8U, t8V, t8W, t8X, t8Y, t8Z, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h
            , t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t910, t911
            , t912, t913, t914, t915, t916, t917, t918, t919, t91a, t91b, t91c, t91d, t91e, t92, t93, t94, t95, t96, t97, t98, t99, t9A
            , t9B, t9C, t9D, t9E, t9F, t9G, t9H, t9I, t9J, t9K, t9L, t9M, t9N, t9O, t9P, t9Q, t9R, t9S, t9T, t9U, t9V, t9W
            , t9X, t9Y, t9Z, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s
            , t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a, *a05, *a32, *a52, *a73, *a77, *a82, *b, *b2, *b3, *b4;
    double  *a01;
    int a15, a42, a67;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 2048))));
    a32 = ((__m128d  *) T);
    s4 = _mm_add_pd(s2, s3);
    *(a32) = s4;
    s5 = _mm_sub_pd(s2, s3);
    *((a32 + 1)) = s5;
    {long i; for(i = 0; i <= 1022; i++) {
        a42 = (2 * i);
        s6 = _mm_loadu_pd(((const double  *) (2 + (src + a42))));
        s7 = v_neg23(_mm_loadu_pd(((const double  *) ((src - a42) + 4094))));
        t = _mm_add_pd(s6, s7);
        t2 = _mm_sub_pd(s6, s7);
        s8 = v_lo2(t, t2);
        s9 = v_hi2(t, t2);
        a52 = (D76 + a42);
        a62 = *(a52);
        a72 = *((a52 + 1));
        b = (((__m128d  *) T) + a42);
        s01 = _mm_add_pd(_mm_mul_pd(a62, s8), _mm_mul_pd(a72, s9));
        *((b + 2)) = s01;
        s11 = _mm_sub_pd(_mm_mul_pd(a62, s9), _mm_mul_pd(a72, s8));
        *((b + 3)) = s11;
    }}
    a82 = ((__m128d  *) T);
    s21 = *(a82);
    s31 = *((a82 + 1024));
    t3 = _mm_add_pd(s21, s31);
    t4 = _mm_sub_pd(s21, s31);
    s41 = *((a82 + 1));
    s51 = *((a82 + 1025));
    t5 = _mm_sub_pd(s41, s51);
    t6 = _mm_add_pd(s41, s51);
    s61 = *((a82 + 512));
    s71 = *((a82 + 513));
    s81 = *((a82 + 1536));
    s91 = *((a82 + 1537));
    t7 = _mm_add_pd(s61, s81);
    t8 = _mm_sub_pd(s71, s91);
    a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s61, s81));
    a03 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s71, s91));
    s02 = _mm_sub_pd(a92, a03);
    s12 = _mm_add_pd(a92, a03);
    t9 = _mm_add_pd(t3, t7);
    t01 = _mm_sub_pd(t3, t7);
    t11 = _mm_sub_pd(t4, t8);
    t21 = _mm_add_pd(t4, t8);
    t31 = _mm_add_pd(t5, s02);
    t41 = _mm_sub_pd(t5, s02);
    t51 = _mm_sub_pd(t6, s12);
    t61 = _mm_add_pd(t6, s12);
    s22 = *((a82 + 64));
    s32 = *((a82 + 65));
    s42 = *((a82 + 1984));
    s52 = *((a82 + 1985));
    t71 = _mm_add_pd(s22, s42);
    t81 = _mm_sub_pd(s32, s52);
    t91 = _mm_sub_pd(s22, s42);
    t02 = _mm_add_pd(s32, s52);
    s62 = *((a82 + 1088));
    s72 = *((a82 + 1089));
    s82 = *((a82 + 960));
    s92 = *((a82 + 961));
    t12 = _mm_add_pd(s62, s82);
    t22 = _mm_sub_pd(s72, s92);
    t32 = _mm_sub_pd(s62, s82);
    t42 = _mm_add_pd(s72, s92);
    t52 = _mm_add_pd(t71, t12);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_sub_pd(t71, t12);
    t82 = _mm_sub_pd(t81, t22);
    t92 = _mm_sub_pd(t91, t42);
    t03 = _mm_add_pd(t02, t32);
    t13 = _mm_add_pd(t91, t42);
    t23 = _mm_sub_pd(t02, t32);
    s03 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t92), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t03));
    s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t92), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t03));
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t72), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t82));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t72), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t82));
    s43 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t13), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t23));
    s53 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t13), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t23));
    s63 = *((a82 + 128));
    s73 = *((a82 + 129));
    s83 = *((a82 + 1920));
    s93 = *((a82 + 1921));
    t33 = _mm_add_pd(s63, s83);
    t43 = _mm_sub_pd(s73, s93);
    t53 = _mm_sub_pd(s63, s83);
    t63 = _mm_add_pd(s73, s93);
    s04 = *((a82 + 1152));
    s14 = *((a82 + 1153));
    s24 = *((a82 + 896));
    s34 = *((a82 + 897));
    t73 = _mm_add_pd(s04, s24);
    t83 = _mm_sub_pd(s14, s34);
    t93 = _mm_sub_pd(s04, s24);
    t04 = _mm_add_pd(s14, s34);
    t14 = _mm_add_pd(t33, t73);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_sub_pd(t33, t73);
    t44 = _mm_sub_pd(t43, t83);
    t54 = _mm_sub_pd(t53, t04);
    t64 = _mm_add_pd(t63, t93);
    t74 = _mm_add_pd(t53, t04);
    t84 = _mm_sub_pd(t63, t93);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t54), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t64));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t54), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t64));
    s64 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t74), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t84));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t74), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t84));
    s05 = *((a82 + 192));
    s15 = *((a82 + 193));
    s25 = *((a82 + 1856));
    s35 = *((a82 + 1857));
    t94 = _mm_add_pd(s05, s25);
    t05 = _mm_sub_pd(s15, s35);
    t15 = _mm_sub_pd(s05, s25);
    t25 = _mm_add_pd(s15, s35);
    s45 = *((a82 + 1216));
    s55 = *((a82 + 1217));
    s65 = *((a82 + 832));
    s75 = *((a82 + 833));
    t35 = _mm_add_pd(s45, s65);
    t45 = _mm_sub_pd(s55, s75);
    t55 = _mm_sub_pd(s45, s65);
    t65 = _mm_add_pd(s55, s75);
    t75 = _mm_add_pd(t94, t35);
    t85 = _mm_add_pd(t05, t45);
    t95 = _mm_sub_pd(t94, t35);
    t06 = _mm_sub_pd(t05, t45);
    t16 = _mm_sub_pd(t15, t65);
    t26 = _mm_add_pd(t25, t55);
    t36 = _mm_add_pd(t15, t65);
    t46 = _mm_sub_pd(t25, t55);
    s85 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t16), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t26));
    s95 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t16), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t26));
    s06 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t95), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t06));
    s16 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t95), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t06));
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t36), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t46));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t36), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t46));
    s46 = *((a82 + 256));
    s56 = *((a82 + 257));
    s66 = *((a82 + 1792));
    s76 = *((a82 + 1793));
    t56 = _mm_add_pd(s46, s66);
    t66 = _mm_sub_pd(s56, s76);
    t76 = _mm_sub_pd(s46, s66);
    t86 = _mm_add_pd(s56, s76);
    s86 = *((a82 + 1280));
    s96 = *((a82 + 1281));
    s07 = *((a82 + 768));
    s17 = *((a82 + 769));
    t96 = _mm_add_pd(s86, s07);
    t07 = _mm_sub_pd(s96, s17);
    t17 = _mm_sub_pd(s86, s07);
    t27 = _mm_add_pd(s96, s17);
    t37 = _mm_add_pd(t56, t96);
    t47 = _mm_add_pd(t66, t07);
    t57 = _mm_sub_pd(t76, t27);
    t67 = _mm_add_pd(t86, t17);
    t77 = _mm_add_pd(t76, t27);
    t87 = _mm_sub_pd(t86, t17);
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    s37 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    a13 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t96));
    a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t66, t07));
    s47 = _mm_sub_pd(a13, a23);
    s57 = _mm_add_pd(a13, a23);
    s67 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t77), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t87));
    s77 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t77), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
    s87 = *((a82 + 320));
    s97 = *((a82 + 321));
    s08 = *((a82 + 1728));
    s18 = *((a82 + 1729));
    t97 = _mm_add_pd(s87, s08);
    t08 = _mm_sub_pd(s97, s18);
    t18 = _mm_sub_pd(s87, s08);
    t28 = _mm_add_pd(s97, s18);
    s28 = *((a82 + 1344));
    s38 = *((a82 + 1345));
    s48 = *((a82 + 704));
    s58 = *((a82 + 705));
    t38 = _mm_add_pd(s28, s48);
    t48 = _mm_sub_pd(s38, s58);
    t58 = _mm_sub_pd(s28, s48);
    t68 = _mm_add_pd(s38, s58);
    t78 = _mm_add_pd(t97, t38);
    t88 = _mm_add_pd(t08, t48);
    t98 = _mm_sub_pd(t97, t38);
    t09 = _mm_sub_pd(t08, t48);
    t19 = _mm_sub_pd(t18, t68);
    t29 = _mm_add_pd(t28, t58);
    t39 = _mm_add_pd(t18, t68);
    t49 = _mm_sub_pd(t28, t58);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t19), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t29));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t19), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t29));
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s09 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t39), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t49));
    s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t39), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t49));
    s29 = *((a82 + 384));
    s39 = *((a82 + 385));
    s49 = *((a82 + 1664));
    s59 = *((a82 + 1665));
    t59 = _mm_add_pd(s29, s49);
    t69 = _mm_sub_pd(s39, s59);
    t79 = _mm_sub_pd(s29, s49);
    t89 = _mm_add_pd(s39, s59);
    s69 = *((a82 + 1408));
    s79 = *((a82 + 1409));
    s89 = *((a82 + 640));
    s99 = *((a82 + 641));
    t99 = _mm_add_pd(s69, s89);
    t0a = _mm_sub_pd(s79, s99);
    t1a = _mm_sub_pd(s69, s89);
    t2a = _mm_add_pd(s79, s99);
    t3a = _mm_add_pd(t59, t99);
    t4a = _mm_add_pd(t69, t0a);
    t5a = _mm_sub_pd(t59, t99);
    t6a = _mm_sub_pd(t69, t0a);
    t7a = _mm_sub_pd(t79, t2a);
    t8a = _mm_add_pd(t89, t1a);
    t9a = _mm_add_pd(t79, t2a);
    t0b = _mm_sub_pd(t89, t1a);
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t7a), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8a));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7a), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t8a));
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6a));
    s4a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
    s6a = *((a82 + 448));
    s7a = *((a82 + 449));
    s8a = *((a82 + 1600));
    s9a = *((a82 + 1601));
    t1b = _mm_add_pd(s6a, s8a);
    t2b = _mm_sub_pd(s7a, s9a);
    t3b = _mm_sub_pd(s6a, s8a);
    t4b = _mm_add_pd(s7a, s9a);
    s0b = *((a82 + 1472));
    s1b = *((a82 + 1473));
    s2b = *((a82 + 576));
    s3b = *((a82 + 577));
    t5b = _mm_add_pd(s0b, s2b);
    t6b = _mm_sub_pd(s1b, s3b);
    t7b = _mm_sub_pd(s0b, s2b);
    t8b = _mm_add_pd(s1b, s3b);
    t9b = _mm_add_pd(t1b, t5b);
    t0c = _mm_add_pd(t2b, t6b);
    t1c = _mm_sub_pd(t1b, t5b);
    t2c = _mm_sub_pd(t2b, t6b);
    t3c = _mm_sub_pd(t3b, t8b);
    t4c = _mm_add_pd(t4b, t7b);
    t5c = _mm_add_pd(t3b, t8b);
    t6c = _mm_sub_pd(t4b, t7b);
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t3c), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4c));
    s5b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3c), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t4c));
    s6b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2c));
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2c));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t5c), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t6c));
    s9b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t5c), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t6c));
    t7c = _mm_add_pd(t9, t37);
    t8c = _mm_sub_pd(t9, t37);
    t9c = _mm_sub_pd(t01, t47);
    t0d = _mm_add_pd(t01, t47);
    t1d = _mm_add_pd(t14, t3a);
    t2d = _mm_sub_pd(t24, t4a);
    a33 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t14, t3a));
    a43 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t24, t4a));
    s0c = _mm_sub_pd(a33, a43);
    s1c = _mm_add_pd(a33, a43);
    t3d = _mm_add_pd(t7c, t1d);
    t4d = _mm_sub_pd(t7c, t1d);
    t5d = _mm_sub_pd(t8c, t2d);
    t6d = _mm_add_pd(t8c, t2d);
    t7d = _mm_add_pd(t9c, s0c);
    t8d = _mm_sub_pd(t9c, s0c);
    t9d = _mm_sub_pd(t0d, s1c);
    t0e = _mm_add_pd(t0d, s1c);
    t1e = _mm_add_pd(t52, t9b);
    t2e = _mm_sub_pd(t62, t0c);
    t3e = _mm_sub_pd(t52, t9b);
    t4e = _mm_add_pd(t62, t0c);
    t5e = _mm_add_pd(t78, t75);
    t6e = _mm_sub_pd(t88, t85);
    t7e = _mm_sub_pd(t78, t75);
    t8e = _mm_add_pd(t88, t85);
    t9e = _mm_add_pd(t1e, t5e);
    t0f = _mm_add_pd(t2e, t6e);
    t1f = _mm_sub_pd(t3e, t8e);
    t2f = _mm_add_pd(t4e, t7e);
    t3f = _mm_add_pd(t3e, t8e);
    t4f = _mm_sub_pd(t4e, t7e);
    s2c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f));
    s3c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2f));
    a53 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1e, t5e));
    a63 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2e, t6e));
    s4c = _mm_sub_pd(a53, a63);
    s5c = _mm_add_pd(a53, a63);
    s6c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4f));
    s7c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
    a73 = ((__m128d  *) T2);
    s8c = _mm_add_pd(t3d, t9e);
    *(a73) = s8c;
    s9c = _mm_sub_pd(t3d, t9e);
    *((a73 + 32)) = s9c;
    s0d = _mm_sub_pd(t4d, t0f);
    *((a73 + 16)) = s0d;
    s1d = _mm_add_pd(t4d, t0f);
    *((a73 + 48)) = s1d;
    s2d = _mm_add_pd(t7d, s2c);
    *((a73 + 4)) = s2d;
    s3d = _mm_sub_pd(t7d, s2c);
    *((a73 + 36)) = s3d;
    s4d = _mm_sub_pd(t8d, s3c);
    *((a73 + 20)) = s4d;
    s5d = _mm_add_pd(t8d, s3c);
    *((a73 + 52)) = s5d;
    s6d = _mm_add_pd(t5d, s4c);
    *((a73 + 8)) = s6d;
    s7d = _mm_sub_pd(t5d, s4c);
    *((a73 + 40)) = s7d;
    s8d = _mm_sub_pd(t6d, s5c);
    *((a73 + 24)) = s8d;
    s9d = _mm_add_pd(t6d, s5c);
    *((a73 + 56)) = s9d;
    s0e = _mm_add_pd(t9d, s6c);
    *((a73 + 12)) = s0e;
    s1e = _mm_sub_pd(t9d, s6c);
    *((a73 + 44)) = s1e;
    s2e = _mm_sub_pd(t0e, s7c);
    *((a73 + 28)) = s2e;
    s3e = _mm_add_pd(t0e, s7c);
    *((a73 + 60)) = s3e;
    t5f = _mm_add_pd(t31, s27);
    t6f = _mm_sub_pd(t31, s27);
    t7f = _mm_sub_pd(t41, s37);
    t8f = _mm_add_pd(t41, s37);
    t9f = _mm_add_pd(s44, s0a);
    t0g = _mm_sub_pd(s54, s1a);
    a83 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s44, s0a));
    a93 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s54, s1a));
    s4e = _mm_sub_pd(a83, a93);
    s5e = _mm_add_pd(a83, a93);
    t1g = _mm_add_pd(t5f, t9f);
    t2g = _mm_sub_pd(t5f, t9f);
    t3g = _mm_sub_pd(t6f, t0g);
    t4g = _mm_add_pd(t6f, t0g);
    t5g = _mm_add_pd(t7f, s4e);
    t6g = _mm_sub_pd(t7f, s4e);
    t7g = _mm_sub_pd(t8f, s5e);
    t8g = _mm_add_pd(t8f, s5e);
    t9g = _mm_add_pd(s03, s4b);
    t0h = _mm_sub_pd(s13, s5b);
    t1h = _mm_sub_pd(s03, s4b);
    t2h = _mm_add_pd(s13, s5b);
    t3h = _mm_add_pd(s68, s85);
    t4h = _mm_sub_pd(s78, s95);
    t5h = _mm_sub_pd(s68, s85);
    t6h = _mm_add_pd(s78, s95);
    t7h = _mm_add_pd(t9g, t3h);
    t8h = _mm_add_pd(t0h, t4h);
    t9h = _mm_sub_pd(t1h, t6h);
    t0i = _mm_add_pd(t2h, t5h);
    t1i = _mm_add_pd(t1h, t6h);
    t2i = _mm_sub_pd(t2h, t5h);
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0i));
    s7e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0i));
    a04 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9g, t3h));
    a14 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0h, t4h));
    s8e = _mm_sub_pd(a04, a14);
    s9e = _mm_add_pd(a04, a14);
    s0f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1i), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2i));
    s1f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1i), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2i));
    s2f = _mm_add_pd(t1g, t7h);
    *((a73 + 1)) = s2f;
    s3f = _mm_sub_pd(t1g, t7h);
    *((a73 + 33)) = s3f;
    s4f = _mm_sub_pd(t2g, t8h);
    *((a73 + 17)) = s4f;
    s5f = _mm_add_pd(t2g, t8h);
    *((a73 + 49)) = s5f;
    s6f = _mm_add_pd(t5g, s6e);
    *((a73 + 5)) = s6f;
    s7f = _mm_sub_pd(t5g, s6e);
    *((a73 + 37)) = s7f;
    s8f = _mm_sub_pd(t6g, s7e);
    *((a73 + 21)) = s8f;
    s9f = _mm_add_pd(t6g, s7e);
    *((a73 + 53)) = s9f;
    s0g = _mm_add_pd(t3g, s8e);
    *((a73 + 9)) = s0g;
    s1g = _mm_sub_pd(t3g, s8e);
    *((a73 + 41)) = s1g;
    s2g = _mm_sub_pd(t4g, s9e);
    *((a73 + 25)) = s2g;
    s3g = _mm_add_pd(t4g, s9e);
    *((a73 + 57)) = s3g;
    s4g = _mm_add_pd(t7g, s0f);
    *((a73 + 13)) = s4g;
    s5g = _mm_sub_pd(t7g, s0f);
    *((a73 + 45)) = s5g;
    s6g = _mm_sub_pd(t8g, s1f);
    *((a73 + 29)) = s6g;
    s7g = _mm_add_pd(t8g, s1f);
    *((a73 + 61)) = s7g;
    t3i = _mm_add_pd(t11, s47);
    t4i = _mm_sub_pd(t11, s47);
    t5i = _mm_sub_pd(t21, s57);
    t6i = _mm_add_pd(t21, s57);
    t7i = _mm_add_pd(s64, s2a);
    t8i = _mm_sub_pd(s74, s3a);
    a24 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s64, s2a));
    a34 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s74, s3a));
    s8g = _mm_sub_pd(a24, a34);
    s9g = _mm_add_pd(a24, a34);
    t9i = _mm_add_pd(t3i, t7i);
    t0j = _mm_sub_pd(t3i, t7i);
    t1j = _mm_sub_pd(t4i, t8i);
    t2j = _mm_add_pd(t4i, t8i);
    t3j = _mm_add_pd(t5i, s8g);
    t4j = _mm_sub_pd(t5i, s8g);
    t5j = _mm_sub_pd(t6i, s9g);
    t6j = _mm_add_pd(t6i, s9g);
    t7j = _mm_add_pd(s23, s6b);
    t8j = _mm_sub_pd(s33, s7b);
    t9j = _mm_sub_pd(s23, s6b);
    t0k = _mm_add_pd(s33, s7b);
    t1k = _mm_add_pd(s88, s06);
    t2k = _mm_sub_pd(s98, s16);
    t3k = _mm_sub_pd(s88, s06);
    t4k = _mm_add_pd(s98, s16);
    t5k = _mm_add_pd(t7j, t1k);
    t6k = _mm_add_pd(t8j, t2k);
    t7k = _mm_sub_pd(t9j, t4k);
    t8k = _mm_add_pd(t0k, t3k);
    t9k = _mm_add_pd(t9j, t4k);
    t0l = _mm_sub_pd(t0k, t3k);
    s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8k));
    s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k));
    a44 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7j, t1k));
    a54 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8j, t2k));
    s2h = _mm_sub_pd(a44, a54);
    s3h = _mm_add_pd(a44, a54);
    s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0l));
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0l));
    s6h = _mm_add_pd(t9i, t5k);
    *((a73 + 2)) = s6h;
    s7h = _mm_sub_pd(t9i, t5k);
    *((a73 + 34)) = s7h;
    s8h = _mm_sub_pd(t0j, t6k);
    *((a73 + 18)) = s8h;
    s9h = _mm_add_pd(t0j, t6k);
    *((a73 + 50)) = s9h;
    s0i = _mm_add_pd(t3j, s0h);
    *((a73 + 6)) = s0i;
    s1i = _mm_sub_pd(t3j, s0h);
    *((a73 + 38)) = s1i;
    s2i = _mm_sub_pd(t4j, s1h);
    *((a73 + 22)) = s2i;
    s3i = _mm_add_pd(t4j, s1h);
    *((a73 + 54)) = s3i;
    s4i = _mm_add_pd(t1j, s2h);
    *((a73 + 10)) = s4i;
    s5i = _mm_sub_pd(t1j, s2h);
    *((a73 + 42)) = s5i;
    s6i = _mm_sub_pd(t2j, s3h);
    *((a73 + 26)) = s6i;
    s7i = _mm_add_pd(t2j, s3h);
    *((a73 + 58)) = s7i;
    s8i = _mm_add_pd(t5j, s4h);
    *((a73 + 14)) = s8i;
    s9i = _mm_sub_pd(t5j, s4h);
    *((a73 + 46)) = s9i;
    s0j = _mm_sub_pd(t6j, s5h);
    *((a73 + 30)) = s0j;
    s1j = _mm_add_pd(t6j, s5h);
    *((a73 + 62)) = s1j;
    t1l = _mm_add_pd(t51, s67);
    t2l = _mm_sub_pd(t51, s67);
    t3l = _mm_sub_pd(t61, s77);
    t4l = _mm_add_pd(t61, s77);
    t5l = _mm_add_pd(s84, s4a);
    t6l = _mm_sub_pd(s94, s5a);
    a64 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s84, s4a));
    a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s94, s5a));
    s2j = _mm_sub_pd(a64, a74);
    s3j = _mm_add_pd(a64, a74);
    t7l = _mm_add_pd(t1l, t5l);
    t8l = _mm_sub_pd(t1l, t5l);
    t9l = _mm_sub_pd(t2l, t6l);
    t0m = _mm_add_pd(t2l, t6l);
    t1m = _mm_add_pd(t3l, s2j);
    t2m = _mm_sub_pd(t3l, s2j);
    t3m = _mm_sub_pd(t4l, s3j);
    t4m = _mm_add_pd(t4l, s3j);
    t5m = _mm_add_pd(s43, s8b);
    t6m = _mm_sub_pd(s53, s9b);
    t7m = _mm_sub_pd(s43, s8b);
    t8m = _mm_add_pd(s53, s9b);
    t9m = _mm_add_pd(s09, s26);
    t0n = _mm_sub_pd(s19, s36);
    t1n = _mm_sub_pd(s09, s26);
    t2n = _mm_add_pd(s19, s36);
    t3n = _mm_add_pd(t5m, t9m);
    t4n = _mm_add_pd(t6m, t0n);
    t5n = _mm_sub_pd(t7m, t2n);
    t6n = _mm_add_pd(t8m, t1n);
    t7n = _mm_add_pd(t7m, t2n);
    t8n = _mm_sub_pd(t8m, t1n);
    s4j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5n), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6n));
    s5j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5n), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6n));
    a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5m, t9m));
    a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6m, t0n));
    s6j = _mm_sub_pd(a84, a94);
    s7j = _mm_add_pd(a84, a94);
    s8j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7n), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8n));
    s9j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7n), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8n));
    s0k = _mm_add_pd(t7l, t3n);
    *((a73 + 3)) = s0k;
    s1k = _mm_sub_pd(t7l, t3n);
    *((a73 + 35)) = s1k;
    s2k = _mm_sub_pd(t8l, t4n);
    *((a73 + 19)) = s2k;
    s3k = _mm_add_pd(t8l, t4n);
    *((a73 + 51)) = s3k;
    s4k = _mm_add_pd(t1m, s4j);
    *((a73 + 7)) = s4k;
    s5k = _mm_sub_pd(t1m, s4j);
    *((a73 + 39)) = s5k;
    s6k = _mm_sub_pd(t2m, s5j);
    *((a73 + 23)) = s6k;
    s7k = _mm_add_pd(t2m, s5j);
    *((a73 + 55)) = s7k;
    s8k = _mm_add_pd(t9l, s6j);
    *((a73 + 11)) = s8k;
    s9k = _mm_sub_pd(t9l, s6j);
    *((a73 + 43)) = s9k;
    s0l = _mm_sub_pd(t0m, s7j);
    *((a73 + 27)) = s0l;
    s1l = _mm_add_pd(t0m, s7j);
    *((a73 + 59)) = s1l;
    s2l = _mm_add_pd(t3m, s8j);
    *((a73 + 15)) = s2l;
    s3l = _mm_sub_pd(t3m, s8j);
    *((a73 + 47)) = s3l;
    s4l = _mm_sub_pd(t4m, s9j);
    *((a73 + 31)) = s4l;
    s5l = _mm_add_pd(t4m, s9j);
    *((a73 + 63)) = s5l;
    {long i2; for(i2 = 0; i2 <= 30; i2++) {
        a05 = ((__m128d  *) T);
        a15 = (2 * i2);
        b2 = (a05 + a15);
        s6l = *((b2 + 2));
        s7l = *((b2 + 3));
        b3 = (a05 - a15);
        s8l = *((b3 + 2046));
        s9l = *((b3 + 2047));
        t9n = _mm_add_pd(s6l, s8l);
        t0o = _mm_sub_pd(s7l, s9l);
        t1o = _mm_sub_pd(s6l, s8l);
        t2o = _mm_add_pd(s7l, s9l);
        s0m = *((b2 + 1026));
        s1m = *((b2 + 1027));
        s2m = *((b3 + 1022));
        s3m = *((b3 + 1023));
        t3o = _mm_add_pd(s0m, s2m);
        t4o = _mm_sub_pd(s1m, s3m);
        t5o = _mm_sub_pd(s0m, s2m);
        t6o = _mm_add_pd(s1m, s3m);
        t7o = _mm_add_pd(t9n, t3o);
        t8o = _mm_add_pd(t0o, t4o);
        t9o = _mm_sub_pd(t9n, t3o);
        t0p = _mm_sub_pd(t0o, t4o);
        t1p = _mm_sub_pd(t1o, t6o);
        t2p = _mm_add_pd(t2o, t5o);
        t3p = _mm_add_pd(t1o, t6o);
        t4p = _mm_sub_pd(t2o, t5o);
        s4m = *((b2 + 514));
        s5m = *((b2 + 515));
        s6m = *((b3 + 1534));
        s7m = *((b3 + 1535));
        t5p = _mm_add_pd(s4m, s6m);
        t6p = _mm_sub_pd(s5m, s7m);
        t7p = _mm_sub_pd(s4m, s6m);
        t8p = _mm_add_pd(s5m, s7m);
        s8m = *((b2 + 1538));
        s9m = *((b2 + 1539));
        s0n = *((b3 + 510));
        s1n = *((b3 + 511));
        t9p = _mm_add_pd(s8m, s0n);
        t0q = _mm_sub_pd(s9m, s1n);
        t1q = _mm_sub_pd(s8m, s0n);
        t2q = _mm_add_pd(s9m, s1n);
        t3q = _mm_add_pd(t5p, t9p);
        t4q = _mm_add_pd(t6p, t0q);
        t5q = _mm_sub_pd(t5p, t9p);
        t6q = _mm_sub_pd(t6p, t0q);
        a25 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7p, t2q));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8p, t1q));
        s2n = _mm_sub_pd(a25, a35);
        s3n = _mm_add_pd(a25, a35);
        a45 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t7p, t2q));
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8p, t1q));
        s4n = _mm_sub_pd(a45, a55);
        s5n = _mm_add_pd(a45, a55);
        t7q = _mm_add_pd(t7o, t3q);
        t8q = _mm_add_pd(t8o, t4q);
        t9q = _mm_sub_pd(t7o, t3q);
        t0r = _mm_sub_pd(t8o, t4q);
        t1r = _mm_add_pd(t1p, s2n);
        t2r = _mm_add_pd(t2p, s3n);
        t3r = _mm_sub_pd(t1p, s2n);
        t4r = _mm_sub_pd(t2p, s3n);
        t5r = _mm_sub_pd(t9o, t6q);
        t6r = _mm_add_pd(t0p, t5q);
        t7r = _mm_add_pd(t9o, t6q);
        t8r = _mm_sub_pd(t0p, t5q);
        t9r = _mm_add_pd(t3p, s4n);
        t0s = _mm_sub_pd(t4p, s5n);
        t1s = _mm_sub_pd(t3p, s4n);
        t2s = _mm_add_pd(t4p, s5n);
        s6n = *((b2 + 130));
        s7n = *((b2 + 131));
        s8n = *((b3 + 1918));
        s9n = *((b3 + 1919));
        t3s = _mm_add_pd(s6n, s8n);
        t4s = _mm_sub_pd(s7n, s9n);
        t5s = _mm_sub_pd(s6n, s8n);
        t6s = _mm_add_pd(s7n, s9n);
        s0o = *((b2 + 1154));
        s1o = *((b2 + 1155));
        s2o = *((b3 + 894));
        s3o = *((b3 + 895));
        t7s = _mm_add_pd(s0o, s2o);
        t8s = _mm_sub_pd(s1o, s3o);
        t9s = _mm_sub_pd(s0o, s2o);
        t0t = _mm_add_pd(s1o, s3o);
        t1t = _mm_add_pd(t3s, t7s);
        t2t = _mm_add_pd(t4s, t8s);
        t3t = _mm_sub_pd(t3s, t7s);
        t4t = _mm_sub_pd(t4s, t8s);
        t5t = _mm_sub_pd(t5s, t0t);
        t6t = _mm_add_pd(t6s, t9s);
        t7t = _mm_add_pd(t5s, t0t);
        t8t = _mm_sub_pd(t6s, t9s);
        s4o = *((b2 + 642));
        s5o = *((b2 + 643));
        s6o = *((b3 + 1406));
        s7o = *((b3 + 1407));
        t9t = _mm_add_pd(s4o, s6o);
        t0u = _mm_sub_pd(s5o, s7o);
        t1u = _mm_sub_pd(s4o, s6o);
        t2u = _mm_add_pd(s5o, s7o);
        s8o = *((b2 + 1666));
        s9o = *((b2 + 1667));
        s0p = *((b3 + 382));
        s1p = *((b3 + 383));
        t3u = _mm_add_pd(s8o, s0p);
        t4u = _mm_sub_pd(s9o, s1p);
        t5u = _mm_sub_pd(s8o, s0p);
        t6u = _mm_add_pd(s9o, s1p);
        t7u = _mm_add_pd(t9t, t3u);
        t8u = _mm_add_pd(t0u, t4u);
        t9u = _mm_sub_pd(t9t, t3u);
        t0v = _mm_sub_pd(t0u, t4u);
        a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1u, t6u));
        a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2u, t5u));
        s2p = _mm_sub_pd(a65, a75);
        s3p = _mm_add_pd(a65, a75);
        a85 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1u, t6u));
        a95 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2u, t5u));
        s4p = _mm_sub_pd(a85, a95);
        s5p = _mm_add_pd(a85, a95);
        t1v = _mm_add_pd(t1t, t7u);
        t2v = _mm_add_pd(t2t, t8u);
        a06 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1t, t7u));
        a16 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2t, t8u));
        s6p = _mm_sub_pd(a06, a16);
        s7p = _mm_add_pd(a06, a16);
        t3v = _mm_add_pd(t5t, s2p);
        t4v = _mm_add_pd(t6t, s3p);
        t5v = _mm_sub_pd(t5t, s2p);
        t6v = _mm_sub_pd(t6t, s3p);
        s8p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3v), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4v));
        s9p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3v), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4v));
        s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5v), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6v));
        s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5v), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6v));
        t7v = _mm_sub_pd(t3t, t0v);
        t8v = _mm_add_pd(t4t, t9u);
        t9v = _mm_add_pd(t3t, t0v);
        t0w = _mm_sub_pd(t4t, t9u);
        s2q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8v));
        s3q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8v));
        s4q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0w));
        s5q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0w));
        t1w = _mm_add_pd(t7t, s4p);
        t2w = _mm_sub_pd(t8t, s5p);
        t3w = _mm_sub_pd(t7t, s4p);
        t4w = _mm_add_pd(t8t, s5p);
        s6q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1w), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2w));
        s7q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1w), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2w));
        s8q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3w), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4w));
        s9q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3w), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4w));
        s0r = *((b2 + 258));
        s1r = *((b2 + 259));
        s2r = *((b3 + 1790));
        s3r = *((b3 + 1791));
        t5w = _mm_add_pd(s0r, s2r);
        t6w = _mm_sub_pd(s1r, s3r);
        t7w = _mm_sub_pd(s0r, s2r);
        t8w = _mm_add_pd(s1r, s3r);
        s4r = *((b2 + 1282));
        s5r = *((b2 + 1283));
        s6r = *((b3 + 766));
        s7r = *((b3 + 767));
        t9w = _mm_add_pd(s4r, s6r);
        t0x = _mm_sub_pd(s5r, s7r);
        t1x = _mm_sub_pd(s4r, s6r);
        t2x = _mm_add_pd(s5r, s7r);
        t3x = _mm_add_pd(t5w, t9w);
        t4x = _mm_add_pd(t6w, t0x);
        t5x = _mm_sub_pd(t5w, t9w);
        t6x = _mm_sub_pd(t6w, t0x);
        t7x = _mm_sub_pd(t7w, t2x);
        t8x = _mm_add_pd(t8w, t1x);
        t9x = _mm_add_pd(t7w, t2x);
        t0y = _mm_sub_pd(t8w, t1x);
        s8r = *((b2 + 770));
        s9r = *((b2 + 771));
        s0s = *((b3 + 1278));
        s1s = *((b3 + 1279));
        t1y = _mm_add_pd(s8r, s0s);
        t2y = _mm_sub_pd(s9r, s1s);
        t3y = _mm_sub_pd(s8r, s0s);
        t4y = _mm_add_pd(s9r, s1s);
        s2s = *((b2 + 1794));
        s3s = *((b2 + 1795));
        s4s = *((b3 + 254));
        s5s = *((b3 + 255));
        t5y = _mm_add_pd(s2s, s4s);
        t6y = _mm_sub_pd(s3s, s5s);
        t7y = _mm_sub_pd(s2s, s4s);
        t8y = _mm_add_pd(s3s, s5s);
        t9y = _mm_add_pd(t1y, t5y);
        t0z = _mm_add_pd(t2y, t6y);
        t1z = _mm_sub_pd(t1y, t5y);
        t2z = _mm_sub_pd(t2y, t6y);
        a26 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3y, t8y));
        a36 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4y, t7y));
        s6s = _mm_sub_pd(a26, a36);
        s7s = _mm_add_pd(a26, a36);
        a46 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3y, t8y));
        a56 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4y, t7y));
        s8s = _mm_sub_pd(a46, a56);
        s9s = _mm_add_pd(a46, a56);
        t3z = _mm_add_pd(t3x, t9y);
        t4z = _mm_add_pd(t4x, t0z);
        t5z = _mm_sub_pd(t3x, t9y);
        t6z = _mm_sub_pd(t4x, t0z);
        t7z = _mm_add_pd(t7x, s6s);
        t8z = _mm_add_pd(t8x, s7s);
        t9z = _mm_sub_pd(t7x, s6s);
        t0A = _mm_sub_pd(t8x, s7s);
        s0t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8z));
        s1t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8z));
        s2t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0A));
        s3t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9z), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0A));
        a66 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5x, t2z));
        a76 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6x, t1z));
        s4t = _mm_sub_pd(a66, a76);
        s5t = _mm_add_pd(a66, a76);
        a86 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5x, t2z));
        a96 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6x, t1z));
        s6t = _mm_sub_pd(a86, a96);
        s7t = _mm_add_pd(a86, a96);
        t1A = _mm_add_pd(t9x, s8s);
        t2A = _mm_sub_pd(t0y, s9s);
        t3A = _mm_sub_pd(t9x, s8s);
        t4A = _mm_add_pd(t0y, s9s);
        s8t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2A));
        s9t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2A));
        s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4A));
        s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3A), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4A));
        s2u = *((b2 + 386));
        s3u = *((b2 + 387));
        s4u = *((b3 + 1662));
        s5u = *((b3 + 1663));
        t5A = _mm_add_pd(s2u, s4u);
        t6A = _mm_sub_pd(s3u, s5u);
        t7A = _mm_sub_pd(s2u, s4u);
        t8A = _mm_add_pd(s3u, s5u);
        s6u = *((b2 + 1410));
        s7u = *((b2 + 1411));
        s8u = *((b3 + 638));
        s9u = *((b3 + 639));
        t9A = _mm_add_pd(s6u, s8u);
        t0B = _mm_sub_pd(s7u, s9u);
        t1B = _mm_sub_pd(s6u, s8u);
        t2B = _mm_add_pd(s7u, s9u);
        t3B = _mm_add_pd(t5A, t9A);
        t4B = _mm_add_pd(t6A, t0B);
        t5B = _mm_sub_pd(t5A, t9A);
        t6B = _mm_sub_pd(t6A, t0B);
        t7B = _mm_sub_pd(t7A, t2B);
        t8B = _mm_add_pd(t8A, t1B);
        t9B = _mm_add_pd(t7A, t2B);
        t0C = _mm_sub_pd(t8A, t1B);
        s0v = *((b2 + 898));
        s1v = *((b2 + 899));
        s2v = *((b3 + 1150));
        s3v = *((b3 + 1151));
        t1C = _mm_add_pd(s0v, s2v);
        t2C = _mm_sub_pd(s1v, s3v);
        t3C = _mm_sub_pd(s0v, s2v);
        t4C = _mm_add_pd(s1v, s3v);
        s4v = *((b2 + 1922));
        s5v = *((b2 + 1923));
        s6v = *((b3 + 126));
        s7v = *((b3 + 127));
        t5C = _mm_add_pd(s4v, s6v);
        t6C = _mm_sub_pd(s5v, s7v);
        t7C = _mm_sub_pd(s4v, s6v);
        t8C = _mm_add_pd(s5v, s7v);
        t9C = _mm_add_pd(t1C, t5C);
        t0D = _mm_add_pd(t2C, t6C);
        t1D = _mm_sub_pd(t1C, t5C);
        t2D = _mm_sub_pd(t2C, t6C);
        a07 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3C, t8C));
        a17 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4C, t7C));
        s8v = _mm_sub_pd(a07, a17);
        s9v = _mm_add_pd(a07, a17);
        a27 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3C, t8C));
        a37 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4C, t7C));
        s0w = _mm_sub_pd(a27, a37);
        s1w = _mm_add_pd(a27, a37);
        t3D = _mm_add_pd(t3B, t9C);
        t4D = _mm_add_pd(t4B, t0D);
        a47 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3B, t9C));
        a57 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4B, t0D));
        s2w = _mm_sub_pd(a47, a57);
        s3w = _mm_add_pd(a47, a57);
        t5D = _mm_add_pd(t7B, s8v);
        t6D = _mm_add_pd(t8B, s9v);
        t7D = _mm_sub_pd(t7B, s8v);
        t8D = _mm_sub_pd(t8B, s9v);
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5D), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6D));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5D), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6D));
        s6w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7D), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8D));
        s7w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7D), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8D));
        t9D = _mm_sub_pd(t5B, t2D);
        t0E = _mm_add_pd(t6B, t1D);
        t1E = _mm_add_pd(t5B, t2D);
        t2E = _mm_sub_pd(t6B, t1D);
        s8w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9D), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0E));
        s9w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9D), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0E));
        s0x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1E), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2E));
        s1x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1E), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2E));
        t3E = _mm_add_pd(t9B, s0w);
        t4E = _mm_sub_pd(t0C, s1w);
        t5E = _mm_sub_pd(t9B, s0w);
        t6E = _mm_add_pd(t0C, s1w);
        s2x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3E), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4E));
        s3x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3E), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4E));
        s4x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5E), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t6E));
        s5x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t5E), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6E));
        t7E = _mm_add_pd(t7q, t3z);
        t8E = _mm_add_pd(t8q, t4z);
        t9E = _mm_sub_pd(t7q, t3z);
        t0F = _mm_sub_pd(t8q, t4z);
        t1F = _mm_add_pd(t1v, t3D);
        t2F = _mm_add_pd(t2v, t4D);
        t3F = _mm_sub_pd(t1v, t3D);
        t4F = _mm_sub_pd(t2v, t4D);
        t5F = _mm_add_pd(t7E, t1F);
        t6F = _mm_add_pd(t8E, t2F);
        t7F = _mm_sub_pd(t7E, t1F);
        t8F = _mm_sub_pd(t8E, t2F);
        t9F = _mm_sub_pd(t9E, t4F);
        t0G = _mm_add_pd(t0F, t3F);
        t1G = _mm_add_pd(t9E, t4F);
        t2G = _mm_sub_pd(t0F, t3F);
        t3G = _mm_add_pd(t1r, s0t);
        t4G = _mm_add_pd(t2r, s1t);
        t5G = _mm_sub_pd(t1r, s0t);
        t6G = _mm_sub_pd(t2r, s1t);
        t7G = _mm_add_pd(s8p, s4w);
        t8G = _mm_add_pd(s9p, s5w);
        t9G = _mm_sub_pd(s8p, s4w);
        t0H = _mm_sub_pd(s9p, s5w);
        t1H = _mm_add_pd(t3G, t7G);
        t2H = _mm_add_pd(t4G, t8G);
        t3H = _mm_sub_pd(t3G, t7G);
        t4H = _mm_sub_pd(t4G, t8G);
        t5H = _mm_sub_pd(t5G, t0H);
        t6H = _mm_add_pd(t6G, t9G);
        t7H = _mm_add_pd(t5G, t0H);
        t8H = _mm_sub_pd(t6G, t9G);
        t9H = _mm_add_pd(t5r, s4t);
        t0I = _mm_add_pd(t6r, s5t);
        t1I = _mm_sub_pd(t5r, s4t);
        t2I = _mm_sub_pd(t6r, s5t);
        t3I = _mm_add_pd(s2q, s8w);
        t4I = _mm_add_pd(s3q, s9w);
        t5I = _mm_sub_pd(s2q, s8w);
        t6I = _mm_sub_pd(s3q, s9w);
        t7I = _mm_add_pd(t9H, t3I);
        t8I = _mm_add_pd(t0I, t4I);
        t9I = _mm_sub_pd(t9H, t3I);
        t0J = _mm_sub_pd(t0I, t4I);
        t1J = _mm_sub_pd(t1I, t6I);
        t2J = _mm_add_pd(t2I, t5I);
        t3J = _mm_add_pd(t1I, t6I);
        t4J = _mm_sub_pd(t2I, t5I);
        t5J = _mm_add_pd(t9r, s8t);
        t6J = _mm_add_pd(t0s, s9t);
        t7J = _mm_sub_pd(t9r, s8t);
        t8J = _mm_sub_pd(t0s, s9t);
        t9J = _mm_add_pd(s6q, s2x);
        t0K = _mm_add_pd(s7q, s3x);
        t1K = _mm_sub_pd(s6q, s2x);
        t2K = _mm_sub_pd(s7q, s3x);
        t3K = _mm_add_pd(t5J, t9J);
        t4K = _mm_add_pd(t6J, t0K);
        t5K = _mm_sub_pd(t5J, t9J);
        t6K = _mm_sub_pd(t6J, t0K);
        t7K = _mm_sub_pd(t7J, t2K);
        t8K = _mm_add_pd(t8J, t1K);
        t9K = _mm_add_pd(t7J, t2K);
        t0L = _mm_sub_pd(t8J, t1K);
        t1L = _mm_sub_pd(t9q, t6z);
        t2L = _mm_add_pd(t0r, t5z);
        t3L = _mm_add_pd(t9q, t6z);
        t4L = _mm_sub_pd(t0r, t5z);
        t5L = _mm_add_pd(s6p, s2w);
        t6L = _mm_sub_pd(s7p, s3w);
        t7L = _mm_sub_pd(s6p, s2w);
        t8L = _mm_add_pd(s7p, s3w);
        t9L = _mm_add_pd(t1L, t5L);
        t0M = _mm_add_pd(t2L, t6L);
        t1M = _mm_sub_pd(t1L, t5L);
        t2M = _mm_sub_pd(t2L, t6L);
        t3M = _mm_sub_pd(t3L, t8L);
        t4M = _mm_add_pd(t4L, t7L);
        t5M = _mm_add_pd(t3L, t8L);
        t6M = _mm_sub_pd(t4L, t7L);
        t7M = _mm_add_pd(t3r, s2t);
        t8M = _mm_add_pd(t4r, s3t);
        t9M = _mm_sub_pd(t3r, s2t);
        t0N = _mm_sub_pd(t4r, s3t);
        t1N = _mm_add_pd(s0q, s6w);
        t2N = _mm_add_pd(s1q, s7w);
        t3N = _mm_sub_pd(s0q, s6w);
        t4N = _mm_sub_pd(s1q, s7w);
        t5N = _mm_add_pd(t7M, t1N);
        t6N = _mm_add_pd(t8M, t2N);
        t7N = _mm_sub_pd(t7M, t1N);
        t8N = _mm_sub_pd(t8M, t2N);
        t9N = _mm_sub_pd(t9M, t4N);
        t0O = _mm_add_pd(t0N, t3N);
        t1O = _mm_add_pd(t9M, t4N);
        t2O = _mm_sub_pd(t0N, t3N);
        t3O = _mm_add_pd(t7r, s6t);
        t4O = _mm_sub_pd(t8r, s7t);
        t5O = _mm_sub_pd(t7r, s6t);
        t6O = _mm_add_pd(t8r, s7t);
        t7O = _mm_add_pd(s4q, s0x);
        t8O = _mm_add_pd(s5q, s1x);
        t9O = _mm_sub_pd(s4q, s0x);
        t0P = _mm_sub_pd(s5q, s1x);
        t1P = _mm_add_pd(t3O, t7O);
        t2P = _mm_add_pd(t4O, t8O);
        t3P = _mm_sub_pd(t3O, t7O);
        t4P = _mm_sub_pd(t4O, t8O);
        t5P = _mm_sub_pd(t5O, t0P);
        t6P = _mm_add_pd(t6O, t9O);
        t7P = _mm_add_pd(t5O, t0P);
        t8P = _mm_sub_pd(t6O, t9O);
        t9P = _mm_add_pd(t1s, s0u);
        t0Q = _mm_add_pd(t2s, s1u);
        t1Q = _mm_sub_pd(t1s, s0u);
        t2Q = _mm_sub_pd(t2s, s1u);
        t3Q = _mm_add_pd(s8q, s4x);
        t4Q = _mm_add_pd(s9q, s5x);
        t5Q = _mm_sub_pd(s8q, s4x);
        t6Q = _mm_sub_pd(s9q, s5x);
        t7Q = _mm_add_pd(t9P, t3Q);
        t8Q = _mm_add_pd(t0Q, t4Q);
        t9Q = _mm_sub_pd(t9P, t3Q);
        t0R = _mm_sub_pd(t0Q, t4Q);
        t1R = _mm_sub_pd(t1Q, t6Q);
        t2R = _mm_add_pd(t2Q, t5Q);
        t3R = _mm_add_pd(t1Q, t6Q);
        t4R = _mm_sub_pd(t2Q, t5Q);
        a67 = (64 * i2);
        a77 = (D75 + a67);
        a87 = *(a77);
        a97 = *((a77 + 1));
        a08 = *((a77 + 2));
        a18 = *((a77 + 3));
        a28 = *((a77 + 4));
        a38 = *((a77 + 5));
        a48 = *((a77 + 6));
        a58 = *((a77 + 7));
        a68 = *((a77 + 8));
        a78 = *((a77 + 9));
        a88 = *((a77 + 10));
        a98 = *((a77 + 11));
        a09 = *((a77 + 12));
        a19 = *((a77 + 13));
        a29 = *((a77 + 14));
        a39 = *((a77 + 15));
        a49 = *((a77 + 16));
        a59 = *((a77 + 17));
        a69 = *((a77 + 18));
        a79 = *((a77 + 19));
        a89 = *((a77 + 20));
        a99 = *((a77 + 21));
        a0a = *((a77 + 22));
        a1a = *((a77 + 23));
        a2a = *((a77 + 24));
        a3a = *((a77 + 25));
        a4a = *((a77 + 26));
        a5a = *((a77 + 27));
        a6a = *((a77 + 28));
        a7a = *((a77 + 29));
        a8a = *((a77 + 30));
        a9a = *((a77 + 31));
        a0b = *((a77 + 32));
        a1b = *((a77 + 33));
        a2b = *((a77 + 34));
        a3b = *((a77 + 35));
        a4b = *((a77 + 36));
        a5b = *((a77 + 37));
        a6b = *((a77 + 38));
        a7b = *((a77 + 39));
        a8b = *((a77 + 40));
        a9b = *((a77 + 41));
        a0c = *((a77 + 42));
        a1c = *((a77 + 43));
        a2c = *((a77 + 44));
        a3c = *((a77 + 45));
        a4c = *((a77 + 46));
        a5c = *((a77 + 47));
        a6c = *((a77 + 48));
        a7c = *((a77 + 49));
        a8c = *((a77 + 50));
        a9c = *((a77 + 51));
        a0d = *((a77 + 52));
        a1d = *((a77 + 53));
        a2d = *((a77 + 54));
        a3d = *((a77 + 55));
        a4d = *((a77 + 56));
        a5d = *((a77 + 57));
        a6d = *((a77 + 58));
        a7d = *((a77 + 59));
        a8d = *((a77 + 60));
        a9d = *((a77 + 61));
        a0e = *((a77 + 62));
        a1e = *((a77 + 63));
        b4 = (((__m128d  *) T2) + a67);
        s6x = _mm_sub_pd(_mm_mul_pd(a87, t5F), _mm_mul_pd(a97, t6F));
        *((b4 + 64)) = s6x;
        s7x = _mm_add_pd(_mm_mul_pd(a97, t5F), _mm_mul_pd(a87, t6F));
        *((b4 + 96)) = s7x;
        s8x = _mm_sub_pd(_mm_mul_pd(a08, t1H), _mm_mul_pd(a18, t2H));
        *((b4 + 65)) = s8x;
        s9x = _mm_add_pd(_mm_mul_pd(a18, t1H), _mm_mul_pd(a08, t2H));
        *((b4 + 97)) = s9x;
        s0y = _mm_sub_pd(_mm_mul_pd(a28, t7I), _mm_mul_pd(a38, t8I));
        *((b4 + 66)) = s0y;
        s1y = _mm_add_pd(_mm_mul_pd(a38, t7I), _mm_mul_pd(a28, t8I));
        *((b4 + 98)) = s1y;
        s2y = _mm_sub_pd(_mm_mul_pd(a48, t3K), _mm_mul_pd(a58, t4K));
        *((b4 + 67)) = s2y;
        s3y = _mm_add_pd(_mm_mul_pd(a58, t3K), _mm_mul_pd(a48, t4K));
        *((b4 + 99)) = s3y;
        s4y = _mm_sub_pd(_mm_mul_pd(a68, t9L), _mm_mul_pd(a78, t0M));
        *((b4 + 68)) = s4y;
        s5y = _mm_add_pd(_mm_mul_pd(a78, t9L), _mm_mul_pd(a68, t0M));
        *((b4 + 100)) = s5y;
        s6y = _mm_sub_pd(_mm_mul_pd(a88, t5N), _mm_mul_pd(a98, t6N));
        *((b4 + 69)) = s6y;
        s7y = _mm_add_pd(_mm_mul_pd(a98, t5N), _mm_mul_pd(a88, t6N));
        *((b4 + 101)) = s7y;
        s8y = _mm_sub_pd(_mm_mul_pd(a09, t1P), _mm_mul_pd(a19, t2P));
        *((b4 + 70)) = s8y;
        s9y = _mm_add_pd(_mm_mul_pd(a19, t1P), _mm_mul_pd(a09, t2P));
        *((b4 + 102)) = s9y;
        s0z = _mm_sub_pd(_mm_mul_pd(a29, t7Q), _mm_mul_pd(a39, t8Q));
        *((b4 + 71)) = s0z;
        s1z = _mm_add_pd(_mm_mul_pd(a39, t7Q), _mm_mul_pd(a29, t8Q));
        *((b4 + 103)) = s1z;
        s2z = _mm_sub_pd(_mm_mul_pd(a49, t9F), _mm_mul_pd(a59, t0G));
        *((b4 + 72)) = s2z;
        s3z = _mm_add_pd(_mm_mul_pd(a59, t9F), _mm_mul_pd(a49, t0G));
        *((b4 + 104)) = s3z;
        s4z = _mm_sub_pd(_mm_mul_pd(a69, t5H), _mm_mul_pd(a79, t6H));
        *((b4 + 73)) = s4z;
        s5z = _mm_add_pd(_mm_mul_pd(a79, t5H), _mm_mul_pd(a69, t6H));
        *((b4 + 105)) = s5z;
        s6z = _mm_sub_pd(_mm_mul_pd(a89, t1J), _mm_mul_pd(a99, t2J));
        *((b4 + 74)) = s6z;
        s7z = _mm_add_pd(_mm_mul_pd(a99, t1J), _mm_mul_pd(a89, t2J));
        *((b4 + 106)) = s7z;
        s8z = _mm_sub_pd(_mm_mul_pd(a0a, t7K), _mm_mul_pd(a1a, t8K));
        *((b4 + 75)) = s8z;
        s9z = _mm_add_pd(_mm_mul_pd(a1a, t7K), _mm_mul_pd(a0a, t8K));
        *((b4 + 107)) = s9z;
        s0A = _mm_sub_pd(_mm_mul_pd(a2a, t3M), _mm_mul_pd(a3a, t4M));
        *((b4 + 76)) = s0A;
        s1A = _mm_add_pd(_mm_mul_pd(a3a, t3M), _mm_mul_pd(a2a, t4M));
        *((b4 + 108)) = s1A;
        s2A = _mm_sub_pd(_mm_mul_pd(a4a, t9N), _mm_mul_pd(a5a, t0O));
        *((b4 + 77)) = s2A;
        s3A = _mm_add_pd(_mm_mul_pd(a5a, t9N), _mm_mul_pd(a4a, t0O));
        *((b4 + 109)) = s3A;
        s4A = _mm_sub_pd(_mm_mul_pd(a6a, t5P), _mm_mul_pd(a7a, t6P));
        *((b4 + 78)) = s4A;
        s5A = _mm_add_pd(_mm_mul_pd(a7a, t5P), _mm_mul_pd(a6a, t6P));
        *((b4 + 110)) = s5A;
        s6A = _mm_sub_pd(_mm_mul_pd(a8a, t1R), _mm_mul_pd(a9a, t2R));
        *((b4 + 79)) = s6A;
        s7A = _mm_add_pd(_mm_mul_pd(a9a, t1R), _mm_mul_pd(a8a, t2R));
        *((b4 + 111)) = s7A;
        s8A = _mm_sub_pd(_mm_mul_pd(a0b, t7F), _mm_mul_pd(a1b, t8F));
        *((b4 + 80)) = s8A;
        s9A = _mm_add_pd(_mm_mul_pd(a1b, t7F), _mm_mul_pd(a0b, t8F));
        *((b4 + 112)) = s9A;
        s0B = _mm_sub_pd(_mm_mul_pd(a2b, t3H), _mm_mul_pd(a3b, t4H));
        *((b4 + 81)) = s0B;
        s1B = _mm_add_pd(_mm_mul_pd(a3b, t3H), _mm_mul_pd(a2b, t4H));
        *((b4 + 113)) = s1B;
        s2B = _mm_sub_pd(_mm_mul_pd(a4b, t9I), _mm_mul_pd(a5b, t0J));
        *((b4 + 82)) = s2B;
        s3B = _mm_add_pd(_mm_mul_pd(a5b, t9I), _mm_mul_pd(a4b, t0J));
        *((b4 + 114)) = s3B;
        s4B = _mm_sub_pd(_mm_mul_pd(a6b, t5K), _mm_mul_pd(a7b, t6K));
        *((b4 + 83)) = s4B;
        s5B = _mm_add_pd(_mm_mul_pd(a7b, t5K), _mm_mul_pd(a6b, t6K));
        *((b4 + 115)) = s5B;
        s6B = _mm_sub_pd(_mm_mul_pd(a8b, t1M), _mm_mul_pd(a9b, t2M));
        *((b4 + 84)) = s6B;
        s7B = _mm_add_pd(_mm_mul_pd(a9b, t1M), _mm_mul_pd(a8b, t2M));
        *((b4 + 116)) = s7B;
        s8B = _mm_sub_pd(_mm_mul_pd(a0c, t7N), _mm_mul_pd(a1c, t8N));
        *((b4 + 85)) = s8B;
        s9B = _mm_add_pd(_mm_mul_pd(a1c, t7N), _mm_mul_pd(a0c, t8N));
        *((b4 + 117)) = s9B;
        s0C = _mm_sub_pd(_mm_mul_pd(a2c, t3P), _mm_mul_pd(a3c, t4P));
        *((b4 + 86)) = s0C;
        s1C = _mm_add_pd(_mm_mul_pd(a3c, t3P), _mm_mul_pd(a2c, t4P));
        *((b4 + 118)) = s1C;
        s2C = _mm_sub_pd(_mm_mul_pd(a4c, t9Q), _mm_mul_pd(a5c, t0R));
        *((b4 + 87)) = s2C;
        s3C = _mm_add_pd(_mm_mul_pd(a5c, t9Q), _mm_mul_pd(a4c, t0R));
        *((b4 + 119)) = s3C;
        s4C = _mm_sub_pd(_mm_mul_pd(a6c, t1G), _mm_mul_pd(a7c, t2G));
        *((b4 + 88)) = s4C;
        s5C = _mm_add_pd(_mm_mul_pd(a7c, t1G), _mm_mul_pd(a6c, t2G));
        *((b4 + 120)) = s5C;
        s6C = _mm_sub_pd(_mm_mul_pd(a8c, t7H), _mm_mul_pd(a9c, t8H));
        *((b4 + 89)) = s6C;
        s7C = _mm_add_pd(_mm_mul_pd(a9c, t7H), _mm_mul_pd(a8c, t8H));
        *((b4 + 121)) = s7C;
        s8C = _mm_sub_pd(_mm_mul_pd(a0d, t3J), _mm_mul_pd(a1d, t4J));
        *((b4 + 90)) = s8C;
        s9C = _mm_add_pd(_mm_mul_pd(a1d, t3J), _mm_mul_pd(a0d, t4J));
        *((b4 + 122)) = s9C;
        s0D = _mm_sub_pd(_mm_mul_pd(a2d, t9K), _mm_mul_pd(a3d, t0L));
        *((b4 + 91)) = s0D;
        s1D = _mm_add_pd(_mm_mul_pd(a3d, t9K), _mm_mul_pd(a2d, t0L));
        *((b4 + 123)) = s1D;
        s2D = _mm_sub_pd(_mm_mul_pd(a4d, t5M), _mm_mul_pd(a5d, t6M));
        *((b4 + 92)) = s2D;
        s3D = _mm_add_pd(_mm_mul_pd(a5d, t5M), _mm_mul_pd(a4d, t6M));
        *((b4 + 124)) = s3D;
        s4D = _mm_sub_pd(_mm_mul_pd(a6d, t1O), _mm_mul_pd(a7d, t2O));
        *((b4 + 93)) = s4D;
        s5D = _mm_add_pd(_mm_mul_pd(a7d, t1O), _mm_mul_pd(a6d, t2O));
        *((b4 + 125)) = s5D;
        s6D = _mm_sub_pd(_mm_mul_pd(a8d, t7P), _mm_mul_pd(a9d, t8P));
        *((b4 + 94)) = s6D;
        s7D = _mm_add_pd(_mm_mul_pd(a9d, t7P), _mm_mul_pd(a8d, t8P));
        *((b4 + 126)) = s7D;
        s8D = _mm_sub_pd(_mm_mul_pd(a0e, t3R), _mm_mul_pd(a1e, t4R));
        *((b4 + 95)) = s8D;
        s9D = _mm_add_pd(_mm_mul_pd(a1e, t3R), _mm_mul_pd(a0e, t4R));
        *((b4 + 127)) = s9D;
    }}
    {long i3; for(i3 = 0; i3 <= 31; i3++) {
        a = (((__m128d  *) T2) + i3);
        s0E = *(a);
        s1E = *((a + 1024));
        t5R = _mm_add_pd(s0E, s1E);
        t6R = _mm_sub_pd(s0E, s1E);
        s2E = *((a + 32));
        s3E = *((a + 1056));
        t7R = _mm_sub_pd(s2E, s3E);
        t8R = _mm_add_pd(s2E, s3E);
        s4E = *((a + 512));
        s5E = *((a + 544));
        s6E = *((a + 1536));
        s7E = *((a + 1568));
        t9R = _mm_add_pd(s4E, s6E);
        t0S = _mm_sub_pd(s5E, s7E);
        a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4E, s6E));
        a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5E, s7E));
        s8E = _mm_sub_pd(a2, a3);
        s9E = _mm_add_pd(a2, a3);
        t1S = _mm_add_pd(t5R, t9R);
        t2S = _mm_sub_pd(t5R, t9R);
        t3S = _mm_sub_pd(t6R, t0S);
        t4S = _mm_add_pd(t6R, t0S);
        t5S = _mm_add_pd(t7R, s8E);
        t6S = _mm_sub_pd(t7R, s8E);
        t7S = _mm_sub_pd(t8R, s9E);
        t8S = _mm_add_pd(t8R, s9E);
        s0F = *((a + 64));
        s1F = *((a + 96));
        s2F = *((a + 1984));
        s3F = *((a + 2016));
        t9S = _mm_add_pd(s0F, s2F);
        t0T = _mm_sub_pd(s1F, s3F);
        t1T = _mm_sub_pd(s0F, s2F);
        t2T = _mm_add_pd(s1F, s3F);
        s4F = *((a + 1088));
        s5F = *((a + 1120));
        s6F = *((a + 960));
        s7F = *((a + 992));
        t3T = _mm_add_pd(s4F, s6F);
        t4T = _mm_sub_pd(s5F, s7F);
        t5T = _mm_sub_pd(s4F, s6F);
        t6T = _mm_add_pd(s5F, s7F);
        t7T = _mm_add_pd(t9S, t3T);
        t8T = _mm_add_pd(t0T, t4T);
        t9T = _mm_sub_pd(t9S, t3T);
        t0U = _mm_sub_pd(t0T, t4T);
        t1U = _mm_sub_pd(t1T, t6T);
        t2U = _mm_add_pd(t2T, t5T);
        t3U = _mm_add_pd(t1T, t6T);
        t4U = _mm_sub_pd(t2T, t5T);
        s8F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1U), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2U));
        s9F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1U), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2U));
        s0G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9T), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0U));
        s1G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9T), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0U));
        s2G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3U), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4U));
        s3G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3U), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4U));
        s4G = *((a + 128));
        s5G = *((a + 160));
        s6G = *((a + 1920));
        s7G = *((a + 1952));
        t5U = _mm_add_pd(s4G, s6G);
        t6U = _mm_sub_pd(s5G, s7G);
        t7U = _mm_sub_pd(s4G, s6G);
        t8U = _mm_add_pd(s5G, s7G);
        s8G = *((a + 1152));
        s9G = *((a + 1184));
        s0H = *((a + 896));
        s1H = *((a + 928));
        t9U = _mm_add_pd(s8G, s0H);
        t0V = _mm_sub_pd(s9G, s1H);
        t1V = _mm_sub_pd(s8G, s0H);
        t2V = _mm_add_pd(s9G, s1H);
        t3V = _mm_add_pd(t5U, t9U);
        t4V = _mm_add_pd(t6U, t0V);
        t5V = _mm_sub_pd(t5U, t9U);
        t6V = _mm_sub_pd(t6U, t0V);
        t7V = _mm_sub_pd(t7U, t2V);
        t8V = _mm_add_pd(t8U, t1V);
        t9V = _mm_add_pd(t7U, t2V);
        t0W = _mm_sub_pd(t8U, t1V);
        s2H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7V), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8V));
        s3H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7V), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8V));
        s4H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5V), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6V));
        s5H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5V), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6V));
        s6H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9V), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0W));
        s7H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9V), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0W));
        s8H = *((a + 192));
        s9H = *((a + 224));
        s0I = *((a + 1856));
        s1I = *((a + 1888));
        t1W = _mm_add_pd(s8H, s0I);
        t2W = _mm_sub_pd(s9H, s1I);
        t3W = _mm_sub_pd(s8H, s0I);
        t4W = _mm_add_pd(s9H, s1I);
        s2I = *((a + 1216));
        s3I = *((a + 1248));
        s4I = *((a + 832));
        s5I = *((a + 864));
        t5W = _mm_add_pd(s2I, s4I);
        t6W = _mm_sub_pd(s3I, s5I);
        t7W = _mm_sub_pd(s2I, s4I);
        t8W = _mm_add_pd(s3I, s5I);
        t9W = _mm_add_pd(t1W, t5W);
        t0X = _mm_add_pd(t2W, t6W);
        t1X = _mm_sub_pd(t1W, t5W);
        t2X = _mm_sub_pd(t2W, t6W);
        t3X = _mm_sub_pd(t3W, t8W);
        t4X = _mm_add_pd(t4W, t7W);
        t5X = _mm_add_pd(t3W, t8W);
        t6X = _mm_sub_pd(t4W, t7W);
        s6I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3X), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4X));
        s7I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3X), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4X));
        s8I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1X), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2X));
        s9I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1X), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2X));
        s0J = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5X), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6X));
        s1J = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5X), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6X));
        s2J = *((a + 256));
        s3J = *((a + 288));
        s4J = *((a + 1792));
        s5J = *((a + 1824));
        t7X = _mm_add_pd(s2J, s4J);
        t8X = _mm_sub_pd(s3J, s5J);
        t9X = _mm_sub_pd(s2J, s4J);
        t0Y = _mm_add_pd(s3J, s5J);
        s6J = *((a + 1280));
        s7J = *((a + 1312));
        s8J = *((a + 768));
        s9J = *((a + 800));
        t1Y = _mm_add_pd(s6J, s8J);
        t2Y = _mm_sub_pd(s7J, s9J);
        t3Y = _mm_sub_pd(s6J, s8J);
        t4Y = _mm_add_pd(s7J, s9J);
        t5Y = _mm_add_pd(t7X, t1Y);
        t6Y = _mm_add_pd(t8X, t2Y);
        t7Y = _mm_sub_pd(t9X, t4Y);
        t8Y = _mm_add_pd(t0Y, t3Y);
        t9Y = _mm_add_pd(t9X, t4Y);
        t0Z = _mm_sub_pd(t0Y, t3Y);
        s0K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7Y), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8Y));
        s1K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7Y), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8Y));
        a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7X, t1Y));
        a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8X, t2Y));
        s2K = _mm_sub_pd(a4, a5);
        s3K = _mm_add_pd(a4, a5);
        s4K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9Y), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0Z));
        s5K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9Y), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0Z));
        s6K = *((a + 320));
        s7K = *((a + 352));
        s8K = *((a + 1728));
        s9K = *((a + 1760));
        t1Z = _mm_add_pd(s6K, s8K);
        t2Z = _mm_sub_pd(s7K, s9K);
        t3Z = _mm_sub_pd(s6K, s8K);
        t4Z = _mm_add_pd(s7K, s9K);
        s0L = *((a + 1344));
        s1L = *((a + 1376));
        s2L = *((a + 704));
        s3L = *((a + 736));
        t5Z = _mm_add_pd(s0L, s2L);
        t6Z = _mm_sub_pd(s1L, s3L);
        t7Z = _mm_sub_pd(s0L, s2L);
        t8Z = _mm_add_pd(s1L, s3L);
        t9Z = _mm_add_pd(t1Z, t5Z);
        t010 = _mm_add_pd(t2Z, t6Z);
        t110 = _mm_sub_pd(t1Z, t5Z);
        t210 = _mm_sub_pd(t2Z, t6Z);
        t310 = _mm_sub_pd(t3Z, t8Z);
        t410 = _mm_add_pd(t4Z, t7Z);
        t510 = _mm_add_pd(t3Z, t8Z);
        t610 = _mm_sub_pd(t4Z, t7Z);
        s4L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t310), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t410));
        s5L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t310), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t410));
        s6L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t110), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t210));
        s7L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t110), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t210));
        s8L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t510), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t610));
        s9L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t510), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t610));
        s0M = *((a + 384));
        s1M = *((a + 416));
        s2M = *((a + 1664));
        s3M = *((a + 1696));
        t710 = _mm_add_pd(s0M, s2M);
        t810 = _mm_sub_pd(s1M, s3M);
        t910 = _mm_sub_pd(s0M, s2M);
        t011 = _mm_add_pd(s1M, s3M);
        s4M = *((a + 1408));
        s5M = *((a + 1440));
        s6M = *((a + 640));
        s7M = *((a + 672));
        t111 = _mm_add_pd(s4M, s6M);
        t211 = _mm_sub_pd(s5M, s7M);
        t311 = _mm_sub_pd(s4M, s6M);
        t411 = _mm_add_pd(s5M, s7M);
        t511 = _mm_add_pd(t710, t111);
        t611 = _mm_add_pd(t810, t211);
        t711 = _mm_sub_pd(t710, t111);
        t811 = _mm_sub_pd(t810, t211);
        t911 = _mm_sub_pd(t910, t411);
        t012 = _mm_add_pd(t011, t311);
        t112 = _mm_add_pd(t910, t411);
        t212 = _mm_sub_pd(t011, t311);
        s8M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t911), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t012));
        s9M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t911), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t012));
        s0N = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t711), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t811));
        s1N = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t711), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t811));
        s2N = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t112), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t212));
        s3N = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t112), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t212));
        s4N = *((a + 448));
        s5N = *((a + 480));
        s6N = *((a + 1600));
        s7N = *((a + 1632));
        t312 = _mm_add_pd(s4N, s6N);
        t412 = _mm_sub_pd(s5N, s7N);
        t512 = _mm_sub_pd(s4N, s6N);
        t612 = _mm_add_pd(s5N, s7N);
        s8N = *((a + 1472));
        s9N = *((a + 1504));
        s0O = *((a + 576));
        s1O = *((a + 608));
        t712 = _mm_add_pd(s8N, s0O);
        t812 = _mm_sub_pd(s9N, s1O);
        t912 = _mm_sub_pd(s8N, s0O);
        t013 = _mm_add_pd(s9N, s1O);
        t113 = _mm_add_pd(t312, t712);
        t213 = _mm_add_pd(t412, t812);
        t313 = _mm_sub_pd(t312, t712);
        t413 = _mm_sub_pd(t412, t812);
        t513 = _mm_sub_pd(t512, t013);
        t613 = _mm_add_pd(t612, t912);
        t713 = _mm_add_pd(t512, t013);
        t813 = _mm_sub_pd(t612, t912);
        s2O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t513), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t613));
        s3O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t513), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t613));
        s4O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t313), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t413));
        s5O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t313), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t413));
        s6O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t713), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t813));
        s7O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t713), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t813));
        t913 = _mm_add_pd(t1S, t5Y);
        t014 = _mm_sub_pd(t1S, t5Y);
        t114 = _mm_sub_pd(t2S, t6Y);
        t214 = _mm_add_pd(t2S, t6Y);
        t314 = _mm_add_pd(t3V, t511);
        t414 = _mm_sub_pd(t4V, t611);
        a6 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3V, t511));
        a7 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4V, t611));
        s8O = _mm_sub_pd(a6, a7);
        s9O = _mm_add_pd(a6, a7);
        t514 = _mm_add_pd(t913, t314);
        t614 = _mm_sub_pd(t913, t314);
        t714 = _mm_sub_pd(t014, t414);
        t814 = _mm_add_pd(t014, t414);
        t914 = _mm_add_pd(t114, s8O);
        t015 = _mm_sub_pd(t114, s8O);
        t115 = _mm_sub_pd(t214, s9O);
        t215 = _mm_add_pd(t214, s9O);
        t315 = _mm_add_pd(t7T, t113);
        t415 = _mm_sub_pd(t8T, t213);
        t515 = _mm_sub_pd(t7T, t113);
        t615 = _mm_add_pd(t8T, t213);
        t715 = _mm_add_pd(t9Z, t9W);
        t815 = _mm_sub_pd(t010, t0X);
        t915 = _mm_sub_pd(t9Z, t9W);
        t016 = _mm_add_pd(t010, t0X);
        t116 = _mm_add_pd(t315, t715);
        t216 = _mm_add_pd(t415, t815);
        t316 = _mm_sub_pd(t515, t016);
        t416 = _mm_add_pd(t615, t915);
        t516 = _mm_add_pd(t515, t016);
        t616 = _mm_sub_pd(t615, t915);
        s0P = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t316), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t416));
        s1P = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t316), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t416));
        a8 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t315, t715));
        a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t415, t815));
        s2P = _mm_sub_pd(a8, a9);
        s3P = _mm_add_pd(a8, a9);
        s4P = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t516), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t616));
        s5P = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t516), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t616));
        a01 = (dst + (2 * i3));
        s6P = _mm_add_pd(t514, t116);
        _mm_storeu_pd(((double  *) a01), s6P);
        s7P = _mm_sub_pd(t514, t116);
        _mm_storeu_pd(((double  *) (a01 + 2048)), s7P);
        s8P = _mm_sub_pd(t614, t216);
        _mm_storeu_pd(((double  *) (a01 + 1024)), s8P);
        s9P = _mm_add_pd(t614, t216);
        _mm_storeu_pd(((double  *) (a01 + 3072)), s9P);
        s0Q = _mm_add_pd(t914, s0P);
        _mm_storeu_pd(((double  *) (a01 + 256)), s0Q);
        s1Q = _mm_sub_pd(t914, s0P);
        _mm_storeu_pd(((double  *) (a01 + 2304)), s1Q);
        s2Q = _mm_sub_pd(t015, s1P);
        _mm_storeu_pd(((double  *) (a01 + 1280)), s2Q);
        s3Q = _mm_add_pd(t015, s1P);
        _mm_storeu_pd(((double  *) (a01 + 3328)), s3Q);
        s4Q = _mm_add_pd(t714, s2P);
        _mm_storeu_pd(((double  *) (a01 + 512)), s4Q);
        s5Q = _mm_sub_pd(t714, s2P);
        _mm_storeu_pd(((double  *) (a01 + 2560)), s5Q);
        s6Q = _mm_sub_pd(t814, s3P);
        _mm_storeu_pd(((double  *) (a01 + 1536)), s6Q);
        s7Q = _mm_add_pd(t814, s3P);
        _mm_storeu_pd(((double  *) (a01 + 3584)), s7Q);
        s8Q = _mm_add_pd(t115, s4P);
        _mm_storeu_pd(((double  *) (a01 + 768)), s8Q);
        s9Q = _mm_sub_pd(t115, s4P);
        _mm_storeu_pd(((double  *) (a01 + 2816)), s9Q);
        s0R = _mm_sub_pd(t215, s5P);
        _mm_storeu_pd(((double  *) (a01 + 1792)), s0R);
        s1R = _mm_add_pd(t215, s5P);
        _mm_storeu_pd(((double  *) (a01 + 3840)), s1R);
        t716 = _mm_add_pd(t5S, s0K);
        t816 = _mm_sub_pd(t5S, s0K);
        t916 = _mm_sub_pd(t6S, s1K);
        t017 = _mm_add_pd(t6S, s1K);
        t117 = _mm_add_pd(s2H, s8M);
        t217 = _mm_sub_pd(s3H, s9M);
        a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2H, s8M));
        a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3H, s9M));
        s2R = _mm_sub_pd(a11, a21);
        s3R = _mm_add_pd(a11, a21);
        t317 = _mm_add_pd(t716, t117);
        t417 = _mm_sub_pd(t716, t117);
        t517 = _mm_sub_pd(t816, t217);
        t617 = _mm_add_pd(t816, t217);
        t717 = _mm_add_pd(t916, s2R);
        t817 = _mm_sub_pd(t916, s2R);
        t917 = _mm_sub_pd(t017, s3R);
        t018 = _mm_add_pd(t017, s3R);
        t118 = _mm_add_pd(s8F, s2O);
        t218 = _mm_sub_pd(s9F, s3O);
        t318 = _mm_sub_pd(s8F, s2O);
        t418 = _mm_add_pd(s9F, s3O);
        t518 = _mm_add_pd(s4L, s6I);
        t618 = _mm_sub_pd(s5L, s7I);
        t718 = _mm_sub_pd(s4L, s6I);
        t818 = _mm_add_pd(s5L, s7I);
        t918 = _mm_add_pd(t118, t518);
        t019 = _mm_add_pd(t218, t618);
        t119 = _mm_sub_pd(t318, t818);
        t219 = _mm_add_pd(t418, t718);
        t319 = _mm_add_pd(t318, t818);
        t419 = _mm_sub_pd(t418, t718);
        s4R = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t119), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t219));
        s5R = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t119), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t219));
        a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t118, t518));
        a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t218, t618));
        s6R = _mm_sub_pd(a31, a41);
        s7R = _mm_add_pd(a31, a41);
        s8R = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t319), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t419));
        s9R = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t319), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t419));
        s0S = _mm_add_pd(t317, t918);
        _mm_storeu_pd(((double  *) (a01 + 64)), s0S);
        s1S = _mm_sub_pd(t317, t918);
        _mm_storeu_pd(((double  *) (a01 + 2112)), s1S);
        s2S = _mm_sub_pd(t417, t019);
        _mm_storeu_pd(((double  *) (a01 + 1088)), s2S);
        s3S = _mm_add_pd(t417, t019);
        _mm_storeu_pd(((double  *) (a01 + 3136)), s3S);
        s4S = _mm_add_pd(t717, s4R);
        _mm_storeu_pd(((double  *) (a01 + 320)), s4S);
        s5S = _mm_sub_pd(t717, s4R);
        _mm_storeu_pd(((double  *) (a01 + 2368)), s5S);
        s6S = _mm_sub_pd(t817, s5R);
        _mm_storeu_pd(((double  *) (a01 + 1344)), s6S);
        s7S = _mm_add_pd(t817, s5R);
        _mm_storeu_pd(((double  *) (a01 + 3392)), s7S);
        s8S = _mm_add_pd(t517, s6R);
        _mm_storeu_pd(((double  *) (a01 + 576)), s8S);
        s9S = _mm_sub_pd(t517, s6R);
        _mm_storeu_pd(((double  *) (a01 + 2624)), s9S);
        s0T = _mm_sub_pd(t617, s7R);
        _mm_storeu_pd(((double  *) (a01 + 1600)), s0T);
        s1T = _mm_add_pd(t617, s7R);
        _mm_storeu_pd(((double  *) (a01 + 3648)), s1T);
        s2T = _mm_add_pd(t917, s8R);
        _mm_storeu_pd(((double  *) (a01 + 832)), s2T);
        s3T = _mm_sub_pd(t917, s8R);
        _mm_storeu_pd(((double  *) (a01 + 2880)), s3T);
        s4T = _mm_sub_pd(t018, s9R);
        _mm_storeu_pd(((double  *) (a01 + 1856)), s4T);
        s5T = _mm_add_pd(t018, s9R);
        _mm_storeu_pd(((double  *) (a01 + 3904)), s5T);
        t519 = _mm_add_pd(t3S, s2K);
        t619 = _mm_sub_pd(t3S, s2K);
        t719 = _mm_sub_pd(t4S, s3K);
        t819 = _mm_add_pd(t4S, s3K);
        t919 = _mm_add_pd(s4H, s0N);
        t01a = _mm_sub_pd(s5H, s1N);
        a51 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4H, s0N));
        a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5H, s1N));
        s6T = _mm_sub_pd(a51, a61);
        s7T = _mm_add_pd(a51, a61);
        t11a = _mm_add_pd(t519, t919);
        t21a = _mm_sub_pd(t519, t919);
        t31a = _mm_sub_pd(t619, t01a);
        t41a = _mm_add_pd(t619, t01a);
        t51a = _mm_add_pd(t719, s6T);
        t61a = _mm_sub_pd(t719, s6T);
        t71a = _mm_sub_pd(t819, s7T);
        t81a = _mm_add_pd(t819, s7T);
        t91a = _mm_add_pd(s0G, s4O);
        t01b = _mm_sub_pd(s1G, s5O);
        t11b = _mm_sub_pd(s0G, s4O);
        t21b = _mm_add_pd(s1G, s5O);
        t31b = _mm_add_pd(s6L, s8I);
        t41b = _mm_sub_pd(s7L, s9I);
        t51b = _mm_sub_pd(s6L, s8I);
        t61b = _mm_add_pd(s7L, s9I);
        t71b = _mm_add_pd(t91a, t31b);
        t81b = _mm_add_pd(t01b, t41b);
        t91b = _mm_sub_pd(t11b, t61b);
        t01c = _mm_add_pd(t21b, t51b);
        t11c = _mm_add_pd(t11b, t61b);
        t21c = _mm_sub_pd(t21b, t51b);
        s8T = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t91b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t01c));
        s9T = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t91b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t01c));
        a71 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t91a, t31b));
        a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t01b, t41b));
        s0U = _mm_sub_pd(a71, a81);
        s1U = _mm_add_pd(a71, a81);
        s2U = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t11c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t21c));
        s3U = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t11c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21c));
        s4U = _mm_add_pd(t11a, t71b);
        _mm_storeu_pd(((double  *) (a01 + 128)), s4U);
        s5U = _mm_sub_pd(t11a, t71b);
        _mm_storeu_pd(((double  *) (a01 + 2176)), s5U);
        s6U = _mm_sub_pd(t21a, t81b);
        _mm_storeu_pd(((double  *) (a01 + 1152)), s6U);
        s7U = _mm_add_pd(t21a, t81b);
        _mm_storeu_pd(((double  *) (a01 + 3200)), s7U);
        s8U = _mm_add_pd(t51a, s8T);
        _mm_storeu_pd(((double  *) (a01 + 384)), s8U);
        s9U = _mm_sub_pd(t51a, s8T);
        _mm_storeu_pd(((double  *) (a01 + 2432)), s9U);
        s0V = _mm_sub_pd(t61a, s9T);
        _mm_storeu_pd(((double  *) (a01 + 1408)), s0V);
        s1V = _mm_add_pd(t61a, s9T);
        _mm_storeu_pd(((double  *) (a01 + 3456)), s1V);
        s2V = _mm_add_pd(t31a, s0U);
        _mm_storeu_pd(((double  *) (a01 + 640)), s2V);
        s3V = _mm_sub_pd(t31a, s0U);
        _mm_storeu_pd(((double  *) (a01 + 2688)), s3V);
        s4V = _mm_sub_pd(t41a, s1U);
        _mm_storeu_pd(((double  *) (a01 + 1664)), s4V);
        s5V = _mm_add_pd(t41a, s1U);
        _mm_storeu_pd(((double  *) (a01 + 3712)), s5V);
        s6V = _mm_add_pd(t71a, s2U);
        _mm_storeu_pd(((double  *) (a01 + 896)), s6V);
        s7V = _mm_sub_pd(t71a, s2U);
        _mm_storeu_pd(((double  *) (a01 + 2944)), s7V);
        s8V = _mm_sub_pd(t81a, s3U);
        _mm_storeu_pd(((double  *) (a01 + 1920)), s8V);
        s9V = _mm_add_pd(t81a, s3U);
        _mm_storeu_pd(((double  *) (a01 + 3968)), s9V);
        t31c = _mm_add_pd(t7S, s4K);
        t41c = _mm_sub_pd(t7S, s4K);
        t51c = _mm_sub_pd(t8S, s5K);
        t61c = _mm_add_pd(t8S, s5K);
        t71c = _mm_add_pd(s6H, s2N);
        t81c = _mm_sub_pd(s7H, s3N);
        a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6H, s2N));
        a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7H, s3N));
        s0W = _mm_sub_pd(a91, a02);
        s1W = _mm_add_pd(a91, a02);
        t91c = _mm_add_pd(t31c, t71c);
        t01d = _mm_sub_pd(t31c, t71c);
        t11d = _mm_sub_pd(t41c, t81c);
        t21d = _mm_add_pd(t41c, t81c);
        t31d = _mm_add_pd(t51c, s0W);
        t41d = _mm_sub_pd(t51c, s0W);
        t51d = _mm_sub_pd(t61c, s1W);
        t61d = _mm_add_pd(t61c, s1W);
        t71d = _mm_add_pd(s2G, s6O);
        t81d = _mm_sub_pd(s3G, s7O);
        t91d = _mm_sub_pd(s2G, s6O);
        t01e = _mm_add_pd(s3G, s7O);
        t11e = _mm_add_pd(s8L, s0J);
        t21e = _mm_sub_pd(s9L, s1J);
        t31e = _mm_sub_pd(s8L, s0J);
        t41e = _mm_add_pd(s9L, s1J);
        t51e = _mm_add_pd(t71d, t11e);
        t61e = _mm_add_pd(t81d, t21e);
        t71e = _mm_sub_pd(t91d, t41e);
        t81e = _mm_add_pd(t01e, t31e);
        t91e = _mm_add_pd(t91d, t41e);
        t01f = _mm_sub_pd(t01e, t31e);
        s2W = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t71e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t81e));
        s3W = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t71e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t81e));
        a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t71d, t11e));
        a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t81d, t21e));
        s4W = _mm_sub_pd(a12, a22);
        s5W = _mm_add_pd(a12, a22);
        s6W = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t91e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t01f));
        s7W = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t91e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t01f));
        s8W = _mm_add_pd(t91c, t51e);
        _mm_storeu_pd(((double  *) (a01 + 192)), s8W);
        s9W = _mm_sub_pd(t91c, t51e);
        _mm_storeu_pd(((double  *) (a01 + 2240)), s9W);
        s0X = _mm_sub_pd(t01d, t61e);
        _mm_storeu_pd(((double  *) (a01 + 1216)), s0X);
        s1X = _mm_add_pd(t01d, t61e);
        _mm_storeu_pd(((double  *) (a01 + 3264)), s1X);
        s2X = _mm_add_pd(t31d, s2W);
        _mm_storeu_pd(((double  *) (a01 + 448)), s2X);
        s3X = _mm_sub_pd(t31d, s2W);
        _mm_storeu_pd(((double  *) (a01 + 2496)), s3X);
        s4X = _mm_sub_pd(t41d, s3W);
        _mm_storeu_pd(((double  *) (a01 + 1472)), s4X);
        s5X = _mm_add_pd(t41d, s3W);
        _mm_storeu_pd(((double  *) (a01 + 3520)), s5X);
        s6X = _mm_add_pd(t11d, s4W);
        _mm_storeu_pd(((double  *) (a01 + 704)), s6X);
        s7X = _mm_sub_pd(t11d, s4W);
        _mm_storeu_pd(((double  *) (a01 + 2752)), s7X);
        s8X = _mm_sub_pd(t21d, s5W);
        _mm_storeu_pd(((double  *) (a01 + 1728)), s8X);
        s9X = _mm_add_pd(t21d, s5W);
        _mm_storeu_pd(((double  *) (a01 + 3776)), s9X);
        s0Y = _mm_add_pd(t51d, s6W);
        _mm_storeu_pd(((double  *) (a01 + 960)), s0Y);
        s1Y = _mm_sub_pd(t51d, s6W);
        _mm_storeu_pd(((double  *) (a01 + 3008)), s1Y);
        s2Y = _mm_sub_pd(t61d, s7W);
        _mm_storeu_pd(((double  *) (a01 + 1984)), s2Y);
        s3Y = _mm_add_pd(t61d, s7W);
        _mm_storeu_pd(((double  *) (a01 + 4032)), s3Y);
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_4096)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_4096_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[4096]);
     SPIRAL_ALIGNED(double T2[4096]);
    __m128d a01, a02, a04, a05, a06, a07, a08, a09, a0a, a0b, a0c, a0d, a0e, a11, a12, a14, a15, a16, a17, a18, a19, a1a
            , a1b, a1c, a1e, a21, a22, a23, a24, a25, a26, a27, a28, a29, a2a, a2b, a2d, a2e, a31, a32, a33, a34, a35, a36
            , a37, a38, a39, a3a, a3b, a3c, a3d, a3e, a41, a42, a43, a44, a45, a46, a47, a48, a49, a4a, a4b, a4c, a4d, a51
            , a52, a53, a54, a55, a56, a57, a58, a59, a5a, a5b, a5c, a5d, a6, a61, a62, a63, a64, a66, a67, a68, a69, a6a
            , a6b, a6c, a6d, a7, a72, a73, a74, a76, a77, a78, a79, a7a, a7b, a7c, a7d, a81, a82, a83, a84, a85, a86, a87
            , a88, a89, a8a, a8b, a8c, a8d, a9, a91, a92, a93, a94, a95, a96, a97, a98, a99, a9a, a9b, a9c, a9d, s, s01
            , s02, s03, s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0G, s0H, s0I, s0J, s0K, s0L, s0M, s0N
            , s0O, s0P, s0Q, s0R, s0S, s0T, s0U, s0V, s0W, s0X, s0Y, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j, s0k
            , s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16, s17
            , s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1G, s1H, s1I, s1J, s1K, s1L, s1M, s1N, s1O, s1P, s1Q, s1R, s1S, s1T
            , s1U, s1V, s1W, s1X, s1Y, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m, s1n, s1o, s1p, s1q
            , s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28, s29, s2A, s2B, s2C
            , s2D, s2E, s2F, s2G, s2H, s2I, s2J, s2K, s2L, s2M, s2N, s2O, s2P, s2Q, s2R, s2S, s2T, s2U, s2V, s2W, s2X, s2Y
            , s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o, s2p, s2q, s2r, s2s, s2t, s2u, s2v
            , s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A, s3B, s3C, s3D, s3E, s3F, s3G, s3H
            , s3I, s3J, s3K, s3L, s3M, s3N, s3O, s3P, s3Q, s3R, s3S, s3T, s3U, s3V, s3W, s3X, s3Y, s3a, s3b, s3c, s3d, s3e
            , s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q, s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4
            , s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C, s4D, s4E, s4F, s4G, s4H, s4I, s4J, s4K, s4L, s4M
            , s4N, s4O, s4P, s4Q, s4R, s4S, s4T, s4U, s4V, s4W, s4X, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k
            , s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s, s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56
            , s57, s58, s59, s5A, s5B, s5C, s5D, s5E, s5F, s5G, s5H, s5I, s5J, s5K, s5L, s5M, s5N, s5O, s5P, s5Q, s5R, s5S
            , s5T, s5U, s5V, s5W, s5X, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q
            , s5r, s5s, s5t, s5u, s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C
            , s6D, s6E, s6F, s6G, s6H, s6I, s6J, s6K, s6L, s6M, s6N, s6O, s6P, s6Q, s6R, s6S, s6T, s6U, s6V, s6W, s6X, s6a
            , s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w
            , s6x, s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7G, s7H, s7I
            , s7J, s7K, s7L, s7M, s7N, s7O, s7P, s7Q, s7R, s7S, s7T, s7U, s7V, s7W, s7X, s7a, s7b, s7c, s7d, s7e, s7f, s7g
            , s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y, s7z, s8, s81, s82
            , s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8F, s8G, s8H, s8I, s8J, s8K, s8L, s8M, s8N, s8O
            , s8P, s8Q, s8R, s8S, s8T, s8U, s8V, s8W, s8X, s8a, s8b, s8c, s8d, s8e, s8f, s8g, s8h, s8i, s8j, s8k, s8l, s8m
            , s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91, s92, s93, s94, s95, s96, s97, s98
            , s99, s9A, s9B, s9C, s9D, s9E, s9F, s9G, s9H, s9I, s9J, s9K, s9L, s9M, s9N, s9O, s9P, s9Q, s9R, s9S, s9T, s9U
            , s9V, s9W, s9X, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i, s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s
            , s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t010, t011, t012, t013, t014, t015, t016, t017, t018, t019, t01a, t01b, t01c
            , t01d, t01e, t01f, t02, t03, t04, t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0G, t0H, t0I, t0J, t0K
            , t0L, t0M, t0N, t0O, t0P, t0Q, t0R, t0S, t0T, t0U, t0V, t0W, t0X, t0Y, t0Z, t0a, t0b, t0c, t0d, t0e, t0f, t0g
            , t0h, t0i, t0j, t0k, t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t110, t111
            , t112, t113, t114, t115, t116, t117, t118, t119, t11a, t11b, t11c, t11d, t11e, t12, t13, t14, t15, t16, t17, t18, t19, t1A
            , t1B, t1C, t1D, t1E, t1F, t1G, t1H, t1I, t1J, t1K, t1L, t1M, t1N, t1O, t1P, t1Q, t1R, t1S, t1T, t1U, t1V, t1W
            , t1X, t1Y, t1Z, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n, t1o, t1p, t1q, t1r, t1s
            , t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t210, t211, t212, t213, t214, t215, t216, t217, t218, t219, t21a, t21b, t21c
            , t21d, t21e, t22, t23, t24, t25, t26, t27, t28, t29, t2A, t2B, t2C, t2D, t2E, t2F, t2G, t2H, t2I, t2J, t2K, t2L
            , t2M, t2N, t2O, t2P, t2Q, t2R, t2S, t2T, t2U, t2V, t2W, t2X, t2Y, t2Z, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h
            , t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p, t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t310, t311
            , t312, t313, t314, t315, t316, t317, t318, t319, t31a, t31b, t31c, t31d, t31e, t32, t33, t34, t35, t36, t37, t38, t39, t3A
            , t3B, t3C, t3D, t3E, t3F, t3G, t3H, t3I, t3J, t3K, t3L, t3M, t3N, t3O, t3P, t3Q, t3R, t3S, t3T, t3U, t3V, t3W
            , t3X, t3Y, t3Z, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s
            , t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t410, t411, t412, t413, t414, t415, t416, t417, t418, t419, t41a, t41b, t41c
            , t41d, t41e, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E, t4F, t4G, t4H, t4I, t4J, t4K, t4L
            , t4M, t4N, t4O, t4P, t4Q, t4R, t4S, t4T, t4U, t4V, t4W, t4X, t4Y, t4Z, t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h
            , t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v, t4w, t4x, t4y, t4z, t5, t51, t510, t511
            , t512, t513, t514, t515, t516, t517, t518, t519, t51a, t51b, t51c, t51d, t51e, t52, t53, t54, t55, t56, t57, t58, t59, t5A
            , t5B, t5C, t5D, t5E, t5F, t5G, t5H, t5I, t5J, t5K, t5L, t5M, t5N, t5O, t5P, t5Q, t5R, t5S, t5T, t5U, t5V, t5W
            , t5X, t5Y, t5Z, t5a, t5b, t5c, t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s
            , t5t, t5u, t5v, t5w, t5x, t5y, t5z, t6, t61, t610, t611, t612, t613, t614, t615, t616, t617, t618, t619, t61a, t61b, t61c
            , t61d, t61e, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6F, t6G, t6H, t6I, t6J, t6K, t6L
            , t6M, t6N, t6O, t6P, t6Q, t6R, t6S, t6T, t6U, t6V, t6W, t6X, t6Y, t6Z, t6a, t6b, t6c, t6d, t6e, t6f, t6g, t6h
            , t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71, t710, t711
            , t712, t713, t714, t715, t716, t717, t718, t719, t71a, t71b, t71c, t71d, t71e, t72, t73, t74, t75, t76, t77, t78, t79, t7A
            , t7B, t7C, t7D, t7E, t7F, t7G, t7H, t7I, t7J, t7K, t7L, t7M, t7N, t7O, t7P, t7Q, t7R, t7S, t7T, t7U, t7V, t7W
            , t7X, t7Y, t7Z, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i, t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s
            , t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t810, t811, t812, t813, t814, t815, t816, t817, t818, t819, t81a, t81b, t81c
            , t81d, t81e, t82, t83, t84, t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8F, t8G, t8H, t8I, t8J, t8K, t8L
            , t8M, t8N, t8O, t8P, t8Q, t8R, t8S, t8T, t8U, t8V, t8W, t8X, t8Y, t8Z, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h
            , t8i, t8j, t8k, t8l, t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t910, t911
            , t912, t913, t914, t915, t916, t917, t918, t919, t91a, t91b, t91c, t91d, t91e, t92, t93, t94, t95, t96, t97, t98, t99, t9A
            , t9B, t9C, t9D, t9E, t9F, t9G, t9H, t9I, t9J, t9K, t9L, t9M, t9N, t9O, t9P, t9Q, t9R, t9S, t9T, t9U, t9V, t9W
            , t9X, t9Y, t9Z, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o, t9p, t9q, t9r, t9s
            , t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a, *a03, *a1d, *a2, *a2c, *a3, *a5, *a71, *a75, *a8, *b, *b2, *b3, *b4;
    int a13, a4, a65;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 1024)));
    a2 = ((__m128d  *) T);
    s4 = _mm_add_pd(s2, s3);
    *(a2) = s4;
    s5 = _mm_sub_pd(s2, s3);
    *((a2 + 1)) = s5;
    {long i; for(i = 0; i <= 1022; i++) {
        a3 = ((__m128d  *) src);
        s6 = *((1 + (a3 + i)));
        s7 = v_neg23(*(((a3 - i) + 2047)));
        t = _mm_add_pd(s6, s7);
        t2 = _mm_sub_pd(s6, s7);
        s8 = v_lo2(t, t2);
        s9 = v_hi2(t, t2);
        a4 = (2 * i);
        a5 = (D76 + a4);
        a6 = *(a5);
        a7 = *((a5 + 1));
        b = (((__m128d  *) T) + a4);
        s01 = _mm_add_pd(_mm_mul_pd(a6, s8), _mm_mul_pd(a7, s9));
        *((b + 2)) = s01;
        s11 = _mm_sub_pd(_mm_mul_pd(a6, s9), _mm_mul_pd(a7, s8));
        *((b + 3)) = s11;
    }}
    a8 = ((__m128d  *) T);
    s21 = *(a8);
    s31 = *((a8 + 1024));
    t3 = _mm_add_pd(s21, s31);
    t4 = _mm_sub_pd(s21, s31);
    s41 = *((a8 + 1));
    s51 = *((a8 + 1025));
    t5 = _mm_sub_pd(s41, s51);
    t6 = _mm_add_pd(s41, s51);
    s61 = *((a8 + 512));
    s71 = *((a8 + 513));
    s81 = *((a8 + 1536));
    s91 = *((a8 + 1537));
    t7 = _mm_add_pd(s61, s81);
    t8 = _mm_sub_pd(s71, s91);
    a9 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s61, s81));
    a01 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s71, s91));
    s02 = _mm_sub_pd(a9, a01);
    s12 = _mm_add_pd(a9, a01);
    t9 = _mm_add_pd(t3, t7);
    t01 = _mm_sub_pd(t3, t7);
    t11 = _mm_sub_pd(t4, t8);
    t21 = _mm_add_pd(t4, t8);
    t31 = _mm_add_pd(t5, s02);
    t41 = _mm_sub_pd(t5, s02);
    t51 = _mm_sub_pd(t6, s12);
    t61 = _mm_add_pd(t6, s12);
    s22 = *((a8 + 64));
    s32 = *((a8 + 65));
    s42 = *((a8 + 1984));
    s52 = *((a8 + 1985));
    t71 = _mm_add_pd(s22, s42);
    t81 = _mm_sub_pd(s32, s52);
    t91 = _mm_sub_pd(s22, s42);
    t02 = _mm_add_pd(s32, s52);
    s62 = *((a8 + 1088));
    s72 = *((a8 + 1089));
    s82 = *((a8 + 960));
    s92 = *((a8 + 961));
    t12 = _mm_add_pd(s62, s82);
    t22 = _mm_sub_pd(s72, s92);
    t32 = _mm_sub_pd(s62, s82);
    t42 = _mm_add_pd(s72, s92);
    t52 = _mm_add_pd(t71, t12);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_sub_pd(t71, t12);
    t82 = _mm_sub_pd(t81, t22);
    t92 = _mm_sub_pd(t91, t42);
    t03 = _mm_add_pd(t02, t32);
    t13 = _mm_add_pd(t91, t42);
    t23 = _mm_sub_pd(t02, t32);
    s03 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t92), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t03));
    s13 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t92), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t03));
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t72), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t82));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t72), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t82));
    s43 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t13), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t23));
    s53 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t13), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t23));
    s63 = *((a8 + 128));
    s73 = *((a8 + 129));
    s83 = *((a8 + 1920));
    s93 = *((a8 + 1921));
    t33 = _mm_add_pd(s63, s83);
    t43 = _mm_sub_pd(s73, s93);
    t53 = _mm_sub_pd(s63, s83);
    t63 = _mm_add_pd(s73, s93);
    s04 = *((a8 + 1152));
    s14 = *((a8 + 1153));
    s24 = *((a8 + 896));
    s34 = *((a8 + 897));
    t73 = _mm_add_pd(s04, s24);
    t83 = _mm_sub_pd(s14, s34);
    t93 = _mm_sub_pd(s04, s24);
    t04 = _mm_add_pd(s14, s34);
    t14 = _mm_add_pd(t33, t73);
    t24 = _mm_add_pd(t43, t83);
    t34 = _mm_sub_pd(t33, t73);
    t44 = _mm_sub_pd(t43, t83);
    t54 = _mm_sub_pd(t53, t04);
    t64 = _mm_add_pd(t63, t93);
    t74 = _mm_add_pd(t53, t04);
    t84 = _mm_sub_pd(t63, t93);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t54), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t64));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t54), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t64));
    s64 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    s74 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t74), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t84));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t74), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t84));
    s05 = *((a8 + 192));
    s15 = *((a8 + 193));
    s25 = *((a8 + 1856));
    s35 = *((a8 + 1857));
    t94 = _mm_add_pd(s05, s25);
    t05 = _mm_sub_pd(s15, s35);
    t15 = _mm_sub_pd(s05, s25);
    t25 = _mm_add_pd(s15, s35);
    s45 = *((a8 + 1216));
    s55 = *((a8 + 1217));
    s65 = *((a8 + 832));
    s75 = *((a8 + 833));
    t35 = _mm_add_pd(s45, s65);
    t45 = _mm_sub_pd(s55, s75);
    t55 = _mm_sub_pd(s45, s65);
    t65 = _mm_add_pd(s55, s75);
    t75 = _mm_add_pd(t94, t35);
    t85 = _mm_add_pd(t05, t45);
    t95 = _mm_sub_pd(t94, t35);
    t06 = _mm_sub_pd(t05, t45);
    t16 = _mm_sub_pd(t15, t65);
    t26 = _mm_add_pd(t25, t55);
    t36 = _mm_add_pd(t15, t65);
    t46 = _mm_sub_pd(t25, t55);
    s85 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t16), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t26));
    s95 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t16), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t26));
    s06 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t95), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t06));
    s16 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t95), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t06));
    s26 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t36), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t46));
    s36 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t36), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t46));
    s46 = *((a8 + 256));
    s56 = *((a8 + 257));
    s66 = *((a8 + 1792));
    s76 = *((a8 + 1793));
    t56 = _mm_add_pd(s46, s66);
    t66 = _mm_sub_pd(s56, s76);
    t76 = _mm_sub_pd(s46, s66);
    t86 = _mm_add_pd(s56, s76);
    s86 = *((a8 + 1280));
    s96 = *((a8 + 1281));
    s07 = *((a8 + 768));
    s17 = *((a8 + 769));
    t96 = _mm_add_pd(s86, s07);
    t07 = _mm_sub_pd(s96, s17);
    t17 = _mm_sub_pd(s86, s07);
    t27 = _mm_add_pd(s96, s17);
    t37 = _mm_add_pd(t56, t96);
    t47 = _mm_add_pd(t66, t07);
    t57 = _mm_sub_pd(t76, t27);
    t67 = _mm_add_pd(t86, t17);
    t77 = _mm_add_pd(t76, t27);
    t87 = _mm_sub_pd(t86, t17);
    s27 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t57), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t67));
    s37 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t57), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t67));
    a11 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t56, t96));
    a21 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t66, t07));
    s47 = _mm_sub_pd(a11, a21);
    s57 = _mm_add_pd(a11, a21);
    s67 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t77), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t87));
    s77 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t77), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t87));
    s87 = *((a8 + 320));
    s97 = *((a8 + 321));
    s08 = *((a8 + 1728));
    s18 = *((a8 + 1729));
    t97 = _mm_add_pd(s87, s08);
    t08 = _mm_sub_pd(s97, s18);
    t18 = _mm_sub_pd(s87, s08);
    t28 = _mm_add_pd(s97, s18);
    s28 = *((a8 + 1344));
    s38 = *((a8 + 1345));
    s48 = *((a8 + 704));
    s58 = *((a8 + 705));
    t38 = _mm_add_pd(s28, s48);
    t48 = _mm_sub_pd(s38, s58);
    t58 = _mm_sub_pd(s28, s48);
    t68 = _mm_add_pd(s38, s58);
    t78 = _mm_add_pd(t97, t38);
    t88 = _mm_add_pd(t08, t48);
    t98 = _mm_sub_pd(t97, t38);
    t09 = _mm_sub_pd(t08, t48);
    t19 = _mm_sub_pd(t18, t68);
    t29 = _mm_add_pd(t28, t58);
    t39 = _mm_add_pd(t18, t68);
    t49 = _mm_sub_pd(t28, t58);
    s68 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t19), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t29));
    s78 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t19), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t29));
    s88 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t98), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t09));
    s98 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t98), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t09));
    s09 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t39), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t49));
    s19 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t39), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t49));
    s29 = *((a8 + 384));
    s39 = *((a8 + 385));
    s49 = *((a8 + 1664));
    s59 = *((a8 + 1665));
    t59 = _mm_add_pd(s29, s49);
    t69 = _mm_sub_pd(s39, s59);
    t79 = _mm_sub_pd(s29, s49);
    t89 = _mm_add_pd(s39, s59);
    s69 = *((a8 + 1408));
    s79 = *((a8 + 1409));
    s89 = *((a8 + 640));
    s99 = *((a8 + 641));
    t99 = _mm_add_pd(s69, s89);
    t0a = _mm_sub_pd(s79, s99);
    t1a = _mm_sub_pd(s69, s89);
    t2a = _mm_add_pd(s79, s99);
    t3a = _mm_add_pd(t59, t99);
    t4a = _mm_add_pd(t69, t0a);
    t5a = _mm_sub_pd(t59, t99);
    t6a = _mm_sub_pd(t69, t0a);
    t7a = _mm_sub_pd(t79, t2a);
    t8a = _mm_add_pd(t89, t1a);
    t9a = _mm_add_pd(t79, t2a);
    t0b = _mm_sub_pd(t89, t1a);
    s0a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t7a), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t8a));
    s1a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t7a), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t8a));
    s2a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5a), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6a));
    s3a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5a), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6a));
    s4a = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t9a), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0b));
    s5a = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9a), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t0b));
    s6a = *((a8 + 448));
    s7a = *((a8 + 449));
    s8a = *((a8 + 1600));
    s9a = *((a8 + 1601));
    t1b = _mm_add_pd(s6a, s8a);
    t2b = _mm_sub_pd(s7a, s9a);
    t3b = _mm_sub_pd(s6a, s8a);
    t4b = _mm_add_pd(s7a, s9a);
    s0b = *((a8 + 1472));
    s1b = *((a8 + 1473));
    s2b = *((a8 + 576));
    s3b = *((a8 + 577));
    t5b = _mm_add_pd(s0b, s2b);
    t6b = _mm_sub_pd(s1b, s3b);
    t7b = _mm_sub_pd(s0b, s2b);
    t8b = _mm_add_pd(s1b, s3b);
    t9b = _mm_add_pd(t1b, t5b);
    t0c = _mm_add_pd(t2b, t6b);
    t1c = _mm_sub_pd(t1b, t5b);
    t2c = _mm_sub_pd(t2b, t6b);
    t3c = _mm_sub_pd(t3b, t8b);
    t4c = _mm_add_pd(t4b, t7b);
    t5c = _mm_add_pd(t3b, t8b);
    t6c = _mm_sub_pd(t4b, t7b);
    s4b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t3c), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t4c));
    s5b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t3c), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t4c));
    s6b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1c), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2c));
    s7b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1c), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2c));
    s8b = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t5c), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t6c));
    s9b = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t5c), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t6c));
    t7c = _mm_add_pd(t9, t37);
    t8c = _mm_sub_pd(t9, t37);
    t9c = _mm_sub_pd(t01, t47);
    t0d = _mm_add_pd(t01, t47);
    t1d = _mm_add_pd(t14, t3a);
    t2d = _mm_sub_pd(t24, t4a);
    a31 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t14, t3a));
    a41 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t24, t4a));
    s0c = _mm_sub_pd(a31, a41);
    s1c = _mm_add_pd(a31, a41);
    t3d = _mm_add_pd(t7c, t1d);
    t4d = _mm_sub_pd(t7c, t1d);
    t5d = _mm_sub_pd(t8c, t2d);
    t6d = _mm_add_pd(t8c, t2d);
    t7d = _mm_add_pd(t9c, s0c);
    t8d = _mm_sub_pd(t9c, s0c);
    t9d = _mm_sub_pd(t0d, s1c);
    t0e = _mm_add_pd(t0d, s1c);
    t1e = _mm_add_pd(t52, t9b);
    t2e = _mm_sub_pd(t62, t0c);
    t3e = _mm_sub_pd(t52, t9b);
    t4e = _mm_add_pd(t62, t0c);
    t5e = _mm_add_pd(t78, t75);
    t6e = _mm_sub_pd(t88, t85);
    t7e = _mm_sub_pd(t78, t75);
    t8e = _mm_add_pd(t88, t85);
    t9e = _mm_add_pd(t1e, t5e);
    t0f = _mm_add_pd(t2e, t6e);
    t1f = _mm_sub_pd(t3e, t8e);
    t2f = _mm_add_pd(t4e, t7e);
    t3f = _mm_add_pd(t3e, t8e);
    t4f = _mm_sub_pd(t4e, t7e);
    s2c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2f));
    s3c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2f));
    a51 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1e, t5e));
    a61 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2e, t6e));
    s4c = _mm_sub_pd(a51, a61);
    s5c = _mm_add_pd(a51, a61);
    s6c = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3f), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4f));
    s7c = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3f), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4f));
    a71 = ((__m128d  *) T2);
    s8c = _mm_add_pd(t3d, t9e);
    *(a71) = s8c;
    s9c = _mm_sub_pd(t3d, t9e);
    *((a71 + 32)) = s9c;
    s0d = _mm_sub_pd(t4d, t0f);
    *((a71 + 16)) = s0d;
    s1d = _mm_add_pd(t4d, t0f);
    *((a71 + 48)) = s1d;
    s2d = _mm_add_pd(t7d, s2c);
    *((a71 + 4)) = s2d;
    s3d = _mm_sub_pd(t7d, s2c);
    *((a71 + 36)) = s3d;
    s4d = _mm_sub_pd(t8d, s3c);
    *((a71 + 20)) = s4d;
    s5d = _mm_add_pd(t8d, s3c);
    *((a71 + 52)) = s5d;
    s6d = _mm_add_pd(t5d, s4c);
    *((a71 + 8)) = s6d;
    s7d = _mm_sub_pd(t5d, s4c);
    *((a71 + 40)) = s7d;
    s8d = _mm_sub_pd(t6d, s5c);
    *((a71 + 24)) = s8d;
    s9d = _mm_add_pd(t6d, s5c);
    *((a71 + 56)) = s9d;
    s0e = _mm_add_pd(t9d, s6c);
    *((a71 + 12)) = s0e;
    s1e = _mm_sub_pd(t9d, s6c);
    *((a71 + 44)) = s1e;
    s2e = _mm_sub_pd(t0e, s7c);
    *((a71 + 28)) = s2e;
    s3e = _mm_add_pd(t0e, s7c);
    *((a71 + 60)) = s3e;
    t5f = _mm_add_pd(t31, s27);
    t6f = _mm_sub_pd(t31, s27);
    t7f = _mm_sub_pd(t41, s37);
    t8f = _mm_add_pd(t41, s37);
    t9f = _mm_add_pd(s44, s0a);
    t0g = _mm_sub_pd(s54, s1a);
    a81 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s44, s0a));
    a91 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s54, s1a));
    s4e = _mm_sub_pd(a81, a91);
    s5e = _mm_add_pd(a81, a91);
    t1g = _mm_add_pd(t5f, t9f);
    t2g = _mm_sub_pd(t5f, t9f);
    t3g = _mm_sub_pd(t6f, t0g);
    t4g = _mm_add_pd(t6f, t0g);
    t5g = _mm_add_pd(t7f, s4e);
    t6g = _mm_sub_pd(t7f, s4e);
    t7g = _mm_sub_pd(t8f, s5e);
    t8g = _mm_add_pd(t8f, s5e);
    t9g = _mm_add_pd(s03, s4b);
    t0h = _mm_sub_pd(s13, s5b);
    t1h = _mm_sub_pd(s03, s4b);
    t2h = _mm_add_pd(s13, s5b);
    t3h = _mm_add_pd(s68, s85);
    t4h = _mm_sub_pd(s78, s95);
    t5h = _mm_sub_pd(s68, s85);
    t6h = _mm_add_pd(s78, s95);
    t7h = _mm_add_pd(t9g, t3h);
    t8h = _mm_add_pd(t0h, t4h);
    t9h = _mm_sub_pd(t1h, t6h);
    t0i = _mm_add_pd(t2h, t5h);
    t1i = _mm_add_pd(t1h, t6h);
    t2i = _mm_sub_pd(t2h, t5h);
    s6e = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9h), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0i));
    s7e = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9h), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0i));
    a02 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9g, t3h));
    a12 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0h, t4h));
    s8e = _mm_sub_pd(a02, a12);
    s9e = _mm_add_pd(a02, a12);
    s0f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1i), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2i));
    s1f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1i), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2i));
    s2f = _mm_add_pd(t1g, t7h);
    *((a71 + 1)) = s2f;
    s3f = _mm_sub_pd(t1g, t7h);
    *((a71 + 33)) = s3f;
    s4f = _mm_sub_pd(t2g, t8h);
    *((a71 + 17)) = s4f;
    s5f = _mm_add_pd(t2g, t8h);
    *((a71 + 49)) = s5f;
    s6f = _mm_add_pd(t5g, s6e);
    *((a71 + 5)) = s6f;
    s7f = _mm_sub_pd(t5g, s6e);
    *((a71 + 37)) = s7f;
    s8f = _mm_sub_pd(t6g, s7e);
    *((a71 + 21)) = s8f;
    s9f = _mm_add_pd(t6g, s7e);
    *((a71 + 53)) = s9f;
    s0g = _mm_add_pd(t3g, s8e);
    *((a71 + 9)) = s0g;
    s1g = _mm_sub_pd(t3g, s8e);
    *((a71 + 41)) = s1g;
    s2g = _mm_sub_pd(t4g, s9e);
    *((a71 + 25)) = s2g;
    s3g = _mm_add_pd(t4g, s9e);
    *((a71 + 57)) = s3g;
    s4g = _mm_add_pd(t7g, s0f);
    *((a71 + 13)) = s4g;
    s5g = _mm_sub_pd(t7g, s0f);
    *((a71 + 45)) = s5g;
    s6g = _mm_sub_pd(t8g, s1f);
    *((a71 + 29)) = s6g;
    s7g = _mm_add_pd(t8g, s1f);
    *((a71 + 61)) = s7g;
    t3i = _mm_add_pd(t11, s47);
    t4i = _mm_sub_pd(t11, s47);
    t5i = _mm_sub_pd(t21, s57);
    t6i = _mm_add_pd(t21, s57);
    t7i = _mm_add_pd(s64, s2a);
    t8i = _mm_sub_pd(s74, s3a);
    a22 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s64, s2a));
    a32 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s74, s3a));
    s8g = _mm_sub_pd(a22, a32);
    s9g = _mm_add_pd(a22, a32);
    t9i = _mm_add_pd(t3i, t7i);
    t0j = _mm_sub_pd(t3i, t7i);
    t1j = _mm_sub_pd(t4i, t8i);
    t2j = _mm_add_pd(t4i, t8i);
    t3j = _mm_add_pd(t5i, s8g);
    t4j = _mm_sub_pd(t5i, s8g);
    t5j = _mm_sub_pd(t6i, s9g);
    t6j = _mm_add_pd(t6i, s9g);
    t7j = _mm_add_pd(s23, s6b);
    t8j = _mm_sub_pd(s33, s7b);
    t9j = _mm_sub_pd(s23, s6b);
    t0k = _mm_add_pd(s33, s7b);
    t1k = _mm_add_pd(s88, s06);
    t2k = _mm_sub_pd(s98, s16);
    t3k = _mm_sub_pd(s88, s06);
    t4k = _mm_add_pd(s98, s16);
    t5k = _mm_add_pd(t7j, t1k);
    t6k = _mm_add_pd(t8j, t2k);
    t7k = _mm_sub_pd(t9j, t4k);
    t8k = _mm_add_pd(t0k, t3k);
    t9k = _mm_add_pd(t9j, t4k);
    t0l = _mm_sub_pd(t0k, t3k);
    s0h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8k));
    s1h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8k));
    a42 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7j, t1k));
    a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8j, t2k));
    s2h = _mm_sub_pd(a42, a52);
    s3h = _mm_add_pd(a42, a52);
    s4h = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9k), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0l));
    s5h = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9k), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0l));
    s6h = _mm_add_pd(t9i, t5k);
    *((a71 + 2)) = s6h;
    s7h = _mm_sub_pd(t9i, t5k);
    *((a71 + 34)) = s7h;
    s8h = _mm_sub_pd(t0j, t6k);
    *((a71 + 18)) = s8h;
    s9h = _mm_add_pd(t0j, t6k);
    *((a71 + 50)) = s9h;
    s0i = _mm_add_pd(t3j, s0h);
    *((a71 + 6)) = s0i;
    s1i = _mm_sub_pd(t3j, s0h);
    *((a71 + 38)) = s1i;
    s2i = _mm_sub_pd(t4j, s1h);
    *((a71 + 22)) = s2i;
    s3i = _mm_add_pd(t4j, s1h);
    *((a71 + 54)) = s3i;
    s4i = _mm_add_pd(t1j, s2h);
    *((a71 + 10)) = s4i;
    s5i = _mm_sub_pd(t1j, s2h);
    *((a71 + 42)) = s5i;
    s6i = _mm_sub_pd(t2j, s3h);
    *((a71 + 26)) = s6i;
    s7i = _mm_add_pd(t2j, s3h);
    *((a71 + 58)) = s7i;
    s8i = _mm_add_pd(t5j, s4h);
    *((a71 + 14)) = s8i;
    s9i = _mm_sub_pd(t5j, s4h);
    *((a71 + 46)) = s9i;
    s0j = _mm_sub_pd(t6j, s5h);
    *((a71 + 30)) = s0j;
    s1j = _mm_add_pd(t6j, s5h);
    *((a71 + 62)) = s1j;
    t1l = _mm_add_pd(t51, s67);
    t2l = _mm_sub_pd(t51, s67);
    t3l = _mm_sub_pd(t61, s77);
    t4l = _mm_add_pd(t61, s77);
    t5l = _mm_add_pd(s84, s4a);
    t6l = _mm_sub_pd(s94, s5a);
    a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s84, s4a));
    a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s94, s5a));
    s2j = _mm_sub_pd(a62, a72);
    s3j = _mm_add_pd(a62, a72);
    t7l = _mm_add_pd(t1l, t5l);
    t8l = _mm_sub_pd(t1l, t5l);
    t9l = _mm_sub_pd(t2l, t6l);
    t0m = _mm_add_pd(t2l, t6l);
    t1m = _mm_add_pd(t3l, s2j);
    t2m = _mm_sub_pd(t3l, s2j);
    t3m = _mm_sub_pd(t4l, s3j);
    t4m = _mm_add_pd(t4l, s3j);
    t5m = _mm_add_pd(s43, s8b);
    t6m = _mm_sub_pd(s53, s9b);
    t7m = _mm_sub_pd(s43, s8b);
    t8m = _mm_add_pd(s53, s9b);
    t9m = _mm_add_pd(s09, s26);
    t0n = _mm_sub_pd(s19, s36);
    t1n = _mm_sub_pd(s09, s26);
    t2n = _mm_add_pd(s19, s36);
    t3n = _mm_add_pd(t5m, t9m);
    t4n = _mm_add_pd(t6m, t0n);
    t5n = _mm_sub_pd(t7m, t2n);
    t6n = _mm_add_pd(t8m, t1n);
    t7n = _mm_add_pd(t7m, t2n);
    t8n = _mm_sub_pd(t8m, t1n);
    s4j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5n), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6n));
    s5j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5n), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6n));
    a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5m, t9m));
    a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6m, t0n));
    s6j = _mm_sub_pd(a82, a92);
    s7j = _mm_add_pd(a82, a92);
    s8j = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7n), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8n));
    s9j = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7n), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8n));
    s0k = _mm_add_pd(t7l, t3n);
    *((a71 + 3)) = s0k;
    s1k = _mm_sub_pd(t7l, t3n);
    *((a71 + 35)) = s1k;
    s2k = _mm_sub_pd(t8l, t4n);
    *((a71 + 19)) = s2k;
    s3k = _mm_add_pd(t8l, t4n);
    *((a71 + 51)) = s3k;
    s4k = _mm_add_pd(t1m, s4j);
    *((a71 + 7)) = s4k;
    s5k = _mm_sub_pd(t1m, s4j);
    *((a71 + 39)) = s5k;
    s6k = _mm_sub_pd(t2m, s5j);
    *((a71 + 23)) = s6k;
    s7k = _mm_add_pd(t2m, s5j);
    *((a71 + 55)) = s7k;
    s8k = _mm_add_pd(t9l, s6j);
    *((a71 + 11)) = s8k;
    s9k = _mm_sub_pd(t9l, s6j);
    *((a71 + 43)) = s9k;
    s0l = _mm_sub_pd(t0m, s7j);
    *((a71 + 27)) = s0l;
    s1l = _mm_add_pd(t0m, s7j);
    *((a71 + 59)) = s1l;
    s2l = _mm_add_pd(t3m, s8j);
    *((a71 + 15)) = s2l;
    s3l = _mm_sub_pd(t3m, s8j);
    *((a71 + 47)) = s3l;
    s4l = _mm_sub_pd(t4m, s9j);
    *((a71 + 31)) = s4l;
    s5l = _mm_add_pd(t4m, s9j);
    *((a71 + 63)) = s5l;
    {long i2; for(i2 = 0; i2 <= 30; i2++) {
        a03 = ((__m128d  *) T);
        a13 = (2 * i2);
        b2 = (a03 + a13);
        s6l = *((b2 + 2));
        s7l = *((b2 + 3));
        b3 = (a03 - a13);
        s8l = *((b3 + 2046));
        s9l = *((b3 + 2047));
        t9n = _mm_add_pd(s6l, s8l);
        t0o = _mm_sub_pd(s7l, s9l);
        t1o = _mm_sub_pd(s6l, s8l);
        t2o = _mm_add_pd(s7l, s9l);
        s0m = *((b2 + 1026));
        s1m = *((b2 + 1027));
        s2m = *((b3 + 1022));
        s3m = *((b3 + 1023));
        t3o = _mm_add_pd(s0m, s2m);
        t4o = _mm_sub_pd(s1m, s3m);
        t5o = _mm_sub_pd(s0m, s2m);
        t6o = _mm_add_pd(s1m, s3m);
        t7o = _mm_add_pd(t9n, t3o);
        t8o = _mm_add_pd(t0o, t4o);
        t9o = _mm_sub_pd(t9n, t3o);
        t0p = _mm_sub_pd(t0o, t4o);
        t1p = _mm_sub_pd(t1o, t6o);
        t2p = _mm_add_pd(t2o, t5o);
        t3p = _mm_add_pd(t1o, t6o);
        t4p = _mm_sub_pd(t2o, t5o);
        s4m = *((b2 + 514));
        s5m = *((b2 + 515));
        s6m = *((b3 + 1534));
        s7m = *((b3 + 1535));
        t5p = _mm_add_pd(s4m, s6m);
        t6p = _mm_sub_pd(s5m, s7m);
        t7p = _mm_sub_pd(s4m, s6m);
        t8p = _mm_add_pd(s5m, s7m);
        s8m = *((b2 + 1538));
        s9m = *((b2 + 1539));
        s0n = *((b3 + 510));
        s1n = *((b3 + 511));
        t9p = _mm_add_pd(s8m, s0n);
        t0q = _mm_sub_pd(s9m, s1n);
        t1q = _mm_sub_pd(s8m, s0n);
        t2q = _mm_add_pd(s9m, s1n);
        t3q = _mm_add_pd(t5p, t9p);
        t4q = _mm_add_pd(t6p, t0q);
        t5q = _mm_sub_pd(t5p, t9p);
        t6q = _mm_sub_pd(t6p, t0q);
        a23 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7p, t2q));
        a33 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t8p, t1q));
        s2n = _mm_sub_pd(a23, a33);
        s3n = _mm_add_pd(a23, a33);
        a43 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t7p, t2q));
        a53 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8p, t1q));
        s4n = _mm_sub_pd(a43, a53);
        s5n = _mm_add_pd(a43, a53);
        t7q = _mm_add_pd(t7o, t3q);
        t8q = _mm_add_pd(t8o, t4q);
        t9q = _mm_sub_pd(t7o, t3q);
        t0r = _mm_sub_pd(t8o, t4q);
        t1r = _mm_add_pd(t1p, s2n);
        t2r = _mm_add_pd(t2p, s3n);
        t3r = _mm_sub_pd(t1p, s2n);
        t4r = _mm_sub_pd(t2p, s3n);
        t5r = _mm_sub_pd(t9o, t6q);
        t6r = _mm_add_pd(t0p, t5q);
        t7r = _mm_add_pd(t9o, t6q);
        t8r = _mm_sub_pd(t0p, t5q);
        t9r = _mm_add_pd(t3p, s4n);
        t0s = _mm_sub_pd(t4p, s5n);
        t1s = _mm_sub_pd(t3p, s4n);
        t2s = _mm_add_pd(t4p, s5n);
        s6n = *((b2 + 130));
        s7n = *((b2 + 131));
        s8n = *((b3 + 1918));
        s9n = *((b3 + 1919));
        t3s = _mm_add_pd(s6n, s8n);
        t4s = _mm_sub_pd(s7n, s9n);
        t5s = _mm_sub_pd(s6n, s8n);
        t6s = _mm_add_pd(s7n, s9n);
        s0o = *((b2 + 1154));
        s1o = *((b2 + 1155));
        s2o = *((b3 + 894));
        s3o = *((b3 + 895));
        t7s = _mm_add_pd(s0o, s2o);
        t8s = _mm_sub_pd(s1o, s3o);
        t9s = _mm_sub_pd(s0o, s2o);
        t0t = _mm_add_pd(s1o, s3o);
        t1t = _mm_add_pd(t3s, t7s);
        t2t = _mm_add_pd(t4s, t8s);
        t3t = _mm_sub_pd(t3s, t7s);
        t4t = _mm_sub_pd(t4s, t8s);
        t5t = _mm_sub_pd(t5s, t0t);
        t6t = _mm_add_pd(t6s, t9s);
        t7t = _mm_add_pd(t5s, t0t);
        t8t = _mm_sub_pd(t6s, t9s);
        s4o = *((b2 + 642));
        s5o = *((b2 + 643));
        s6o = *((b3 + 1406));
        s7o = *((b3 + 1407));
        t9t = _mm_add_pd(s4o, s6o);
        t0u = _mm_sub_pd(s5o, s7o);
        t1u = _mm_sub_pd(s4o, s6o);
        t2u = _mm_add_pd(s5o, s7o);
        s8o = *((b2 + 1666));
        s9o = *((b2 + 1667));
        s0p = *((b3 + 382));
        s1p = *((b3 + 383));
        t3u = _mm_add_pd(s8o, s0p);
        t4u = _mm_sub_pd(s9o, s1p);
        t5u = _mm_sub_pd(s8o, s0p);
        t6u = _mm_add_pd(s9o, s1p);
        t7u = _mm_add_pd(t9t, t3u);
        t8u = _mm_add_pd(t0u, t4u);
        t9u = _mm_sub_pd(t9t, t3u);
        t0v = _mm_sub_pd(t0u, t4u);
        a63 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1u, t6u));
        a73 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2u, t5u));
        s2p = _mm_sub_pd(a63, a73);
        s3p = _mm_add_pd(a63, a73);
        a83 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1u, t6u));
        a93 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2u, t5u));
        s4p = _mm_sub_pd(a83, a93);
        s5p = _mm_add_pd(a83, a93);
        t1v = _mm_add_pd(t1t, t7u);
        t2v = _mm_add_pd(t2t, t8u);
        a04 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1t, t7u));
        a14 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2t, t8u));
        s6p = _mm_sub_pd(a04, a14);
        s7p = _mm_add_pd(a04, a14);
        t3v = _mm_add_pd(t5t, s2p);
        t4v = _mm_add_pd(t6t, s3p);
        t5v = _mm_sub_pd(t5t, s2p);
        t6v = _mm_sub_pd(t6t, s3p);
        s8p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3v), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4v));
        s9p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3v), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4v));
        s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5v), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6v));
        s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5v), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6v));
        t7v = _mm_sub_pd(t3t, t0v);
        t8v = _mm_add_pd(t4t, t9u);
        t9v = _mm_add_pd(t3t, t0v);
        t0w = _mm_sub_pd(t4t, t9u);
        s2q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8v));
        s3q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8v));
        s4q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9v), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0w));
        s5q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9v), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0w));
        t1w = _mm_add_pd(t7t, s4p);
        t2w = _mm_sub_pd(t8t, s5p);
        t3w = _mm_sub_pd(t7t, s4p);
        t4w = _mm_add_pd(t8t, s5p);
        s6q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1w), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2w));
        s7q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1w), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2w));
        s8q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t3w), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4w));
        s9q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3w), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t4w));
        s0r = *((b2 + 258));
        s1r = *((b2 + 259));
        s2r = *((b3 + 1790));
        s3r = *((b3 + 1791));
        t5w = _mm_add_pd(s0r, s2r);
        t6w = _mm_sub_pd(s1r, s3r);
        t7w = _mm_sub_pd(s0r, s2r);
        t8w = _mm_add_pd(s1r, s3r);
        s4r = *((b2 + 1282));
        s5r = *((b2 + 1283));
        s6r = *((b3 + 766));
        s7r = *((b3 + 767));
        t9w = _mm_add_pd(s4r, s6r);
        t0x = _mm_sub_pd(s5r, s7r);
        t1x = _mm_sub_pd(s4r, s6r);
        t2x = _mm_add_pd(s5r, s7r);
        t3x = _mm_add_pd(t5w, t9w);
        t4x = _mm_add_pd(t6w, t0x);
        t5x = _mm_sub_pd(t5w, t9w);
        t6x = _mm_sub_pd(t6w, t0x);
        t7x = _mm_sub_pd(t7w, t2x);
        t8x = _mm_add_pd(t8w, t1x);
        t9x = _mm_add_pd(t7w, t2x);
        t0y = _mm_sub_pd(t8w, t1x);
        s8r = *((b2 + 770));
        s9r = *((b2 + 771));
        s0s = *((b3 + 1278));
        s1s = *((b3 + 1279));
        t1y = _mm_add_pd(s8r, s0s);
        t2y = _mm_sub_pd(s9r, s1s);
        t3y = _mm_sub_pd(s8r, s0s);
        t4y = _mm_add_pd(s9r, s1s);
        s2s = *((b2 + 1794));
        s3s = *((b2 + 1795));
        s4s = *((b3 + 254));
        s5s = *((b3 + 255));
        t5y = _mm_add_pd(s2s, s4s);
        t6y = _mm_sub_pd(s3s, s5s);
        t7y = _mm_sub_pd(s2s, s4s);
        t8y = _mm_add_pd(s3s, s5s);
        t9y = _mm_add_pd(t1y, t5y);
        t0z = _mm_add_pd(t2y, t6y);
        t1z = _mm_sub_pd(t1y, t5y);
        t2z = _mm_sub_pd(t2y, t6y);
        a24 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3y, t8y));
        a34 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4y, t7y));
        s6s = _mm_sub_pd(a24, a34);
        s7s = _mm_add_pd(a24, a34);
        a44 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3y, t8y));
        a54 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4y, t7y));
        s8s = _mm_sub_pd(a44, a54);
        s9s = _mm_add_pd(a44, a54);
        t3z = _mm_add_pd(t3x, t9y);
        t4z = _mm_add_pd(t4x, t0z);
        t5z = _mm_sub_pd(t3x, t9y);
        t6z = _mm_sub_pd(t4x, t0z);
        t7z = _mm_add_pd(t7x, s6s);
        t8z = _mm_add_pd(t8x, s7s);
        t9z = _mm_sub_pd(t7x, s6s);
        t0A = _mm_sub_pd(t8x, s7s);
        s0t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8z));
        s1t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8z));
        s2t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t9z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0A));
        s3t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9z), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t0A));
        a64 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5x, t2z));
        a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6x, t1z));
        s4t = _mm_sub_pd(a64, a74);
        s5t = _mm_add_pd(a64, a74);
        a84 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t5x, t2z));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6x, t1z));
        s6t = _mm_sub_pd(a84, a94);
        s7t = _mm_add_pd(a84, a94);
        t1A = _mm_add_pd(t9x, s8s);
        t2A = _mm_sub_pd(t0y, s9s);
        t3A = _mm_sub_pd(t9x, s8s);
        t4A = _mm_add_pd(t0y, s9s);
        s8t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1A), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2A));
        s9t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2A));
        s0u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t3A), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4A));
        s1u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3A), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t4A));
        s2u = *((b2 + 386));
        s3u = *((b2 + 387));
        s4u = *((b3 + 1662));
        s5u = *((b3 + 1663));
        t5A = _mm_add_pd(s2u, s4u);
        t6A = _mm_sub_pd(s3u, s5u);
        t7A = _mm_sub_pd(s2u, s4u);
        t8A = _mm_add_pd(s3u, s5u);
        s6u = *((b2 + 1410));
        s7u = *((b2 + 1411));
        s8u = *((b3 + 638));
        s9u = *((b3 + 639));
        t9A = _mm_add_pd(s6u, s8u);
        t0B = _mm_sub_pd(s7u, s9u);
        t1B = _mm_sub_pd(s6u, s8u);
        t2B = _mm_add_pd(s7u, s9u);
        t3B = _mm_add_pd(t5A, t9A);
        t4B = _mm_add_pd(t6A, t0B);
        t5B = _mm_sub_pd(t5A, t9A);
        t6B = _mm_sub_pd(t6A, t0B);
        t7B = _mm_sub_pd(t7A, t2B);
        t8B = _mm_add_pd(t8A, t1B);
        t9B = _mm_add_pd(t7A, t2B);
        t0C = _mm_sub_pd(t8A, t1B);
        s0v = *((b2 + 898));
        s1v = *((b2 + 899));
        s2v = *((b3 + 1150));
        s3v = *((b3 + 1151));
        t1C = _mm_add_pd(s0v, s2v);
        t2C = _mm_sub_pd(s1v, s3v);
        t3C = _mm_sub_pd(s0v, s2v);
        t4C = _mm_add_pd(s1v, s3v);
        s4v = *((b2 + 1922));
        s5v = *((b2 + 1923));
        s6v = *((b3 + 126));
        s7v = *((b3 + 127));
        t5C = _mm_add_pd(s4v, s6v);
        t6C = _mm_sub_pd(s5v, s7v);
        t7C = _mm_sub_pd(s4v, s6v);
        t8C = _mm_add_pd(s5v, s7v);
        t9C = _mm_add_pd(t1C, t5C);
        t0D = _mm_add_pd(t2C, t6C);
        t1D = _mm_sub_pd(t1C, t5C);
        t2D = _mm_sub_pd(t2C, t6C);
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3C, t8C));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4C, t7C));
        s8v = _mm_sub_pd(a05, a15);
        s9v = _mm_add_pd(a05, a15);
        a25 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t3C, t8C));
        a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4C, t7C));
        s0w = _mm_sub_pd(a25, a35);
        s1w = _mm_add_pd(a25, a35);
        t3D = _mm_add_pd(t3B, t9C);
        t4D = _mm_add_pd(t4B, t0D);
        a45 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_sub_pd(t3B, t9C));
        a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4B, t0D));
        s2w = _mm_sub_pd(a45, a55);
        s3w = _mm_add_pd(a45, a55);
        t5D = _mm_add_pd(t7B, s8v);
        t6D = _mm_add_pd(t8B, s9v);
        t7D = _mm_sub_pd(t7B, s8v);
        t8D = _mm_sub_pd(t8B, s9v);
        s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t5D), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t6D));
        s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t5D), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t6D));
        s6w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t7D), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8D));
        s7w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7D), _mm_mul_pd(_mm_set1_pd((-0.98078528040323043)), t8D));
        t9D = _mm_sub_pd(t5B, t2D);
        t0E = _mm_add_pd(t6B, t1D);
        t1E = _mm_add_pd(t5B, t2D);
        t2E = _mm_sub_pd(t6B, t1D);
        s8w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9D), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0E));
        s9w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9D), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0E));
        s0x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t1E), _mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t2E));
        s1x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.38268343236508978)), t1E), _mm_mul_pd(_mm_set1_pd((-0.92387953251128674)), t2E));
        t3E = _mm_add_pd(t9B, s0w);
        t4E = _mm_sub_pd(t0C, s1w);
        t5E = _mm_sub_pd(t9B, s0w);
        t6E = _mm_add_pd(t0C, s1w);
        s2x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3E), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4E));
        s3x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3E), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4E));
        s4x = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t5E), _mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t6E));
        s5x = _mm_add_pd(_mm_mul_pd(_mm_set1_pd((-0.83146961230254524)), t5E), _mm_mul_pd(_mm_set1_pd((-0.55557023301960218)), t6E));
        t7E = _mm_add_pd(t7q, t3z);
        t8E = _mm_add_pd(t8q, t4z);
        t9E = _mm_sub_pd(t7q, t3z);
        t0F = _mm_sub_pd(t8q, t4z);
        t1F = _mm_add_pd(t1v, t3D);
        t2F = _mm_add_pd(t2v, t4D);
        t3F = _mm_sub_pd(t1v, t3D);
        t4F = _mm_sub_pd(t2v, t4D);
        t5F = _mm_add_pd(t7E, t1F);
        t6F = _mm_add_pd(t8E, t2F);
        t7F = _mm_sub_pd(t7E, t1F);
        t8F = _mm_sub_pd(t8E, t2F);
        t9F = _mm_sub_pd(t9E, t4F);
        t0G = _mm_add_pd(t0F, t3F);
        t1G = _mm_add_pd(t9E, t4F);
        t2G = _mm_sub_pd(t0F, t3F);
        t3G = _mm_add_pd(t1r, s0t);
        t4G = _mm_add_pd(t2r, s1t);
        t5G = _mm_sub_pd(t1r, s0t);
        t6G = _mm_sub_pd(t2r, s1t);
        t7G = _mm_add_pd(s8p, s4w);
        t8G = _mm_add_pd(s9p, s5w);
        t9G = _mm_sub_pd(s8p, s4w);
        t0H = _mm_sub_pd(s9p, s5w);
        t1H = _mm_add_pd(t3G, t7G);
        t2H = _mm_add_pd(t4G, t8G);
        t3H = _mm_sub_pd(t3G, t7G);
        t4H = _mm_sub_pd(t4G, t8G);
        t5H = _mm_sub_pd(t5G, t0H);
        t6H = _mm_add_pd(t6G, t9G);
        t7H = _mm_add_pd(t5G, t0H);
        t8H = _mm_sub_pd(t6G, t9G);
        t9H = _mm_add_pd(t5r, s4t);
        t0I = _mm_add_pd(t6r, s5t);
        t1I = _mm_sub_pd(t5r, s4t);
        t2I = _mm_sub_pd(t6r, s5t);
        t3I = _mm_add_pd(s2q, s8w);
        t4I = _mm_add_pd(s3q, s9w);
        t5I = _mm_sub_pd(s2q, s8w);
        t6I = _mm_sub_pd(s3q, s9w);
        t7I = _mm_add_pd(t9H, t3I);
        t8I = _mm_add_pd(t0I, t4I);
        t9I = _mm_sub_pd(t9H, t3I);
        t0J = _mm_sub_pd(t0I, t4I);
        t1J = _mm_sub_pd(t1I, t6I);
        t2J = _mm_add_pd(t2I, t5I);
        t3J = _mm_add_pd(t1I, t6I);
        t4J = _mm_sub_pd(t2I, t5I);
        t5J = _mm_add_pd(t9r, s8t);
        t6J = _mm_add_pd(t0s, s9t);
        t7J = _mm_sub_pd(t9r, s8t);
        t8J = _mm_sub_pd(t0s, s9t);
        t9J = _mm_add_pd(s6q, s2x);
        t0K = _mm_add_pd(s7q, s3x);
        t1K = _mm_sub_pd(s6q, s2x);
        t2K = _mm_sub_pd(s7q, s3x);
        t3K = _mm_add_pd(t5J, t9J);
        t4K = _mm_add_pd(t6J, t0K);
        t5K = _mm_sub_pd(t5J, t9J);
        t6K = _mm_sub_pd(t6J, t0K);
        t7K = _mm_sub_pd(t7J, t2K);
        t8K = _mm_add_pd(t8J, t1K);
        t9K = _mm_add_pd(t7J, t2K);
        t0L = _mm_sub_pd(t8J, t1K);
        t1L = _mm_sub_pd(t9q, t6z);
        t2L = _mm_add_pd(t0r, t5z);
        t3L = _mm_add_pd(t9q, t6z);
        t4L = _mm_sub_pd(t0r, t5z);
        t5L = _mm_add_pd(s6p, s2w);
        t6L = _mm_sub_pd(s7p, s3w);
        t7L = _mm_sub_pd(s6p, s2w);
        t8L = _mm_add_pd(s7p, s3w);
        t9L = _mm_add_pd(t1L, t5L);
        t0M = _mm_add_pd(t2L, t6L);
        t1M = _mm_sub_pd(t1L, t5L);
        t2M = _mm_sub_pd(t2L, t6L);
        t3M = _mm_sub_pd(t3L, t8L);
        t4M = _mm_add_pd(t4L, t7L);
        t5M = _mm_add_pd(t3L, t8L);
        t6M = _mm_sub_pd(t4L, t7L);
        t7M = _mm_add_pd(t3r, s2t);
        t8M = _mm_add_pd(t4r, s3t);
        t9M = _mm_sub_pd(t3r, s2t);
        t0N = _mm_sub_pd(t4r, s3t);
        t1N = _mm_add_pd(s0q, s6w);
        t2N = _mm_add_pd(s1q, s7w);
        t3N = _mm_sub_pd(s0q, s6w);
        t4N = _mm_sub_pd(s1q, s7w);
        t5N = _mm_add_pd(t7M, t1N);
        t6N = _mm_add_pd(t8M, t2N);
        t7N = _mm_sub_pd(t7M, t1N);
        t8N = _mm_sub_pd(t8M, t2N);
        t9N = _mm_sub_pd(t9M, t4N);
        t0O = _mm_add_pd(t0N, t3N);
        t1O = _mm_add_pd(t9M, t4N);
        t2O = _mm_sub_pd(t0N, t3N);
        t3O = _mm_add_pd(t7r, s6t);
        t4O = _mm_sub_pd(t8r, s7t);
        t5O = _mm_sub_pd(t7r, s6t);
        t6O = _mm_add_pd(t8r, s7t);
        t7O = _mm_add_pd(s4q, s0x);
        t8O = _mm_add_pd(s5q, s1x);
        t9O = _mm_sub_pd(s4q, s0x);
        t0P = _mm_sub_pd(s5q, s1x);
        t1P = _mm_add_pd(t3O, t7O);
        t2P = _mm_add_pd(t4O, t8O);
        t3P = _mm_sub_pd(t3O, t7O);
        t4P = _mm_sub_pd(t4O, t8O);
        t5P = _mm_sub_pd(t5O, t0P);
        t6P = _mm_add_pd(t6O, t9O);
        t7P = _mm_add_pd(t5O, t0P);
        t8P = _mm_sub_pd(t6O, t9O);
        t9P = _mm_add_pd(t1s, s0u);
        t0Q = _mm_add_pd(t2s, s1u);
        t1Q = _mm_sub_pd(t1s, s0u);
        t2Q = _mm_sub_pd(t2s, s1u);
        t3Q = _mm_add_pd(s8q, s4x);
        t4Q = _mm_add_pd(s9q, s5x);
        t5Q = _mm_sub_pd(s8q, s4x);
        t6Q = _mm_sub_pd(s9q, s5x);
        t7Q = _mm_add_pd(t9P, t3Q);
        t8Q = _mm_add_pd(t0Q, t4Q);
        t9Q = _mm_sub_pd(t9P, t3Q);
        t0R = _mm_sub_pd(t0Q, t4Q);
        t1R = _mm_sub_pd(t1Q, t6Q);
        t2R = _mm_add_pd(t2Q, t5Q);
        t3R = _mm_add_pd(t1Q, t6Q);
        t4R = _mm_sub_pd(t2Q, t5Q);
        a65 = (64 * i2);
        a75 = (D77 + a65);
        a85 = *(a75);
        a95 = *((a75 + 1));
        a06 = *((a75 + 2));
        a16 = *((a75 + 3));
        a26 = *((a75 + 4));
        a36 = *((a75 + 5));
        a46 = *((a75 + 6));
        a56 = *((a75 + 7));
        a66 = *((a75 + 8));
        a76 = *((a75 + 9));
        a86 = *((a75 + 10));
        a96 = *((a75 + 11));
        a07 = *((a75 + 12));
        a17 = *((a75 + 13));
        a27 = *((a75 + 14));
        a37 = *((a75 + 15));
        a47 = *((a75 + 16));
        a57 = *((a75 + 17));
        a67 = *((a75 + 18));
        a77 = *((a75 + 19));
        a87 = *((a75 + 20));
        a97 = *((a75 + 21));
        a08 = *((a75 + 22));
        a18 = *((a75 + 23));
        a28 = *((a75 + 24));
        a38 = *((a75 + 25));
        a48 = *((a75 + 26));
        a58 = *((a75 + 27));
        a68 = *((a75 + 28));
        a78 = *((a75 + 29));
        a88 = *((a75 + 30));
        a98 = *((a75 + 31));
        a09 = *((a75 + 32));
        a19 = *((a75 + 33));
        a29 = *((a75 + 34));
        a39 = *((a75 + 35));
        a49 = *((a75 + 36));
        a59 = *((a75 + 37));
        a69 = *((a75 + 38));
        a79 = *((a75 + 39));
        a89 = *((a75 + 40));
        a99 = *((a75 + 41));
        a0a = *((a75 + 42));
        a1a = *((a75 + 43));
        a2a = *((a75 + 44));
        a3a = *((a75 + 45));
        a4a = *((a75 + 46));
        a5a = *((a75 + 47));
        a6a = *((a75 + 48));
        a7a = *((a75 + 49));
        a8a = *((a75 + 50));
        a9a = *((a75 + 51));
        a0b = *((a75 + 52));
        a1b = *((a75 + 53));
        a2b = *((a75 + 54));
        a3b = *((a75 + 55));
        a4b = *((a75 + 56));
        a5b = *((a75 + 57));
        a6b = *((a75 + 58));
        a7b = *((a75 + 59));
        a8b = *((a75 + 60));
        a9b = *((a75 + 61));
        a0c = *((a75 + 62));
        a1c = *((a75 + 63));
        b4 = (((__m128d  *) T2) + a65);
        s6x = _mm_sub_pd(_mm_mul_pd(a85, t5F), _mm_mul_pd(a95, t6F));
        *((b4 + 64)) = s6x;
        s7x = _mm_add_pd(_mm_mul_pd(a95, t5F), _mm_mul_pd(a85, t6F));
        *((b4 + 96)) = s7x;
        s8x = _mm_sub_pd(_mm_mul_pd(a06, t1H), _mm_mul_pd(a16, t2H));
        *((b4 + 65)) = s8x;
        s9x = _mm_add_pd(_mm_mul_pd(a16, t1H), _mm_mul_pd(a06, t2H));
        *((b4 + 97)) = s9x;
        s0y = _mm_sub_pd(_mm_mul_pd(a26, t7I), _mm_mul_pd(a36, t8I));
        *((b4 + 66)) = s0y;
        s1y = _mm_add_pd(_mm_mul_pd(a36, t7I), _mm_mul_pd(a26, t8I));
        *((b4 + 98)) = s1y;
        s2y = _mm_sub_pd(_mm_mul_pd(a46, t3K), _mm_mul_pd(a56, t4K));
        *((b4 + 67)) = s2y;
        s3y = _mm_add_pd(_mm_mul_pd(a56, t3K), _mm_mul_pd(a46, t4K));
        *((b4 + 99)) = s3y;
        s4y = _mm_sub_pd(_mm_mul_pd(a66, t9L), _mm_mul_pd(a76, t0M));
        *((b4 + 68)) = s4y;
        s5y = _mm_add_pd(_mm_mul_pd(a76, t9L), _mm_mul_pd(a66, t0M));
        *((b4 + 100)) = s5y;
        s6y = _mm_sub_pd(_mm_mul_pd(a86, t5N), _mm_mul_pd(a96, t6N));
        *((b4 + 69)) = s6y;
        s7y = _mm_add_pd(_mm_mul_pd(a96, t5N), _mm_mul_pd(a86, t6N));
        *((b4 + 101)) = s7y;
        s8y = _mm_sub_pd(_mm_mul_pd(a07, t1P), _mm_mul_pd(a17, t2P));
        *((b4 + 70)) = s8y;
        s9y = _mm_add_pd(_mm_mul_pd(a17, t1P), _mm_mul_pd(a07, t2P));
        *((b4 + 102)) = s9y;
        s0z = _mm_sub_pd(_mm_mul_pd(a27, t7Q), _mm_mul_pd(a37, t8Q));
        *((b4 + 71)) = s0z;
        s1z = _mm_add_pd(_mm_mul_pd(a37, t7Q), _mm_mul_pd(a27, t8Q));
        *((b4 + 103)) = s1z;
        s2z = _mm_sub_pd(_mm_mul_pd(a47, t9F), _mm_mul_pd(a57, t0G));
        *((b4 + 72)) = s2z;
        s3z = _mm_add_pd(_mm_mul_pd(a57, t9F), _mm_mul_pd(a47, t0G));
        *((b4 + 104)) = s3z;
        s4z = _mm_sub_pd(_mm_mul_pd(a67, t5H), _mm_mul_pd(a77, t6H));
        *((b4 + 73)) = s4z;
        s5z = _mm_add_pd(_mm_mul_pd(a77, t5H), _mm_mul_pd(a67, t6H));
        *((b4 + 105)) = s5z;
        s6z = _mm_sub_pd(_mm_mul_pd(a87, t1J), _mm_mul_pd(a97, t2J));
        *((b4 + 74)) = s6z;
        s7z = _mm_add_pd(_mm_mul_pd(a97, t1J), _mm_mul_pd(a87, t2J));
        *((b4 + 106)) = s7z;
        s8z = _mm_sub_pd(_mm_mul_pd(a08, t7K), _mm_mul_pd(a18, t8K));
        *((b4 + 75)) = s8z;
        s9z = _mm_add_pd(_mm_mul_pd(a18, t7K), _mm_mul_pd(a08, t8K));
        *((b4 + 107)) = s9z;
        s0A = _mm_sub_pd(_mm_mul_pd(a28, t3M), _mm_mul_pd(a38, t4M));
        *((b4 + 76)) = s0A;
        s1A = _mm_add_pd(_mm_mul_pd(a38, t3M), _mm_mul_pd(a28, t4M));
        *((b4 + 108)) = s1A;
        s2A = _mm_sub_pd(_mm_mul_pd(a48, t9N), _mm_mul_pd(a58, t0O));
        *((b4 + 77)) = s2A;
        s3A = _mm_add_pd(_mm_mul_pd(a58, t9N), _mm_mul_pd(a48, t0O));
        *((b4 + 109)) = s3A;
        s4A = _mm_sub_pd(_mm_mul_pd(a68, t5P), _mm_mul_pd(a78, t6P));
        *((b4 + 78)) = s4A;
        s5A = _mm_add_pd(_mm_mul_pd(a78, t5P), _mm_mul_pd(a68, t6P));
        *((b4 + 110)) = s5A;
        s6A = _mm_sub_pd(_mm_mul_pd(a88, t1R), _mm_mul_pd(a98, t2R));
        *((b4 + 79)) = s6A;
        s7A = _mm_add_pd(_mm_mul_pd(a98, t1R), _mm_mul_pd(a88, t2R));
        *((b4 + 111)) = s7A;
        s8A = _mm_sub_pd(_mm_mul_pd(a09, t7F), _mm_mul_pd(a19, t8F));
        *((b4 + 80)) = s8A;
        s9A = _mm_add_pd(_mm_mul_pd(a19, t7F), _mm_mul_pd(a09, t8F));
        *((b4 + 112)) = s9A;
        s0B = _mm_sub_pd(_mm_mul_pd(a29, t3H), _mm_mul_pd(a39, t4H));
        *((b4 + 81)) = s0B;
        s1B = _mm_add_pd(_mm_mul_pd(a39, t3H), _mm_mul_pd(a29, t4H));
        *((b4 + 113)) = s1B;
        s2B = _mm_sub_pd(_mm_mul_pd(a49, t9I), _mm_mul_pd(a59, t0J));
        *((b4 + 82)) = s2B;
        s3B = _mm_add_pd(_mm_mul_pd(a59, t9I), _mm_mul_pd(a49, t0J));
        *((b4 + 114)) = s3B;
        s4B = _mm_sub_pd(_mm_mul_pd(a69, t5K), _mm_mul_pd(a79, t6K));
        *((b4 + 83)) = s4B;
        s5B = _mm_add_pd(_mm_mul_pd(a79, t5K), _mm_mul_pd(a69, t6K));
        *((b4 + 115)) = s5B;
        s6B = _mm_sub_pd(_mm_mul_pd(a89, t1M), _mm_mul_pd(a99, t2M));
        *((b4 + 84)) = s6B;
        s7B = _mm_add_pd(_mm_mul_pd(a99, t1M), _mm_mul_pd(a89, t2M));
        *((b4 + 116)) = s7B;
        s8B = _mm_sub_pd(_mm_mul_pd(a0a, t7N), _mm_mul_pd(a1a, t8N));
        *((b4 + 85)) = s8B;
        s9B = _mm_add_pd(_mm_mul_pd(a1a, t7N), _mm_mul_pd(a0a, t8N));
        *((b4 + 117)) = s9B;
        s0C = _mm_sub_pd(_mm_mul_pd(a2a, t3P), _mm_mul_pd(a3a, t4P));
        *((b4 + 86)) = s0C;
        s1C = _mm_add_pd(_mm_mul_pd(a3a, t3P), _mm_mul_pd(a2a, t4P));
        *((b4 + 118)) = s1C;
        s2C = _mm_sub_pd(_mm_mul_pd(a4a, t9Q), _mm_mul_pd(a5a, t0R));
        *((b4 + 87)) = s2C;
        s3C = _mm_add_pd(_mm_mul_pd(a5a, t9Q), _mm_mul_pd(a4a, t0R));
        *((b4 + 119)) = s3C;
        s4C = _mm_sub_pd(_mm_mul_pd(a6a, t1G), _mm_mul_pd(a7a, t2G));
        *((b4 + 88)) = s4C;
        s5C = _mm_add_pd(_mm_mul_pd(a7a, t1G), _mm_mul_pd(a6a, t2G));
        *((b4 + 120)) = s5C;
        s6C = _mm_sub_pd(_mm_mul_pd(a8a, t7H), _mm_mul_pd(a9a, t8H));
        *((b4 + 89)) = s6C;
        s7C = _mm_add_pd(_mm_mul_pd(a9a, t7H), _mm_mul_pd(a8a, t8H));
        *((b4 + 121)) = s7C;
        s8C = _mm_sub_pd(_mm_mul_pd(a0b, t3J), _mm_mul_pd(a1b, t4J));
        *((b4 + 90)) = s8C;
        s9C = _mm_add_pd(_mm_mul_pd(a1b, t3J), _mm_mul_pd(a0b, t4J));
        *((b4 + 122)) = s9C;
        s0D = _mm_sub_pd(_mm_mul_pd(a2b, t9K), _mm_mul_pd(a3b, t0L));
        *((b4 + 91)) = s0D;
        s1D = _mm_add_pd(_mm_mul_pd(a3b, t9K), _mm_mul_pd(a2b, t0L));
        *((b4 + 123)) = s1D;
        s2D = _mm_sub_pd(_mm_mul_pd(a4b, t5M), _mm_mul_pd(a5b, t6M));
        *((b4 + 92)) = s2D;
        s3D = _mm_add_pd(_mm_mul_pd(a5b, t5M), _mm_mul_pd(a4b, t6M));
        *((b4 + 124)) = s3D;
        s4D = _mm_sub_pd(_mm_mul_pd(a6b, t1O), _mm_mul_pd(a7b, t2O));
        *((b4 + 93)) = s4D;
        s5D = _mm_add_pd(_mm_mul_pd(a7b, t1O), _mm_mul_pd(a6b, t2O));
        *((b4 + 125)) = s5D;
        s6D = _mm_sub_pd(_mm_mul_pd(a8b, t7P), _mm_mul_pd(a9b, t8P));
        *((b4 + 94)) = s6D;
        s7D = _mm_add_pd(_mm_mul_pd(a9b, t7P), _mm_mul_pd(a8b, t8P));
        *((b4 + 126)) = s7D;
        s8D = _mm_sub_pd(_mm_mul_pd(a0c, t3R), _mm_mul_pd(a1c, t4R));
        *((b4 + 95)) = s8D;
        s9D = _mm_add_pd(_mm_mul_pd(a1c, t3R), _mm_mul_pd(a0c, t4R));
        *((b4 + 127)) = s9D;
    }}
    {long i3; for(i3 = 0; i3 <= 31; i3++) {
        a2c = (((__m128d  *) T2) + i3);
        s0E = *(a2c);
        s1E = *((a2c + 1024));
        t5R = _mm_add_pd(s0E, s1E);
        t6R = _mm_sub_pd(s0E, s1E);
        s2E = *((a2c + 32));
        s3E = *((a2c + 1056));
        t7R = _mm_sub_pd(s2E, s3E);
        t8R = _mm_add_pd(s2E, s3E);
        s4E = *((a2c + 512));
        s5E = *((a2c + 544));
        s6E = *((a2c + 1536));
        s7E = *((a2c + 1568));
        t9R = _mm_add_pd(s4E, s6E);
        t0S = _mm_sub_pd(s5E, s7E);
        a3c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4E, s6E));
        a4c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5E, s7E));
        s8E = _mm_sub_pd(a3c, a4c);
        s9E = _mm_add_pd(a3c, a4c);
        t1S = _mm_add_pd(t5R, t9R);
        t2S = _mm_sub_pd(t5R, t9R);
        t3S = _mm_sub_pd(t6R, t0S);
        t4S = _mm_add_pd(t6R, t0S);
        t5S = _mm_add_pd(t7R, s8E);
        t6S = _mm_sub_pd(t7R, s8E);
        t7S = _mm_sub_pd(t8R, s9E);
        t8S = _mm_add_pd(t8R, s9E);
        s0F = *((a2c + 64));
        s1F = *((a2c + 96));
        s2F = *((a2c + 1984));
        s3F = *((a2c + 2016));
        t9S = _mm_add_pd(s0F, s2F);
        t0T = _mm_sub_pd(s1F, s3F);
        t1T = _mm_sub_pd(s0F, s2F);
        t2T = _mm_add_pd(s1F, s3F);
        s4F = *((a2c + 1088));
        s5F = *((a2c + 1120));
        s6F = *((a2c + 960));
        s7F = *((a2c + 992));
        t3T = _mm_add_pd(s4F, s6F);
        t4T = _mm_sub_pd(s5F, s7F);
        t5T = _mm_sub_pd(s4F, s6F);
        t6T = _mm_add_pd(s5F, s7F);
        t7T = _mm_add_pd(t9S, t3T);
        t8T = _mm_add_pd(t0T, t4T);
        t9T = _mm_sub_pd(t9S, t3T);
        t0U = _mm_sub_pd(t0T, t4T);
        t1U = _mm_sub_pd(t1T, t6T);
        t2U = _mm_add_pd(t2T, t5T);
        t3U = _mm_add_pd(t1T, t6T);
        t4U = _mm_sub_pd(t2T, t5T);
        s8F = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t1U), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t2U));
        s9F = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t1U), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t2U));
        s0G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9T), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0U));
        s1G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9T), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0U));
        s2G = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3U), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4U));
        s3G = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3U), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4U));
        s4G = *((a2c + 128));
        s5G = *((a2c + 160));
        s6G = *((a2c + 1920));
        s7G = *((a2c + 1952));
        t5U = _mm_add_pd(s4G, s6G);
        t6U = _mm_sub_pd(s5G, s7G);
        t7U = _mm_sub_pd(s4G, s6G);
        t8U = _mm_add_pd(s5G, s7G);
        s8G = *((a2c + 1152));
        s9G = *((a2c + 1184));
        s0H = *((a2c + 896));
        s1H = *((a2c + 928));
        t9U = _mm_add_pd(s8G, s0H);
        t0V = _mm_sub_pd(s9G, s1H);
        t1V = _mm_sub_pd(s8G, s0H);
        t2V = _mm_add_pd(s9G, s1H);
        t3V = _mm_add_pd(t5U, t9U);
        t4V = _mm_add_pd(t6U, t0V);
        t5V = _mm_sub_pd(t5U, t9U);
        t6V = _mm_sub_pd(t6U, t0V);
        t7V = _mm_sub_pd(t7U, t2V);
        t8V = _mm_add_pd(t8U, t1V);
        t9V = _mm_add_pd(t7U, t2V);
        t0W = _mm_sub_pd(t8U, t1V);
        s2H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t7V), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t8V));
        s3H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t7V), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t8V));
        s4H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5V), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6V));
        s5H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5V), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6V));
        s6H = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t9V), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t0W));
        s7H = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t9V), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t0W));
        s8H = *((a2c + 192));
        s9H = *((a2c + 224));
        s0I = *((a2c + 1856));
        s1I = *((a2c + 1888));
        t1W = _mm_add_pd(s8H, s0I);
        t2W = _mm_sub_pd(s9H, s1I);
        t3W = _mm_sub_pd(s8H, s0I);
        t4W = _mm_add_pd(s9H, s1I);
        s2I = *((a2c + 1216));
        s3I = *((a2c + 1248));
        s4I = *((a2c + 832));
        s5I = *((a2c + 864));
        t5W = _mm_add_pd(s2I, s4I);
        t6W = _mm_sub_pd(s3I, s5I);
        t7W = _mm_sub_pd(s2I, s4I);
        t8W = _mm_add_pd(s3I, s5I);
        t9W = _mm_add_pd(t1W, t5W);
        t0X = _mm_add_pd(t2W, t6W);
        t1X = _mm_sub_pd(t1W, t5W);
        t2X = _mm_sub_pd(t2W, t6W);
        t3X = _mm_sub_pd(t3W, t8W);
        t4X = _mm_add_pd(t4W, t7W);
        t5X = _mm_add_pd(t3W, t8W);
        t6X = _mm_sub_pd(t4W, t7W);
        s6I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t3X), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t4X));
        s7I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t3X), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t4X));
        s8I = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1X), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2X));
        s9I = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1X), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2X));
        s0J = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t5X), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t6X));
        s1J = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t5X), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t6X));
        s2J = *((a2c + 256));
        s3J = *((a2c + 288));
        s4J = *((a2c + 1792));
        s5J = *((a2c + 1824));
        t7X = _mm_add_pd(s2J, s4J);
        t8X = _mm_sub_pd(s3J, s5J);
        t9X = _mm_sub_pd(s2J, s4J);
        t0Y = _mm_add_pd(s3J, s5J);
        s6J = *((a2c + 1280));
        s7J = *((a2c + 1312));
        s8J = *((a2c + 768));
        s9J = *((a2c + 800));
        t1Y = _mm_add_pd(s6J, s8J);
        t2Y = _mm_sub_pd(s7J, s9J);
        t3Y = _mm_sub_pd(s6J, s8J);
        t4Y = _mm_add_pd(s7J, s9J);
        t5Y = _mm_add_pd(t7X, t1Y);
        t6Y = _mm_add_pd(t8X, t2Y);
        t7Y = _mm_sub_pd(t9X, t4Y);
        t8Y = _mm_add_pd(t0Y, t3Y);
        t9Y = _mm_add_pd(t9X, t4Y);
        t0Z = _mm_sub_pd(t0Y, t3Y);
        s0K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7Y), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8Y));
        s1K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7Y), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8Y));
        a5c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t7X, t1Y));
        a6c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t8X, t2Y));
        s2K = _mm_sub_pd(a5c, a6c);
        s3K = _mm_add_pd(a5c, a6c);
        s4K = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9Y), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0Z));
        s5K = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9Y), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0Z));
        s6K = *((a2c + 320));
        s7K = *((a2c + 352));
        s8K = *((a2c + 1728));
        s9K = *((a2c + 1760));
        t1Z = _mm_add_pd(s6K, s8K);
        t2Z = _mm_sub_pd(s7K, s9K);
        t3Z = _mm_sub_pd(s6K, s8K);
        t4Z = _mm_add_pd(s7K, s9K);
        s0L = *((a2c + 1344));
        s1L = *((a2c + 1376));
        s2L = *((a2c + 704));
        s3L = *((a2c + 736));
        t5Z = _mm_add_pd(s0L, s2L);
        t6Z = _mm_sub_pd(s1L, s3L);
        t7Z = _mm_sub_pd(s0L, s2L);
        t8Z = _mm_add_pd(s1L, s3L);
        t9Z = _mm_add_pd(t1Z, t5Z);
        t010 = _mm_add_pd(t2Z, t6Z);
        t110 = _mm_sub_pd(t1Z, t5Z);
        t210 = _mm_sub_pd(t2Z, t6Z);
        t310 = _mm_sub_pd(t3Z, t8Z);
        t410 = _mm_add_pd(t4Z, t7Z);
        t510 = _mm_add_pd(t3Z, t8Z);
        t610 = _mm_sub_pd(t4Z, t7Z);
        s4L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t310), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t410));
        s5L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t310), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t410));
        s6L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t110), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t210));
        s7L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t110), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t210));
        s8L = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t510), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t610));
        s9L = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t510), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t610));
        s0M = *((a2c + 384));
        s1M = *((a2c + 416));
        s2M = *((a2c + 1664));
        s3M = *((a2c + 1696));
        t710 = _mm_add_pd(s0M, s2M);
        t810 = _mm_sub_pd(s1M, s3M);
        t910 = _mm_sub_pd(s0M, s2M);
        t011 = _mm_add_pd(s1M, s3M);
        s4M = *((a2c + 1408));
        s5M = *((a2c + 1440));
        s6M = *((a2c + 640));
        s7M = *((a2c + 672));
        t111 = _mm_add_pd(s4M, s6M);
        t211 = _mm_sub_pd(s5M, s7M);
        t311 = _mm_sub_pd(s4M, s6M);
        t411 = _mm_add_pd(s5M, s7M);
        t511 = _mm_add_pd(t710, t111);
        t611 = _mm_add_pd(t810, t211);
        t711 = _mm_sub_pd(t710, t111);
        t811 = _mm_sub_pd(t810, t211);
        t911 = _mm_sub_pd(t910, t411);
        t012 = _mm_add_pd(t011, t311);
        t112 = _mm_add_pd(t910, t411);
        t212 = _mm_sub_pd(t011, t311);
        s8M = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t911), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t012));
        s9M = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t911), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t012));
        s0N = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t711), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t811));
        s1N = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t711), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t811));
        s2N = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t112), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t212));
        s3N = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t112), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t212));
        s4N = *((a2c + 448));
        s5N = *((a2c + 480));
        s6N = *((a2c + 1600));
        s7N = *((a2c + 1632));
        t312 = _mm_add_pd(s4N, s6N);
        t412 = _mm_sub_pd(s5N, s7N);
        t512 = _mm_sub_pd(s4N, s6N);
        t612 = _mm_add_pd(s5N, s7N);
        s8N = *((a2c + 1472));
        s9N = *((a2c + 1504));
        s0O = *((a2c + 576));
        s1O = *((a2c + 608));
        t712 = _mm_add_pd(s8N, s0O);
        t812 = _mm_sub_pd(s9N, s1O);
        t912 = _mm_sub_pd(s8N, s0O);
        t013 = _mm_add_pd(s9N, s1O);
        t113 = _mm_add_pd(t312, t712);
        t213 = _mm_add_pd(t412, t812);
        t313 = _mm_sub_pd(t312, t712);
        t413 = _mm_sub_pd(t412, t812);
        t513 = _mm_sub_pd(t512, t013);
        t613 = _mm_add_pd(t612, t912);
        t713 = _mm_add_pd(t512, t013);
        t813 = _mm_sub_pd(t612, t912);
        s2O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t513), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t613));
        s3O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t513), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t613));
        s4O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t313), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t413));
        s5O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t313), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t413));
        s6O = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t713), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t813));
        s7O = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t713), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t813));
        t913 = _mm_add_pd(t1S, t5Y);
        t014 = _mm_sub_pd(t1S, t5Y);
        t114 = _mm_sub_pd(t2S, t6Y);
        t214 = _mm_add_pd(t2S, t6Y);
        t314 = _mm_add_pd(t3V, t511);
        t414 = _mm_sub_pd(t4V, t611);
        a7c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3V, t511));
        a8c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t4V, t611));
        s8O = _mm_sub_pd(a7c, a8c);
        s9O = _mm_add_pd(a7c, a8c);
        t514 = _mm_add_pd(t913, t314);
        t614 = _mm_sub_pd(t913, t314);
        t714 = _mm_sub_pd(t014, t414);
        t814 = _mm_add_pd(t014, t414);
        t914 = _mm_add_pd(t114, s8O);
        t015 = _mm_sub_pd(t114, s8O);
        t115 = _mm_sub_pd(t214, s9O);
        t215 = _mm_add_pd(t214, s9O);
        t315 = _mm_add_pd(t7T, t113);
        t415 = _mm_sub_pd(t8T, t213);
        t515 = _mm_sub_pd(t7T, t113);
        t615 = _mm_add_pd(t8T, t213);
        t715 = _mm_add_pd(t9Z, t9W);
        t815 = _mm_sub_pd(t010, t0X);
        t915 = _mm_sub_pd(t9Z, t9W);
        t016 = _mm_add_pd(t010, t0X);
        t116 = _mm_add_pd(t315, t715);
        t216 = _mm_add_pd(t415, t815);
        t316 = _mm_sub_pd(t515, t016);
        t416 = _mm_add_pd(t615, t915);
        t516 = _mm_add_pd(t515, t016);
        t616 = _mm_sub_pd(t615, t915);
        s0P = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t316), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t416));
        s1P = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t316), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t416));
        a9c = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t315, t715));
        a0d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t415, t815));
        s2P = _mm_sub_pd(a9c, a0d);
        s3P = _mm_add_pd(a9c, a0d);
        s4P = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t516), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t616));
        s5P = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t516), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t616));
        a1d = (((__m128d  *) dst) + i3);
        s6P = _mm_add_pd(t514, t116);
        *(a1d) = s6P;
        s7P = _mm_sub_pd(t514, t116);
        *((a1d + 1024)) = s7P;
        s8P = _mm_sub_pd(t614, t216);
        *((a1d + 512)) = s8P;
        s9P = _mm_add_pd(t614, t216);
        *((a1d + 1536)) = s9P;
        s0Q = _mm_add_pd(t914, s0P);
        *((a1d + 128)) = s0Q;
        s1Q = _mm_sub_pd(t914, s0P);
        *((a1d + 1152)) = s1Q;
        s2Q = _mm_sub_pd(t015, s1P);
        *((a1d + 640)) = s2Q;
        s3Q = _mm_add_pd(t015, s1P);
        *((a1d + 1664)) = s3Q;
        s4Q = _mm_add_pd(t714, s2P);
        *((a1d + 256)) = s4Q;
        s5Q = _mm_sub_pd(t714, s2P);
        *((a1d + 1280)) = s5Q;
        s6Q = _mm_sub_pd(t814, s3P);
        *((a1d + 768)) = s6Q;
        s7Q = _mm_add_pd(t814, s3P);
        *((a1d + 1792)) = s7Q;
        s8Q = _mm_add_pd(t115, s4P);
        *((a1d + 384)) = s8Q;
        s9Q = _mm_sub_pd(t115, s4P);
        *((a1d + 1408)) = s9Q;
        s0R = _mm_sub_pd(t215, s5P);
        *((a1d + 896)) = s0R;
        s1R = _mm_add_pd(t215, s5P);
        *((a1d + 1920)) = s1R;
        t716 = _mm_add_pd(t5S, s0K);
        t816 = _mm_sub_pd(t5S, s0K);
        t916 = _mm_sub_pd(t6S, s1K);
        t017 = _mm_add_pd(t6S, s1K);
        t117 = _mm_add_pd(s2H, s8M);
        t217 = _mm_sub_pd(s3H, s9M);
        a2d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2H, s8M));
        a3d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3H, s9M));
        s2R = _mm_sub_pd(a2d, a3d);
        s3R = _mm_add_pd(a2d, a3d);
        t317 = _mm_add_pd(t716, t117);
        t417 = _mm_sub_pd(t716, t117);
        t517 = _mm_sub_pd(t816, t217);
        t617 = _mm_add_pd(t816, t217);
        t717 = _mm_add_pd(t916, s2R);
        t817 = _mm_sub_pd(t916, s2R);
        t917 = _mm_sub_pd(t017, s3R);
        t018 = _mm_add_pd(t017, s3R);
        t118 = _mm_add_pd(s8F, s2O);
        t218 = _mm_sub_pd(s9F, s3O);
        t318 = _mm_sub_pd(s8F, s2O);
        t418 = _mm_add_pd(s9F, s3O);
        t518 = _mm_add_pd(s4L, s6I);
        t618 = _mm_sub_pd(s5L, s7I);
        t718 = _mm_sub_pd(s4L, s6I);
        t818 = _mm_add_pd(s5L, s7I);
        t918 = _mm_add_pd(t118, t518);
        t019 = _mm_add_pd(t218, t618);
        t119 = _mm_sub_pd(t318, t818);
        t219 = _mm_add_pd(t418, t718);
        t319 = _mm_add_pd(t318, t818);
        t419 = _mm_sub_pd(t418, t718);
        s4R = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t119), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t219));
        s5R = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t119), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t219));
        a4d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t118, t518));
        a5d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t218, t618));
        s6R = _mm_sub_pd(a4d, a5d);
        s7R = _mm_add_pd(a4d, a5d);
        s8R = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t319), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t419));
        s9R = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t319), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t419));
        s0S = _mm_add_pd(t317, t918);
        *((a1d + 32)) = s0S;
        s1S = _mm_sub_pd(t317, t918);
        *((a1d + 1056)) = s1S;
        s2S = _mm_sub_pd(t417, t019);
        *((a1d + 544)) = s2S;
        s3S = _mm_add_pd(t417, t019);
        *((a1d + 1568)) = s3S;
        s4S = _mm_add_pd(t717, s4R);
        *((a1d + 160)) = s4S;
        s5S = _mm_sub_pd(t717, s4R);
        *((a1d + 1184)) = s5S;
        s6S = _mm_sub_pd(t817, s5R);
        *((a1d + 672)) = s6S;
        s7S = _mm_add_pd(t817, s5R);
        *((a1d + 1696)) = s7S;
        s8S = _mm_add_pd(t517, s6R);
        *((a1d + 288)) = s8S;
        s9S = _mm_sub_pd(t517, s6R);
        *((a1d + 1312)) = s9S;
        s0T = _mm_sub_pd(t617, s7R);
        *((a1d + 800)) = s0T;
        s1T = _mm_add_pd(t617, s7R);
        *((a1d + 1824)) = s1T;
        s2T = _mm_add_pd(t917, s8R);
        *((a1d + 416)) = s2T;
        s3T = _mm_sub_pd(t917, s8R);
        *((a1d + 1440)) = s3T;
        s4T = _mm_sub_pd(t018, s9R);
        *((a1d + 928)) = s4T;
        s5T = _mm_add_pd(t018, s9R);
        *((a1d + 1952)) = s5T;
        t519 = _mm_add_pd(t3S, s2K);
        t619 = _mm_sub_pd(t3S, s2K);
        t719 = _mm_sub_pd(t4S, s3K);
        t819 = _mm_add_pd(t4S, s3K);
        t919 = _mm_add_pd(s4H, s0N);
        t01a = _mm_sub_pd(s5H, s1N);
        a6d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s4H, s0N));
        a7d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s5H, s1N));
        s6T = _mm_sub_pd(a6d, a7d);
        s7T = _mm_add_pd(a6d, a7d);
        t11a = _mm_add_pd(t519, t919);
        t21a = _mm_sub_pd(t519, t919);
        t31a = _mm_sub_pd(t619, t01a);
        t41a = _mm_add_pd(t619, t01a);
        t51a = _mm_add_pd(t719, s6T);
        t61a = _mm_sub_pd(t719, s6T);
        t71a = _mm_sub_pd(t819, s7T);
        t81a = _mm_add_pd(t819, s7T);
        t91a = _mm_add_pd(s0G, s4O);
        t01b = _mm_sub_pd(s1G, s5O);
        t11b = _mm_sub_pd(s0G, s4O);
        t21b = _mm_add_pd(s1G, s5O);
        t31b = _mm_add_pd(s6L, s8I);
        t41b = _mm_sub_pd(s7L, s9I);
        t51b = _mm_sub_pd(s6L, s8I);
        t61b = _mm_add_pd(s7L, s9I);
        t71b = _mm_add_pd(t91a, t31b);
        t81b = _mm_add_pd(t01b, t41b);
        t91b = _mm_sub_pd(t11b, t61b);
        t01c = _mm_add_pd(t21b, t51b);
        t11c = _mm_add_pd(t11b, t61b);
        t21c = _mm_sub_pd(t21b, t51b);
        s8T = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t91b), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t01c));
        s9T = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t91b), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t01c));
        a8d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t91a, t31b));
        a9d = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t01b, t41b));
        s0U = _mm_sub_pd(a8d, a9d);
        s1U = _mm_add_pd(a8d, a9d);
        s2U = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t11c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t21c));
        s3U = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t11c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t21c));
        s4U = _mm_add_pd(t11a, t71b);
        *((a1d + 64)) = s4U;
        s5U = _mm_sub_pd(t11a, t71b);
        *((a1d + 1088)) = s5U;
        s6U = _mm_sub_pd(t21a, t81b);
        *((a1d + 576)) = s6U;
        s7U = _mm_add_pd(t21a, t81b);
        *((a1d + 1600)) = s7U;
        s8U = _mm_add_pd(t51a, s8T);
        *((a1d + 192)) = s8U;
        s9U = _mm_sub_pd(t51a, s8T);
        *((a1d + 1216)) = s9U;
        s0V = _mm_sub_pd(t61a, s9T);
        *((a1d + 704)) = s0V;
        s1V = _mm_add_pd(t61a, s9T);
        *((a1d + 1728)) = s1V;
        s2V = _mm_add_pd(t31a, s0U);
        *((a1d + 320)) = s2V;
        s3V = _mm_sub_pd(t31a, s0U);
        *((a1d + 1344)) = s3V;
        s4V = _mm_sub_pd(t41a, s1U);
        *((a1d + 832)) = s4V;
        s5V = _mm_add_pd(t41a, s1U);
        *((a1d + 1856)) = s5V;
        s6V = _mm_add_pd(t71a, s2U);
        *((a1d + 448)) = s6V;
        s7V = _mm_sub_pd(t71a, s2U);
        *((a1d + 1472)) = s7V;
        s8V = _mm_sub_pd(t81a, s3U);
        *((a1d + 960)) = s8V;
        s9V = _mm_add_pd(t81a, s3U);
        *((a1d + 1984)) = s9V;
        t31c = _mm_add_pd(t7S, s4K);
        t41c = _mm_sub_pd(t7S, s4K);
        t51c = _mm_sub_pd(t8S, s5K);
        t61c = _mm_add_pd(t8S, s5K);
        t71c = _mm_add_pd(s6H, s2N);
        t81c = _mm_sub_pd(s7H, s3N);
        a0e = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6H, s2N));
        a1e = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7H, s3N));
        s0W = _mm_sub_pd(a0e, a1e);
        s1W = _mm_add_pd(a0e, a1e);
        t91c = _mm_add_pd(t31c, t71c);
        t01d = _mm_sub_pd(t31c, t71c);
        t11d = _mm_sub_pd(t41c, t81c);
        t21d = _mm_add_pd(t41c, t81c);
        t31d = _mm_add_pd(t51c, s0W);
        t41d = _mm_sub_pd(t51c, s0W);
        t51d = _mm_sub_pd(t61c, s1W);
        t61d = _mm_add_pd(t61c, s1W);
        t71d = _mm_add_pd(s2G, s6O);
        t81d = _mm_sub_pd(s3G, s7O);
        t91d = _mm_sub_pd(s2G, s6O);
        t01e = _mm_add_pd(s3G, s7O);
        t11e = _mm_add_pd(s8L, s0J);
        t21e = _mm_sub_pd(s9L, s1J);
        t31e = _mm_sub_pd(s8L, s0J);
        t41e = _mm_add_pd(s9L, s1J);
        t51e = _mm_add_pd(t71d, t11e);
        t61e = _mm_add_pd(t81d, t21e);
        t71e = _mm_sub_pd(t91d, t41e);
        t81e = _mm_add_pd(t01e, t31e);
        t91e = _mm_add_pd(t91d, t41e);
        t01f = _mm_sub_pd(t01e, t31e);
        s2W = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t71e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t81e));
        s3W = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t71e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t81e));
        a2e = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t71d, t11e));
        a3e = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t81d, t21e));
        s4W = _mm_sub_pd(a2e, a3e);
        s5W = _mm_add_pd(a2e, a3e);
        s6W = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t91e), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t01f));
        s7W = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t91e), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t01f));
        s8W = _mm_add_pd(t91c, t51e);
        *((a1d + 96)) = s8W;
        s9W = _mm_sub_pd(t91c, t51e);
        *((a1d + 1120)) = s9W;
        s0X = _mm_sub_pd(t01d, t61e);
        *((a1d + 608)) = s0X;
        s1X = _mm_add_pd(t01d, t61e);
        *((a1d + 1632)) = s1X;
        s2X = _mm_add_pd(t31d, s2W);
        *((a1d + 224)) = s2X;
        s3X = _mm_sub_pd(t31d, s2W);
        *((a1d + 1248)) = s3X;
        s4X = _mm_sub_pd(t41d, s3W);
        *((a1d + 736)) = s4X;
        s5X = _mm_add_pd(t41d, s3W);
        *((a1d + 1760)) = s5X;
        s6X = _mm_add_pd(t11d, s4W);
        *((a1d + 352)) = s6X;
        s7X = _mm_sub_pd(t11d, s4W);
        *((a1d + 1376)) = s7X;
        s8X = _mm_sub_pd(t21d, s5W);
        *((a1d + 864)) = s8X;
        s9X = _mm_add_pd(t21d, s5W);
        *((a1d + 1888)) = s9X;
        s0Y = _mm_add_pd(t51d, s6W);
        *((a1d + 480)) = s0Y;
        s1Y = _mm_sub_pd(t51d, s6W);
        *((a1d + 1504)) = s1Y;
        s2Y = _mm_sub_pd(t61d, s7W);
        *((a1d + 992)) = s2Y;
        s3Y = _mm_add_pd(t61d, s7W);
        *((a1d + 2016)) = s3Y;
    }}
    }
    
    return SPIRAL_OK;
    }
}

SPIRAL_PRIV(spiral_status_t, spiral_rfftinv_double_8192_unaligned)(const double *pSrc, double *pDst ) {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[8192]);
     SPIRAL_ALIGNED(double T2[1024]);
    __m128d a, a01, a02, a03, a04, a05, a06, a07, a08, a09, a11, a12, a13, a14, a16, a17, a18, a19, a2, a21, a22, a23
            , a24, a26, a27, a28, a29, a3, a31, a32, a33, a34, a35, a36, a37, a39, a4, a41, a42, a43, a44, a45, a46, a48
            , a49, a51, a52, a53, a54, a55, a56, a57, a58, a59, a61, a62, a63, a65, a66, a67, a68, a71, a72, a73, a74, a76
            , a77, a78, a81, a82, a83, a84, a85, a86, a87, a88, a9, a91, a93, a94, a95, a96, a97, a98, s, s01, s02, s03
            , s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j
            , s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16
            , s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m
            , s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2A, s2B, s2C, s2D, s2E, s2F, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A
            , s3B, s3C, s3D, s3E, s3F, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q
            , s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C
            , s4D, s4E, s4F, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s
            , s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E
            , s5F, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u
            , s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6a
            , s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w
            , s6x, s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7a, s7b, s7c
            , s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y
            , s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8a, s8b, s8c, s8d, s8e, s8f
            , s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91
            , s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i
            , s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04
            , t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k
            , t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17
            , t18, t19, t1A, t1B, t1C, t1D, t1E, t1F, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n
            , t1o, t1p, t1q, t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29
            , t2A, t2B, t2C, t2D, t2E, t2F, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p
            , t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3A, t3B
            , t3C, t3D, t3E, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s
            , t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E
            , t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v
            , t4w, t4x, t4y, t4z, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y
            , t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6a, t6b, t6c, t6d, t6e, t6f
            , t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71
            , t72, t73, t74, t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i
            , t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l
            , t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97
            , t98, t99, t9A, t9B, t9C, t9D, t9E, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o
            , t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a15, *a47, *a5, *a64, *a75, *a8, *a92, *b3, *b4, *b5, *b6, *b7;
    double  *a38;
    const double  *b, *b2;
    int a25, a6, a7;
    s = _mm_loadu_pd(((const double  *) src));
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), _mm_loadu_pd(((const double  *) (src + 4096))));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = _mm_loadu_pd(((const double  *) (src + 512)));
    s5 = v_neg23(_mm_loadu_pd(((const double  *) (src + 7680))));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = _mm_loadu_pd(((const double  *) (src + 1024)));
    s11 = v_neg23(_mm_loadu_pd(((const double  *) (src + 7168))));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = _mm_loadu_pd(((const double  *) (src + 1536)));
    s71 = v_neg23(_mm_loadu_pd(((const double  *) (src + 6656))));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = _mm_loadu_pd(((const double  *) (src + 2048)));
    s32 = v_neg23(_mm_loadu_pd(((const double  *) (src + 6144))));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = _mm_loadu_pd(((const double  *) (src + 2560)));
    s92 = v_neg23(_mm_loadu_pd(((const double  *) (src + 5632))));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = _mm_loadu_pd(((const double  *) (src + 3072)));
    s53 = v_neg23(_mm_loadu_pd(((const double  *) (src + 5120))));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = _mm_loadu_pd(((const double  *) (src + 3584)));
    s14 = v_neg23(_mm_loadu_pd(((const double  *) (src + 4608))));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a, a2);
    s74 = _mm_add_pd(a, a2);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a3, a4);
    s15 = _mm_add_pd(a3, a4);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a5 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a5) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a5 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a5 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a5 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a5 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a5 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a5 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a5 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a5 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a5 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a5 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a5 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a5 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a5 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a5 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a5 + 15)) = s96;
    {long i; for(i = 0; i <= 254; i++) {
        a6 = (2 * i);
        b = (src + a6);
        s07 = _mm_loadu_pd(((const double  *) (b + 2)));
        b2 = (src - a6);
        s17 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 8190))));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a7 = (16 * i);
        a8 = (D80 + a7);
        a9 = *(a8);
        a01 = *((a8 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a9, s27), _mm_mul_pd(a01, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a9, s37), _mm_mul_pd(a01, s27));
        s67 = _mm_loadu_pd(((const double  *) (b + 1026)));
        s77 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 7166))));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a11 = *((a8 + 2));
        a21 = *((a8 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a11, s87), _mm_mul_pd(a21, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a11, s97), _mm_mul_pd(a21, s87));
        s28 = _mm_loadu_pd(((const double  *) (b + 2050)));
        s38 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 6142))));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a31 = *((a8 + 4));
        a41 = *((a8 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a31, s48), _mm_mul_pd(a41, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a31, s58), _mm_mul_pd(a41, s48));
        s88 = _mm_loadu_pd(((const double  *) (b + 3074)));
        s98 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 5118))));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a51 = *((a8 + 6));
        a61 = *((a8 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a51, s09), _mm_mul_pd(a61, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a51, s19), _mm_mul_pd(a61, s09));
        s49 = _mm_loadu_pd(((const double  *) (b + 4098)));
        s59 = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 4094))));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a71 = *((a8 + 8));
        a81 = *((a8 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a71, s69), _mm_mul_pd(a81, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a71, s79), _mm_mul_pd(a81, s69));
        s0a = _mm_loadu_pd(((const double  *) (b + 5122)));
        s1a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 3070))));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a91 = *((a8 + 10));
        a02 = *((a8 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a91, s2a), _mm_mul_pd(a02, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a91, s3a), _mm_mul_pd(a02, s2a));
        s6a = _mm_loadu_pd(((const double  *) (b + 6146)));
        s7a = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 2046))));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a12 = *((a8 + 12));
        a22 = *((a8 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a12, s8a), _mm_mul_pd(a22, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a12, s9a), _mm_mul_pd(a22, s8a));
        s2b = _mm_loadu_pd(((const double  *) (b + 7170)));
        s3b = v_neg23(_mm_loadu_pd(((const double  *) (b2 + 1022))));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a32 = *((a8 + 14));
        a42 = *((a8 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a32, s4b), _mm_mul_pd(a42, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a32, s5b), _mm_mul_pd(a42, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a52 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a52, a62);
        s9b = _mm_add_pd(a52, a62);
        a72 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a82 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a72, a82);
        s1c = _mm_add_pd(a72, a82);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a92 = (D79 + a7);
        a03 = *(a92);
        a13 = *((a92 + 1));
        a23 = *((a92 + 2));
        a33 = *((a92 + 3));
        a43 = *((a92 + 4));
        a53 = *((a92 + 5));
        a63 = *((a92 + 6));
        a73 = *((a92 + 7));
        a83 = *((a92 + 8));
        a93 = *((a92 + 9));
        a04 = *((a92 + 10));
        a14 = *((a92 + 11));
        a24 = *((a92 + 12));
        a34 = *((a92 + 13));
        a44 = *((a92 + 14));
        a54 = *((a92 + 15));
        b3 = (((__m128d  *) T) + a7);
        s2c = _mm_sub_pd(_mm_mul_pd(a03, t98), _mm_mul_pd(a13, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a03, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a23, t39), _mm_mul_pd(a33, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a23, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a43, t79), _mm_mul_pd(a53, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a43, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a63, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a63, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a83, t19), _mm_mul_pd(a93, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a83, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a04, t59), _mm_mul_pd(a14, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a04, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a24, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a24, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a44, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a44, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a64 = (((__m128d  *) T) + i2);
        s8d = *(a64);
        s9d = *((a64 + 2048));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a64 + 8));
        s1e = *((a64 + 2056));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a64 + 1024));
        s3e = *((a64 + 1032));
        s4e = *((a64 + 3072));
        s5e = *((a64 + 3080));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a74 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a74, a84);
        s7e = _mm_add_pd(a74, a84);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a64 + 512));
        s9e = *((a64 + 520));
        s0f = *((a64 + 3584));
        s1f = *((a64 + 3592));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a64 + 2560));
        s3f = *((a64 + 2568));
        s4f = *((a64 + 1536));
        s5f = *((a64 + 1544));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t1c, t6c);
        t0d = _mm_add_pd(t2c, t5c);
        t1d = _mm_add_pd(t1c, t6c);
        t2d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9b, t3c));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0c, t4c));
        s8f = _mm_sub_pd(a94, a05);
        s9f = _mm_add_pd(a94, a05);
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d));
        a15 = ((__m128d  *) T2);
        s2g = _mm_add_pd(t1b, t7c);
        *(a15) = s2g;
        s3g = _mm_sub_pd(t1b, t7c);
        *((a15 + 8)) = s3g;
        s4g = _mm_sub_pd(t2b, t8c);
        *((a15 + 4)) = s4g;
        s5g = _mm_add_pd(t2b, t8c);
        *((a15 + 12)) = s5g;
        s6g = _mm_add_pd(t5b, s6f);
        *((a15 + 1)) = s6g;
        s7g = _mm_sub_pd(t5b, s6f);
        *((a15 + 9)) = s7g;
        s8g = _mm_sub_pd(t6b, s7f);
        *((a15 + 5)) = s8g;
        s9g = _mm_add_pd(t6b, s7f);
        *((a15 + 13)) = s9g;
        s0h = _mm_add_pd(t3b, s8f);
        *((a15 + 2)) = s0h;
        s1h = _mm_sub_pd(t3b, s8f);
        *((a15 + 10)) = s1h;
        s2h = _mm_sub_pd(t4b, s9f);
        *((a15 + 6)) = s2h;
        s3h = _mm_add_pd(t4b, s9f);
        *((a15 + 14)) = s3h;
        s4h = _mm_add_pd(t7b, s0g);
        *((a15 + 3)) = s4h;
        s5h = _mm_sub_pd(t7b, s0g);
        *((a15 + 11)) = s5h;
        s6h = _mm_sub_pd(t8b, s1g);
        *((a15 + 7)) = s6h;
        s7h = _mm_add_pd(t8b, s1g);
        *((a15 + 15)) = s7h;
        {long i3; for(i3 = 0; i3 <= 30; i3++) {
            a25 = (16 * i3);
            b4 = (((__m128d  *) T) + i2);
            b5 = (b4 + a25);
            s8h = *((b5 + 16));
            s9h = *((b5 + 24));
            b6 = (b4 - a25);
            s0i = *((b6 + 4080));
            s1i = *((b6 + 4088));
            t3d = _mm_add_pd(s8h, s0i);
            t4d = _mm_sub_pd(s9h, s1i);
            t5d = _mm_sub_pd(s8h, s0i);
            t6d = _mm_add_pd(s9h, s1i);
            s2i = *((b5 + 2064));
            s3i = *((b5 + 2072));
            s4i = *((b6 + 2032));
            s5i = *((b6 + 2040));
            t7d = _mm_add_pd(s2i, s4i);
            t8d = _mm_sub_pd(s3i, s5i);
            t9d = _mm_sub_pd(s2i, s4i);
            t0e = _mm_add_pd(s3i, s5i);
            t1e = _mm_add_pd(t3d, t7d);
            t2e = _mm_add_pd(t4d, t8d);
            t3e = _mm_sub_pd(t3d, t7d);
            t4e = _mm_sub_pd(t4d, t8d);
            t5e = _mm_sub_pd(t5d, t0e);
            t6e = _mm_add_pd(t6d, t9d);
            t7e = _mm_add_pd(t5d, t0e);
            t8e = _mm_sub_pd(t6d, t9d);
            s6i = *((b5 + 1040));
            s7i = *((b5 + 1048));
            s8i = *((b6 + 3056));
            s9i = *((b6 + 3064));
            t9e = _mm_add_pd(s6i, s8i);
            t0f = _mm_sub_pd(s7i, s9i);
            t1f = _mm_sub_pd(s6i, s8i);
            t2f = _mm_add_pd(s7i, s9i);
            s0j = *((b5 + 3088));
            s1j = *((b5 + 3096));
            s2j = *((b6 + 1008));
            s3j = *((b6 + 1016));
            t3f = _mm_add_pd(s0j, s2j);
            t4f = _mm_sub_pd(s1j, s3j);
            t5f = _mm_sub_pd(s0j, s2j);
            t6f = _mm_add_pd(s1j, s3j);
            t7f = _mm_add_pd(t9e, t3f);
            t8f = _mm_add_pd(t0f, t4f);
            t9f = _mm_sub_pd(t9e, t3f);
            t0g = _mm_sub_pd(t0f, t4f);
            a35 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1f, t6f));
            a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2f, t5f));
            s4j = _mm_sub_pd(a35, a45);
            s5j = _mm_add_pd(a35, a45);
            a55 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1f, t6f));
            a65 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2f, t5f));
            s6j = _mm_sub_pd(a55, a65);
            s7j = _mm_add_pd(a55, a65);
            t1g = _mm_add_pd(t1e, t7f);
            t2g = _mm_add_pd(t2e, t8f);
            t3g = _mm_sub_pd(t1e, t7f);
            t4g = _mm_sub_pd(t2e, t8f);
            t5g = _mm_add_pd(t5e, s4j);
            t6g = _mm_add_pd(t6e, s5j);
            t7g = _mm_sub_pd(t5e, s4j);
            t8g = _mm_sub_pd(t6e, s5j);
            t9g = _mm_sub_pd(t3e, t0g);
            t0h = _mm_add_pd(t4e, t9f);
            t1h = _mm_add_pd(t3e, t0g);
            t2h = _mm_sub_pd(t4e, t9f);
            t3h = _mm_add_pd(t7e, s6j);
            t4h = _mm_sub_pd(t8e, s7j);
            t5h = _mm_sub_pd(t7e, s6j);
            t6h = _mm_add_pd(t8e, s7j);
            a75 = (D78 + a25);
            a85 = *(a75);
            a95 = *((a75 + 1));
            a06 = *((a75 + 2));
            a16 = *((a75 + 3));
            a26 = *((a75 + 4));
            a36 = *((a75 + 5));
            a46 = *((a75 + 6));
            a56 = *((a75 + 7));
            a66 = *((a75 + 8));
            a76 = *((a75 + 9));
            a86 = *((a75 + 10));
            a96 = *((a75 + 11));
            a07 = *((a75 + 12));
            a17 = *((a75 + 13));
            a27 = *((a75 + 14));
            a37 = *((a75 + 15));
            b7 = (((__m128d  *) T2) + a25);
            s8j = _mm_sub_pd(_mm_mul_pd(a85, t1g), _mm_mul_pd(a95, t2g));
            *((b7 + 16)) = s8j;
            s9j = _mm_add_pd(_mm_mul_pd(a95, t1g), _mm_mul_pd(a85, t2g));
            *((b7 + 24)) = s9j;
            s0k = _mm_sub_pd(_mm_mul_pd(a06, t5g), _mm_mul_pd(a16, t6g));
            *((b7 + 17)) = s0k;
            s1k = _mm_add_pd(_mm_mul_pd(a16, t5g), _mm_mul_pd(a06, t6g));
            *((b7 + 25)) = s1k;
            s2k = _mm_sub_pd(_mm_mul_pd(a26, t9g), _mm_mul_pd(a36, t0h));
            *((b7 + 18)) = s2k;
            s3k = _mm_add_pd(_mm_mul_pd(a36, t9g), _mm_mul_pd(a26, t0h));
            *((b7 + 26)) = s3k;
            s4k = _mm_sub_pd(_mm_mul_pd(a46, t3h), _mm_mul_pd(a56, t4h));
            *((b7 + 19)) = s4k;
            s5k = _mm_add_pd(_mm_mul_pd(a56, t3h), _mm_mul_pd(a46, t4h));
            *((b7 + 27)) = s5k;
            s6k = _mm_sub_pd(_mm_mul_pd(a66, t3g), _mm_mul_pd(a76, t4g));
            *((b7 + 20)) = s6k;
            s7k = _mm_add_pd(_mm_mul_pd(a76, t3g), _mm_mul_pd(a66, t4g));
            *((b7 + 28)) = s7k;
            s8k = _mm_sub_pd(_mm_mul_pd(a86, t7g), _mm_mul_pd(a96, t8g));
            *((b7 + 21)) = s8k;
            s9k = _mm_add_pd(_mm_mul_pd(a96, t7g), _mm_mul_pd(a86, t8g));
            *((b7 + 29)) = s9k;
            s0l = _mm_sub_pd(_mm_mul_pd(a07, t1h), _mm_mul_pd(a17, t2h));
            *((b7 + 22)) = s0l;
            s1l = _mm_add_pd(_mm_mul_pd(a17, t1h), _mm_mul_pd(a07, t2h));
            *((b7 + 30)) = s1l;
            s2l = _mm_sub_pd(_mm_mul_pd(a27, t5h), _mm_mul_pd(a37, t6h));
            *((b7 + 23)) = s2l;
            s3l = _mm_add_pd(_mm_mul_pd(a37, t5h), _mm_mul_pd(a27, t6h));
            *((b7 + 31)) = s3l;
        }}
        {long i4; for(i4 = 0; i4 <= 7; i4++) {
            a47 = (((__m128d  *) T2) + i4);
            s4l = *(a47);
            s5l = *((a47 + 256));
            t7h = _mm_add_pd(s4l, s5l);
            t8h = _mm_sub_pd(s4l, s5l);
            s6l = *((a47 + 8));
            s7l = *((a47 + 264));
            t9h = _mm_sub_pd(s6l, s7l);
            t0i = _mm_add_pd(s6l, s7l);
            s8l = *((a47 + 128));
            s9l = *((a47 + 136));
            s0m = *((a47 + 384));
            s1m = *((a47 + 392));
            t1i = _mm_add_pd(s8l, s0m);
            t2i = _mm_sub_pd(s9l, s1m);
            a57 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8l, s0m));
            a67 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9l, s1m));
            s2m = _mm_sub_pd(a57, a67);
            s3m = _mm_add_pd(a57, a67);
            t3i = _mm_add_pd(t7h, t1i);
            t4i = _mm_sub_pd(t7h, t1i);
            t5i = _mm_sub_pd(t8h, t2i);
            t6i = _mm_add_pd(t8h, t2i);
            t7i = _mm_add_pd(t9h, s2m);
            t8i = _mm_sub_pd(t9h, s2m);
            t9i = _mm_sub_pd(t0i, s3m);
            t0j = _mm_add_pd(t0i, s3m);
            s4m = *((a47 + 16));
            s5m = *((a47 + 24));
            s6m = *((a47 + 496));
            s7m = *((a47 + 504));
            t1j = _mm_add_pd(s4m, s6m);
            t2j = _mm_sub_pd(s5m, s7m);
            t3j = _mm_sub_pd(s4m, s6m);
            t4j = _mm_add_pd(s5m, s7m);
            s8m = *((a47 + 272));
            s9m = *((a47 + 280));
            s0n = *((a47 + 240));
            s1n = *((a47 + 248));
            t5j = _mm_add_pd(s8m, s0n);
            t6j = _mm_sub_pd(s9m, s1n);
            t7j = _mm_sub_pd(s8m, s0n);
            t8j = _mm_add_pd(s9m, s1n);
            t9j = _mm_add_pd(t1j, t5j);
            t0k = _mm_add_pd(t2j, t6j);
            t1k = _mm_sub_pd(t1j, t5j);
            t2k = _mm_sub_pd(t2j, t6j);
            t3k = _mm_sub_pd(t3j, t8j);
            t4k = _mm_add_pd(t4j, t7j);
            t5k = _mm_add_pd(t3j, t8j);
            t6k = _mm_sub_pd(t4j, t7j);
            s2n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t3k), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t4k));
            s3n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t3k), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t4k));
            s4n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1k), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2k));
            s5n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1k), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2k));
            s6n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t5k), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t6k));
            s7n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t5k), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t6k));
            s8n = *((a47 + 32));
            s9n = *((a47 + 40));
            s0o = *((a47 + 480));
            s1o = *((a47 + 488));
            t7k = _mm_add_pd(s8n, s0o);
            t8k = _mm_sub_pd(s9n, s1o);
            t9k = _mm_sub_pd(s8n, s0o);
            t0l = _mm_add_pd(s9n, s1o);
            s2o = *((a47 + 288));
            s3o = *((a47 + 296));
            s4o = *((a47 + 224));
            s5o = *((a47 + 232));
            t1l = _mm_add_pd(s2o, s4o);
            t2l = _mm_sub_pd(s3o, s5o);
            t3l = _mm_sub_pd(s2o, s4o);
            t4l = _mm_add_pd(s3o, s5o);
            t5l = _mm_add_pd(t7k, t1l);
            t6l = _mm_add_pd(t8k, t2l);
            t7l = _mm_sub_pd(t7k, t1l);
            t8l = _mm_sub_pd(t8k, t2l);
            t9l = _mm_sub_pd(t9k, t4l);
            t0m = _mm_add_pd(t0l, t3l);
            t1m = _mm_add_pd(t9k, t4l);
            t2m = _mm_sub_pd(t0l, t3l);
            s6o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9l), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0m));
            s7o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9l), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0m));
            s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7l), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8l));
            s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7l), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8l));
            s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1m), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2m));
            s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1m), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2m));
            s2p = *((a47 + 48));
            s3p = *((a47 + 56));
            s4p = *((a47 + 464));
            s5p = *((a47 + 472));
            t3m = _mm_add_pd(s2p, s4p);
            t4m = _mm_sub_pd(s3p, s5p);
            t5m = _mm_sub_pd(s2p, s4p);
            t6m = _mm_add_pd(s3p, s5p);
            s6p = *((a47 + 304));
            s7p = *((a47 + 312));
            s8p = *((a47 + 208));
            s9p = *((a47 + 216));
            t7m = _mm_add_pd(s6p, s8p);
            t8m = _mm_sub_pd(s7p, s9p);
            t9m = _mm_sub_pd(s6p, s8p);
            t0n = _mm_add_pd(s7p, s9p);
            t1n = _mm_add_pd(t3m, t7m);
            t2n = _mm_add_pd(t4m, t8m);
            t3n = _mm_sub_pd(t3m, t7m);
            t4n = _mm_sub_pd(t4m, t8m);
            t5n = _mm_sub_pd(t5m, t0n);
            t6n = _mm_add_pd(t6m, t9m);
            t7n = _mm_add_pd(t5m, t0n);
            t8n = _mm_sub_pd(t6m, t9m);
            s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t5n), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t6n));
            s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t5n), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t6n));
            s2q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3n), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4n));
            s3q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3n), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4n));
            s4q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t7n), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t8n));
            s5q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t7n), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t8n));
            s6q = *((a47 + 64));
            s7q = *((a47 + 72));
            s8q = *((a47 + 448));
            s9q = *((a47 + 456));
            t9n = _mm_add_pd(s6q, s8q);
            t0o = _mm_sub_pd(s7q, s9q);
            t1o = _mm_sub_pd(s6q, s8q);
            t2o = _mm_add_pd(s7q, s9q);
            s0r = *((a47 + 320));
            s1r = *((a47 + 328));
            s2r = *((a47 + 192));
            s3r = *((a47 + 200));
            t3o = _mm_add_pd(s0r, s2r);
            t4o = _mm_sub_pd(s1r, s3r);
            t5o = _mm_sub_pd(s0r, s2r);
            t6o = _mm_add_pd(s1r, s3r);
            t7o = _mm_add_pd(t9n, t3o);
            t8o = _mm_add_pd(t0o, t4o);
            t9o = _mm_sub_pd(t1o, t6o);
            t0p = _mm_add_pd(t2o, t5o);
            t1p = _mm_add_pd(t1o, t6o);
            t2p = _mm_sub_pd(t2o, t5o);
            s4r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9o), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0p));
            s5r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9o), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0p));
            a77 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9n, t3o));
            a87 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0o, t4o));
            s6r = _mm_sub_pd(a77, a87);
            s7r = _mm_add_pd(a77, a87);
            s8r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2p));
            s9r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2p));
            s0s = *((a47 + 80));
            s1s = *((a47 + 88));
            s2s = *((a47 + 432));
            s3s = *((a47 + 440));
            t3p = _mm_add_pd(s0s, s2s);
            t4p = _mm_sub_pd(s1s, s3s);
            t5p = _mm_sub_pd(s0s, s2s);
            t6p = _mm_add_pd(s1s, s3s);
            s4s = *((a47 + 336));
            s5s = *((a47 + 344));
            s6s = *((a47 + 176));
            s7s = *((a47 + 184));
            t7p = _mm_add_pd(s4s, s6s);
            t8p = _mm_sub_pd(s5s, s7s);
            t9p = _mm_sub_pd(s4s, s6s);
            t0q = _mm_add_pd(s5s, s7s);
            t1q = _mm_add_pd(t3p, t7p);
            t2q = _mm_add_pd(t4p, t8p);
            t3q = _mm_sub_pd(t3p, t7p);
            t4q = _mm_sub_pd(t4p, t8p);
            t5q = _mm_sub_pd(t5p, t0q);
            t6q = _mm_add_pd(t6p, t9p);
            t7q = _mm_add_pd(t5p, t0q);
            t8q = _mm_sub_pd(t6p, t9p);
            s8s = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t5q), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t6q));
            s9s = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t5q), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t6q));
            s0t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3q), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4q));
            s1t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3q), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4q));
            s2t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t7q), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t8q));
            s3t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t7q), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t8q));
            s4t = *((a47 + 96));
            s5t = *((a47 + 104));
            s6t = *((a47 + 416));
            s7t = *((a47 + 424));
            t9q = _mm_add_pd(s4t, s6t);
            t0r = _mm_sub_pd(s5t, s7t);
            t1r = _mm_sub_pd(s4t, s6t);
            t2r = _mm_add_pd(s5t, s7t);
            s8t = *((a47 + 352));
            s9t = *((a47 + 360));
            s0u = *((a47 + 160));
            s1u = *((a47 + 168));
            t3r = _mm_add_pd(s8t, s0u);
            t4r = _mm_sub_pd(s9t, s1u);
            t5r = _mm_sub_pd(s8t, s0u);
            t6r = _mm_add_pd(s9t, s1u);
            t7r = _mm_add_pd(t9q, t3r);
            t8r = _mm_add_pd(t0r, t4r);
            t9r = _mm_sub_pd(t9q, t3r);
            t0s = _mm_sub_pd(t0r, t4r);
            t1s = _mm_sub_pd(t1r, t6r);
            t2s = _mm_add_pd(t2r, t5r);
            t3s = _mm_add_pd(t1r, t6r);
            t4s = _mm_sub_pd(t2r, t5r);
            s2u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1s), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2s));
            s3u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1s), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2s));
            s4u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0s));
            s5u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0s));
            s6u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3s), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4s));
            s7u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3s), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4s));
            s8u = *((a47 + 112));
            s9u = *((a47 + 120));
            s0v = *((a47 + 400));
            s1v = *((a47 + 408));
            t5s = _mm_add_pd(s8u, s0v);
            t6s = _mm_sub_pd(s9u, s1v);
            t7s = _mm_sub_pd(s8u, s0v);
            t8s = _mm_add_pd(s9u, s1v);
            s2v = *((a47 + 368));
            s3v = *((a47 + 376));
            s4v = *((a47 + 144));
            s5v = *((a47 + 152));
            t9s = _mm_add_pd(s2v, s4v);
            t0t = _mm_sub_pd(s3v, s5v);
            t1t = _mm_sub_pd(s2v, s4v);
            t2t = _mm_add_pd(s3v, s5v);
            t3t = _mm_add_pd(t5s, t9s);
            t4t = _mm_add_pd(t6s, t0t);
            t5t = _mm_sub_pd(t5s, t9s);
            t6t = _mm_sub_pd(t6s, t0t);
            t7t = _mm_sub_pd(t7s, t2t);
            t8t = _mm_add_pd(t8s, t1t);
            t9t = _mm_add_pd(t7s, t2t);
            t0u = _mm_sub_pd(t8s, t1t);
            s6v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t7t), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t8t));
            s7v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t7t), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t8t));
            s8v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5t), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t6t));
            s9v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t5t), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6t));
            s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9t), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t0u));
            s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t9t), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0u));
            t1u = _mm_add_pd(t3i, t7o);
            t2u = _mm_sub_pd(t3i, t7o);
            t3u = _mm_sub_pd(t4i, t8o);
            t4u = _mm_add_pd(t4i, t8o);
            t5u = _mm_add_pd(t5l, t7r);
            t6u = _mm_sub_pd(t6l, t8r);
            a97 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5l, t7r));
            a08 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6l, t8r));
            s2w = _mm_sub_pd(a97, a08);
            s3w = _mm_add_pd(a97, a08);
            t7u = _mm_add_pd(t1u, t5u);
            t8u = _mm_sub_pd(t1u, t5u);
            t9u = _mm_sub_pd(t2u, t6u);
            t0v = _mm_add_pd(t2u, t6u);
            t1v = _mm_add_pd(t3u, s2w);
            t2v = _mm_sub_pd(t3u, s2w);
            t3v = _mm_sub_pd(t4u, s3w);
            t4v = _mm_add_pd(t4u, s3w);
            t5v = _mm_add_pd(t9j, t3t);
            t6v = _mm_sub_pd(t0k, t4t);
            t7v = _mm_sub_pd(t9j, t3t);
            t8v = _mm_add_pd(t0k, t4t);
            t9v = _mm_add_pd(t1q, t1n);
            t0w = _mm_sub_pd(t2q, t2n);
            t1w = _mm_sub_pd(t1q, t1n);
            t2w = _mm_add_pd(t2q, t2n);
            t3w = _mm_add_pd(t5v, t9v);
            t4w = _mm_add_pd(t6v, t0w);
            t5w = _mm_sub_pd(t7v, t2w);
            t6w = _mm_add_pd(t8v, t1w);
            t7w = _mm_add_pd(t7v, t2w);
            t8w = _mm_sub_pd(t8v, t1w);
            s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5w), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6w));
            s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5w), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6w));
            a18 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5v, t9v));
            a28 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6v, t0w));
            s6w = _mm_sub_pd(a18, a28);
            s7w = _mm_add_pd(a18, a28);
            s8w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7w), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8w));
            s9w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7w), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8w));
            a38 = (dst + ((2 * i2) + (16 * i4)));
            s0x = _mm_add_pd(t7u, t3w);
            _mm_storeu_pd(((double  *) a38), s0x);
            s1x = _mm_sub_pd(t7u, t3w);
            _mm_storeu_pd(((double  *) (a38 + 4096)), s1x);
            s2x = _mm_sub_pd(t8u, t4w);
            _mm_storeu_pd(((double  *) (a38 + 2048)), s2x);
            s3x = _mm_add_pd(t8u, t4w);
            _mm_storeu_pd(((double  *) (a38 + 6144)), s3x);
            s4x = _mm_add_pd(t1v, s4w);
            _mm_storeu_pd(((double  *) (a38 + 512)), s4x);
            s5x = _mm_sub_pd(t1v, s4w);
            _mm_storeu_pd(((double  *) (a38 + 4608)), s5x);
            s6x = _mm_sub_pd(t2v, s5w);
            _mm_storeu_pd(((double  *) (a38 + 2560)), s6x);
            s7x = _mm_add_pd(t2v, s5w);
            _mm_storeu_pd(((double  *) (a38 + 6656)), s7x);
            s8x = _mm_add_pd(t9u, s6w);
            _mm_storeu_pd(((double  *) (a38 + 1024)), s8x);
            s9x = _mm_sub_pd(t9u, s6w);
            _mm_storeu_pd(((double  *) (a38 + 5120)), s9x);
            s0y = _mm_sub_pd(t0v, s7w);
            _mm_storeu_pd(((double  *) (a38 + 3072)), s0y);
            s1y = _mm_add_pd(t0v, s7w);
            _mm_storeu_pd(((double  *) (a38 + 7168)), s1y);
            s2y = _mm_add_pd(t3v, s8w);
            _mm_storeu_pd(((double  *) (a38 + 1536)), s2y);
            s3y = _mm_sub_pd(t3v, s8w);
            _mm_storeu_pd(((double  *) (a38 + 5632)), s3y);
            s4y = _mm_sub_pd(t4v, s9w);
            _mm_storeu_pd(((double  *) (a38 + 3584)), s4y);
            s5y = _mm_add_pd(t4v, s9w);
            _mm_storeu_pd(((double  *) (a38 + 7680)), s5y);
            t9w = _mm_add_pd(t7i, s4r);
            t0x = _mm_sub_pd(t7i, s4r);
            t1x = _mm_sub_pd(t8i, s5r);
            t2x = _mm_add_pd(t8i, s5r);
            t3x = _mm_add_pd(s6o, s2u);
            t4x = _mm_sub_pd(s7o, s3u);
            a48 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6o, s2u));
            a58 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7o, s3u));
            s6y = _mm_sub_pd(a48, a58);
            s7y = _mm_add_pd(a48, a58);
            t5x = _mm_add_pd(t9w, t3x);
            t6x = _mm_sub_pd(t9w, t3x);
            t7x = _mm_sub_pd(t0x, t4x);
            t8x = _mm_add_pd(t0x, t4x);
            t9x = _mm_add_pd(t1x, s6y);
            t0y = _mm_sub_pd(t1x, s6y);
            t1y = _mm_sub_pd(t2x, s7y);
            t2y = _mm_add_pd(t2x, s7y);
            t3y = _mm_add_pd(s2n, s6v);
            t4y = _mm_sub_pd(s3n, s7v);
            t5y = _mm_sub_pd(s2n, s6v);
            t6y = _mm_add_pd(s3n, s7v);
            t7y = _mm_add_pd(s8s, s0q);
            t8y = _mm_sub_pd(s9s, s1q);
            t9y = _mm_sub_pd(s8s, s0q);
            t0z = _mm_add_pd(s9s, s1q);
            t1z = _mm_add_pd(t3y, t7y);
            t2z = _mm_add_pd(t4y, t8y);
            t3z = _mm_sub_pd(t5y, t0z);
            t4z = _mm_add_pd(t6y, t9y);
            t5z = _mm_add_pd(t5y, t0z);
            t6z = _mm_sub_pd(t6y, t9y);
            s8y = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4z));
            s9y = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4z));
            a68 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3y, t7y));
            a78 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4y, t8y));
            s0z = _mm_sub_pd(a68, a78);
            s1z = _mm_add_pd(a68, a78);
            s2z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6z));
            s3z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6z));
            s4z = _mm_add_pd(t5x, t1z);
            _mm_storeu_pd(((double  *) (a38 + 128)), s4z);
            s5z = _mm_sub_pd(t5x, t1z);
            _mm_storeu_pd(((double  *) (a38 + 4224)), s5z);
            s6z = _mm_sub_pd(t6x, t2z);
            _mm_storeu_pd(((double  *) (a38 + 2176)), s6z);
            s7z = _mm_add_pd(t6x, t2z);
            _mm_storeu_pd(((double  *) (a38 + 6272)), s7z);
            s8z = _mm_add_pd(t9x, s8y);
            _mm_storeu_pd(((double  *) (a38 + 640)), s8z);
            s9z = _mm_sub_pd(t9x, s8y);
            _mm_storeu_pd(((double  *) (a38 + 4736)), s9z);
            s0A = _mm_sub_pd(t0y, s9y);
            _mm_storeu_pd(((double  *) (a38 + 2688)), s0A);
            s1A = _mm_add_pd(t0y, s9y);
            _mm_storeu_pd(((double  *) (a38 + 6784)), s1A);
            s2A = _mm_add_pd(t7x, s0z);
            _mm_storeu_pd(((double  *) (a38 + 1152)), s2A);
            s3A = _mm_sub_pd(t7x, s0z);
            _mm_storeu_pd(((double  *) (a38 + 5248)), s3A);
            s4A = _mm_sub_pd(t8x, s1z);
            _mm_storeu_pd(((double  *) (a38 + 3200)), s4A);
            s5A = _mm_add_pd(t8x, s1z);
            _mm_storeu_pd(((double  *) (a38 + 7296)), s5A);
            s6A = _mm_add_pd(t1y, s2z);
            _mm_storeu_pd(((double  *) (a38 + 1664)), s6A);
            s7A = _mm_sub_pd(t1y, s2z);
            _mm_storeu_pd(((double  *) (a38 + 5760)), s7A);
            s8A = _mm_sub_pd(t2y, s3z);
            _mm_storeu_pd(((double  *) (a38 + 3712)), s8A);
            s9A = _mm_add_pd(t2y, s3z);
            _mm_storeu_pd(((double  *) (a38 + 7808)), s9A);
            t7z = _mm_add_pd(t5i, s6r);
            t8z = _mm_sub_pd(t5i, s6r);
            t9z = _mm_sub_pd(t6i, s7r);
            t0A = _mm_add_pd(t6i, s7r);
            t1A = _mm_add_pd(s8o, s4u);
            t2A = _mm_sub_pd(s9o, s5u);
            a88 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8o, s4u));
            a98 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9o, s5u));
            s0B = _mm_sub_pd(a88, a98);
            s1B = _mm_add_pd(a88, a98);
            t3A = _mm_add_pd(t7z, t1A);
            t4A = _mm_sub_pd(t7z, t1A);
            t5A = _mm_sub_pd(t8z, t2A);
            t6A = _mm_add_pd(t8z, t2A);
            t7A = _mm_add_pd(t9z, s0B);
            t8A = _mm_sub_pd(t9z, s0B);
            t9A = _mm_sub_pd(t0A, s1B);
            t0B = _mm_add_pd(t0A, s1B);
            t1B = _mm_add_pd(s4n, s8v);
            t2B = _mm_sub_pd(s5n, s9v);
            t3B = _mm_sub_pd(s4n, s8v);
            t4B = _mm_add_pd(s5n, s9v);
            t5B = _mm_add_pd(s0t, s2q);
            t6B = _mm_sub_pd(s1t, s3q);
            t7B = _mm_sub_pd(s0t, s2q);
            t8B = _mm_add_pd(s1t, s3q);
            t9B = _mm_add_pd(t1B, t5B);
            t0C = _mm_add_pd(t2B, t6B);
            t1C = _mm_sub_pd(t3B, t8B);
            t2C = _mm_add_pd(t4B, t7B);
            t3C = _mm_add_pd(t3B, t8B);
            t4C = _mm_sub_pd(t4B, t7B);
            s2B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1C), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2C));
            s3B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1C), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2C));
            a09 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1B, t5B));
            a19 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2B, t6B));
            s4B = _mm_sub_pd(a09, a19);
            s5B = _mm_add_pd(a09, a19);
            s6B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3C), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4C));
            s7B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3C), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4C));
            s8B = _mm_add_pd(t3A, t9B);
            _mm_storeu_pd(((double  *) (a38 + 256)), s8B);
            s9B = _mm_sub_pd(t3A, t9B);
            _mm_storeu_pd(((double  *) (a38 + 4352)), s9B);
            s0C = _mm_sub_pd(t4A, t0C);
            _mm_storeu_pd(((double  *) (a38 + 2304)), s0C);
            s1C = _mm_add_pd(t4A, t0C);
            _mm_storeu_pd(((double  *) (a38 + 6400)), s1C);
            s2C = _mm_add_pd(t7A, s2B);
            _mm_storeu_pd(((double  *) (a38 + 768)), s2C);
            s3C = _mm_sub_pd(t7A, s2B);
            _mm_storeu_pd(((double  *) (a38 + 4864)), s3C);
            s4C = _mm_sub_pd(t8A, s3B);
            _mm_storeu_pd(((double  *) (a38 + 2816)), s4C);
            s5C = _mm_add_pd(t8A, s3B);
            _mm_storeu_pd(((double  *) (a38 + 6912)), s5C);
            s6C = _mm_add_pd(t5A, s4B);
            _mm_storeu_pd(((double  *) (a38 + 1280)), s6C);
            s7C = _mm_sub_pd(t5A, s4B);
            _mm_storeu_pd(((double  *) (a38 + 5376)), s7C);
            s8C = _mm_sub_pd(t6A, s5B);
            _mm_storeu_pd(((double  *) (a38 + 3328)), s8C);
            s9C = _mm_add_pd(t6A, s5B);
            _mm_storeu_pd(((double  *) (a38 + 7424)), s9C);
            s0D = _mm_add_pd(t9A, s6B);
            _mm_storeu_pd(((double  *) (a38 + 1792)), s0D);
            s1D = _mm_sub_pd(t9A, s6B);
            _mm_storeu_pd(((double  *) (a38 + 5888)), s1D);
            s2D = _mm_sub_pd(t0B, s7B);
            _mm_storeu_pd(((double  *) (a38 + 3840)), s2D);
            s3D = _mm_add_pd(t0B, s7B);
            _mm_storeu_pd(((double  *) (a38 + 7936)), s3D);
            t5C = _mm_add_pd(t9i, s8r);
            t6C = _mm_sub_pd(t9i, s8r);
            t7C = _mm_sub_pd(t0j, s9r);
            t8C = _mm_add_pd(t0j, s9r);
            t9C = _mm_add_pd(s0p, s6u);
            t0D = _mm_sub_pd(s1p, s7u);
            a29 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0p, s6u));
            a39 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1p, s7u));
            s4D = _mm_sub_pd(a29, a39);
            s5D = _mm_add_pd(a29, a39);
            t1D = _mm_add_pd(t5C, t9C);
            t2D = _mm_sub_pd(t5C, t9C);
            t3D = _mm_sub_pd(t6C, t0D);
            t4D = _mm_add_pd(t6C, t0D);
            t5D = _mm_add_pd(t7C, s4D);
            t6D = _mm_sub_pd(t7C, s4D);
            t7D = _mm_sub_pd(t8C, s5D);
            t8D = _mm_add_pd(t8C, s5D);
            t9D = _mm_add_pd(s6n, s0w);
            t0E = _mm_sub_pd(s7n, s1w);
            t1E = _mm_sub_pd(s6n, s0w);
            t2E = _mm_add_pd(s7n, s1w);
            t3E = _mm_add_pd(s2t, s4q);
            t4E = _mm_sub_pd(s3t, s5q);
            t5E = _mm_sub_pd(s2t, s4q);
            t6E = _mm_add_pd(s3t, s5q);
            t7E = _mm_add_pd(t9D, t3E);
            t8E = _mm_add_pd(t0E, t4E);
            t9E = _mm_sub_pd(t1E, t6E);
            t0F = _mm_add_pd(t2E, t5E);
            t1F = _mm_add_pd(t1E, t6E);
            t2F = _mm_sub_pd(t2E, t5E);
            s6D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9E), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0F));
            s7D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9E), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0F));
            a49 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9D, t3E));
            a59 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0E, t4E));
            s8D = _mm_sub_pd(a49, a59);
            s9D = _mm_add_pd(a49, a59);
            s0E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2F));
            s1E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2F));
            s2E = _mm_add_pd(t1D, t7E);
            _mm_storeu_pd(((double  *) (a38 + 384)), s2E);
            s3E = _mm_sub_pd(t1D, t7E);
            _mm_storeu_pd(((double  *) (a38 + 4480)), s3E);
            s4E = _mm_sub_pd(t2D, t8E);
            _mm_storeu_pd(((double  *) (a38 + 2432)), s4E);
            s5E = _mm_add_pd(t2D, t8E);
            _mm_storeu_pd(((double  *) (a38 + 6528)), s5E);
            s6E = _mm_add_pd(t5D, s6D);
            _mm_storeu_pd(((double  *) (a38 + 896)), s6E);
            s7E = _mm_sub_pd(t5D, s6D);
            _mm_storeu_pd(((double  *) (a38 + 4992)), s7E);
            s8E = _mm_sub_pd(t6D, s7D);
            _mm_storeu_pd(((double  *) (a38 + 2944)), s8E);
            s9E = _mm_add_pd(t6D, s7D);
            _mm_storeu_pd(((double  *) (a38 + 7040)), s9E);
            s0F = _mm_add_pd(t3D, s8D);
            _mm_storeu_pd(((double  *) (a38 + 1408)), s0F);
            s1F = _mm_sub_pd(t3D, s8D);
            _mm_storeu_pd(((double  *) (a38 + 5504)), s1F);
            s2F = _mm_sub_pd(t4D, s9D);
            _mm_storeu_pd(((double  *) (a38 + 3456)), s2F);
            s3F = _mm_add_pd(t4D, s9D);
            _mm_storeu_pd(((double  *) (a38 + 7552)), s3F);
            s4F = _mm_add_pd(t7D, s0E);
            _mm_storeu_pd(((double  *) (a38 + 1920)), s4F);
            s5F = _mm_sub_pd(t7D, s0E);
            _mm_storeu_pd(((double  *) (a38 + 6016)), s5F);
            s6F = _mm_sub_pd(t8D, s1E);
            _mm_storeu_pd(((double  *) (a38 + 3968)), s6F);
            s7F = _mm_add_pd(t8D, s1E);
            _mm_storeu_pd(((double  *) (a38 + 8064)), s7F);
        }}
    }}
    }
    
    return SPIRAL_OK;
}

SPIRAL_API(spiral_status_t, spiral_rfftinv_double_8192)(const double *pSrc, double *pDst ) {
    if (!is_aligned(pSrc) || !is_aligned(pDst))
    	return spiral_rfftinv_double_8192_unaligned(pSrc, pDst);
    else {
    const double  *src = (const double *)pSrc; 
    double        *dst = (double *)pDst;
    
    { SPIRAL_ALIGNED(double T[8192]);
     SPIRAL_ALIGNED(double T2[1024]);
    __m128d a01, a02, a04, a05, a06, a07, a08, a09, a11, a12, a13, a14, a15, a16, a17, a18, a19, a2, a21, a22, a23, a24
            , a26, a27, a28, a29, a3, a31, a32, a33, a34, a36, a37, a38, a39, a4, a41, a42, a43, a44, a45, a46, a47, a49
            , a5, a51, a52, a53, a54, a55, a56, a58, a59, a61, a62, a63, a64, a65, a66, a67, a68, a69, a71, a72, a73, a75
            , a76, a77, a78, a81, a82, a83, a84, a86, a87, a88, a91, a92, a93, a94, a95, a96, a97, a98, s, s01, s02, s03
            , s04, s05, s06, s07, s08, s09, s0A, s0B, s0C, s0D, s0E, s0F, s0a, s0b, s0c, s0d, s0e, s0f, s0g, s0h, s0i, s0j
            , s0k, s0l, s0m, s0n, s0o, s0p, s0q, s0r, s0s, s0t, s0u, s0v, s0w, s0x, s0y, s0z, s11, s12, s13, s14, s15, s16
            , s17, s18, s19, s1A, s1B, s1C, s1D, s1E, s1F, s1a, s1b, s1c, s1d, s1e, s1f, s1g, s1h, s1i, s1j, s1k, s1l, s1m
            , s1n, s1o, s1p, s1q, s1r, s1s, s1t, s1u, s1v, s1w, s1x, s1y, s1z, s2, s21, s22, s23, s24, s25, s26, s27, s28
            , s29, s2A, s2B, s2C, s2D, s2E, s2F, s2a, s2b, s2c, s2d, s2e, s2f, s2g, s2h, s2i, s2j, s2k, s2l, s2m, s2n, s2o
            , s2p, s2q, s2r, s2s, s2t, s2u, s2v, s2w, s2x, s2y, s2z, s3, s31, s32, s33, s34, s35, s36, s37, s38, s39, s3A
            , s3B, s3C, s3D, s3E, s3F, s3a, s3b, s3c, s3d, s3e, s3f, s3g, s3h, s3i, s3j, s3k, s3l, s3m, s3n, s3o, s3p, s3q
            , s3r, s3s, s3t, s3u, s3v, s3w, s3x, s3y, s3z, s4, s41, s42, s43, s44, s45, s46, s47, s48, s49, s4A, s4B, s4C
            , s4D, s4E, s4F, s4a, s4b, s4c, s4d, s4e, s4f, s4g, s4h, s4i, s4j, s4k, s4l, s4m, s4n, s4o, s4p, s4q, s4r, s4s
            , s4t, s4u, s4v, s4w, s4x, s4y, s4z, s5, s51, s52, s53, s54, s55, s56, s57, s58, s59, s5A, s5B, s5C, s5D, s5E
            , s5F, s5a, s5b, s5c, s5d, s5e, s5f, s5g, s5h, s5i, s5j, s5k, s5l, s5m, s5n, s5o, s5p, s5q, s5r, s5s, s5t, s5u
            , s5v, s5w, s5x, s5y, s5z, s6, s61, s62, s63, s64, s65, s66, s67, s68, s69, s6A, s6B, s6C, s6D, s6E, s6F, s6a
            , s6b, s6c, s6d, s6e, s6f, s6g, s6h, s6i, s6j, s6k, s6l, s6m, s6n, s6o, s6p, s6q, s6r, s6s, s6t, s6u, s6v, s6w
            , s6x, s6y, s6z, s7, s71, s72, s73, s74, s75, s76, s77, s78, s79, s7A, s7B, s7C, s7D, s7E, s7F, s7a, s7b, s7c
            , s7d, s7e, s7f, s7g, s7h, s7i, s7j, s7k, s7l, s7m, s7n, s7o, s7p, s7q, s7r, s7s, s7t, s7u, s7v, s7w, s7x, s7y
            , s7z, s8, s81, s82, s83, s84, s85, s86, s87, s88, s89, s8A, s8B, s8C, s8D, s8E, s8a, s8b, s8c, s8d, s8e, s8f
            , s8g, s8h, s8i, s8j, s8k, s8l, s8m, s8n, s8o, s8p, s8q, s8r, s8s, s8t, s8u, s8v, s8w, s8x, s8y, s8z, s9, s91
            , s92, s93, s94, s95, s96, s97, s98, s99, s9A, s9B, s9C, s9D, s9E, s9a, s9b, s9c, s9d, s9e, s9f, s9g, s9h, s9i
            , s9j, s9k, s9l, s9m, s9n, s9o, s9p, s9q, s9r, s9s, s9t, s9u, s9v, s9w, s9x, s9y, s9z, t, t01, t02, t03, t04
            , t05, t06, t07, t08, t09, t0A, t0B, t0C, t0D, t0E, t0F, t0a, t0b, t0c, t0d, t0e, t0f, t0g, t0h, t0i, t0j, t0k
            , t0l, t0m, t0n, t0o, t0p, t0q, t0r, t0s, t0t, t0u, t0v, t0w, t0x, t0y, t0z, t11, t12, t13, t14, t15, t16, t17
            , t18, t19, t1A, t1B, t1C, t1D, t1E, t1F, t1a, t1b, t1c, t1d, t1e, t1f, t1g, t1h, t1i, t1j, t1k, t1l, t1m, t1n
            , t1o, t1p, t1q, t1r, t1s, t1t, t1u, t1v, t1w, t1x, t1y, t1z, t2, t21, t22, t23, t24, t25, t26, t27, t28, t29
            , t2A, t2B, t2C, t2D, t2E, t2F, t2a, t2b, t2c, t2d, t2e, t2f, t2g, t2h, t2i, t2j, t2k, t2l, t2m, t2n, t2o, t2p
            , t2q, t2r, t2s, t2t, t2u, t2v, t2w, t2x, t2y, t2z, t3, t31, t32, t33, t34, t35, t36, t37, t38, t39, t3A, t3B
            , t3C, t3D, t3E, t3a, t3b, t3c, t3d, t3e, t3f, t3g, t3h, t3i, t3j, t3k, t3l, t3m, t3n, t3o, t3p, t3q, t3r, t3s
            , t3t, t3u, t3v, t3w, t3x, t3y, t3z, t4, t41, t42, t43, t44, t45, t46, t47, t48, t49, t4A, t4B, t4C, t4D, t4E
            , t4a, t4b, t4c, t4d, t4e, t4f, t4g, t4h, t4i, t4j, t4k, t4l, t4m, t4n, t4o, t4p, t4q, t4r, t4s, t4t, t4u, t4v
            , t4w, t4x, t4y, t4z, t5, t51, t52, t53, t54, t55, t56, t57, t58, t59, t5A, t5B, t5C, t5D, t5E, t5a, t5b, t5c
            , t5d, t5e, t5f, t5g, t5h, t5i, t5j, t5k, t5l, t5m, t5n, t5o, t5p, t5q, t5r, t5s, t5t, t5u, t5v, t5w, t5x, t5y
            , t5z, t6, t61, t62, t63, t64, t65, t66, t67, t68, t69, t6A, t6B, t6C, t6D, t6E, t6a, t6b, t6c, t6d, t6e, t6f
            , t6g, t6h, t6i, t6j, t6k, t6l, t6m, t6n, t6o, t6p, t6q, t6r, t6s, t6t, t6u, t6v, t6w, t6x, t6y, t6z, t7, t71
            , t72, t73, t74, t75, t76, t77, t78, t79, t7A, t7B, t7C, t7D, t7E, t7a, t7b, t7c, t7d, t7e, t7f, t7g, t7h, t7i
            , t7j, t7k, t7l, t7m, t7n, t7o, t7p, t7q, t7r, t7s, t7t, t7u, t7v, t7w, t7x, t7y, t7z, t8, t81, t82, t83, t84
            , t85, t86, t87, t88, t89, t8A, t8B, t8C, t8D, t8E, t8a, t8b, t8c, t8d, t8e, t8f, t8g, t8h, t8i, t8j, t8k, t8l
            , t8m, t8n, t8o, t8p, t8q, t8r, t8s, t8t, t8u, t8v, t8w, t8x, t8y, t8z, t9, t91, t92, t93, t94, t95, t96, t97
            , t98, t99, t9A, t9B, t9C, t9D, t9E, t9a, t9b, t9c, t9d, t9e, t9f, t9g, t9h, t9i, t9j, t9k, t9l, t9m, t9n, t9o
            , t9p, t9q, t9r, t9s, t9t, t9u, t9v, t9w, t9x, t9y, t9z;
    __m128d  *a, *a03, *a25, *a48, *a57, *a6, *a7, *a74, *a85, *a9, *b, *b2, *b3, *b4, *b5, *b6, *b7;
    int a35, a8;
    a = ((__m128d  *) src);
    s = *(a);
    s2 = _mm_add_pd(v_neg03(v_hi2(s, s)), v_lo2(s, s));
    s3 = _mm_mul_pd(_mm_set_pd((-2.0), 2.0), *((a + 2048)));
    t = _mm_add_pd(s2, s3);
    t2 = _mm_sub_pd(s2, s3);
    s4 = *((a + 256));
    s5 = v_neg23(*((a + 3840)));
    t3 = _mm_add_pd(s4, s5);
    t4 = _mm_sub_pd(s4, s5);
    s6 = v_lo2(t3, t4);
    s7 = v_hi2(t3, t4);
    s8 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s6), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s7));
    s9 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 0.0), s6), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 2.0), s7));
    s01 = *((a + 512));
    s11 = v_neg23(*((a + 3584)));
    t5 = _mm_add_pd(s01, s11);
    t6 = _mm_sub_pd(s01, s11);
    s21 = v_lo2(t5, t6);
    s31 = v_hi2(t5, t6);
    s41 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s21), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s31));
    s51 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 0.0), s21), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 2.0), s31));
    s61 = *((a + 768));
    s71 = v_neg23(*((a + 3328)));
    t7 = _mm_add_pd(s61, s71);
    t8 = _mm_sub_pd(s61, s71);
    s81 = v_lo2(t7, t8);
    s91 = v_hi2(t7, t8);
    s02 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s81), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s91));
    s12 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 0.0), s81), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 2.0), s91));
    s22 = *((a + 1024));
    s32 = v_neg23(*((a + 3072)));
    t9 = _mm_add_pd(s22, s32);
    t01 = _mm_sub_pd(s22, s32);
    s42 = v_lo2(t9, t01);
    s52 = v_hi2(t9, t01);
    s62 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s52));
    s72 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.4142135623730951, 0.0), s42), _mm_mul_pd(_mm_set_pd(1.4142135623730951, 2.0), s52));
    s82 = *((a + 1280));
    s92 = v_neg23(*((a + 2816)));
    t11 = _mm_add_pd(s82, s92);
    t21 = _mm_sub_pd(s82, s92);
    s03 = v_lo2(t11, t21);
    s13 = v_hi2(t11, t21);
    s23 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s03), _mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s13));
    s33 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.6629392246050905, 0.0), s03), _mm_mul_pd(_mm_set_pd(1.1111404660392044, 2.0), s13));
    s43 = *((a + 1536));
    s53 = v_neg23(*((a + 2560)));
    t31 = _mm_add_pd(s43, s53);
    t41 = _mm_sub_pd(s43, s53);
    s63 = v_lo2(t31, t41);
    s73 = v_hi2(t31, t41);
    s83 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s63), _mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s73));
    s93 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.8477590650225735, 0.0), s63), _mm_mul_pd(_mm_set_pd(0.76536686473017956, 2.0), s73));
    s04 = *((a + 1792));
    s14 = v_neg23(*((a + 2304)));
    t51 = _mm_add_pd(s04, s14);
    t61 = _mm_sub_pd(s04, s14);
    s24 = v_lo2(t51, t61);
    s34 = v_hi2(t51, t61);
    s44 = _mm_sub_pd(_mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s24), _mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s34));
    s54 = _mm_add_pd(_mm_mul_pd(_mm_set_pd(1.9615705608064609, 0.0), s24), _mm_mul_pd(_mm_set_pd(0.39018064403225655, 2.0), s34));
    t71 = _mm_add_pd(t, s62);
    t81 = _mm_sub_pd(t, s62);
    t91 = _mm_sub_pd(t2, s72);
    t02 = _mm_add_pd(t2, s72);
    t12 = _mm_add_pd(s41, s83);
    t22 = _mm_sub_pd(s51, s93);
    a2 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s41, s83));
    a3 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s51, s93));
    s64 = _mm_sub_pd(a2, a3);
    s74 = _mm_add_pd(a2, a3);
    t32 = _mm_add_pd(t71, t12);
    t42 = _mm_sub_pd(t71, t12);
    t52 = _mm_sub_pd(t81, t22);
    t62 = _mm_add_pd(t81, t22);
    t72 = _mm_add_pd(t91, s64);
    t82 = _mm_sub_pd(t91, s64);
    t92 = _mm_sub_pd(t02, s74);
    t03 = _mm_add_pd(t02, s74);
    t13 = _mm_add_pd(s8, s44);
    t23 = _mm_sub_pd(s9, s54);
    t33 = _mm_sub_pd(s8, s44);
    t43 = _mm_add_pd(s9, s54);
    t53 = _mm_add_pd(s23, s02);
    t63 = _mm_sub_pd(s33, s12);
    t73 = _mm_sub_pd(s23, s02);
    t83 = _mm_add_pd(s33, s12);
    t93 = _mm_add_pd(t13, t53);
    t04 = _mm_add_pd(t23, t63);
    t14 = _mm_sub_pd(t33, t83);
    t24 = _mm_add_pd(t43, t73);
    t34 = _mm_add_pd(t33, t83);
    t44 = _mm_sub_pd(t43, t73);
    s84 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t14), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t24));
    s94 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t14), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t24));
    a4 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t13, t53));
    a5 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t23, t63));
    s05 = _mm_sub_pd(a4, a5);
    s15 = _mm_add_pd(a4, a5);
    s25 = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t34), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t44));
    s35 = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t34), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t44));
    a6 = ((__m128d  *) T);
    s45 = _mm_add_pd(t32, t93);
    *(a6) = s45;
    s55 = _mm_sub_pd(t32, t93);
    *((a6 + 8)) = s55;
    s65 = _mm_sub_pd(t42, t04);
    *((a6 + 4)) = s65;
    s75 = _mm_add_pd(t42, t04);
    *((a6 + 12)) = s75;
    s85 = _mm_add_pd(t72, s84);
    *((a6 + 1)) = s85;
    s95 = _mm_sub_pd(t72, s84);
    *((a6 + 9)) = s95;
    s06 = _mm_sub_pd(t82, s94);
    *((a6 + 5)) = s06;
    s16 = _mm_add_pd(t82, s94);
    *((a6 + 13)) = s16;
    s26 = _mm_add_pd(t52, s05);
    *((a6 + 2)) = s26;
    s36 = _mm_sub_pd(t52, s05);
    *((a6 + 10)) = s36;
    s46 = _mm_sub_pd(t62, s15);
    *((a6 + 6)) = s46;
    s56 = _mm_add_pd(t62, s15);
    *((a6 + 14)) = s56;
    s66 = _mm_add_pd(t92, s25);
    *((a6 + 3)) = s66;
    s76 = _mm_sub_pd(t92, s25);
    *((a6 + 11)) = s76;
    s86 = _mm_sub_pd(t03, s35);
    *((a6 + 7)) = s86;
    s96 = _mm_add_pd(t03, s35);
    *((a6 + 15)) = s96;
    {long i; for(i = 0; i <= 254; i++) {
        a7 = ((__m128d  *) src);
        b = (a7 + i);
        s07 = *((b + 1));
        b2 = (a7 - i);
        s17 = v_neg23(*((b2 + 4095)));
        t54 = _mm_add_pd(s07, s17);
        t64 = _mm_sub_pd(s07, s17);
        s27 = v_lo2(t54, t64);
        s37 = v_hi2(t54, t64);
        a8 = (16 * i);
        a9 = (D80 + a8);
        a01 = *(a9);
        a11 = *((a9 + 1));
        s47 = _mm_add_pd(_mm_mul_pd(a01, s27), _mm_mul_pd(a11, s37));
        s57 = _mm_sub_pd(_mm_mul_pd(a01, s37), _mm_mul_pd(a11, s27));
        s67 = *((b + 513));
        s77 = v_neg23(*((b2 + 3583)));
        t74 = _mm_add_pd(s67, s77);
        t84 = _mm_sub_pd(s67, s77);
        s87 = v_lo2(t74, t84);
        s97 = v_hi2(t74, t84);
        a21 = *((a9 + 2));
        a31 = *((a9 + 3));
        s08 = _mm_add_pd(_mm_mul_pd(a21, s87), _mm_mul_pd(a31, s97));
        s18 = _mm_sub_pd(_mm_mul_pd(a21, s97), _mm_mul_pd(a31, s87));
        s28 = *((b + 1025));
        s38 = v_neg23(*((b2 + 3071)));
        t94 = _mm_add_pd(s28, s38);
        t05 = _mm_sub_pd(s28, s38);
        s48 = v_lo2(t94, t05);
        s58 = v_hi2(t94, t05);
        a41 = *((a9 + 4));
        a51 = *((a9 + 5));
        s68 = _mm_add_pd(_mm_mul_pd(a41, s48), _mm_mul_pd(a51, s58));
        s78 = _mm_sub_pd(_mm_mul_pd(a41, s58), _mm_mul_pd(a51, s48));
        s88 = *((b + 1537));
        s98 = v_neg23(*((b2 + 2559)));
        t15 = _mm_add_pd(s88, s98);
        t25 = _mm_sub_pd(s88, s98);
        s09 = v_lo2(t15, t25);
        s19 = v_hi2(t15, t25);
        a61 = *((a9 + 6));
        a71 = *((a9 + 7));
        s29 = _mm_add_pd(_mm_mul_pd(a61, s09), _mm_mul_pd(a71, s19));
        s39 = _mm_sub_pd(_mm_mul_pd(a61, s19), _mm_mul_pd(a71, s09));
        s49 = *((b + 2049));
        s59 = v_neg23(*((b2 + 2047)));
        t35 = _mm_add_pd(s49, s59);
        t45 = _mm_sub_pd(s49, s59);
        s69 = v_lo2(t35, t45);
        s79 = v_hi2(t35, t45);
        a81 = *((a9 + 8));
        a91 = *((a9 + 9));
        s89 = _mm_add_pd(_mm_mul_pd(a81, s69), _mm_mul_pd(a91, s79));
        s99 = _mm_sub_pd(_mm_mul_pd(a81, s79), _mm_mul_pd(a91, s69));
        s0a = *((b + 2561));
        s1a = v_neg23(*((b2 + 1535)));
        t55 = _mm_add_pd(s0a, s1a);
        t65 = _mm_sub_pd(s0a, s1a);
        s2a = v_lo2(t55, t65);
        s3a = v_hi2(t55, t65);
        a02 = *((a9 + 10));
        a12 = *((a9 + 11));
        s4a = _mm_add_pd(_mm_mul_pd(a02, s2a), _mm_mul_pd(a12, s3a));
        s5a = _mm_sub_pd(_mm_mul_pd(a02, s3a), _mm_mul_pd(a12, s2a));
        s6a = *((b + 3073));
        s7a = v_neg23(*((b2 + 1023)));
        t75 = _mm_add_pd(s6a, s7a);
        t85 = _mm_sub_pd(s6a, s7a);
        s8a = v_lo2(t75, t85);
        s9a = v_hi2(t75, t85);
        a22 = *((a9 + 12));
        a32 = *((a9 + 13));
        s0b = _mm_add_pd(_mm_mul_pd(a22, s8a), _mm_mul_pd(a32, s9a));
        s1b = _mm_sub_pd(_mm_mul_pd(a22, s9a), _mm_mul_pd(a32, s8a));
        s2b = *((b + 3585));
        s3b = v_neg23(*((b2 + 511)));
        t95 = _mm_add_pd(s2b, s3b);
        t06 = _mm_sub_pd(s2b, s3b);
        s4b = v_lo2(t95, t06);
        s5b = v_hi2(t95, t06);
        a42 = *((a9 + 14));
        a52 = *((a9 + 15));
        s6b = _mm_add_pd(_mm_mul_pd(a42, s4b), _mm_mul_pd(a52, s5b));
        s7b = _mm_sub_pd(_mm_mul_pd(a42, s5b), _mm_mul_pd(a52, s4b));
        t16 = _mm_add_pd(s47, s89);
        t26 = _mm_add_pd(s57, s99);
        t36 = _mm_sub_pd(s47, s89);
        t46 = _mm_sub_pd(s57, s99);
        t56 = _mm_add_pd(s68, s0b);
        t66 = _mm_add_pd(s78, s1b);
        t76 = _mm_sub_pd(s68, s0b);
        t86 = _mm_sub_pd(s78, s1b);
        t96 = _mm_add_pd(t16, t56);
        t07 = _mm_add_pd(t26, t66);
        t17 = _mm_sub_pd(t16, t56);
        t27 = _mm_sub_pd(t26, t66);
        t37 = _mm_sub_pd(t36, t86);
        t47 = _mm_add_pd(t46, t76);
        t57 = _mm_add_pd(t36, t86);
        t67 = _mm_sub_pd(t46, t76);
        t77 = _mm_add_pd(s08, s4a);
        t87 = _mm_add_pd(s18, s5a);
        t97 = _mm_sub_pd(s08, s4a);
        t08 = _mm_sub_pd(s18, s5a);
        t18 = _mm_add_pd(s29, s6b);
        t28 = _mm_add_pd(s39, s7b);
        t38 = _mm_sub_pd(s29, s6b);
        t48 = _mm_sub_pd(s39, s7b);
        t58 = _mm_add_pd(t77, t18);
        t68 = _mm_add_pd(t87, t28);
        t78 = _mm_sub_pd(t77, t18);
        t88 = _mm_sub_pd(t87, t28);
        a62 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t97, t48));
        a72 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t08, t38));
        s8b = _mm_sub_pd(a62, a72);
        s9b = _mm_add_pd(a62, a72);
        a82 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t97, t48));
        a92 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t08, t38));
        s0c = _mm_sub_pd(a82, a92);
        s1c = _mm_add_pd(a82, a92);
        t98 = _mm_add_pd(t96, t58);
        t09 = _mm_add_pd(t07, t68);
        t19 = _mm_sub_pd(t96, t58);
        t29 = _mm_sub_pd(t07, t68);
        t39 = _mm_add_pd(t37, s8b);
        t49 = _mm_add_pd(t47, s9b);
        t59 = _mm_sub_pd(t37, s8b);
        t69 = _mm_sub_pd(t47, s9b);
        t79 = _mm_sub_pd(t17, t88);
        t89 = _mm_add_pd(t27, t78);
        t99 = _mm_add_pd(t17, t88);
        t0a = _mm_sub_pd(t27, t78);
        t1a = _mm_add_pd(t57, s0c);
        t2a = _mm_sub_pd(t67, s1c);
        t3a = _mm_sub_pd(t57, s0c);
        t4a = _mm_add_pd(t67, s1c);
        a03 = (D82 + a8);
        a13 = *(a03);
        a23 = *((a03 + 1));
        a33 = *((a03 + 2));
        a43 = *((a03 + 3));
        a53 = *((a03 + 4));
        a63 = *((a03 + 5));
        a73 = *((a03 + 6));
        a83 = *((a03 + 7));
        a93 = *((a03 + 8));
        a04 = *((a03 + 9));
        a14 = *((a03 + 10));
        a24 = *((a03 + 11));
        a34 = *((a03 + 12));
        a44 = *((a03 + 13));
        a54 = *((a03 + 14));
        a64 = *((a03 + 15));
        b3 = (((__m128d  *) T) + a8);
        s2c = _mm_sub_pd(_mm_mul_pd(a13, t98), _mm_mul_pd(a23, t09));
        *((b3 + 16)) = s2c;
        s3c = _mm_add_pd(_mm_mul_pd(a23, t98), _mm_mul_pd(a13, t09));
        *((b3 + 24)) = s3c;
        s4c = _mm_sub_pd(_mm_mul_pd(a33, t39), _mm_mul_pd(a43, t49));
        *((b3 + 17)) = s4c;
        s5c = _mm_add_pd(_mm_mul_pd(a43, t39), _mm_mul_pd(a33, t49));
        *((b3 + 25)) = s5c;
        s6c = _mm_sub_pd(_mm_mul_pd(a53, t79), _mm_mul_pd(a63, t89));
        *((b3 + 18)) = s6c;
        s7c = _mm_add_pd(_mm_mul_pd(a63, t79), _mm_mul_pd(a53, t89));
        *((b3 + 26)) = s7c;
        s8c = _mm_sub_pd(_mm_mul_pd(a73, t1a), _mm_mul_pd(a83, t2a));
        *((b3 + 19)) = s8c;
        s9c = _mm_add_pd(_mm_mul_pd(a83, t1a), _mm_mul_pd(a73, t2a));
        *((b3 + 27)) = s9c;
        s0d = _mm_sub_pd(_mm_mul_pd(a93, t19), _mm_mul_pd(a04, t29));
        *((b3 + 20)) = s0d;
        s1d = _mm_add_pd(_mm_mul_pd(a04, t19), _mm_mul_pd(a93, t29));
        *((b3 + 28)) = s1d;
        s2d = _mm_sub_pd(_mm_mul_pd(a14, t59), _mm_mul_pd(a24, t69));
        *((b3 + 21)) = s2d;
        s3d = _mm_add_pd(_mm_mul_pd(a24, t59), _mm_mul_pd(a14, t69));
        *((b3 + 29)) = s3d;
        s4d = _mm_sub_pd(_mm_mul_pd(a34, t99), _mm_mul_pd(a44, t0a));
        *((b3 + 22)) = s4d;
        s5d = _mm_add_pd(_mm_mul_pd(a44, t99), _mm_mul_pd(a34, t0a));
        *((b3 + 30)) = s5d;
        s6d = _mm_sub_pd(_mm_mul_pd(a54, t3a), _mm_mul_pd(a64, t4a));
        *((b3 + 23)) = s6d;
        s7d = _mm_add_pd(_mm_mul_pd(a64, t3a), _mm_mul_pd(a54, t4a));
        *((b3 + 31)) = s7d;
    }}
    {long i2; for(i2 = 0; i2 <= 7; i2++) {
        a74 = (((__m128d  *) T) + i2);
        s8d = *(a74);
        s9d = *((a74 + 2048));
        t5a = _mm_add_pd(s8d, s9d);
        t6a = _mm_sub_pd(s8d, s9d);
        s0e = *((a74 + 8));
        s1e = *((a74 + 2056));
        t7a = _mm_sub_pd(s0e, s1e);
        t8a = _mm_add_pd(s0e, s1e);
        s2e = *((a74 + 1024));
        s3e = *((a74 + 1032));
        s4e = *((a74 + 3072));
        s5e = *((a74 + 3080));
        t9a = _mm_add_pd(s2e, s4e);
        t0b = _mm_sub_pd(s3e, s5e);
        a84 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s2e, s4e));
        a94 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s3e, s5e));
        s6e = _mm_sub_pd(a84, a94);
        s7e = _mm_add_pd(a84, a94);
        t1b = _mm_add_pd(t5a, t9a);
        t2b = _mm_sub_pd(t5a, t9a);
        t3b = _mm_sub_pd(t6a, t0b);
        t4b = _mm_add_pd(t6a, t0b);
        t5b = _mm_add_pd(t7a, s6e);
        t6b = _mm_sub_pd(t7a, s6e);
        t7b = _mm_sub_pd(t8a, s7e);
        t8b = _mm_add_pd(t8a, s7e);
        s8e = *((a74 + 512));
        s9e = *((a74 + 520));
        s0f = *((a74 + 3584));
        s1f = *((a74 + 3592));
        t9b = _mm_add_pd(s8e, s0f);
        t0c = _mm_sub_pd(s9e, s1f);
        t1c = _mm_sub_pd(s8e, s0f);
        t2c = _mm_add_pd(s9e, s1f);
        s2f = *((a74 + 2560));
        s3f = *((a74 + 2568));
        s4f = *((a74 + 1536));
        s5f = *((a74 + 1544));
        t3c = _mm_add_pd(s2f, s4f);
        t4c = _mm_sub_pd(s3f, s5f);
        t5c = _mm_sub_pd(s2f, s4f);
        t6c = _mm_add_pd(s3f, s5f);
        t7c = _mm_add_pd(t9b, t3c);
        t8c = _mm_add_pd(t0c, t4c);
        t9c = _mm_sub_pd(t1c, t6c);
        t0d = _mm_add_pd(t2c, t5c);
        t1d = _mm_add_pd(t1c, t6c);
        t2d = _mm_sub_pd(t2c, t5c);
        s6f = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9c), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0d));
        s7f = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9c), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0d));
        a05 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9b, t3c));
        a15 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0c, t4c));
        s8f = _mm_sub_pd(a05, a15);
        s9f = _mm_add_pd(a05, a15);
        s0g = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1d), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2d));
        s1g = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1d), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2d));
        a25 = ((__m128d  *) T2);
        s2g = _mm_add_pd(t1b, t7c);
        *(a25) = s2g;
        s3g = _mm_sub_pd(t1b, t7c);
        *((a25 + 8)) = s3g;
        s4g = _mm_sub_pd(t2b, t8c);
        *((a25 + 4)) = s4g;
        s5g = _mm_add_pd(t2b, t8c);
        *((a25 + 12)) = s5g;
        s6g = _mm_add_pd(t5b, s6f);
        *((a25 + 1)) = s6g;
        s7g = _mm_sub_pd(t5b, s6f);
        *((a25 + 9)) = s7g;
        s8g = _mm_sub_pd(t6b, s7f);
        *((a25 + 5)) = s8g;
        s9g = _mm_add_pd(t6b, s7f);
        *((a25 + 13)) = s9g;
        s0h = _mm_add_pd(t3b, s8f);
        *((a25 + 2)) = s0h;
        s1h = _mm_sub_pd(t3b, s8f);
        *((a25 + 10)) = s1h;
        s2h = _mm_sub_pd(t4b, s9f);
        *((a25 + 6)) = s2h;
        s3h = _mm_add_pd(t4b, s9f);
        *((a25 + 14)) = s3h;
        s4h = _mm_add_pd(t7b, s0g);
        *((a25 + 3)) = s4h;
        s5h = _mm_sub_pd(t7b, s0g);
        *((a25 + 11)) = s5h;
        s6h = _mm_sub_pd(t8b, s1g);
        *((a25 + 7)) = s6h;
        s7h = _mm_add_pd(t8b, s1g);
        *((a25 + 15)) = s7h;
        {long i3; for(i3 = 0; i3 <= 30; i3++) {
            a35 = (16 * i3);
            b4 = (((__m128d  *) T) + i2);
            b5 = (b4 + a35);
            s8h = *((b5 + 16));
            s9h = *((b5 + 24));
            b6 = (b4 - a35);
            s0i = *((b6 + 4080));
            s1i = *((b6 + 4088));
            t3d = _mm_add_pd(s8h, s0i);
            t4d = _mm_sub_pd(s9h, s1i);
            t5d = _mm_sub_pd(s8h, s0i);
            t6d = _mm_add_pd(s9h, s1i);
            s2i = *((b5 + 2064));
            s3i = *((b5 + 2072));
            s4i = *((b6 + 2032));
            s5i = *((b6 + 2040));
            t7d = _mm_add_pd(s2i, s4i);
            t8d = _mm_sub_pd(s3i, s5i);
            t9d = _mm_sub_pd(s2i, s4i);
            t0e = _mm_add_pd(s3i, s5i);
            t1e = _mm_add_pd(t3d, t7d);
            t2e = _mm_add_pd(t4d, t8d);
            t3e = _mm_sub_pd(t3d, t7d);
            t4e = _mm_sub_pd(t4d, t8d);
            t5e = _mm_sub_pd(t5d, t0e);
            t6e = _mm_add_pd(t6d, t9d);
            t7e = _mm_add_pd(t5d, t0e);
            t8e = _mm_sub_pd(t6d, t9d);
            s6i = *((b5 + 1040));
            s7i = *((b5 + 1048));
            s8i = *((b6 + 3056));
            s9i = *((b6 + 3064));
            t9e = _mm_add_pd(s6i, s8i);
            t0f = _mm_sub_pd(s7i, s9i);
            t1f = _mm_sub_pd(s6i, s8i);
            t2f = _mm_add_pd(s7i, s9i);
            s0j = *((b5 + 3088));
            s1j = *((b5 + 3096));
            s2j = *((b6 + 1008));
            s3j = *((b6 + 1016));
            t3f = _mm_add_pd(s0j, s2j);
            t4f = _mm_sub_pd(s1j, s3j);
            t5f = _mm_sub_pd(s0j, s2j);
            t6f = _mm_add_pd(s1j, s3j);
            t7f = _mm_add_pd(t9e, t3f);
            t8f = _mm_add_pd(t0f, t4f);
            t9f = _mm_sub_pd(t9e, t3f);
            t0g = _mm_sub_pd(t0f, t4f);
            a45 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1f, t6f));
            a55 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t2f, t5f));
            s4j = _mm_sub_pd(a45, a55);
            s5j = _mm_add_pd(a45, a55);
            a65 = _mm_mul_pd(_mm_set1_pd((-0.70710678118654757)), _mm_add_pd(t1f, t6f));
            a75 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2f, t5f));
            s6j = _mm_sub_pd(a65, a75);
            s7j = _mm_add_pd(a65, a75);
            t1g = _mm_add_pd(t1e, t7f);
            t2g = _mm_add_pd(t2e, t8f);
            t3g = _mm_sub_pd(t1e, t7f);
            t4g = _mm_sub_pd(t2e, t8f);
            t5g = _mm_add_pd(t5e, s4j);
            t6g = _mm_add_pd(t6e, s5j);
            t7g = _mm_sub_pd(t5e, s4j);
            t8g = _mm_sub_pd(t6e, s5j);
            t9g = _mm_sub_pd(t3e, t0g);
            t0h = _mm_add_pd(t4e, t9f);
            t1h = _mm_add_pd(t3e, t0g);
            t2h = _mm_sub_pd(t4e, t9f);
            t3h = _mm_add_pd(t7e, s6j);
            t4h = _mm_sub_pd(t8e, s7j);
            t5h = _mm_sub_pd(t7e, s6j);
            t6h = _mm_add_pd(t8e, s7j);
            a85 = (D81 + a35);
            a95 = *(a85);
            a06 = *((a85 + 1));
            a16 = *((a85 + 2));
            a26 = *((a85 + 3));
            a36 = *((a85 + 4));
            a46 = *((a85 + 5));
            a56 = *((a85 + 6));
            a66 = *((a85 + 7));
            a76 = *((a85 + 8));
            a86 = *((a85 + 9));
            a96 = *((a85 + 10));
            a07 = *((a85 + 11));
            a17 = *((a85 + 12));
            a27 = *((a85 + 13));
            a37 = *((a85 + 14));
            a47 = *((a85 + 15));
            b7 = (((__m128d  *) T2) + a35);
            s8j = _mm_sub_pd(_mm_mul_pd(a95, t1g), _mm_mul_pd(a06, t2g));
            *((b7 + 16)) = s8j;
            s9j = _mm_add_pd(_mm_mul_pd(a06, t1g), _mm_mul_pd(a95, t2g));
            *((b7 + 24)) = s9j;
            s0k = _mm_sub_pd(_mm_mul_pd(a16, t5g), _mm_mul_pd(a26, t6g));
            *((b7 + 17)) = s0k;
            s1k = _mm_add_pd(_mm_mul_pd(a26, t5g), _mm_mul_pd(a16, t6g));
            *((b7 + 25)) = s1k;
            s2k = _mm_sub_pd(_mm_mul_pd(a36, t9g), _mm_mul_pd(a46, t0h));
            *((b7 + 18)) = s2k;
            s3k = _mm_add_pd(_mm_mul_pd(a46, t9g), _mm_mul_pd(a36, t0h));
            *((b7 + 26)) = s3k;
            s4k = _mm_sub_pd(_mm_mul_pd(a56, t3h), _mm_mul_pd(a66, t4h));
            *((b7 + 19)) = s4k;
            s5k = _mm_add_pd(_mm_mul_pd(a66, t3h), _mm_mul_pd(a56, t4h));
            *((b7 + 27)) = s5k;
            s6k = _mm_sub_pd(_mm_mul_pd(a76, t3g), _mm_mul_pd(a86, t4g));
            *((b7 + 20)) = s6k;
            s7k = _mm_add_pd(_mm_mul_pd(a86, t3g), _mm_mul_pd(a76, t4g));
            *((b7 + 28)) = s7k;
            s8k = _mm_sub_pd(_mm_mul_pd(a96, t7g), _mm_mul_pd(a07, t8g));
            *((b7 + 21)) = s8k;
            s9k = _mm_add_pd(_mm_mul_pd(a07, t7g), _mm_mul_pd(a96, t8g));
            *((b7 + 29)) = s9k;
            s0l = _mm_sub_pd(_mm_mul_pd(a17, t1h), _mm_mul_pd(a27, t2h));
            *((b7 + 22)) = s0l;
            s1l = _mm_add_pd(_mm_mul_pd(a27, t1h), _mm_mul_pd(a17, t2h));
            *((b7 + 30)) = s1l;
            s2l = _mm_sub_pd(_mm_mul_pd(a37, t5h), _mm_mul_pd(a47, t6h));
            *((b7 + 23)) = s2l;
            s3l = _mm_add_pd(_mm_mul_pd(a47, t5h), _mm_mul_pd(a37, t6h));
            *((b7 + 31)) = s3l;
        }}
        {long i4; for(i4 = 0; i4 <= 7; i4++) {
            a57 = (((__m128d  *) T2) + i4);
            s4l = *(a57);
            s5l = *((a57 + 256));
            t7h = _mm_add_pd(s4l, s5l);
            t8h = _mm_sub_pd(s4l, s5l);
            s6l = *((a57 + 8));
            s7l = *((a57 + 264));
            t9h = _mm_sub_pd(s6l, s7l);
            t0i = _mm_add_pd(s6l, s7l);
            s8l = *((a57 + 128));
            s9l = *((a57 + 136));
            s0m = *((a57 + 384));
            s1m = *((a57 + 392));
            t1i = _mm_add_pd(s8l, s0m);
            t2i = _mm_sub_pd(s9l, s1m);
            a67 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8l, s0m));
            a77 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9l, s1m));
            s2m = _mm_sub_pd(a67, a77);
            s3m = _mm_add_pd(a67, a77);
            t3i = _mm_add_pd(t7h, t1i);
            t4i = _mm_sub_pd(t7h, t1i);
            t5i = _mm_sub_pd(t8h, t2i);
            t6i = _mm_add_pd(t8h, t2i);
            t7i = _mm_add_pd(t9h, s2m);
            t8i = _mm_sub_pd(t9h, s2m);
            t9i = _mm_sub_pd(t0i, s3m);
            t0j = _mm_add_pd(t0i, s3m);
            s4m = *((a57 + 16));
            s5m = *((a57 + 24));
            s6m = *((a57 + 496));
            s7m = *((a57 + 504));
            t1j = _mm_add_pd(s4m, s6m);
            t2j = _mm_sub_pd(s5m, s7m);
            t3j = _mm_sub_pd(s4m, s6m);
            t4j = _mm_add_pd(s5m, s7m);
            s8m = *((a57 + 272));
            s9m = *((a57 + 280));
            s0n = *((a57 + 240));
            s1n = *((a57 + 248));
            t5j = _mm_add_pd(s8m, s0n);
            t6j = _mm_sub_pd(s9m, s1n);
            t7j = _mm_sub_pd(s8m, s0n);
            t8j = _mm_add_pd(s9m, s1n);
            t9j = _mm_add_pd(t1j, t5j);
            t0k = _mm_add_pd(t2j, t6j);
            t1k = _mm_sub_pd(t1j, t5j);
            t2k = _mm_sub_pd(t2j, t6j);
            t3k = _mm_sub_pd(t3j, t8j);
            t4k = _mm_add_pd(t4j, t7j);
            t5k = _mm_add_pd(t3j, t8j);
            t6k = _mm_sub_pd(t4j, t7j);
            s2n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t3k), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t4k));
            s3n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t3k), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t4k));
            s4n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t1k), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t2k));
            s5n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t1k), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t2k));
            s6n = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t5k), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t6k));
            s7n = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t5k), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t6k));
            s8n = *((a57 + 32));
            s9n = *((a57 + 40));
            s0o = *((a57 + 480));
            s1o = *((a57 + 488));
            t7k = _mm_add_pd(s8n, s0o);
            t8k = _mm_sub_pd(s9n, s1o);
            t9k = _mm_sub_pd(s8n, s0o);
            t0l = _mm_add_pd(s9n, s1o);
            s2o = *((a57 + 288));
            s3o = *((a57 + 296));
            s4o = *((a57 + 224));
            s5o = *((a57 + 232));
            t1l = _mm_add_pd(s2o, s4o);
            t2l = _mm_sub_pd(s3o, s5o);
            t3l = _mm_sub_pd(s2o, s4o);
            t4l = _mm_add_pd(s3o, s5o);
            t5l = _mm_add_pd(t7k, t1l);
            t6l = _mm_add_pd(t8k, t2l);
            t7l = _mm_sub_pd(t7k, t1l);
            t8l = _mm_sub_pd(t8k, t2l);
            t9l = _mm_sub_pd(t9k, t4l);
            t0m = _mm_add_pd(t0l, t3l);
            t1m = _mm_add_pd(t9k, t4l);
            t2m = _mm_sub_pd(t0l, t3l);
            s6o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t9l), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t0m));
            s7o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t9l), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t0m));
            s8o = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7l), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8l));
            s9o = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7l), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8l));
            s0p = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1m), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2m));
            s1p = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1m), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2m));
            s2p = *((a57 + 48));
            s3p = *((a57 + 56));
            s4p = *((a57 + 464));
            s5p = *((a57 + 472));
            t3m = _mm_add_pd(s2p, s4p);
            t4m = _mm_sub_pd(s3p, s5p);
            t5m = _mm_sub_pd(s2p, s4p);
            t6m = _mm_add_pd(s3p, s5p);
            s6p = *((a57 + 304));
            s7p = *((a57 + 312));
            s8p = *((a57 + 208));
            s9p = *((a57 + 216));
            t7m = _mm_add_pd(s6p, s8p);
            t8m = _mm_sub_pd(s7p, s9p);
            t9m = _mm_sub_pd(s6p, s8p);
            t0n = _mm_add_pd(s7p, s9p);
            t1n = _mm_add_pd(t3m, t7m);
            t2n = _mm_add_pd(t4m, t8m);
            t3n = _mm_sub_pd(t3m, t7m);
            t4n = _mm_sub_pd(t4m, t8m);
            t5n = _mm_sub_pd(t5m, t0n);
            t6n = _mm_add_pd(t6m, t9m);
            t7n = _mm_add_pd(t5m, t0n);
            t8n = _mm_sub_pd(t6m, t9m);
            s0q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.95694033573220882), t5n), _mm_mul_pd(_mm_set1_pd(0.29028467725446239), t6n));
            s1q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.29028467725446239), t5n), _mm_mul_pd(_mm_set1_pd(0.95694033573220882), t6n));
            s2q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3n), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4n));
            s3q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3n), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4n));
            s4q = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t7n), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t8n));
            s5q = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t7n), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t8n));
            s6q = *((a57 + 64));
            s7q = *((a57 + 72));
            s8q = *((a57 + 448));
            s9q = *((a57 + 456));
            t9n = _mm_add_pd(s6q, s8q);
            t0o = _mm_sub_pd(s7q, s9q);
            t1o = _mm_sub_pd(s6q, s8q);
            t2o = _mm_add_pd(s7q, s9q);
            s0r = *((a57 + 320));
            s1r = *((a57 + 328));
            s2r = *((a57 + 192));
            s3r = *((a57 + 200));
            t3o = _mm_add_pd(s0r, s2r);
            t4o = _mm_sub_pd(s1r, s3r);
            t5o = _mm_sub_pd(s0r, s2r);
            t6o = _mm_add_pd(s1r, s3r);
            t7o = _mm_add_pd(t9n, t3o);
            t8o = _mm_add_pd(t0o, t4o);
            t9o = _mm_sub_pd(t1o, t6o);
            t0p = _mm_add_pd(t2o, t5o);
            t1p = _mm_add_pd(t1o, t6o);
            t2p = _mm_sub_pd(t2o, t5o);
            s4r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9o), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0p));
            s5r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9o), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0p));
            a87 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9n, t3o));
            a97 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0o, t4o));
            s6r = _mm_sub_pd(a87, a97);
            s7r = _mm_add_pd(a87, a97);
            s8r = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1p), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2p));
            s9r = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1p), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2p));
            s0s = *((a57 + 80));
            s1s = *((a57 + 88));
            s2s = *((a57 + 432));
            s3s = *((a57 + 440));
            t3p = _mm_add_pd(s0s, s2s);
            t4p = _mm_sub_pd(s1s, s3s);
            t5p = _mm_sub_pd(s0s, s2s);
            t6p = _mm_add_pd(s1s, s3s);
            s4s = *((a57 + 336));
            s5s = *((a57 + 344));
            s6s = *((a57 + 176));
            s7s = *((a57 + 184));
            t7p = _mm_add_pd(s4s, s6s);
            t8p = _mm_sub_pd(s5s, s7s);
            t9p = _mm_sub_pd(s4s, s6s);
            t0q = _mm_add_pd(s5s, s7s);
            t1q = _mm_add_pd(t3p, t7p);
            t2q = _mm_add_pd(t4p, t8p);
            t3q = _mm_sub_pd(t3p, t7p);
            t4q = _mm_sub_pd(t4p, t8p);
            t5q = _mm_sub_pd(t5p, t0q);
            t6q = _mm_add_pd(t6p, t9p);
            t7q = _mm_add_pd(t5p, t0q);
            t8q = _mm_sub_pd(t6p, t9p);
            s8s = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t5q), _mm_mul_pd(_mm_set1_pd(0.47139673682599764), t6q));
            s9s = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.47139673682599764), t5q), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t6q));
            s0t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t3q), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t4q));
            s1t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t3q), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t4q));
            s2t = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.098017140329560604), t7q), _mm_mul_pd(_mm_set1_pd(0.99518472667219693), t8q));
            s3t = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.99518472667219693), t7q), _mm_mul_pd(_mm_set1_pd(0.098017140329560604), t8q));
            s4t = *((a57 + 96));
            s5t = *((a57 + 104));
            s6t = *((a57 + 416));
            s7t = *((a57 + 424));
            t9q = _mm_add_pd(s4t, s6t);
            t0r = _mm_sub_pd(s5t, s7t);
            t1r = _mm_sub_pd(s4t, s6t);
            t2r = _mm_add_pd(s5t, s7t);
            s8t = *((a57 + 352));
            s9t = *((a57 + 360));
            s0u = *((a57 + 160));
            s1u = *((a57 + 168));
            t3r = _mm_add_pd(s8t, s0u);
            t4r = _mm_sub_pd(s9t, s1u);
            t5r = _mm_sub_pd(s8t, s0u);
            t6r = _mm_add_pd(s9t, s1u);
            t7r = _mm_add_pd(t9q, t3r);
            t8r = _mm_add_pd(t0r, t4r);
            t9r = _mm_sub_pd(t9q, t3r);
            t0s = _mm_sub_pd(t0r, t4r);
            t1s = _mm_sub_pd(t1r, t6r);
            t2s = _mm_add_pd(t2r, t5r);
            t3s = _mm_add_pd(t1r, t6r);
            t4s = _mm_sub_pd(t2r, t5r);
            s2u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.83146961230254524), t1s), _mm_mul_pd(_mm_set1_pd(0.55557023301960218), t2s));
            s3u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.55557023301960218), t1s), _mm_mul_pd(_mm_set1_pd(0.83146961230254524), t2s));
            s4u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9r), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0s));
            s5u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9r), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0s));
            s6u = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t3s), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t4s));
            s7u = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t3s), _mm_mul_pd(_mm_set1_pd((-0.19509032201612828)), t4s));
            s8u = *((a57 + 112));
            s9u = *((a57 + 120));
            s0v = *((a57 + 400));
            s1v = *((a57 + 408));
            t5s = _mm_add_pd(s8u, s0v);
            t6s = _mm_sub_pd(s9u, s1v);
            t7s = _mm_sub_pd(s8u, s0v);
            t8s = _mm_add_pd(s9u, s1v);
            s2v = *((a57 + 368));
            s3v = *((a57 + 376));
            s4v = *((a57 + 144));
            s5v = *((a57 + 152));
            t9s = _mm_add_pd(s2v, s4v);
            t0t = _mm_sub_pd(s3v, s5v);
            t1t = _mm_sub_pd(s2v, s4v);
            t2t = _mm_add_pd(s3v, s5v);
            t3t = _mm_add_pd(t5s, t9s);
            t4t = _mm_add_pd(t6s, t0t);
            t5t = _mm_sub_pd(t5s, t9s);
            t6t = _mm_sub_pd(t6s, t0t);
            t7t = _mm_sub_pd(t7s, t2t);
            t8t = _mm_add_pd(t8s, t1t);
            t9t = _mm_add_pd(t7s, t2t);
            t0u = _mm_sub_pd(t8s, t1t);
            s6v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.77301045336273699), t7t), _mm_mul_pd(_mm_set1_pd(0.63439328416364549), t8t));
            s7v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.63439328416364549), t7t), _mm_mul_pd(_mm_set1_pd(0.77301045336273699), t8t));
            s8v = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.19509032201612828), t5t), _mm_mul_pd(_mm_set1_pd(0.98078528040323043), t6t));
            s9v = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.98078528040323043), t5t), _mm_mul_pd(_mm_set1_pd(0.19509032201612828), t6t));
            s0w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t9t), _mm_mul_pd(_mm_set1_pd(0.88192126434835505), t0u));
            s1w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.88192126434835505), t9t), _mm_mul_pd(_mm_set1_pd((-0.47139673682599764)), t0u));
            t1u = _mm_add_pd(t3i, t7o);
            t2u = _mm_sub_pd(t3i, t7o);
            t3u = _mm_sub_pd(t4i, t8o);
            t4u = _mm_add_pd(t4i, t8o);
            t5u = _mm_add_pd(t5l, t7r);
            t6u = _mm_sub_pd(t6l, t8r);
            a08 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5l, t7r));
            a18 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(t6l, t8r));
            s2w = _mm_sub_pd(a08, a18);
            s3w = _mm_add_pd(a08, a18);
            t7u = _mm_add_pd(t1u, t5u);
            t8u = _mm_sub_pd(t1u, t5u);
            t9u = _mm_sub_pd(t2u, t6u);
            t0v = _mm_add_pd(t2u, t6u);
            t1v = _mm_add_pd(t3u, s2w);
            t2v = _mm_sub_pd(t3u, s2w);
            t3v = _mm_sub_pd(t4u, s3w);
            t4v = _mm_add_pd(t4u, s3w);
            t5v = _mm_add_pd(t9j, t3t);
            t6v = _mm_sub_pd(t0k, t4t);
            t7v = _mm_sub_pd(t9j, t3t);
            t8v = _mm_add_pd(t0k, t4t);
            t9v = _mm_add_pd(t1q, t1n);
            t0w = _mm_sub_pd(t2q, t2n);
            t1w = _mm_sub_pd(t1q, t1n);
            t2w = _mm_add_pd(t2q, t2n);
            t3w = _mm_add_pd(t5v, t9v);
            t4w = _mm_add_pd(t6v, t0w);
            t5w = _mm_sub_pd(t7v, t2w);
            t6w = _mm_add_pd(t8v, t1w);
            t7w = _mm_add_pd(t7v, t2w);
            t8w = _mm_sub_pd(t8v, t1w);
            s4w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5w), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6w));
            s5w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5w), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6w));
            a28 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t5v, t9v));
            a38 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t6v, t0w));
            s6w = _mm_sub_pd(a28, a38);
            s7w = _mm_add_pd(a28, a38);
            s8w = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t7w), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t8w));
            s9w = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t7w), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t8w));
            a48 = (((__m128d  *) dst) + (i2 + (8 * i4)));
            s0x = _mm_add_pd(t7u, t3w);
            *(a48) = s0x;
            s1x = _mm_sub_pd(t7u, t3w);
            *((a48 + 2048)) = s1x;
            s2x = _mm_sub_pd(t8u, t4w);
            *((a48 + 1024)) = s2x;
            s3x = _mm_add_pd(t8u, t4w);
            *((a48 + 3072)) = s3x;
            s4x = _mm_add_pd(t1v, s4w);
            *((a48 + 256)) = s4x;
            s5x = _mm_sub_pd(t1v, s4w);
            *((a48 + 2304)) = s5x;
            s6x = _mm_sub_pd(t2v, s5w);
            *((a48 + 1280)) = s6x;
            s7x = _mm_add_pd(t2v, s5w);
            *((a48 + 3328)) = s7x;
            s8x = _mm_add_pd(t9u, s6w);
            *((a48 + 512)) = s8x;
            s9x = _mm_sub_pd(t9u, s6w);
            *((a48 + 2560)) = s9x;
            s0y = _mm_sub_pd(t0v, s7w);
            *((a48 + 1536)) = s0y;
            s1y = _mm_add_pd(t0v, s7w);
            *((a48 + 3584)) = s1y;
            s2y = _mm_add_pd(t3v, s8w);
            *((a48 + 768)) = s2y;
            s3y = _mm_sub_pd(t3v, s8w);
            *((a48 + 2816)) = s3y;
            s4y = _mm_sub_pd(t4v, s9w);
            *((a48 + 1792)) = s4y;
            s5y = _mm_add_pd(t4v, s9w);
            *((a48 + 3840)) = s5y;
            t9w = _mm_add_pd(t7i, s4r);
            t0x = _mm_sub_pd(t7i, s4r);
            t1x = _mm_sub_pd(t8i, s5r);
            t2x = _mm_add_pd(t8i, s5r);
            t3x = _mm_add_pd(s6o, s2u);
            t4x = _mm_sub_pd(s7o, s3u);
            a58 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s6o, s2u));
            a68 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s7o, s3u));
            s6y = _mm_sub_pd(a58, a68);
            s7y = _mm_add_pd(a58, a68);
            t5x = _mm_add_pd(t9w, t3x);
            t6x = _mm_sub_pd(t9w, t3x);
            t7x = _mm_sub_pd(t0x, t4x);
            t8x = _mm_add_pd(t0x, t4x);
            t9x = _mm_add_pd(t1x, s6y);
            t0y = _mm_sub_pd(t1x, s6y);
            t1y = _mm_sub_pd(t2x, s7y);
            t2y = _mm_add_pd(t2x, s7y);
            t3y = _mm_add_pd(s2n, s6v);
            t4y = _mm_sub_pd(s3n, s7v);
            t5y = _mm_sub_pd(s2n, s6v);
            t6y = _mm_add_pd(s3n, s7v);
            t7y = _mm_add_pd(s8s, s0q);
            t8y = _mm_sub_pd(s9s, s1q);
            t9y = _mm_sub_pd(s8s, s0q);
            t0z = _mm_add_pd(s9s, s1q);
            t1z = _mm_add_pd(t3y, t7y);
            t2z = _mm_add_pd(t4y, t8y);
            t3z = _mm_sub_pd(t5y, t0z);
            t4z = _mm_add_pd(t6y, t9y);
            t5z = _mm_add_pd(t5y, t0z);
            t6z = _mm_sub_pd(t6y, t9y);
            s8y = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4z));
            s9y = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4z));
            a78 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t3y, t7y));
            a88 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t4y, t8y));
            s0z = _mm_sub_pd(a78, a88);
            s1z = _mm_add_pd(a78, a88);
            s2z = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t5z), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t6z));
            s3z = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t5z), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t6z));
            s4z = _mm_add_pd(t5x, t1z);
            *((a48 + 64)) = s4z;
            s5z = _mm_sub_pd(t5x, t1z);
            *((a48 + 2112)) = s5z;
            s6z = _mm_sub_pd(t6x, t2z);
            *((a48 + 1088)) = s6z;
            s7z = _mm_add_pd(t6x, t2z);
            *((a48 + 3136)) = s7z;
            s8z = _mm_add_pd(t9x, s8y);
            *((a48 + 320)) = s8z;
            s9z = _mm_sub_pd(t9x, s8y);
            *((a48 + 2368)) = s9z;
            s0A = _mm_sub_pd(t0y, s9y);
            *((a48 + 1344)) = s0A;
            s1A = _mm_add_pd(t0y, s9y);
            *((a48 + 3392)) = s1A;
            s2A = _mm_add_pd(t7x, s0z);
            *((a48 + 576)) = s2A;
            s3A = _mm_sub_pd(t7x, s0z);
            *((a48 + 2624)) = s3A;
            s4A = _mm_sub_pd(t8x, s1z);
            *((a48 + 1600)) = s4A;
            s5A = _mm_add_pd(t8x, s1z);
            *((a48 + 3648)) = s5A;
            s6A = _mm_add_pd(t1y, s2z);
            *((a48 + 832)) = s6A;
            s7A = _mm_sub_pd(t1y, s2z);
            *((a48 + 2880)) = s7A;
            s8A = _mm_sub_pd(t2y, s3z);
            *((a48 + 1856)) = s8A;
            s9A = _mm_add_pd(t2y, s3z);
            *((a48 + 3904)) = s9A;
            t7z = _mm_add_pd(t5i, s6r);
            t8z = _mm_sub_pd(t5i, s6r);
            t9z = _mm_sub_pd(t6i, s7r);
            t0A = _mm_add_pd(t6i, s7r);
            t1A = _mm_add_pd(s8o, s4u);
            t2A = _mm_sub_pd(s9o, s5u);
            a98 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s8o, s4u));
            a09 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s9o, s5u));
            s0B = _mm_sub_pd(a98, a09);
            s1B = _mm_add_pd(a98, a09);
            t3A = _mm_add_pd(t7z, t1A);
            t4A = _mm_sub_pd(t7z, t1A);
            t5A = _mm_sub_pd(t8z, t2A);
            t6A = _mm_add_pd(t8z, t2A);
            t7A = _mm_add_pd(t9z, s0B);
            t8A = _mm_sub_pd(t9z, s0B);
            t9A = _mm_sub_pd(t0A, s1B);
            t0B = _mm_add_pd(t0A, s1B);
            t1B = _mm_add_pd(s4n, s8v);
            t2B = _mm_sub_pd(s5n, s9v);
            t3B = _mm_sub_pd(s4n, s8v);
            t4B = _mm_add_pd(s5n, s9v);
            t5B = _mm_add_pd(s0t, s2q);
            t6B = _mm_sub_pd(s1t, s3q);
            t7B = _mm_sub_pd(s0t, s2q);
            t8B = _mm_add_pd(s1t, s3q);
            t9B = _mm_add_pd(t1B, t5B);
            t0C = _mm_add_pd(t2B, t6B);
            t1C = _mm_sub_pd(t3B, t8B);
            t2C = _mm_add_pd(t4B, t7B);
            t3C = _mm_add_pd(t3B, t8B);
            t4C = _mm_sub_pd(t4B, t7B);
            s2B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1C), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2C));
            s3B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1C), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2C));
            a19 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t1B, t5B));
            a29 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t2B, t6B));
            s4B = _mm_sub_pd(a19, a29);
            s5B = _mm_add_pd(a19, a29);
            s6B = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t3C), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t4C));
            s7B = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t3C), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t4C));
            s8B = _mm_add_pd(t3A, t9B);
            *((a48 + 128)) = s8B;
            s9B = _mm_sub_pd(t3A, t9B);
            *((a48 + 2176)) = s9B;
            s0C = _mm_sub_pd(t4A, t0C);
            *((a48 + 1152)) = s0C;
            s1C = _mm_add_pd(t4A, t0C);
            *((a48 + 3200)) = s1C;
            s2C = _mm_add_pd(t7A, s2B);
            *((a48 + 384)) = s2C;
            s3C = _mm_sub_pd(t7A, s2B);
            *((a48 + 2432)) = s3C;
            s4C = _mm_sub_pd(t8A, s3B);
            *((a48 + 1408)) = s4C;
            s5C = _mm_add_pd(t8A, s3B);
            *((a48 + 3456)) = s5C;
            s6C = _mm_add_pd(t5A, s4B);
            *((a48 + 640)) = s6C;
            s7C = _mm_sub_pd(t5A, s4B);
            *((a48 + 2688)) = s7C;
            s8C = _mm_sub_pd(t6A, s5B);
            *((a48 + 1664)) = s8C;
            s9C = _mm_add_pd(t6A, s5B);
            *((a48 + 3712)) = s9C;
            s0D = _mm_add_pd(t9A, s6B);
            *((a48 + 896)) = s0D;
            s1D = _mm_sub_pd(t9A, s6B);
            *((a48 + 2944)) = s1D;
            s2D = _mm_sub_pd(t0B, s7B);
            *((a48 + 1920)) = s2D;
            s3D = _mm_add_pd(t0B, s7B);
            *((a48 + 3968)) = s3D;
            t5C = _mm_add_pd(t9i, s8r);
            t6C = _mm_sub_pd(t9i, s8r);
            t7C = _mm_sub_pd(t0j, s9r);
            t8C = _mm_add_pd(t0j, s9r);
            t9C = _mm_add_pd(s0p, s6u);
            t0D = _mm_sub_pd(s1p, s7u);
            a39 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(s0p, s6u));
            a49 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_add_pd(s1p, s7u));
            s4D = _mm_sub_pd(a39, a49);
            s5D = _mm_add_pd(a39, a49);
            t1D = _mm_add_pd(t5C, t9C);
            t2D = _mm_sub_pd(t5C, t9C);
            t3D = _mm_sub_pd(t6C, t0D);
            t4D = _mm_add_pd(t6C, t0D);
            t5D = _mm_add_pd(t7C, s4D);
            t6D = _mm_sub_pd(t7C, s4D);
            t7D = _mm_sub_pd(t8C, s5D);
            t8D = _mm_add_pd(t8C, s5D);
            t9D = _mm_add_pd(s6n, s0w);
            t0E = _mm_sub_pd(s7n, s1w);
            t1E = _mm_sub_pd(s6n, s0w);
            t2E = _mm_add_pd(s7n, s1w);
            t3E = _mm_add_pd(s2t, s4q);
            t4E = _mm_sub_pd(s3t, s5q);
            t5E = _mm_sub_pd(s2t, s4q);
            t6E = _mm_add_pd(s3t, s5q);
            t7E = _mm_add_pd(t9D, t3E);
            t8E = _mm_add_pd(t0E, t4E);
            t9E = _mm_sub_pd(t1E, t6E);
            t0F = _mm_add_pd(t2E, t5E);
            t1F = _mm_add_pd(t1E, t6E);
            t2F = _mm_sub_pd(t2E, t5E);
            s6D = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t9E), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t0F));
            s7D = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t9E), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t0F));
            a59 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t9D, t3E));
            a69 = _mm_mul_pd(_mm_set1_pd(0.70710678118654757), _mm_sub_pd(t0E, t4E));
            s8D = _mm_sub_pd(a59, a69);
            s9D = _mm_add_pd(a59, a69);
            s0E = _mm_sub_pd(_mm_mul_pd(_mm_set1_pd(0.38268343236508978), t1F), _mm_mul_pd(_mm_set1_pd(0.92387953251128674), t2F));
            s1E = _mm_add_pd(_mm_mul_pd(_mm_set1_pd(0.92387953251128674), t1F), _mm_mul_pd(_mm_set1_pd(0.38268343236508978), t2F));
            s2E = _mm_add_pd(t1D, t7E);
            *((a48 + 192)) = s2E;
            s3E = _mm_sub_pd(t1D, t7E);
            *((a48 + 2240)) = s3E;
            s4E = _mm_sub_pd(t2D, t8E);
            *((a48 + 1216)) = s4E;
            s5E = _mm_add_pd(t2D, t8E);
            *((a48 + 3264)) = s5E;
            s6E = _mm_add_pd(t5D, s6D);
            *((a48 + 448)) = s6E;
            s7E = _mm_sub_pd(t5D, s6D);
            *((a48 + 2496)) = s7E;
            s8E = _mm_sub_pd(t6D, s7D);
            *((a48 + 1472)) = s8E;
            s9E = _mm_add_pd(t6D, s7D);
            *((a48 + 3520)) = s9E;
            s0F = _mm_add_pd(t3D, s8D);
            *((a48 + 704)) = s0F;
            s1F = _mm_sub_pd(t3D, s8D);
            *((a48 + 2752)) = s1F;
            s2F = _mm_sub_pd(t4D, s9D);
            *((a48 + 1728)) = s2F;
            s3F = _mm_add_pd(t4D, s9D);
            *((a48 + 3776)) = s3F;
            s4F = _mm_add_pd(t7D, s0E);
            *((a48 + 960)) = s4F;
            s5F = _mm_sub_pd(t7D, s0E);
            *((a48 + 3008)) = s5F;
            s6F = _mm_sub_pd(t8D, s1E);
            *((a48 + 1984)) = s6F;
            s7F = _mm_add_pd(t8D, s1E);
            *((a48 + 4032)) = s7F;
        }}
    }}
    }
    
    return SPIRAL_OK;
    }
}

